import random
import time
import datetime
import string
import threading
import subprocess
import platform
import os
import shutil

def main():
    RED = '\033[91m'
    GREEN = '\033[92m'
    PURPLE = '\033[35m'
    ORANGE = '\033[93m'
    BLUE = '\033[94m'
    RESET = '\033[0m'
    print()
    def set_usr(newUsr):
        global usr
        usr = newUsr
    new = input("Set session username: ")
    user = f"{GREEN}{new}{RESET}"
    maroon = "^m^"
    medicci = f"{RED}{maroon}{RESET}"
    dollar = "$"
    sign = f"{PURPLE}{dollar}{RESET}"
    set_usr(medicci + "" + " " + "" + "[" + "" + user + "" + "]" + "" + " " + "" + sign + "" + " ")
    print()

    def version():
        title =  usr + "" + " " + "" + f"{RED}>>>{RESET} {ORANGE}I.S. (Incubator Studios) Outbeat Produce: MProcs-5.14.8.4.2-s by tderk - Established Lpro.py (Life-pro) and Destiny [2024]{RESET}"
        title2 = f"| {BLUE}Indicative: #USVU && © Medicine, Computable (N_2025) && FNTCCI{RESET} |"
        title3 = f"{ORANGE}All Rights Reserved - Medicci.ca{RESET}"
        title4 = f"- {RED}P0cket Un1-Ver$e{RESET}"
        cdt = datetime.datetime.now()
        time = f"{GREEN}{cdt}{RESET}"
        print(title, time, title3, title4)
        print()
        print(title2)
        print()
    version()

    def alerts():
        def generate_random_letters():
            random1 = random.choice(string.ascii_letters)
            random2 = random.choice(string.ascii_letters)
            random3 = random.choice(string.ascii_letters)
            random4 = random.choice(string.ascii_letters)
            random5 = random.choice(string.ascii_letters)
            letters = [random1, random2, random3, random4, random5]
            random.shuffle(letters)
            return letters
        random_letters = generate_random_letters()
        value = (round(random.random()*9999999999,10))
        ct = datetime.datetime.now()
        alerts = "Alerts:"
        print(alerts, value, random_letters, ct)

    alerts()
    time.sleep(0)
    print()
    print("(Ctrl+C to stop a process)")
    print()
    print()
    print ("type 'commands'")
    print()

    diction = ["a", "aa", "aaa", "aaron", "ab", "abandoned", "abc", "aberdeen", "abilities", "ability", "able", "aboriginal", "abortion", "about", "above", "abraham", "abroad", "abs", "absence", "absent", "absolute", "absolutely", "absorption", "abstract", "abstracts", "abu", "abuse", "ac", "academic", "academics", "academy", "acc", "accent", "accept", "acceptable", "acceptance", "accepted", "accepting", "accepts", "access", "accessed", "accessibility", "accessible", "accessing", "accessories", "accessory", "accident", "accidents", "accommodate", "accommodation", "accommodations", "accompanied", "accompanying", "accomplish", "accomplished", "accordance", "according", "accordingly", "account", "accountability", "accounting", "accounts", "accreditation", "accredited", "accuracy", "accurate", "accurately", "accused", "acdbentity", "ace", "acer", "achieve", "achieved", "achievement", "achievements", "achieving", "acid", "acids", "acknowledge", "acknowledged", "acm", "acne", "acoustic", "acquire", "acquired", "acquisition", "acquisitions", "acre", "acres", "acrobat", "across", "acrylic", "act", "acting", "action", "actions", "activated", "activation", "active", "actively", "activists", "activities", "activity", "actor", "actors", "actress", "acts", "actual", "actually", "acute", "ad", "ada", "adam", "adams", "adaptation", "adapted", "adapter", "adapters", "adaptive", "adaptor", "add", "added", "addiction", "adding", "addition", "additional", "additionally", "additions", "address", "addressed", "addresses", "addressing", "adds", "adelaide", "adequate", "adidas", "adipex", "adjacent", "adjust", "adjustable", "adjusted", "adjustment", "adjustments", "admin", "administered", "administration", "administrative", "administrator", "administrators", "admission", "admissions", "admit", "admitted", "adobe", "adolescent", "adopt", "adopted", "adoption", "adrian", "ads", "adsl", "adult", "adults", "advance", "advanced", "advancement", "advances", "advantage", "advantages", "adventure", "adventures", "adverse", "advert", "advertise", "advertisement", "advertisements", "advertiser", "advertisers", "advertising", "advice", "advise", "advised", "advisor", "advisors", "advisory", "advocacy", "advocate", "adware", "ae", "aerial", "aerospace", "af", "affair", "affairs", "affect", "affected", "affecting", "affects", "affiliate", "affiliated", "affiliates", "affiliation", "afford", "affordable", "afghanistan", "afraid", "africa", "african", "after", "afternoon", "afterwards", "ag", "again", "against", "age", "aged", "agencies", "agency", "agenda", "agent", "agents", "ages", "aggregate", "aggressive", "aging", "ago", "agree", "agreed", "agreement", "agreements", "agrees", "agricultural", "agriculture", "ah", "ahead", "ai", "aid", "aids", "aim", "aimed", "aims", "air", "aircraft", "airfare", "airline", "airlines", "airplane", "airport", "airports", "aj", "ak", "aka", "al", "ala", "alabama", "alan", "alarm", "alaska", "albania", "albany", "albert", "alberta", "album", "albums", "albuquerque", "alcohol", "alert", "alerts", "alex", "alexander", "alexandria", "alfred", "algebra", "algeria", "algorithm", "algorithms", "ali", "alias", "alice", "alien", "align", "alignment", "alike", "alive", "all", "allah", "allan", "alleged", "allen", "allergy", "alliance", "allied", "allocated", "allocation", "allow", "allowance", "allowed", "allowing", "allows", "alloy", "almost", "alone", "along", "alot", "alpha", "alphabetical", "alpine", "already", "also", "alt", "alter", "altered", "alternate", "alternative", "alternatively", "alternatives", "although", "alto", "aluminium", "aluminum", "alumni", "always", "am", "amanda", "amateur", "amazing", "amazon", "amazoncom", "amazoncouk", "ambassador", "amber", "ambien", "ambient", "amd", "amend", "amended", "amendment", "amendments", "amenities", "america", "american", "americans", "americas", "amino", "among", "amongst", "amount", "amounts", "amp", "ampland", "amplifier", "amsterdam", "amy", "an", "ana", "anaheim", "analog", "analyses", "analysis", "analyst", "analysts", "analytical", "analyze", "analyzed", "anatomy", "anchor", "ancient", "and", "andale", "anderson", "andorra", "andrea", "andreas", "andrew", "andrews", "andy", "angel", "angela", "angeles", "angels", "anger", "angle", "angola", "angry", "animal", "animals", "animated", "animation", "anime", "ann", "anna", "anne", "annex", "annie", "anniversary", "annotated", "annotation", "announce", "announced", "announcement", "announcements", "announces", "annoying", "annual", "annually", "anonymous", "another", "answer", "answered", "answering", "answers", "ant", "antarctica", "antenna", "anthony", "anthropology", "anti", "antibodies", "antibody", "anticipated", "antigua", "antique", "antiques", "antivirus", "antonio", "anxiety", "any", "anybody", "anymore", "anyone", "anything", "anytime", "anyway", "anywhere", "aol", "ap", "apache", "apart", "apartment", "apartments", "api", "apnic", "apollo", "app", "apparatus", "apparel", "apparent", "apparently", "appeal", "appeals", "appear", "appearance", "appeared", "appearing", "appears", "appendix", "apple", "appliance", "appliances", "applicable", "applicant", "applicants", "application", "applications", "applied", "applies", "apply", "applying", "appointed", "appointment", "appointments", "appraisal", "appreciate", "appreciated", "appreciation", "approach", "approaches", "appropriate", "appropriations", "approval", "approve", "approved", "approx", "approximate", "approximately", "apps", "apr", "april", "apt", "aqua", "aquarium", "aquatic", "ar", "arab", "arabia", "arabic", "arbitrary",\
    "arbitration", "arc", "arcade", "arch", "architect", "architects", "architectural", "architecture", "archive", "archived", "archives", "arctic", "are", "area", "areas", "arena", "arg", "argentina", "argue", "argued", "argument", "arguments", "arise", "arising", "arizona", "arkansas", "arlington", "arm", "armed", "armenia", "armor", "arms", "armstrong", "army", "arnold", "around", "arrange", "arranged", "arrangement", "arrangements", "array", "arrest", "arrested", "arrival", "arrivals", "arrive", "arrived", "arrives", "arrow", "art", "arthritis", "arthur", "article", "articles", "artificial", "artist", "artistic", "artists", "arts", "artwork", "aruba", "as", "asbestos", "ascii", "ash", "ashley", "asia", "asian", "aside", "asin", "ask", "asked", "asking", "asks", "asn", "asp", "aspect", "aspects", "aspnet", "ass", "assault", "assembled", "assembly", "assess", "assessed", "assessing", "assessment", "assessments", "asset", "assets", "assign", "assigned", "assignment", "assignments", "assist", "assistance", "assistant", "assisted", "assists", "associate", "associated", "associates", "association", "associations", "assume", "assumed", "assumes", "assuming", "assumption", "assumptions", "assurance", "assure", "assured", "asthma", "astrology", "astronomy", "asus", "at", "ata", "ate", "athens", "athletes", "athletic", "athletics", "ati", "atlanta", "atlantic", "atlas", "atm", "atmosphere", "atmospheric", "atom", "atomic", "attach", "attached", "attachment", "attachments", "attack", "attacked", "attacks", "attempt", "attempted", "attempting", "attempts", "attend", "attendance", "attended", "attending", "attention", "attitude", "attitudes", "attorney", "attorneys", "attract", "attraction", "attractions", "attractive", "attribute", "attributes", "au", "auburn", "auckland", "auction", "auctions", "aud", "audi", "audience", "audio", "audit", "auditor", "aug", "august", "aurora", "aus", "austin", "australia", "australian", "austria", "authentic", "authentication", "author", "authorities", "authority", "authorization", "authorized", "authors", "auto", "automated", "automatic", "automatically", "automation", "automobile", "automobiles", "automotive", "autos", "autumn", "av", "availability", "available", "avatar", "ave", "avenue", "average", "avg", "avi", "aviation", "avoid", "avoiding", "avon", "aw", "award", "awarded", "awards", "aware", "awareness", "away", "awesome", "awful", "axis", "aye", "az", "azerbaijan", "b", "ba", "babe", "babes", "babies", "baby", "bachelor", "back", "backed", "background", "backgrounds", "backing", "backup", "bacon", "bacteria", "bacterial", "bad", "badge", "badly", "bag", "baghdad", "bags", "bahamas", "bahrain", "bailey", "baker", "baking", "balance", "balanced", "bald", "bali", "ball", "ballet", "balloon", "ballot", "balls", "baltimore", "ban", "banana", "band", "bands", "bandwidth", "bang", "bangkok", "bangladesh", "bank", "banking", "bankruptcy", "banks", "banned", "banner", "banners", "baptist", "bar", "barbados", "barbara", "barbie", "barcelona", "bare", "barely", "bargain", "bargains", "barn", "barnes", "barrel", "barrier", "barriers", "barry", "bars", "base", "baseball", "based", "baseline", "basement", "basename", "bases", "basic", "basically", "basics", "basin", "basis", "basket", "basketball", "baskets", "bass", "bat", "batch", "bath", "bathroom", "bathrooms", "baths", "batman", "batteries", "battery", "battle", "battlefield", "bay", "bb", "bbc", "bbs", "bbw", "bc", "bd", "bdsm", "be", "beach", "beaches", "beads", "beam", "bean", "beans", "bear", "bearing", "bears", "beast", "beastality", "beastiality", "beat", "beatles", "beats", "beautiful", "beautifully", "beauty", "beaver", "became", "because", "become", "becomes", "becoming", "bed", "bedding", "bedford", "bedroom", "bedrooms", "beds", "bee", "beef", "been", "beer", "before", "began", "begin", "beginner", "beginners", "beginning", "begins", "begun", "behalf", "behavior", "behavioral", "behaviour", "behind", "beijing", "being", "beings", "belarus", "belfast", "belgium", "belief", "beliefs", "believe", "believed", "believes", "belize", "belkin", "bell", "belle", "belly", "belong", "belongs", "below", "belt", "belts", "ben", "bench", "benchmark", "bend", "beneath", "beneficial", "benefit", "benefits", "benjamin", "bennett", "benz", "berkeley", "berlin", "bermuda", "bernard", "berry", "beside", "besides", "best", "bestiality", "bestsellers", "bet", "beta", "beth", "better", "betting", "betty", "between", "beverage", "beverages", "beverly", "beyond", "bg", "bhutan", "bi", "bias", "bible", "biblical", "bibliographic", "bibliography", "bicycle", "bid", "bidder", "bidding", "bids", "big", "bigger", "biggest", "bike", "bikes", "bikini", "bill", "billing", "billion", "bills", "billy", "bin", "binary", "bind", "binding", "bingo", "bio", "biodiversity", "biographies", "biography", "biol", "biological", "biology", "bios", "biotechnology", "bird", "birds", "birmingham", "birth", "birthday", "bishop", "bit", "bitch", "bite", "bits", "biz", "bizarre", "bizrate", "bk", "bl", "black", "blackberry", "blackjack", "blacks", "blade", "blades", "blah", "blair", "blake", "blame", "blank", "blanket", "blast", "bleeding", "blend", "bless", "blessed", "blind", "blink", "block",\
    "blocked", "blocking", "blocks", "blog", "blogger", "bloggers", "blogging", "blogs", "blond", "blonde", "blood", "bloody", "bloom", "bloomberg", "blue", "blues", "bluetooth", "blvd", "bm", "bmw", "bo", "board", "boards", "boat", "boating", "boats", "bob", "bobby", "boc", "bodies", "body", "bold", "bolivia", "bolt", "bomb", "bon", "bond", "bondage", "bonds", "bone", "bones", "bonus", "boob", "boobs", "book", "booking", "bookings", "bookmark", "bookmarks", "books", "bookstore", "bool", "boolean", "boom", "boost", "boot", "booth", "boots", "booty", "border", "borders", "bored", "boring", "born", "borough", "bosnia", "boss", "boston", "both", "bother", "botswana", "bottle", "bottles", "bottom", "bought", "boulder", "boulevard", "bound", "boundaries", "boundary", "bouquet", "boutique", "bow", "bowl", "bowling", "box", "boxed", "boxes", "boxing", "boy", "boys", "bp", "br", "bra", "bracelet", "bracelets", "bracket", "brad", "bradford", "bradley", "brain", "brake", "brakes", "branch", "branches", "brand", "brandon", "brands", "bras", "brass", "brave", "brazil", "brazilian", "breach", "bread", "break", "breakdown", "breakfast", "breaking", "breaks", "breast", "breasts", "breath", "breathing", "breed", "breeding", "breeds", "brian", "brick", "bridal", "bride", "bridge", "bridges", "brief", "briefing", "briefly", "briefs", "bright", "brighton", "brilliant", "bring", "bringing", "brings", "brisbane", "bristol", "britain", "britannica", "british", "britney", "broad", "broadband", "broadcast", "broadcasting", "broader", "broadway", "brochure", "brochures", "broke", "broken", "broker", "brokers", "bronze", "brook", "brooklyn", "brooks", "bros", "brother", "brothers", "brought", "brown", "browse", "browser", "browsers", "browsing", "bruce", "brunei", "brunette", "brunswick", "brush", "brussels", "brutal", "bryan", "bryant", "bs", "bt", "bubble", "buck", "bucks", "budapest", "buddy", "budget", "budgets", "buf", "buffalo", "buffer", "bufing", "bug", "bugs", "build", "builder", "builders", "building", "buildings", "builds", "built", "bulgaria", "bulgarian", "bulk", "bull", "bullet", "bulletin", "bumper", "bunch", "bundle", "bunny", "burden", "bureau", "buried", "burke", "burlington", "burn", "burner", "burning", "burns", "burst", "burton", "bus", "buses", "bush", "business", "businesses", "busty", "busy", "but", "butler", "butt", "butter", "butterfly", "button", "buttons", "butts", "buy", "buyer", "buyers", "buying", "buys", "buzz", "bw", "by", "bye", "byte", "bytes", "c", "ca", "cab", "cabin", "cabinet", "cabinets", "cable", "cables", "cache", "cached", "cad", "cadillac", "cafe", "cage", "cake", "cakes", "cal", "calcium", "calculate", "calculated", "calculation", "calculations", "calculator", "calculators", "calendar", "calendars", "calgary", "calibration", "calif", "california", "call", "called", "calling", "calls", "calm", "calvin", "cam", "cambodia", "cambridge", "camcorder", "camcorders", "came", "camel", "camera", "cameras", "cameron", "cameroon", "camp", "campaign", "campaigns", "campbell", "camping", "camps", "campus", "cams", "can", "canada", "canadian", "canal", "canberra", "cancel", "cancellation", "cancelled", "cancer", "candidate", "candidates", "candle", "candles", "candy", "cannon", "canon", "cant", "canvas", "canyon", "cap", "capabilities", "capability", "capable", "capacity", "cape", "capital", "capitol", "caps", "captain", "capture", "captured", "car", "carb", "carbon", "card", "cardiac", "cardiff", "cardiovascular", "cards", "care", "career", "careers", "careful", "carefully", "carey", "cargo", "caribbean", "caring", "carl", "carlo", "carlos", "carmen", "carnival", "carol", "carolina", "caroline", "carpet", "carried", "carrier", "carriers", "carries", "carroll", "carry", "carrying", "cars", "cart", "carter", "cartoon", "cartoons", "cartridge", "cartridges", "cas", "casa", "case", "cases", "casey", "cash", "cashiers", "casino", "casinos", "casio", "cassette", "cast", "casting", "castle", "casual", "cat", "catalog", "catalogs", "catalogue", "catalyst", "catch", "categories", "category", "catering", "cathedral", "catherine", "catholic", "cats", "cattle", "caught", "cause", "caused", "causes", "causing", "caution", "cave", "cayman", "cb", "cbs", "cc", "ccd", "cd", "cdna", "cds", "cdt", "ce", "cedar", "ceiling", "celebrate", "celebration", "celebrities", "celebrity", "celebs", "cell", "cells", "cellular", "celtic", "cement", "cemetery", "census", "cent", "center", "centered", "centers", "central", "centre", "centres", "cents", "centuries", "century", "ceo", "ceramic", "ceremony", "certain", "certainly", "certificate", "certificates", "certification", "certified", "cest", "cet", "cf", "cfr", "cg", "cgi", "ch", "chad", "chain", "chains", "chair", "chairman", "chairs", "challenge", "challenged", "challenges", "challenging", "chamber", "chambers", "champagne", "champion", "champions", "championship", "championships", "chan", "chance", "chancellor", "chances", "change", "changed", "changelog", "changes", "changing", "channel", "channels", "chaos", "chapel", "chapter", "chapters", "char", "character", "characteristic", "characteristics",\
    "characterization", "characterized", "characters", "charge", "charged", "charger", "chargers", "charges", "charging", "charitable", "charity", "charles", "charleston", "charlie", "charlotte", "charm", "charming", "charms", "chart", "charter", "charts", "chase", "chassis", "chat", "cheap", "cheaper", "cheapest", "cheat", "cheats", "check", "checked", "checking", "checklist", "checkout", "checks", "cheers", "cheese", "chef", "chelsea", "chem", "chemical", "chemicals", "chemistry", "chen", "cheque", "cherry", "chess", "chest", "chester", "chevrolet", "chevy", "chi", "chicago", "chick", "chicken", "chicks", "chief", "child", "childhood", "children", "childrens", "chile", "china", "chinese", "chip", "chips", "cho", "chocolate", "choice", "choices", "choir", "cholesterol", "choose", "choosing", "chorus", "chose", "chosen", "chris", "christ", "christian", "christianity", "christians", "christina", "christine", "christmas", "christopher", "chrome", "chronic", "chronicle", "chronicles", "chrysler", "chubby", "chuck", "church", "churches", "ci", "cia", "cialis", "ciao", "cigarette", "cigarettes", "cincinnati", "cindy", "cinema", "cingular", "cio", "cir", "circle", "circles", "circuit", "circuits", "circular", "circulation", "circumstances", "circus", "cisco", "citation", "citations", "cite", "cited", "cities", "citizen", "citizens", "citizenship", "city", "citysearch", "civic", "civil", "civilian", "civilization", "cj", "cl", "claim", "claimed", "claims", "claire", "clan", "clara", "clarity", "clark", "clarke", "class", "classes", "classic", "classical", "classics", "classification", "classified", "classifieds", "classroom", "clause", "clay", "clean", "cleaner", "cleaners", "cleaning", "cleanup", "clear", "clearance", "cleared", "clearing", "clearly", "clerk", "cleveland", "click", "clicking", "clicks", "client", "clients", "cliff", "climate", "climb", "climbing", "clinic", "clinical", "clinics", "clinton", "clip", "clips", "clock", "clocks", "clone", "close", "closed", "closely", "closer", "closes", "closest", "closing", "closure", "cloth", "clothes", "clothing", "cloud", "clouds", "cloudy", "club", "clubs", "cluster", "clusters", "cm", "cms", "cn", "cnet", "cnetcom", "cnn", "co", "coach", "coaches", "coaching", "coal", "coalition", "coast", "coastal", "coat", "coated", "coating", "cod", "code", "codes", "coding", "coffee", "cognitive", "cohen", "coin", "coins", "col", "cold", "cole", "coleman", "colin", "collaboration", "collaborative", "collapse", "collar", "colleague", "colleagues", "collect", "collectables", "collected", "collectible", "collectibles", "collecting", "collection", "collections", "collective", "collector", "collectors", "college", "colleges", "collins", "cologne", "colombia", "colon", "colonial", "colony", "color", "colorado", "colored", "colors", "colour", "colours", "columbia", "columbus", "column", "columnists", "columns", "com", "combat", "combination", "combinations", "combine", "combined", "combines", "combining", "combo", "come", "comedy", "comes", "comfort", "comfortable", "comic", "comics", "coming", "comm", "command", "commander", "commands", "comment", "commentary", "commented", "comments", "commerce", "commercial", "commission", "commissioner", "commissioners", "commissions", "commit", "commitment", "commitments", "committed", "committee", "committees", "commodities", "commodity", "common", "commonly", "commons", "commonwealth", "communicate", "communication", "communications", "communist", "communities", "community", "comp", "compact", "companies", "companion", "company", "compaq", "comparable", "comparative", "compare", "compared", "comparing", "comparison", "comparisons", "compatibility", "compatible", "compensation", "compete", "competent", "competing", "competition", "competitions", "competitive", "competitors", "compilation", "compile", "compiled", "compiler", "complaint", "complaints", "complement", "complete", "completed", "completely", "completing", "completion", "complex", "complexity", "compliance", "compliant", "complicated", "complications", "complimentary", "comply", "component", "components", "composed", "composer", "composite", "composition", "compound", "compounds", "comprehensive", "compressed", "compression", "compromise", "computation", "computational", "compute", "computed", "computer", "computers", "computing", "con", "concentrate", "concentration", "concentrations", "concept", "concepts", "conceptual", "concern", "concerned", "concerning", "concerns", "concert", "concerts", "conclude", "concluded", "conclusion", "conclusions", "concord", "concrete", "condition", "conditional", "conditioning", "conditions", "condo", "condos", "conduct", "conducted", "conducting", "conf", "conference", "conferences", "conferencing", "confidence", "confident", "confidential", "confidentiality", "config", "configuration", "configure", "configured", "configuring", "confirm", "confirmation", "confirmed", "conflict", "conflicts", "confused", "confusion", "congo", "congratulations", "congress", "congressional", "conjunction", "connect", "connected", "connecticut", "connecting", "connection", "connections", "connectivity", "connector", "connectors", "cons", "conscious", "consciousness", "consecutive", "consensus", "consent", "consequence", "consequences", "consequently", "conservation", "conservative", "consider", "considerable", "consideration", "considerations", "considered", "considering", "considers", "consist", "consistency", "consistent", "consistently", "consisting", "consists", "console", "consoles", "consolidated", "consolidation", "consortium", "conspiracy", "const", "constant", "constantly", "constitute", "constitutes", "constitution", "constitutional", "constraint", "constraints", "construct", "constructed", "construction", "consult", "consultancy", "consultant", "consultants", "consultation", "consulting", "consumer", "consumers", "consumption", "contact", "contacted", "contacting", "contacts", "contain", "contained", "container", "containers",\
    "containing", "contains", "contamination", "contemporary", "content", "contents", "contest", "contests", "context", "continent", "continental", "continually", "continue", "continued", "continues", "continuing", "continuity", "continuous", "continuously", "contract", "contracting", "contractor", "contractors", "contracts", "contrary", "contrast", "contribute", "contributed", "contributing", "contribution", "contributions", "contributor", "contributors", "control", "controlled", "controller", "controllers", "controlling", "controls", "controversial", "controversy", "convenience", "convenient", "convention", "conventional", "conventions", "convergence", "conversation", "conversations", "conversion", "convert", "converted", "converter", "convertible", "convicted", "conviction", "convinced", "cook", "cookbook", "cooked", "cookie", "cookies", "cooking", "cool", "cooler", "cooling", "cooper", "cooperation", "cooperative", "coordinate", "coordinated", "coordinates", "coordination", "coordinator", "cop", "cope", "copied", "copies", "copper", "copy", "copying", "copyright", "copyrighted", "copyrights", "coral", "cord", "cordless", "core", "cork", "corn", "cornell", "corner", "corners", "cornwall", "corp", "corporate", "corporation", "corporations", "corps", "corpus", "correct", "corrected", "correction", "corrections", "correctly", "correlation", "correspondence", "corresponding", "corruption", "cos", "cosmetic", "cosmetics", "cost", "costa", "costs", "costume", "costumes", "cottage", "cottages", "cotton", "could", "council", "councils", "counsel", "counseling", "count", "counted", "counter", "counters", "counties", "counting", "countries", "country", "counts", "county", "couple", "coupled", "couples", "coupon", "coupons", "courage", "courier", "course", "courses", "court", "courtesy", "courts", "cove", "cover", "coverage", "covered", "covering", "covers", "cow", "cowboy", "cox", "cp", "cpu", "cr", "crack", "cradle", "craft", "crafts", "craig", "crap", "craps", "crash", "crawford", "crazy", "cream", "create", "created", "creates", "creating", "creation", "creations", "creative", "creativity", "creator", "creature", "creatures", "credit", "credits", "creek", "crest", "crew", "cricket", "crime", "crimes", "criminal", "crisis", "criteria", "criterion", "critical", "criticism", "critics", "crm", "croatia", "crop", "crops", "cross", "crossing", "crossword", "crowd", "crown", "crucial", "crude", "cruise", "cruises", "cruz", "cry", "crystal", "cs", "css", "cst", "ct", "cu", "cuba", "cube", "cubic", "cuisine", "cult", "cultural", "culture", "cultures", "cumulative", "cup", "cups", "cure", "curious", "currencies", "currency", "current", "currently", "curriculum", "cursor", "curtis", "curve", "curves", "custody", "custom", "customer", "customers", "customise", "customize", "customized", "customs", "cut", "cute", "cuts", "cutting", "cv", "cvs", "cw", "cyber", "cycle", "cycles", "cycling", "cylinder", "cyprus", "cz", "czech", "d", "da", "dad", "daddy", "daily", "dairy", "daisy", "dakota", "dale", "dallas", "dam", "damage", "damaged", "damages", "dame", "damn", "dan", "dana", "dance", "dancing", "danger", "dangerous", "daniel", "danish", "danny", "dans", "dare", "dark", "darkness", "darwin", "das", "dash", "dat", "data", "database", "databases", "date", "dated", "dates", "dating", "daughter", "daughters", "dave", "david", "davidson", "davis", "dawn", "day", "days", "dayton", "db", "dc", "dd", "ddr", "de", "dead", "deadline", "deadly", "deaf", "deal", "dealer", "dealers", "dealing", "deals", "dealt", "dealtime", "dean", "dear", "death", "deaths", "debate", "debian", "deborah", "debt", "debug", "debut", "dec", "decade", "decades", "december", "decent", "decide", "decided", "decimal", "decision", "decisions", "deck", "declaration", "declare", "declared", "decline", "declined", "decor", "decorating", "decorative", "decrease", "decreased", "dedicated", "dee", "deemed", "deep", "deeper", "deeply", "deer", "def", "default", "defeat", "defects", "defence", "defend", "defendant", "defense", "defensive", "deferred", "deficit", "define", "defined", "defines", "defining", "definitely", "definition", "definitions", "degree", "degrees", "del", "delaware", "delay", "delayed", "delays", "delegation", "delete", "deleted", "delhi", "delicious", "delight", "deliver", "delivered", "delivering", "delivers", "delivery", "dell", "delta", "deluxe", "dem", "demand", "demanding", "demands", "demo", "democracy", "democrat", "democratic", "democrats", "demographic", "demonstrate", "demonstrated", "demonstrates", "demonstration", "den", "denial", "denied", "denmark", "dennis", "dense", "density", "dental", "dentists", "denver", "deny", "department", "departmental", "departments", "departure", "depend", "dependence", "dependent", "depending", "depends", "deployment", "deposit", "deposits", "depot", "depression", "dept", "depth", "deputy", "der", "derby", "derek", "derived", "des", "descending", "describe", "described", "describes", "describing", "description", "descriptions", "desert", "deserve", "design", "designated", "designation", "designed", "designer", "designers", "designing", "designs", "desirable", "desire", "desired", "desk", "desktop", "desktops", "desperate", "despite", "destination", "destinations", "destiny", "destroy", "destroyed", "destruction", "detail", "detailed", "details", "detect", "detected", "detection", "detective", "detector", "determination", "determine", "determined", "determines", "determining", "detroit",\
    "deutsch", "deutsche", "deutschland", "dev", "devel", "develop", "developed", "developer", "developers", "developing", "development", "developmental", "developments", "develops", "deviant", "deviation", "device", "devices", "devil", "devon", "devoted", "df", "dg", "dh", "di", "diabetes", "diagnosis", "diagnostic", "diagram", "dial", "dialog", "dialogue", "diameter", "diamond", "diamonds", "diana", "diane", "diary", "dice", "dictionaries", "dictionary", "did", "die", "died", "diego", "dies", "diesel", "diet", "dietary", "diff", "differ", "difference", "differences", "different", "differential", "differently", "difficult", "difficulties", "difficulty", "diffs", "dig", "digest", "digit", "digital", "dildo", "dildos", "dim", "dimension", "dimensional", "dimensions", "dining", "dinner", "dip", "diploma", "dir", "direct", "directed", "direction", "directions", "directive", "directly", "director", "directories", "directors", "directory", "dirt", "dirty", "dis", "disabilities", "disability", "disable", "disabled", "disagree", "disappointed", "disaster", "disc", "discharge", "disciplinary", "discipline", "disciplines", "disclaimer", "disclaimers", "disclose", "disclosure", "disco", "discount", "discounted", "discounts", "discover", "discovered", "discovery", "discrete", "discretion", "discrimination", "discs", "discuss", "discussed", "discusses", "discussing", "discussion", "discussions", "disease", "diseases", "dish", "dishes", "disk", "disks", "disney", "disorder", "disorders", "dispatch", "dispatched", "display", "displayed", "displaying", "displays", "disposal", "disposition", "dispute", "disputes", "dist", "distance", "distances", "distant", "distinct", "distinction", "distinguished", "distribute", "distributed", "distribution", "distributions", "distributor", "distributors", "district", "districts", "disturbed", "div", "dive", "diverse", "diversity", "divide", "divided", "dividend", "divine", "diving", "division", "divisions", "divorce", "divx", "diy", "dj", "dk", "dl", "dm", "dna", "dns", "do", "doc", "dock", "docs", "doctor", "doctors", "doctrine", "document", "documentary", "documentation", "documentcreatetextnode", "documented", "documents", "dod", "dodge", "doe", "does", "dog", "dogs", "doing", "doll", "dollar", "dollars", "dolls", "dom", "domain", "domains", "dome", "domestic", "dominant", "dominican", "don", "donald", "donate", "donated", "donation", "donations", "done", "donna", "donor", "donors", "dont", "doom", "door", "doors", "dos", "dosage", "dose", "dot", "double", "doubt", "doug", "douglas", "dover", "dow", "down", "download", "downloadable", "downloadcom", "downloaded", "downloading", "downloads", "downtown", "dozen", "dozens", "dp", "dpi", "dr", "draft", "drag", "dragon", "drain", "drainage", "drama", "dramatic", "dramatically", "draw", "drawing", "drawings", "drawn", "draws", "dream", "dreams", "dress", "dressed", "dresses", "dressing", "drew", "dried", "drill", "drilling", "drink", "drinking", "drinks", "drive", "driven", "driver", "drivers", "drives", "driving", "drop", "dropped", "drops", "drove", "drug", "drugs", "drum", "drums", "drunk", "dry", "dryer", "ds", "dsc", "dsl", "dt", "dts", "du", "dual", "dubai", "dublin", "duck", "dude", "due", "dui", "duke", "dumb", "dump", "duncan", "duo", "duplicate", "durable", "duration", "durham", "during", "dust", "dutch", "duties", "duty", "dv", "dvd", "dvds", "dx", "dying", "dylan", "dynamic", "dynamics", "e", "ea", "each", "eagle", "eagles", "ear", "earl", "earlier", "earliest", "early", "earn", "earned", "earning", "earnings", "earrings", "ears", "earth", "earthquake", "ease", "easier", "easily", "east", "easter", "eastern", "easy", "eat", "eating", "eau", "ebay", "ebony", "ebook", "ebooks", "ec", "echo", "eclipse", "eco", "ecological", "ecology", "ecommerce", "economic", "economics", "economies", "economy", "ecuador", "ed", "eddie", "eden", "edgar", "edge", "edges", "edinburgh", "edit", "edited", "editing", "edition", "editions", "editor", "editorial", "editorials", "editors", "edmonton", "eds", "edt", "educated", "education", "educational", "educators", "edward", "edwards", "ee", "ef", "effect", "effective", "effectively", "effectiveness", "effects", "efficiency", "efficient", "efficiently", "effort", "efforts", "eg", "egg", "eggs", "egypt", "egyptian", "eh", "eight", "either", "el", "elder", "elderly", "elect", "elected", "election", "elections", "electoral", "electric", "electrical", "electricity", "electro", "electron", "electronic", "electronics", "elegant", "element", "elementary", "elements", "elephant", "elevation", "eleven", "eligibility", "eligible", "eliminate", "elimination", "elite", "elizabeth", "ellen", "elliott", "ellis", "else", "elsewhere", "elvis", "em", "emacs", "email", "emails", "embassy", "embedded", "emerald", "emergency", "emerging", "emily", "eminem", "emirates", "emission", "emissions", "emma", "emotional", "emotions", "emperor", "emphasis", "empire", "empirical", "employ", "employed", "employee", "employees", "employer", "employers", "employment", "empty", "en", "enable", "enabled", "enables", "enabling", "enb", "enclosed", "enclosure", "encoding", "encounter", "encountered", "encourage", "encouraged", "encourages", "encouraging", "encryption", "encyclopedia", "end", "endangered", "ended", "endif", "ending", "endless",\
    "endorsed", "endorsement", "ends", "enemies", "enemy", "energy", "enforcement", "eng", "engage", "engaged", "engagement", "engaging", "engine", "engineer", "engineering", "engineers", "engines", "england", "english", "enhance", "enhanced", "enhancement", "enhancements", "enhancing", "enjoy", "enjoyed", "enjoying", "enlarge", "enlargement", "enormous", "enough", "enquiries", "enquiry", "enrolled", "enrollment", "ensemble", "ensure", "ensures", "ensuring", "ent", "enter", "entered", "entering", "enterprise", "enterprises", "enters", "entertaining", "entertainment", "entire", "entirely", "entities", "entitled", "entity", "entrance", "entrepreneur", "entrepreneurs", "entries", "entry", "envelope", "environment", "environmental", "environments", "enzyme", "eos", "ep", "epa", "epic", "epinions", "epinionscom", "episode", "episodes", "epson", "eq", "equal", "equality", "equally", "equation", "equations", "equilibrium", "equipment", "equipped", "equity", "equivalent", "er", "era", "eric", "ericsson", "erik", "erotic", "erotica", "erp", "error", "errors", "es", "escape", "escort", "escorts", "especially", "espn", "essay", "essays", "essence", "essential", "essentially", "essentials", "essex", "est", "establish", "established", "establishing", "establishment", "estate", "estates", "estimate", "estimated", "estimates", "estimation", "estonia", "et", "etc", "eternal", "ethernet", "ethical", "ethics", "ethiopia", "ethnic", "eu", "eugene", "eur", "euro", "europe", "european", "euros", "ev", "eva", "eval", "evaluate", "evaluated", "evaluating", "evaluation", "evaluations", "evanescence", "evans", "eve", "even", "evening", "event", "events", "eventually", "ever", "every", "everybody", "everyday", "everyone", "everything", "everywhere", "evidence", "evident", "evil", "evolution", "ex", "exact", "exactly", "exam", "examination", "examinations", "examine", "examined", "examines", "examining", "example", "examples", "exams", "exceed", "excel", "excellence", "excellent", "except", "exception", "exceptional", "exceptions", "excerpt", "excess", "excessive", "exchange", "exchanges", "excited", "excitement", "exciting", "exclude", "excluded", "excluding", "exclusion", "exclusive", "exclusively", "excuse", "exec", "execute", "executed", "execution", "executive", "executives", "exempt", "exemption", "exercise", "exercises", "exhaust", "exhibit", "exhibition", "exhibitions", "exhibits", "exist", "existed", "existence", "existing", "exists", "exit", "exotic", "exp", "expand", "expanded", "expanding", "expansion", "expansys", "expect", "expectations", "expected", "expects", "expedia", "expenditure", "expenditures", "expense", "expenses", "expensive", "experience", "experienced", "experiences", "experiencing", "experiment", "experimental", "experiments", "expert", "expertise", "experts", "expiration", "expired", "expires", "explain", "explained", "explaining", "explains", "explanation", "explicit", "explicitly", "exploration", "explore", "explorer", "exploring", "explosion", "expo", "export", "exports", "exposed", "exposure", "express", "expressed", "expression", "expressions", "ext", "extend", "extended", "extending", "extends", "extension", "extensions", "extensive", "extent", "exterior", "external", "extra", "extract", "extraction", "extraordinary", "extras", "extreme", "extremely", "eye", "eyed", "eyes", "ez", "f", "fa", "fabric", "fabrics", "fabulous", "face", "faced", "faces", "facial", "facilitate", "facilities", "facility", "facing", "fact", "factor", "factors", "factory", "facts", "faculty", "fail", "failed", "failing", "fails", "failure", "failures", "fair", "fairfield", "fairly", "fairy", "faith", "fake", "fall", "fallen", "falling", "falls", "false", "fame", "familiar", "families", "family", "famous", "fan", "fancy", "fans", "fantastic", "fantasy", "faq", "faqs", "far", "fare", "fares", "farm", "farmer", "farmers", "farming", "farms", "fascinating", "fashion", "fast", "faster", "fastest", "fat", "fatal", "fate", "father", "fathers", "fatty", "fault", "favor", "favorite", "favorites", "favors", "favour", "favourite", "favourites", "fax", "fbi", "fc", "fcc", "fd", "fda", "fe", "fear", "fears", "feat", "feature", "featured", "features", "featuring", "feb", "february", "fed", "federal", "federation", "fee", "feed", "feedback", "feeding", "feeds", "feel", "feeling", "feelings", "feels", "fees", "feet", "fell", "fellow", "fellowship", "felt", "female", "females", "fence", "feof", "ferrari", "ferry", "festival", "festivals", "fever", "few", "fewer", "ff", "fg", "fi", "fiber", "fibre", "fiction", "field", "fields", "fifteen", "fifth", "fifty", "fig", "fight", "fighter", "fighters", "fighting", "figure", "figured", "figures", "fiji", "file", "filed", "filename", "files", "filing", "fill", "filled", "filling", "film", "filme", "films", "filter", "filtering", "filters", "fin", "final", "finally", "finals", "finance", "finances", "financial", "financing", "find", "findarticles", "finder", "finding", "findings", "findlaw", "finds", "fine", "finest", "finger", "fingering", "fingers", "finish", "finished", "finishing", "finite", "finland", "finnish", "fioricet", "fire", "fired", "firefox", "fireplace", "fires", "firewall", "firewire", "firm", "firms", "firmware", "first", "fiscal", "fish", "fisher", "fisheries", "fishing", "fist", "fisting", "fit", "fitness", "fits", "fitted", "fitting", "five", "fix", "fixed", "fixes", "fixtures", "fl",\
    "fla", "flag", "flags", "flame", "flash", "flashers", "flashing", "flat", "flavor", "fleece", "fleet", "flesh", "flex", "flexibility", "flexible", "flickr", "flight", "flights", "flip", "float", "floating", "flood", "floor", "flooring", "floors", "floppy", "floral", "florence", "florida", "florist", "florists", "flour", "flow", "flower", "flowers", "flows", "floyd", "flu", "fluid", "flush", "flux", "fly", "flyer", "flying", "fm", "fo", "foam", "focal", "focus", "focused", "focuses", "focusing", "fog", "fold", "folder", "folders", "folding", "folk", "folks", "follow", "followed", "following", "follows", "font", "fonts", "foo", "food", "foods", "fool", "foot", "footage", "football", "footwear", "for", "forbes", "forbidden", "force", "forced", "forces", "ford", "forecast", "forecasts", "foreign", "forest", "forestry", "forests", "forever", "forge", "forget", "forgot", "forgotten", "fork", "form", "formal", "format", "formation", "formats", "formatting", "formed", "former", "formerly", "forming", "forms", "formula", "fort", "forth", "fortune", "forty", "forum", "forums", "forward", "forwarding", "fossil", "foster", "foto", "fotos", "fought", "foul", "found", "foundation", "foundations", "founded", "founder", "fountain", "four", "fourth", "fox", "fp", "fr", "fraction", "fragrance", "fragrances", "frame", "framed", "frames", "framework", "framing", "france", "franchise", "francis", "francisco", "frank", "frankfurt", "franklin", "fraser", "fraud", "fred", "frederick", "free", "freebsd", "freedom", "freelance", "freely", "freeware", "freeze", "freight", "french", "frequencies", "frequency", "frequent", "frequently", "fresh", "fri", "friday", "fridge", "friend", "friendly", "friends", "friendship", "frog", "from", "front", "frontier", "frontpage", "frost", "frozen", "fruit", "fruits", "fs", "ft", "ftp", "fu", "fuel", "fuji", "fujitsu", "full", "fully", "fun", "function", "functional", "functionality", "functioning", "functions", "fund", "fundamental", "fundamentals", "funded", "funding", "fundraising", "funds", "funeral", "funk", "funky", "funny", "fur", "furnished", "furnishings", "furniture", "further", "furthermore", "fusion", "future", "futures", "fuzzy", "fw", "fwd", "fx", "fy", "g", "ga", "gabriel", "gadgets", "gage", "gain", "gained", "gains", "galaxy", "gale", "galleries", "gallery", "gambling", "game", "gamecube", "games", "gamespot", "gaming", "gamma", "gang", "gap", "gaps", "garage", "garbage", "garcia", "garden", "gardening", "gardens", "garlic", "garmin", "gary", "gas", "gasoline", "gate", "gates", "gateway", "gather", "gathered", "gathering", "gauge", "gave", "gay", "gazette", "gb", "gba", "gbp", "gc", "gcc", "gd", "gdp", "ge", "gear", "geek", "gel", "gem", "gen", "gender", "gene", "genealogy", "general", "generally", "generate", "generated", "generates", "generating", "generation", "generations", "generator", "generators", "generic", "generous", "genes", "genesis", "genetic", "genetics", "geneva", "genius", "genome", "genre", "genres", "gentle", "gentleman", "gently", "genuine", "geo", "geographic", "geographical", "geography", "geological", "geology", "geometry", "george", "georgia", "gerald", "german", "germany", "get", "gets", "getting", "gg", "ghana", "ghost", "ghz", "gi", "giant", "giants", "gibraltar", "gibson", "gif", "gift", "gifts", "gig", "gilbert", "girl", "girlfriend", "girls", "gis", "give", "given", "gives", "giving", "gl", "glad", "glance", "glasgow", "glass", "glasses", "glen", "glenn", "global", "globe", "glory", "glossary", "gloves", "glow", "glucose", "gm", "gmbh", "gmc", "gmt", "gnome", "gnu", "go", "goal", "goals", "goat", "god", "gods", "goes", "going", "gold", "golden", "golf", "gone", "gonna", "good", "goods", "google", "gordon", "gore", "gorgeous", "gospel", "gossip", "got", "gothic", "goto", "gotta", "gotten", "gourmet", "gov", "governance", "governing", "government", "governmental", "governments", "governor", "govt", "gp", "gpl", "gps", "gr", "grab", "grace", "grad", "grade", "grades", "gradually", "graduate", "graduated", "graduates", "graduation", "graham", "grain", "grammar", "grams", "grand", "grande", "granny", "grant", "granted", "grants", "graph", "graphic", "graphical", "graphics", "graphs", "gras", "grass", "grateful", "gratis", "gratuit", "grave", "gravity", "gray", "great", "greater", "greatest", "greatly", "greece", "greek", "green", "greene", "greenhouse", "greensboro", "greeting", "greetings", "greg", "gregory", "grenada", "grew", "grey", "grid", "griffin", "grill", "grip", "grocery", "groove", "gross", "ground", "grounds", "groundwater", "group", "groups", "grove", "grow", "growing", "grown", "grows", "growth", "gs", "gsm", "gst", "gt", "gtk", "guam", "guarantee", "guaranteed", "guarantees", "guard", "guardian", "guards", "guatemala", "guess", "guest", "guestbook", "guests", "gui", "guidance", "guide", "guided", "guidelines", "guides", "guild", "guilty", "guinea", "guitar", "guitars",\
    "gulf", "gun", "guns", "guru", "guy", "guyana", "guys", "gym", "gzip", "h", "ha", "habitat", "habits", "hack", "hacker", "had", "hair", "hairy", "haiti", "half", "halfcom", "halifax", "hall", "halloween", "halo", "ham", "hamburg", "hamilton", "hammer", "hampshire", "hampton", "hand", "handbags", "handbook", "handed", "handheld", "handhelds", "handle", "handled", "handles", "handling", "handmade", "hands", "handy", "hang", "hanging", "hans", "hansen", "happen", "happened", "happening", "happens", "happiness", "happy", "harassment", "harbor", "harbour", "hard", "hardcore", "hardcover", "harder", "hardly", "hardware", "hardwood", "harley", "harm", "harmful", "harmony", "harold", "harper", "harris", "harrison", "harry", "hart", "hartford", "harvard", "harvest", "harvey", "has", "hash", "hat", "hate", "hats", "have", "haven", "having", "hawaii", "hawaiian", "hawk", "hay", "hayes", "hazard", "hazardous", "hazards", "hb", "hc", "hd", "hdtv", "he", "head", "headed", "header", "headers", "heading", "headline", "headlines", "headphones", "headquarters", "heads", "headset", "healing", "health", "healthcare", "healthy", "hear", "heard", "hearing", "hearings", "heart", "hearts", "heat", "heated", "heater", "heath", "heather", "heating", "heaven", "heavily", "heavy", "hebrew", "heel", "height", "heights", "held", "helen", "helena", "helicopter", "hell", "hello", "helmet", "help", "helped", "helpful", "helping", "helps", "hence", "henderson", "henry", "hentai", "hepatitis", "her", "herald", "herb", "herbal", "herbs", "here", "hereby", "herein", "heritage", "hero", "heroes", "herself", "hewlett", "hey", "hh", "hi", "hidden", "hide", "hierarchy", "high", "higher", "highest", "highland", "highlight", "highlighted", "highlights", "highly", "highs", "highway", "highways", "hiking", "hill", "hills", "hilton", "him", "himself", "hindu", "hint", "hints", "hip", "hire", "hired", "hiring", "his", "hispanic", "hist", "historic", "historical", "history", "hit", "hitachi", "hits", "hitting", "hiv", "hk", "hl", "ho", "hobbies", "hobby", "hockey", "hold", "holdem", "holder", "holders", "holding", "holdings", "holds", "hole", "holes", "holiday", "holidays", "holland", "hollow", "holly", "hollywood", "holmes", "holocaust", "holy", "home", "homeland", "homeless", "homepage", "homes", "hometown", "homework", "hon", "honda", "honduras", "honest", "honey", "hong", "honolulu", "honor", "honors", "hood", "hook", "hop", "hope", "hoped", "hopefully", "hopes", "hoping", "hopkins", "horizon", "horizontal", "hormone", "horn", "horny", "horrible", "horror", "horse", "horses", "hose", "hospital", "hospitality", "hospitals", "host", "hosted", "hostel", "hostels", "hosting", "hosts", "hot", "hotel", "hotels", "hotelscom", "hotmail", "hottest", "hour", "hourly", "hours", "house", "household", "households", "houses", "housewares", "housewives", "housing", "houston", "how", "howard", "however", "howto", "hp", "hq", "hr", "href", "hrs", "hs", "ht", "html", "http", "hu", "hub", "hudson", "huge", "hugh", "hughes", "hugo", "hull", "human", "humanitarian", "humanities", "humanity", "humans", "humidity", "humor", "hundred", "hundreds", "hung", "hungarian", "hungary", "hunger", "hungry", "hunt", "hunter", "hunting", "huntington", "hurricane", "hurt", "husband", "hwy", "hybrid", "hydraulic", "hydrocodone", "hydrogen", "hygiene", "hypothesis", "hypothetical", "hyundai", "hz", "i", "ia", "ian", "ibm", "ic", "ice", "iceland", "icon", "icons", "icq", "ict", "id", "idaho", "ide", "idea", "ideal", "ideas", "identical", "identification", "identified", "identifier", "identifies", "identify", "identifying", "identity", "idle", "idol", "ids", "ie", "ieee", "if", "ignore", "ignored", "ii", "iii", "il", "ill", "illegal", "illinois", "illness", "illustrated", "illustration", "illustrations", "im", "ima", "image", "images", "imagination", "imagine", "imaging", "img", "immediate", "immediately", "immigrants", "immigration", "immune", "immunology", "impact", "impacts", "impaired", "imperial", "implement", "implementation", "implemented", "implementing", "implications", "implied", "implies", "import", "importance", "important", "importantly", "imported", "imports", "impose", "imposed", "impossible", "impressed", "impression", "impressive", "improve", "improved", "improvement", "improvements", "improving", "in", "inappropriate", "inbox", "inc", "incentive", "incentives", "incest", "inch", "inches", "incidence", "incident", "incidents", "incl", "include", "included", "includes", "including", "inclusion", "inclusive", "income", "incoming", "incomplete", "incorporate", "incorporated", "incorrect", "increase", "increased", "increases", "increasing", "increasingly", "incredible", "incurred", "ind", "indeed", "independence", "independent", "independently", "index", "indexed", "indexes", "india", "indian", "indiana", "indianapolis", "indians", "indicate", "indicated", "indicates", "indicating", "indication", "indicator", "indicators", "indices", "indie", "indigenous", "indirect", "individual", "individually", "individuals", "indonesia", "indonesian", "indoor", "induced", "induction", "industrial", "industries", "industry", "inexpensive", "inf", "infant", "infants", "infected",\
    "infection", "infections", "infectious", "infinite", "inflation", "influence", "influenced", "influences", "info", "inform", "informal", "information", "informational", "informative", "informed", "infrared", "infrastructure", "ing", "ingredients", "inherited", "initial", "initially", "initiated", "initiative", "initiatives", "injection", "injured", "injuries", "injury", "ink", "inkjet", "inline", "inn", "inner", "innocent", "innovation", "innovations", "innovative", "inns", "input", "inputs", "inquire", "inquiries", "inquiry", "ins", "insects", "insert", "inserted", "insertion", "inside", "insider", "insight", "insights", "inspection", "inspections", "inspector", "inspiration", "inspired", "install", "installation", "installations", "installed", "installing", "instance", "instances", "instant", "instantly", "instead", "institute", "institutes", "institution", "institutional", "institutions", "instruction", "instructional", "instructions", "instructor", "instructors", "instrument", "instrumental", "instrumentation", "instruments", "insulin", "insurance", "insured", "int", "intake", "integer", "integral", "integrate", "integrated", "integrating", "integration", "integrity", "intel", "intellectual", "intelligence", "intelligent", "intend", "intended", "intense", "intensity", "intensive", "intent", "intention", "inter", "interact", "interaction", "interactions", "interactive", "interest", "interested", "interesting", "interests", "interface", "interfaces", "interference", "interim", "interior", "intermediate", "internal", "international", "internationally", "internet", "internship", "interpretation", "interpreted", "interracial", "intersection", "interstate", "interval", "intervals", "intervention", "interventions", "interview", "interviews", "intimate", "intl", "into", "intranet", "intro", "introduce", "introduced", "introduces", "introducing", "introduction", "introductory", "invalid", "invasion", "invention", "inventory", "invest", "investigate", "investigated", "investigation", "investigations", "investigator", "investigators", "investing", "investment", "investments", "investor", "investors", "invisible", "invision", "invitation", "invitations", "invite", "invited", "invoice", "involve", "involved", "involvement", "involves", "involving", "io", "ion", "iowa", "ip", "ipaq", "ipod", "ips", "ir", "ira", "iran", "iraq", "iraqi", "irc", "ireland", "irish", "iron", "irrigation", "irs", "is", "isa", "isaac", "isbn", "islam", "islamic", "island", "islands", "isle", "iso", "isolated", "isolation", "isp", "israel", "israeli", "issn", "issue", "issued", "issues", "ist", "istanbul", "it", "italia", "italian", "italiano", "italic", "italy", "item", "items", "its", "itsa", "itself", "itunes", "iv", "ivory", "ix", "j", "ja", "jack", "jacket", "jackets", "jackie", "jackson", "jacksonville", "jacob", "jade", "jaguar", "jail", "jake", "jam", "jamaica", "james", "jamie", "jan", "jane", "janet", "january", "japan", "japanese", "jar", "jason", "java", "javascript", "jay", "jazz", "jc", "jd", "je", "jean", "jeans", "jeep", "jeff", "jefferson", "jeffrey", "jelsoft", "jennifer", "jenny", "jeremy", "jerry", "jersey", "jerusalem", "jesse", "jessica", "jesus", "jet", "jets", "jewel", "jewellery", "jewelry", "jewish", "jews", "jill", "jim", "jimmy", "jj", "jm", "jo", "joan", "job", "jobs", "joe", "joel", "john", "johnny", "johns", "johnson", "johnston", "join", "joined", "joining", "joins", "joint", "joke", "jokes", "jon", "jonathan", "jones", "jordan", "jose", "joseph", "josh", "joshua", "journal", "journalism", "journalist", "journalists", "journals", "journey", "joy", "joyce", "jp", "jpeg", "jpg", "jr", "js", "juan", "judge", "judges", "judgment", "judicial", "judy", "juice", "jul", "julia", "julian", "julie", "july", "jump", "jumping", "jun", "junction", "june", "jungle", "junior", "junk", "jurisdiction", "jury", "just", "justice", "justify", "justin", "juvenile", "jvc", "k", "ka", "kai", "kansas", "karaoke", "karen", "karl", "karma", "kate", "kathy", "katie", "katrina", "kay", "kazakhstan", "kb", "kde", "keen", "keep", "keeping", "keeps", "keith", "kelkoo", "kelly", "ken", "kennedy", "kenneth", "kenny", "keno", "kent", "kentucky", "kenya", "kept", "kernel", "kerry", "kevin", "key", "keyboard", "keyboards", "keys", "keyword", "keywords", "kg", "kick", "kid", "kidney", "kids", "kijiji", "kill", "killed", "killer", "killing", "kills", "kilometers", "kim", "kinase", "kind", "kinda", "kinds", "king", "kingdom", "kings", "kingston", "kirk", "kiss", "kissing", "kit", "kitchen", "kits", "kitty", "klein", "km", "knee", "knew", "knife", "knight", "knights", "knit", "knitting", "knives", "knock", "know", "knowing", "knowledge", "knowledgestorm", "known", "knows", "ko", "kodak", "kong", "korea", "korean", "kruger", "ks", "kurt", "kuwait", "kw", "ky", "kyle", "l", "la", "lab", "label", "labeled", "labels", "labor", "laboratories", "laboratory", "labour", "labs", "lace", "lack", "ladder", "laden", "ladies", "lady", "lafayette", "laid", "lake", "lakes", "lamb", "lambda", "lamp", "lamps", "lan", "lancaster", "lance", "land", "landing", "lands", "landscape", "landscapes", "lane", "lanes", "lang", "language", "languages", "lanka", "lap", "laptop", "laptops", "large", "largely", "larger", "largest",\
    "larry", "las", "laser", "last", "lasting", "lat", "late", "lately", "later", "latest", "latex", "latin", "latina", "latinas", "latino", "latitude", "latter", "latvia", "lauderdale", "laugh", "laughing", "launch", "launched", "launches", "laundry", "laura", "lauren", "law", "lawn", "lawrence", "laws", "lawsuit", "lawyer", "lawyers", "lay", "layer", "layers", "layout", "lazy", "lb", "lbs", "lc", "lcd", "ld", "le", "lead", "leader", "leaders", "leadership", "leading", "leads", "leaf", "league", "lean", "learn", "learned", "learners", "learning", "lease", "leasing", "least", "leather", "leave", "leaves", "leaving", "lebanon", "lecture", "lectures", "led", "lee", "leeds", "left", "leg", "legacy", "legal", "legally", "legend", "legendary", "legends", "legislation", "legislative", "legislature", "legitimate", "legs", "leisure", "lemon", "len", "lender", "lenders", "lending", "length", "lens", "lenses", "leo", "leon", "leonard", "leone", "les", "lesbian", "lesbians", "leslie", "less", "lesser", "lesson", "lessons", "let", "lets", "letter", "letters", "letting", "leu", "level", "levels", "levitra", "levy", "lewis", "lexington", "lexmark", "lexus", "lf", "lg", "li", "liabilities", "liability", "liable", "lib", "liberal", "liberia", "liberty", "librarian", "libraries", "library", "libs", "licence", "license", "licensed", "licenses", "licensing", "licking", "lid", "lie", "liechtenstein", "lies", "life", "lifestyle", "lifetime", "lift", "light", "lighter", "lighting", "lightning", "lights", "lightweight", "like", "liked", "likelihood", "likely", "likes", "likewise", "lil", "lime", "limit", "limitation", "limitations", "limited", "limiting", "limits", "limousines", "lincoln", "linda", "lindsay", "line", "linear", "lined", "lines", "lingerie", "link", "linked", "linking", "links", "linux", "lion", "lions", "lip", "lips", "liquid", "lisa", "list", "listed", "listen", "listening", "listing", "listings", "listprice", "lists", "lit", "lite", "literacy", "literally", "literary", "literature", "lithuania", "litigation", "little", "live", "livecam", "lived", "liver", "liverpool", "lives", "livestock", "living", "liz", "ll", "llc", "lloyd", "llp", "lm", "ln", "lo", "load", "loaded", "loading", "loads", "loan", "loans", "lobby", "loc", "local", "locale", "locally", "locate", "located", "location", "locations", "locator", "lock", "locked", "locking", "locks", "lodge", "lodging", "log", "logan", "logged", "logging", "logic", "logical", "login", "logistics", "logitech", "logo", "logos", "logs", "lol", "lolita", "london", "lone", "lonely", "long", "longer", "longest", "longitude", "look", "looked", "looking", "looks", "looksmart", "lookup", "loop", "loops", "loose", "lopez", "lord", "los", "lose", "losing", "loss", "losses", "lost", "lot", "lots", "lottery", "lotus", "lou", "loud", "louis", "louise", "louisiana", "louisville", "lounge", "love", "loved", "lovely", "lover", "lovers", "loves", "loving", "low", "lower", "lowest", "lows", "lp", "ls", "lt", "ltd", "lu", "lucas", "lucia", "luck", "lucky", "lucy", "luggage", "luis", "luke", "lunch", "lung", "luther", "luxembourg", "luxury", "lycos", "lying", "lynn", "lyric", "lyrics", "m", "ma", "mac", "macedonia", "machine", "machinery", "machines", "macintosh", "macro", "macromedia", "mad", "madagascar", "made", "madison", "madness", "madonna", "madrid", "mae", "mag", "magazine", "magazines", "magic", "magical", "magnet", "magnetic", "magnificent", "magnitude", "mai", "maiden", "mail", "mailed", "mailing", "mailman", "mails", "mailto", "main", "maine", "mainland", "mainly", "mainstream", "maintain", "maintained", "maintaining", "maintains", "maintenance", "major", "majority", "make", "maker", "makers", "makes", "makeup", "making", "malawi", "malaysia", "maldives", "male", "males", "mali", "mall", "malpractice", "malta", "mambo", "man", "manage", "managed", "management", "manager", "managers", "managing", "manchester", "mandate", "mandatory", "manga", "manhattan", "manitoba", "manner", "manor", "manual", "manually", "manuals", "manufacture", "manufactured", "manufacturer", "manufacturers", "manufacturing", "many", "map", "maple", "mapping", "maps", "mar", "marathon", "marble", "marc", "march", "marco", "marcus", "mardi", "margaret", "margin", "maria", "mariah", "marie", "marijuana", "marilyn", "marina", "marine", "mario", "marion", "maritime", "mark", "marked", "marker", "markers", "market", "marketing", "marketplace", "markets", "marking", "marks", "marriage", "married", "marriott", "mars", "marshall", "mart", "martha", "martial", "martin", "marvel", "mary", "maryland", "mas", "mask", "mason", "mass", "massachusetts", "massage", "massive", "master", "mastercard", "masters", "mat", "match", "matched", "matches", "matching", "mate", "material", "materials", "maternity", "math", "mathematical", "mathematics", "mating", "matrix", "mats", "matt", "matter", "matters", "matthew", "mattress", "mature", "maui", "mauritius", "max", "maximize", "maximum", "may", "maybe", "mayor", "mazda",\
    "mb", "mba", "mc", "mcdonald", "md", "me", "meal", "meals", "mean", "meaning", "meaningful", "means", "meant", "meanwhile", "measure", "measured", "measurement", "measurements", "measures", "measuring", "meat", "mechanical", "mechanics", "mechanism", "mechanisms", "med", "medal", "media", "median", "medicaid", "medical", "medicare", "medication", "medications", "medicine", "medicines", "medieval", "meditation", "mediterranean", "medium", "medline", "meet", "meeting", "meetings", "meets", "meetup", "mega", "mel", "melbourne", "melissa", "mem", "member", "members", "membership", "membrane", "memo", "memorabilia", "memorial", "memories", "memory", "memphis", "men", "mens", "ment", "mental", "mention", "mentioned", "mentor", "menu", "menus", "mercedes", "merchandise", "merchant", "merchants", "mercury", "mercy", "mere", "merely", "merge", "merger", "merit", "merry", "mesa", "mesh", "mess", "message", "messages", "messaging", "messenger", "met", "meta", "metabolism", "metadata", "metal", "metallic", "metallica", "metals", "meter", "meters", "method", "methodology", "methods", "metres", "metric", "metro", "metropolitan", "mexican", "mexico", "meyer", "mf", "mfg", "mg", "mh", "mhz", "mi", "mia", "miami", "mic", "mice", "michael", "michel", "michelle", "michigan", "micro", "microphone", "microsoft", "microwave", "mid", "middle", "midi", "midlands", "midnight", "midwest", "might", "mighty", "migration", "mike", "mil", "milan", "mild", "mile", "mileage", "miles", "milf", "milfhunter", "milfs", "military", "milk", "mill", "millennium", "miller", "million", "millions", "mills", "milton", "milwaukee", "mime", "min", "mind", "minds", "mine", "mineral", "minerals", "mines", "mini", "miniature", "minimal", "minimize", "minimum", "mining", "minister", "ministers", "ministries", "ministry", "minneapolis", "minnesota", "minolta", "minor", "minority", "mins", "mint", "minus", "minute", "minutes", "miracle", "mirror", "mirrors", "misc", "miscellaneous", "miss", "missed", "missile", "missing", "mission", "missions", "mississippi", "missouri", "mistake", "mistakes", "mistress", "mit", "mitchell", "mitsubishi", "mix", "mixed", "mixer", "mixing", "mixture", "mj", "ml", "mlb", "mls", "mm", "mn", "mo", "mobile", "mobiles", "mobility", "mod", "mode", "model", "modeling", "modelling", "models", "modem", "modems", "moderate", "moderator", "moderators", "modern", "modes", "modification", "modifications", "modified", "modify", "mods", "modular", "module", "modules", "moisture", "mold", "moldova", "molecular", "molecules", "mom", "moment", "moments", "momentum", "moms", "mon", "monaco", "monday", "monetary", "money", "mongolia", "monica", "monitor", "monitored", "monitoring", "monitors", "monkey", "mono", "monroe", "monster", "montana", "monte", "montgomery", "month", "monthly", "months", "montreal", "mood", "moon", "moore", "moral", "more", "moreover", "morgan", "morning", "morocco", "morris", "morrison", "mortality", "mortgage", "mortgages", "moscow", "moses", "moss", "most", "mostly", "motel", "motels", "mother", "motherboard", "mothers", "motion", "motivated", "motivation", "motor", "motorcycle", "motorcycles", "motorola", "motors", "mount", "mountain", "mountains", "mounted", "mounting", "mounts", "mouse", "mouth", "move", "moved", "movement", "movements", "movers", "moves", "movie", "movies", "moving", "mozambique", "mozilla", "mp", "mpeg", "mpegs", "mpg", "mph", "mr", "mrna", "mrs", "ms", "msg", "msgid", "msgstr", "msie", "msn", "mt", "mtv", "mu", "much", "mud", "mug", "multi", "multimedia", "multiple", "mumbai", "munich", "municipal", "municipality", "murder", "murphy", "murray", "muscle", "muscles", "museum", "museums", "music", "musical", "musician", "musicians", "muslim", "muslims", "must", "mustang", "mutual", "muze", "mv", "mw", "mx", "my", "myanmar", "myers", "myrtle", "myself", "mysimon", "myspace", "mysql", "mysterious", "mystery", "myth", "n", "na", "nail", "nails", "naked", "nam", "name", "named", "namely", "names", "namespace", "namibia", "nancy", "nano", "naples", "narrative", "narrow", "nasa", "nascar", "nasdaq", "nashville", "nasty", "nat", "nathan", "nation", "national", "nationally", "nations", "nationwide", "native", "nato", "natural", "naturally", "naturals", "nature", "naughty", "nav", "naval", "navigate", "navigation", "navigator", "navy", "nb", "nba", "nbc", "nc", "ncaa", "nd", "ne", "near", "nearby", "nearest", "nearly", "nebraska", "nec", "necessarily", "necessary", "necessity", "neck", "necklace", "need", "needed", "needle", "needs", "negative", "negotiation", "negotiations", "neighbor", "neighborhood", "neighbors", "neil", "neither", "nelson", "neo", "neon", "nepal", "nerve", "nervous", "nest", "nested", "net", "netherlands", "netscape", "network", "networking", "networks", "neural", "neutral", "nevada", "never", "nevertheless", "new", "newark", "newbie", "newcastle", "newer", "newest", "newfoundland", "newly", "newport", "news", "newscom", "newsletter", "newsletters", "newspaper", "newspapers", "newton", "next", "nextel", "nfl", "ng", "nh", "nhl", "nhs", "ni", "niagara", "nicaragua", "nice", "nicholas", "nick", "nickel",\
    "nickname", "nicole", "niger", "nigeria", "night", "nightlife", "nightmare", "nights", "nike", "nikon", "nil", "nine", "nintendo", "nipple", "nipples", "nirvana", "nissan", "nitrogen", "nj", "nl", "nm", "nn", "no", "noble", "nobody", "node", "nodes", "noise", "nokia", "nominated", "nomination", "nominations", "non", "none", "nonprofit", "noon", "nor", "norfolk", "norm", "normal", "normally", "norman", "north", "northeast", "northern", "northwest", "norton", "norway", "norwegian", "nos", "nose", "not", "note", "notebook", "notebooks", "noted", "notes", "nothing", "notice", "noticed", "notices", "notification", "notifications", "notified", "notify", "notion", "notre", "nottingham", "nov", "nova", "novel", "novels", "novelty", "november", "now", "nowhere", "np", "nr", "ns", "nsw", "nt", "ntsc", "nu", "nuclear", "nude", "nudist", "nudity", "nuke", "null", "number", "numbers", "numeric", "numerical", "numerous", "nurse", "nursery", "nurses", "nursing", "nut", "nutrition", "nutritional", "nuts", "nutten", "nv", "nvidia", "nw", "ny", "nyc", "nylon", "nz", "o", "oak", "oakland", "oaks", "oasis", "ob", "obesity", "obituaries", "obj", "object", "objective", "objectives", "objects", "obligation", "obligations", "observation", "observations", "observe", "observed", "observer", "obtain", "obtained", "obtaining", "obvious", "obviously", "oc", "occasion", "occasional", "occasionally", "occasions", "occupation", "occupational", "occupations", "occupied", "occur", "occurred", "occurrence", "occurring", "occurs", "ocean", "oclc", "oct", "october", "odd", "odds", "oe", "oecd", "oem", "of", "off", "offense", "offensive", "offer", "offered", "offering", "offerings", "offers", "office", "officer", "officers", "offices", "official", "officially", "officials", "offline", "offset", "offshore", "often", "og", "oh", "ohio", "oil", "oils", "ok", "okay", "oklahoma", "ol", "old", "older", "oldest", "olive", "oliver", "olympic", "olympics", "olympus", "om", "omaha", "oman", "omega", "omissions", "on", "once", "one", "ones", "ongoing", "onion", "online", "only", "ons", "ontario", "onto", "oo", "ooo", "oops", "op", "open", "opened", "opening", "openings", "opens", "opera", "operate", "operated", "operates", "operating", "operation", "operational", "operations", "operator", "operators", "opinion", "opinions", "opponent", "opponents", "opportunities", "opportunity", "opposed", "opposite", "opposition", "opt", "optical", "optics", "optimal", "optimization", "optimize", "optimum", "option", "optional", "options", "or", "oracle", "oral", "orange", "orbit", "orchestra", "order", "ordered", "ordering", "orders", "ordinance", "ordinary", "oregon", "org", "organ", "organic", "organisation", "organisations", "organised", "organisms", "organization", "organizational", "organizations", "organize", "organized", "organizer", "organizing", "orgasm", "orgy", "oriental", "orientation", "oriented", "origin", "original", "originally", "origins", "orlando", "orleans", "os", "oscar", "ot", "other", "others", "otherwise", "ottawa", "ou", "ought", "our", "ours", "ourselves", "out", "outcome", "outcomes", "outdoor", "outdoors", "outer", "outlet", "outline", "outlined", "outlook", "output", "outputs", "outreach", "outside", "outsourcing", "outstanding", "oval", "oven", "over", "overall", "overcome", "overhead", "overnight", "overseas", "overview", "owen", "own", "owned", "owner", "owners", "ownership", "owns", "oxford", "oxide", "oxygen", "oz", "ozone", "p", "pa", "pac", "pace", "pacific", "pack", "package", "packages", "packaging", "packard", "packed", "packet", "packets", "packing", "packs", "pad", "pads", "page", "pages", "paid", "pain", "painful", "paint", "paintball", "painted", "painting", "paintings", "pair", "pairs", "pakistan", "pal", "palace", "pale", "palestine", "palestinian", "palm", "palmer", "pam", "pamela", "pan", "panama", "panasonic", "panel", "panels", "panic", "panties", "pants", "pantyhose", "paper", "paperback", "paperbacks", "papers", "papua", "par", "para", "parade", "paradise", "paragraph", "paragraphs", "paraguay", "parallel", "parameter", "parameters", "parcel", "parent", "parental", "parenting", "parents", "paris", "parish", "park", "parker", "parking", "parks", "parliament", "parliamentary", "part", "partial", "partially", "participant", "participants", "participate", "participated", "participating", "participation", "particle", "particles", "particular", "particularly", "parties", "partition", "partly", "partner", "partners", "partnership", "partnerships", "parts", "party", "pas", "paso", "pass", "passage", "passed", "passenger", "passengers", "passes", "passing", "passion", "passive", "passport", "password", "passwords", "past", "pasta", "paste", "pastor", "pat", "patch", "patches", "patent", "patents", "path", "pathology", "paths", "patient", "patients", "patio", "patricia", "patrick", "patrol", "pattern", "patterns", "paul", "pavilion", "paxil", "pay", "payable", "payday", "paying", "payment", "payments", "paypal", "payroll", "pays", "pb", "pc", "pci", "pcs", "pct", "pd", "pda", "pdas", "pdf", "pdt", "pe", "peace", "peaceful", "peak", "pearl", "peas", "pediatric", "pee", "peeing", "peer", "peers",\
    "pen", "penalties", "penalty", "pencil", "pendant", "pending", "penetration", "penguin", "peninsula", "penn", "pennsylvania", "penny", "pens", "pension", "pensions", "pentium", "people", "peoples", "pepper", "per", "perceived", "percent", "percentage", "perception", "perfect", "perfectly", "perform", "performance", "performances", "performed", "performer", "performing", "performs", "perfume", "perhaps", "period", "periodic", "periodically", "periods", "peripheral", "peripherals", "perl", "permalink", "permanent", "permission", "permissions", "permit", "permits", "permitted", "perry", "persian", "persistent", "person", "personal", "personality", "personalized", "personally", "personals", "personnel", "persons", "perspective", "perspectives", "perth", "peru", "pest", "pet", "pete", "peter", "petersburg", "peterson", "petite", "petition", "petroleum", "pets", "pf", "pg", "pgp", "ph", "phantom", "pharmaceutical", "pharmaceuticals", "pharmacies", "pharmacology", "pharmacy", "phase", "phases", "phd", "phenomenon", "phentermine", "phi", "phil", "philadelphia", "philip", "philippines", "philips", "phillips", "philosophy", "phoenix", "phone", "phones", "photo", "photograph", "photographer", "photographers", "photographic", "photographs", "photography", "photos", "photoshop", "php", "phpbb", "phrase", "phrases", "phys", "physical", "physically", "physician", "physicians", "physics", "physiology", "pi", "piano", "pic", "pichunter", "pick", "picked", "picking", "picks", "pickup", "picnic", "pics", "picture", "pictures", "pie", "piece", "pieces", "pierce", "pierre", "pig", "pike", "pill", "pillow", "pills", "pilot", "pin", "pine", "ping", "pink", "pins", "pioneer", "pipe", "pipeline", "pipes", "pirates", "piss", "pissing", "pit", "pitch", "pittsburgh", "pix", "pixel", "pixels", "pizza", "pj", "pk", "pl", "place", "placed", "placement", "places", "placing", "plain", "plains", "plaintiff", "plan", "plane", "planes", "planet", "planets", "planned", "planner", "planners", "planning", "plans", "plant", "plants", "plasma", "plastic", "plastics", "plate", "plates", "platform", "platforms", "platinum", "play", "playback", "playboy", "played", "player", "players", "playing", "playlist", "plays", "playstation", "plaza", "plc", "pleasant", "please", "pleased", "pleasure", "pledge", "plenty", "plot", "plots", "plug", "plugin", "plugins", "plumbing", "plus", "plymouth", "pm", "pmc", "pmid", "pn", "po", "pocket", "pockets", "pod", "podcast", "podcasts", "poem", "poems", "poet", "poetry", "point", "pointed", "pointer", "pointing", "points", "pokemon", "poker", "poland", "polar", "pole", "police", "policies", "policy", "polish", "polished", "political", "politicians", "politics", "poll", "polls", "pollution", "polo", "poly", "polyester", "polymer", "polyphonic", "pond", "pontiac", "pool", "pools", "poor", "pop", "pope", "popular", "popularity", "population", "populations", "por", "porcelain", "pork", "porsche", "port", "portable", "portal", "porter", "portfolio", "portion", "portions", "portland", "portrait", "portraits", "ports", "portsmouth", "portugal", "portuguese", "pos", "pose", "posing", "position", "positioning", "positions", "positive", "possess", "possession", "possibilities", "possibility", "possible", "possibly", "post", "postage", "postal", "postcard", "postcards", "posted", "poster", "posters", "posting", "postings", "postposted", "posts", "pot", "potato", "potatoes", "potential", "potentially", "potter", "pottery", "poultry", "pound", "pounds", "pour", "poverty", "powder", "powell", "power", "powered", "powerful", "powerpoint", "powers", "powerseller", "pp", "ppc", "ppm", "pr", "practical", "practice", "practices", "practitioner", "practitioners", "prague", "prairie", "praise", "pray", "prayer", "prayers", "pre", "preceding", "precious", "precipitation", "precise", "precisely", "precision", "predict", "predicted", "prediction", "predictions", "prefer", "preference", "preferences", "preferred", "prefers", "prefix", "pregnancy", "pregnant", "preliminary", "premier", "premiere", "premises", "premium", "prep", "prepaid", "preparation", "prepare", "prepared", "preparing", "prerequisite", "prescribed", "prescription", "presence", "present", "presentation", "presentations", "presented", "presenting", "presently", "presents", "preservation", "preserve", "president", "presidential", "press", "pressed", "pressing", "pressure", "preston", "pretty", "prev", "prevent", "preventing", "prevention", "preview", "previews", "previous", "previously", "price", "priced", "prices", "pricing", "pride", "priest", "primarily", "primary", "prime", "prince", "princess", "princeton", "principal", "principle", "principles", "print", "printable", "printed", "printer", "printers", "printing", "prints", "prior", "priorities", "priority", "prison", "prisoner", "prisoners", "privacy", "private", "privilege", "privileges", "prix", "prize", "prizes", "pro", "probability", "probably", "probe", "problem", "problems", "proc", "procedure", "procedures", "proceed", "proceeding", "proceedings", "proceeds", "process", "processed", "processes", "processing", "processor", "processors", "procurement", "produce", "produced", "producer", "producers", "produces", "producing", "product", "production", "productions", "productive", "productivity", "products", "prof", "profession", "professional", "professionals", "professor", "profile", "profiles", "profit", "profits", "program", "programme", "programmer", "programmers", "programmes", "programming", "programs", "progress", "progressive", "prohibited", "project", "projected", "projection", "projector",\
    "projectors", "projects", "prominent", "promise", "promised", "promises", "promising", "promo", "promote", "promoted", "promotes", "promoting", "promotion", "promotional", "promotions", "prompt", "promptly", "proof", "propecia", "proper", "properly", "properties", "property", "prophet", "proportion", "proposal", "proposals", "propose", "proposed", "proposition", "proprietary", "pros", "prospect", "prospective", "prospects", "prostate", "prostores", "prot", "protect", "protected", "protecting", "protection", "protective", "protein", "proteins", "protest", "protocol", "protocols", "prototype", "proud", "proudly", "prove", "proved", "proven", "provide", "provided", "providence", "provider", "providers", "provides", "providing", "province", "provinces", "provincial", "provision", "provisions", "proxy", "prozac", "ps", "psi", "psp", "pst", "psychiatry", "psychological", "psychology", "pt", "pts", "pty", "pub", "public", "publication", "publications", "publicity", "publicly", "publish", "published", "publisher", "publishers", "publishing", "pubmed", "pubs", "puerto", "pull", "pulled", "pulling", "pulse", "pump", "pumps", "punch", "punishment", "punk", "pupils", "puppy", "purchase", "purchased", "purchases", "purchasing", "pure", "purple", "purpose", "purposes", "purse", "pursuant", "pursue", "pursuit", "push", "pushed", "pushing", "pussy", "put", "puts", "putting", "puzzle", "puzzles", "pvc", "python", "q", "qatar", "qc", "qld", "qt", "qty", "quad", "qualification", "qualifications", "qualified", "qualify", "qualifying", "qualities", "quality", "quantitative", "quantities", "quantity", "quantum", "quarter", "quarterly", "quarters", "que", "quebec", "queen", "queens", "queensland", "queries", "query", "quest", "question", "questionnaire", "questions", "queue", "qui", "quick", "quickly", "quiet", "quilt", "quit", "quite", "quiz", "quizzes", "quotations", "quote", "quoted", "quotes", "r", "ra", "rabbit", "race", "races", "rachel", "racial", "racing", "rack", "racks", "radar", "radiation", "radical", "radio", "radios", "radius", "rage", "raid", "rail", "railroad", "railway", "rain", "rainbow", "raise", "raised", "raises", "raising", "raleigh", "rally", "ralph", "ram", "ran", "ranch", "rand", "random", "randy", "range", "rangers", "ranges", "ranging", "rank", "ranked", "ranking", "rankings", "ranks", "rap", "rape", "rapid", "rapidly", "rapids", "rare", "rarely", "rat", "rate", "rated", "rates", "rather", "rating", "ratings", "ratio", "rational", "ratios", "rats", "raw", "ray", "raymond", "rays", "rb", "rc", "rca", "rd", "re", "reach", "reached", "reaches", "reaching", "reaction", "reactions", "read", "reader", "readers", "readily", "reading", "readings", "reads", "ready", "real", "realistic", "reality", "realize", "realized", "really", "realm", "realtor", "realtors", "realty", "rear", "reason", "reasonable", "reasonably", "reasoning", "reasons", "rebate", "rebates", "rebecca", "rebel", "rebound", "rec", "recall", "receipt", "receive", "received", "receiver", "receivers", "receives", "receiving", "recent", "recently", "reception", "receptor", "receptors", "recipe", "recipes", "recipient", "recipients", "recognised", "recognition", "recognize", "recognized", "recommend", "recommendation", "recommendations", "recommended", "recommends", "reconstruction", "record", "recorded", "recorder", "recorders", "recording", "recordings", "records", "recover", "recovered", "recovery", "recreation", "recreational", "recruiting", "recruitment", "recycling", "red", "redeem", "redhead", "reduce", "reduced", "reduces", "reducing", "reduction", "reductions", "reed", "reef", "reel", "ref", "refer", "reference", "referenced", "references", "referral", "referrals", "referred", "referring", "refers", "refinance", "refine", "refined", "reflect", "reflected", "reflection", "reflections", "reflects", "reform", "reforms", "refresh", "refrigerator", "refugees", "refund", "refurbished", "refuse", "refused", "reg", "regard", "regarded", "regarding", "regardless", "regards", "reggae", "regime", "region", "regional", "regions", "register", "registered", "registrar", "registration", "registry", "regression", "regular", "regularly", "regulated", "regulation", "regulations", "regulatory", "rehab", "rehabilitation", "reid", "reject", "rejected", "rel", "relate", "related", "relates", "relating", "relation", "relations", "relationship", "relationships", "relative", "relatively", "relatives", "relax", "relaxation", "relay", "release", "released", "releases", "relevance", "relevant", "reliability", "reliable", "reliance", "relief", "religion", "religions", "religious", "reload", "relocation", "rely", "relying", "remain", "remainder", "remained", "remaining", "remains", "remark", "remarkable", "remarks", "remedies", "remedy", "remember", "remembered", "remind", "reminder", "remix", "remote", "removable", "removal", "remove", "removed", "removing", "renaissance", "render", "rendered", "rendering", "renew", "renewable", "renewal", "reno", "rent", "rental", "rentals", "rentcom", "rep", "repair", "repairs", "repeat", "repeated", "replace", "replaced", "replacement", "replacing", "replica", "replication", "replied", "replies", "reply", "report", "reported", "reporter", "reporters", "reporting", "reports", "repository", "represent", "representation", "representations", "representative", "representatives", "represented", "representing", "represents", "reprint", "reprints", "reproduce", "reproduced", "reproduction", "reproductive", "republic", "republican", "republicans", "reputation", "request", "requested", "requesting", "requests", "require", "required", "requirement", "requirements",\
    "requires", "requiring", "res", "rescue", "research", "researcher", "researchers", "reseller", "reservation", "reservations", "reserve", "reserved", "reserves", "reservoir", "reset", "residence", "resident", "residential", "residents", "resist", "resistance", "resistant", "resolution", "resolutions", "resolve", "resolved", "resort", "resorts", "resource", "resources", "respect", "respected", "respective", "respectively", "respiratory", "respond", "responded", "respondent", "respondents", "responding", "response", "responses", "responsibilities", "responsibility", "responsible", "rest", "restaurant", "restaurants", "restoration", "restore", "restored", "restrict", "restricted", "restriction", "restrictions", "restructuring", "result", "resulted", "resulting", "results", "resume", "resumes", "retail", "retailer", "retailers", "retain", "retained", "retention", "retired", "retirement", "retreat", "retrieval", "retrieve", "retrieved", "retro", "return", "returned", "returning", "returns", "reunion", "reuters", "rev", "reveal", "revealed", "reveals", "revelation", "revenge", "revenue", "revenues", "reverse", "review", "reviewed", "reviewer", "reviewing", "reviews", "revised", "revision", "revisions", "revolution", "revolutionary", "reward", "rewards", "reynolds", "rf", "rfc", "rg", "rh", "rhode", "rhythm", "ri", "ribbon", "rica", "rice", "rich", "richard", "richards", "richardson", "richmond", "rick", "rico", "rid", "ride", "rider", "riders", "rides", "ridge", "riding", "right", "rights", "rim", "ring", "rings", "ringtone", "ringtones", "rio", "rip", "ripe", "rise", "rising", "risk", "risks", "river", "rivers", "riverside", "rj", "rl", "rm", "rn", "rna", "ro", "road", "roads", "rob", "robert", "roberts", "robertson", "robin", "robinson", "robot", "robots", "robust", "rochester", "rock", "rocket", "rocks", "rocky", "rod", "roger", "rogers", "roland", "role", "roles", "roll", "rolled", "roller", "rolling", "rolls", "rom", "roman", "romance", "romania", "romantic", "rome", "ron", "ronald", "roof", "room", "roommate", "roommates", "rooms", "root", "roots", "rope", "rosa", "rose", "roses", "ross", "roster", "rotary", "rotation", "rouge", "rough", "roughly", "roulette", "round", "rounds", "route", "router", "routers", "routes", "routine", "routines", "routing", "rover", "row", "rows", "roy", "royal", "royalty", "rp", "rpg", "rpm", "rr", "rrp", "rs", "rss", "rt", "ru", "rubber", "ruby", "rug", "rugby", "rugs", "rule", "ruled", "rules", "ruling", "run", "runner", "running", "runs", "runtime", "rural", "rush", "russell", "russia", "russian", "ruth", "rv", "rw", "rwanda", "rx", "ryan", "s", "sa", "sacramento", "sacred", "sacrifice", "sad", "saddam", "safari", "safe", "safely", "safer", "safety", "sage", "sagem", "said", "sail", "sailing", "saint", "saints", "sake", "salad", "salaries", "salary", "sale", "salem", "sales", "sally", "salmon", "salon", "salt", "salvador", "salvation", "sam", "samba", "same", "samoa", "sample", "samples", "sampling", "samsung", "samuel", "san", "sand", "sandra", "sandwich", "sandy", "sans", "santa", "sanyo", "sao", "sap", "sapphire", "sara", "sarah", "sas", "saskatchewan", "sat", "satellite", "satin", "satisfaction", "satisfactory", "satisfied", "satisfy", "saturday", "saturn", "sauce", "saudi", "savage", "savannah", "save", "saved", "saver", "saves", "saving", "savings", "saw", "say", "saying", "says", "sb", "sbjct", "sc", "scale", "scales", "scan", "scanned", "scanner", "scanners", "scanning", "scary", "scenario", "scenarios", "scene", "scenes", "scenic", "schedule", "scheduled", "schedules", "scheduling", "schema", "scheme", "schemes", "scholar", "scholars", "scholarship", "scholarships", "school", "schools", "sci", "science", "sciences", "scientific", "scientist", "scientists", "scoop", "scope", "score", "scored", "scores", "scoring", "scotia", "scotland", "scott", "scottish", "scout", "scratch", "screen", "screening", "screens", "screensaver", "screensavers", "screenshot", "screenshots", "screw", "script", "scripting", "scripts", "scroll", "scsi", "scuba", "sculpture", "sd", "se", "sea", "seafood", "seal", "sealed", "sean", "search", "searchcom", "searched", "searches", "searching", "seas", "season", "seasonal", "seasons", "seat", "seating", "seats", "seattle", "sec", "second", "secondary", "seconds", "secret", "secretariat", "secretary", "secrets", "section", "sections", "sector", "sectors", "secure", "secured", "securely", "securities", "security", "see", "seed", "seeds", "seeing", "seek", "seeker", "seekers", "seeking", "seeks", "seem", "seemed", "seems", "seen", "sees", "sega", "segment", "segments", "select", "selected", "selecting", "selection", "selections", "selective", "self", "sell", "seller", "sellers", "selling", "sells", "semester", "semi", "semiconductor", "seminar", "seminars", "sen", "senate", "senator", "senators", "send", "sender", "sending", "sends", "senegal", "senior", "seniors", "sense", "sensitive", "sensitivity", "sensor", "sensors", "sent", "sentence", "sentences", "seo", "sep", "separate", "separated", "separately", "separation", "sept", "september", "seq", "sequence", "sequences", "ser", "serbia", "serial", "series", "serious",\
    "seriously", "serum", "serve", "served", "server", "servers", "serves", "service", "services", "serving", "session", "sessions", "set", "sets", "setting", "settings", "settle", "settled", "settlement", "setup", "seven", "seventh", "several", "severe", "sewing", "sexo", "sexual", "sexuality", "sexually", "sexy", "sf", "sg", "sh", "shade", "shades", "shadow", "shadows", "shaft", "shake", "shakespeare", "shakira", "shall", "shame", "shanghai", "shannon", "shape", "shaped", "shapes", "share", "shared", "shareholders", "shares", "shareware", "sharing", "shark", "sharon", "sharp", "shaved", "shaw", "she", "shed", "sheep", "sheer", "sheet", "sheets", "sheffield", "shelf", "shell", "shelter", "shepherd", "sheriff", "sherman", "shield", "shift", "shine", "ship", "shipment", "shipments", "shipped", "shipping", "ships", "shirt", "shirts", "shit", "shock", "shoe", "shoes", "shoot", "shooting", "shop", "shopper", "shoppercom", "shoppers", "shopping", "shoppingcom", "shops", "shopzilla", "shore", "short", "shortcuts", "shorter", "shortly", "shorts", "shot", "shots", "should", "shoulder", "show", "showcase", "showed", "shower", "showers", "showing", "shown", "shows", "showtimes", "shut", "shuttle", "si", "sic", "sick", "side", "sides", "sie", "siemens", "sierra", "sig", "sight", "sigma", "sign", "signal", "signals", "signature", "signatures", "signed", "significance", "significant", "significantly", "signing", "signs", "signup", "silence", "silent", "silicon", "silk", "silly", "silver", "sim", "similar", "similarly", "simon", "simple", "simplified", "simply", "simpson", "simpsons", "sims", "simulation", "simulations", "simultaneously", "sin", "since", "sing", "singapore", "singer", "singh", "singing", "single", "singles", "sink", "sip", "sir", "sister", "sisters", "sit", "site", "sitemap", "sites", "sitting", "situated", "situation", "situations", "six", "sixth", "size", "sized", "sizes", "sk", "skating", "ski", "skiing", "skill", "skilled", "skills", "skin", "skins", "skip", "skirt", "skirts", "sku", "sky", "skype", "sl", "slave", "sleep", "sleeping", "sleeps", "sleeve", "slide", "slides", "slideshow", "slight", "slightly", "slim", "slip", "slope", "slot", "slots", "slovak", "slovakia", "slovenia", "slow", "slowly", "sm", "small", "smaller", "smart", "smell", "smile", "smilies", "smith", "smithsonian", "smoke", "smoking", "smooth", "sms", "smtp", "sn", "snake", "snap", "snapshot", "snow", "snowboard", "so", "soa", "soap", "soc", "soccer", "social", "societies", "society", "sociology", "socket", "socks", "sodium", "sofa", "soft", "softball", "software", "soil", "sol", "solar", "solaris", "sold", "soldier", "soldiers", "sole", "solely", "solid", "solo", "solomon", "solution", "solutions", "solve", "solved", "solving", "soma", "somalia", "some", "somebody", "somehow", "someone", "somerset", "something", "sometimes", "somewhat", "somewhere", "son", "song", "songs", "sonic", "sons", "sony", "soon", "soonest", "sophisticated", "sorry", "sort", "sorted", "sorts", "sought", "soul", "souls", "sound", "sounds", "soundtrack", "soup", "source", "sources", "south", "southampton", "southeast", "southern", "southwest", "soviet", "sox", "sp", "spa", "space", "spaces", "spain", "spam", "span", "spanish", "spank", "spanking", "sparc", "spare", "spas", "spatial", "speak", "speaker", "speakers", "speaking", "speaks", "spears", "spec", "special", "specialist", "specialists", "specialized", "specializing", "specially", "specials", "specialties", "specialty", "species", "specific", "specifically", "specification", "specifications", "specifics", "specified", "specifies", "specify", "specs", "spectacular", "spectrum", "speech", "speeches", "speed", "speeds", "spell", "spelling", "spencer", "spend", "spending", "spent", "sphere", "spice", "spider", "spies", "spin", "spine", "spirit", "spirits", "spiritual", "spirituality", "split", "spoke", "spoken", "spokesman", "sponsor", "sponsored", "sponsors", "sponsorship", "sport", "sporting", "sports", "spot", "spotlight", "spots", "spouse", "spray", "spread", "spreading", "spring", "springer", "springfield", "springs", "sprint", "spy", "spyware", "sq", "sql", "squad", "square", "squirt", "squirting", "sr", "src", "sri", "ss", "ssl", "st", "stability", "stable", "stack", "stadium", "staff", "staffing", "stage", "stages", "stainless", "stakeholders", "stamp", "stamps", "stan", "stand", "standard", "standards", "standing", "standings", "stands", "stanford", "stanley", "star", "starring", "stars", "starsmerchant", "start", "started", "starter", "starting", "starts", "startup", "stat", "state", "stated", "statement", "statements", "states", "statewide", "static", "stating", "station", "stationery", "stations", "statistical", "statistics", "stats", "status", "statute", "statutes", "statutory", "stay", "stayed", "staying", "stays", "std", "ste", "steady", "steal", "steam", "steel", "steering", "stem", "step", "stephanie", "stephen", "steps", "stereo", "sterling", "steve", "steven", "stevens", "stewart", "stick", "sticker", "stickers", "sticks", "sticky", "still",\
    "stock", "stockholm", "stockings", "stocks", "stolen", "stomach", "stone", "stones", "stood", "stop", "stopped", "stopping", "stops", "storage", "store", "stored", "stores", "stories", "storm", "story", "str", "straight", "strain", "strand", "strange", "stranger", "strap", "strategic", "strategies", "strategy", "stream", "streaming", "streams", "street", "streets", "strength", "strengthen", "strengthening", "strengths", "stress", "stretch", "strict", "strictly", "strike", "strikes", "striking", "string", "strings", "strip", "stripes", "strips", "stroke", "strong", "stronger", "strongly", "struck", "struct", "structural", "structure", "structured", "structures", "struggle", "stuart", "stuck", "stud", "student", "students", "studied", "studies", "studio", "studios", "study", "studying", "stuff", "stuffed", "stunning", "stupid", "style", "styles", "stylish", "stylus", "su", "sub", "subaru", "subcommittee", "subdivision", "subject", "subjects", "sublime", "sublimedirectory", "submission", "submissions", "submit", "submitted", "submitting", "subscribe", "subscriber", "subscribers", "subscription", "subscriptions", "subsection", "subsequent", "subsequently", "subsidiaries", "subsidiary", "substance", "substances", "substantial", "substantially", "substitute", "subtle", "suburban", "succeed", "success", "successful", "successfully", "such", "suck", "sucking", "sucks", "sudan", "sudden", "suddenly", "sue", "suffer", "suffered", "suffering", "sufficient", "sufficiently", "sugar", "suggest", "suggested", "suggesting", "suggestion", "suggestions", "suggests", "suicide", "suit", "suitable", "suite", "suited", "suites", "suits", "sullivan", "sum", "summaries", "summary", "summer", "summit", "sun", "sunday", "sunglasses", "sunny", "sunrise", "sunset", "sunshine", "super", "superb", "superintendent", "superior", "supervision", "supervisor", "supervisors", "supplement", "supplemental", "supplements", "supplied", "supplier", "suppliers", "supplies", "supply", "support", "supported", "supporters", "supporting", "supports", "suppose", "supposed", "supreme", "sur", "sure", "surely", "surf", "surface", "surfaces", "surfing", "surge", "surgeon", "surgeons", "surgery", "surgical", "surname", "surplus", "surprise", "surprised", "surprising", "surrey", "surround", "surrounded", "surrounding", "surveillance", "survey", "surveys", "survival", "survive", "survivor", "survivors", "susan", "suse", "suspect", "suspected", "suspended", "suspension", "sussex", "sustainability", "sustainable", "sustained", "suzuki", "sv", "sw", "swap", "sweden", "swedish", "sweet", "swift", "swim", "swimming", "swing", "swingers", "swiss", "switch", "switched", "switches", "switching", "switzerland", "sword", "sydney", "symantec", "symbol", "symbols", "sympathy", "symphony", "symposium", "symptoms", "sync", "syndicate", "syndication", "syndrome", "synopsis", "syntax", "synthesis", "synthetic", "syracuse", "syria", "sys", "system", "systematic", "systems", "t", "ta", "tab", "table", "tables", "tablet", "tablets", "tabs", "tackle", "tactics", "tag", "tagged", "tags", "tahoe", "tail", "taiwan", "take", "taken", "takes", "taking", "tale", "talent", "talented", "tales", "talk", "talked", "talking", "talks", "tall", "tamil", "tampa", "tan", "tank", "tanks", "tanzania", "tap", "tape", "tapes", "tar", "target", "targeted", "targets", "tariff", "task", "tasks", "taste", "tattoo", "taught", "tax", "taxation", "taxes", "taxi", "taylor", "tb", "tba", "tc", "tcp", "td", "te", "tea", "teach", "teacher", "teachers", "teaches", "teaching", "team", "teams", "tear", "tears", "tech", "technical", "technician", "technique", "techniques", "techno", "technological", "technologies", "technology", "techrepublic", "ted", "teddy", "tee", "teen", "teenage", "teens", "teeth", "tel", "telecharger", "telecom", "telecommunications", "telephone", "telephony", "telescope", "television", "televisions", "tell", "telling", "tells", "temp", "temperature", "temperatures", "template", "templates", "temple", "temporal", "temporarily", "temporary", "ten", "tenant", "tend", "tender", "tennessee", "tennis", "tension", "tent", "term", "terminal", "terminals", "termination", "terminology", "terms", "terrace", "terrain", "terrible", "territories", "territory", "terror", "terrorism", "terrorist", "terrorists", "terry", "test", "testament", "tested", "testimonials", "testimony", "testing", "tests", "tex", "texas", "text", "textbook", "textbooks", "textile", "textiles", "texts", "texture", "tf", "tft", "tgp", "th", "thai", "thailand", "than", "thank", "thanks", "thanksgiving", "that", "thats", "the", "theater", "theaters", "theatre", "thee", "theft", "thehun", "their", "them", "theme", "themes", "themselves", "then", "theology", "theorem", "theoretical", "theories", "theory", "therapeutic", "therapist", "therapy", "there", "thereafter", "thereby", "therefore", "thereof", "thermal", "thesaurus", "these", "thesis", "they", "thick", "thickness", "thin", "thing", "things", "think", "thinking", "thinkpad", "thinks", "third", "thirty", "this", "thomas", "thompson", "thomson", "thong", "thongs", "thorough", "thoroughly", "those", "thou", "though", "thought", "thoughts", "thousand", "thousands", "thread", "threaded", "threads", "threat", "threatened", "threatening", "threats", "three", "threesome", "threshold", "thriller", "throat", "through", "throughout", "throw", "throwing", "thrown", "throws", "thru", "thu", "thumb", "thumbnail", "thumbnails", "thumbs", "thumbzilla", "thunder",\
    "thursday", "thus", "thy", "ti", "ticket", "tickets", "tide", "tie", "tied", "tier", "ties", "tiffany", "tiger", "tigers", "tight", "til", "tile", "tiles", "till", "tim", "timber", "time", "timeline", "timely", "timer", "times", "timing", "timothy", "tin", "tiny", "tion", "tions", "tip", "tips", "tire", "tired", "tires", "tissue", "tit", "titanium", "titans", "title", "titled", "titles", "titten", "tm", "tmp", "tn", "to", "tobacco", "tobago", "today", "todd", "toddler", "toe", "together", "toilet", "token", "tokyo", "told", "tolerance", "toll", "tom", "tomato", "tomatoes", "tommy", "tomorrow", "ton", "tone", "toner", "tones", "tongue", "tonight", "tons", "tony", "too", "took", "tool", "toolbar", "toolbox", "toolkit", "tools", "tooth", "top", "topic", "topics", "topless", "tops", "toronto", "torture", "toshiba", "total", "totally", "totals", "touch", "touched", "tough", "tour", "touring", "tourism", "tourist", "tournament", "tournaments", "tours", "toward", "towards", "tower", "towers", "town", "towns", "township", "toxic", "toy", "toyota", "toys", "tp", "tr", "trace", "track", "trackback", "trackbacks", "tracked", "tracker", "tracking", "tracks", "tract", "tractor", "tracy", "trade", "trademark", "trademarks", "trader", "trades", "trading", "tradition", "traditional", "traditions", "traffic", "tragedy", "trail", "trailer", "trailers", "trails", "train", "trained", "trainer", "trainers", "training", "trains", "tramadol", "trance", "transaction", "transactions", "transcript", "transcription", "transcripts", "transfer", "transferred", "transfers", "transform", "transformation", "transit", "transition", "translate", "translated", "translation", "translations", "translator", "transmission", "transmit", "transmitted", "transparency", "transparent", "transport", "transportation", "transsexual", "trap", "trash", "trauma", "travel", "traveler", "travelers", "traveling", "traveller", "travelling", "travels", "travesti", "travis", "tray", "treasure", "treasurer", "treasures", "treasury", "treat", "treated", "treating", "treatment", "treatments", "treaty", "tree", "trees", "trek", "trembl", "tremendous", "trend", "trends", "treo", "tri", "trial", "trials", "triangle", "tribal", "tribe", "tribes", "tribunal", "tribune", "tribute", "trick", "tricks", "tried", "tries", "trigger", "trim", "trinidad", "trinity", "trio", "trip", "tripadvisor", "triple", "trips", "triumph", "trivia", "troops", "tropical", "trouble", "troubleshooting", "trout", "troy", "truck", "trucks", "true", "truly", "trunk", "trust", "trusted", "trustee", "trustees", "trusts", "truth", "try", "trying", "ts", "tsunami", "tt", "tu", "tub", "tube", "tubes", "tucson", "tue", "tuesday", "tuition", "tulsa", "tumor", "tune", "tuner", "tunes", "tuning", "tunisia", "tunnel", "turbo", "turkey", "turkish", "turn", "turned", "turner", "turning", "turns", "turtle", "tutorial", "tutorials", "tv", "tvcom", "tvs", "twelve", "twenty", "twice", "twiki", "twin", "twinks", "twins", "twist", "twisted", "two", "tx", "ty", "tyler", "type", "types", "typical", "typically", "typing", "u", "uc", "uganda", "ugly", "uh", "ui", "uk", "ukraine", "ul", "ultimate", "ultimately", "ultra", "ultram", "um", "un", "una", "unable", "unauthorized", "unavailable", "uncertainty", "uncle", "und", "undefined", "under", "undergraduate", "underground", "underlying", "understand", "understanding", "understood", "undertake", "undertaken", "underwear", "undo", "une", "unemployment", "unexpected", "unfortunately", "uni", "unified", "uniform", "union", "unions", "uniprotkb", "unique", "unit", "united", "units", "unity", "univ", "universal", "universe", "universities", "university", "unix", "unknown", "unless", "unlike", "unlikely", "unlimited", "unlock", "unnecessary", "unsigned", "unsubscribe", "until", "untitled", "unto", "unusual", "unwrap", "up", "upc", "upcoming", "update", "updated", "updates", "updating", "upgrade", "upgrades", "upgrading", "upload", "uploaded", "upon", "upper", "ups", "upset", "upskirt", "upskirts", "ur", "urban", "urge", "urgent", "uri", "url", "urls", "uruguay", "urw", "us", "usa", "usage", "usb", "usc", "usd", "usda", "use", "used", "useful", "user", "username", "users", "uses", "usgs", "using", "usps", "usr", "usual", "usually", "ut", "utah", "utc", "utilities", "utility", "utilization", "utilize", "utils", "uv", "uw", "uzbekistan", "v", "va", "vacancies", "vacation", "vacations", "vaccine", "vacuum", "vagina", "val", "valentine", "valid", "validation", "validity", "valium", "valley", "valuable", "valuation", "value", "valued", "values", "valve", "valves", "vampire", "van", "vancouver", "vanilla", "var", "variable", "variables", "variance", "variation", "variations", "varied", "varies", "variety", "various", "vary", "varying", "vast", "vat", "vatican", "vault", "vb", "vbulletin", "vc", "vcr", "ve", "vector", "vegas", "vegetable", "vegetables", "vegetarian", "vegetation", "vehicle", "vehicles", "velocity", "velvet", "vendor", "vendors", "venezuela", "venice", "venture", "ventures", "venue", "venues", "ver",\
    "verbal", "verde", "verification", "verified", "verify", "verizon", "vermont", "vernon", "verse", "version", "versions", "versus", "vertex", "vertical", "very", "verzeichnis", "vessel", "vessels", "veteran", "veterans", "veterinary", "vg", "vhs", "vi", "via", "viagra", "vibrator", "vibrators", "vic", "vice", "victim", "victims", "victor", "victoria", "victorian", "victory", "vid", "video", "videos", "vids", "vienna", "vietnam", "vietnamese", "view", "viewed", "viewer", "viewers", "viewing", "viewpicture", "views", "vii", "viii", "viking", "villa", "village", "villages", "villas", "vincent", "vintage", "vinyl", "violation", "violations", "violence", "violent", "violin", "vip", "viral", "virgin", "virginia", "virtual", "virtually", "virtue", "virus", "viruses", "visa", "visibility", "visible", "vision", "visit", "visited", "visiting", "visitor", "visitors", "visits", "vista", "visual", "vital", "vitamin", "vitamins", "vocabulary", "vocal", "vocals", "vocational", "voice", "voices", "void", "voip", "vol", "volkswagen", "volleyball", "volt", "voltage", "volume", "volumes", "voluntary", "volunteer", "volunteers", "volvo", "von", "vote", "voted", "voters", "votes", "voting", "voyeur", "voyeurweb", "voyuer", "vp", "vpn", "vs", "vsnet", "vt", "vulnerability", "vulnerable", "w", "wa", "wage", "wages", "wagner", "wagon", "wait", "waiting", "waiver", "wake", "wal", "wales", "walk", "walked", "walker", "walking", "walks", "wall", "wallace", "wallet", "wallpaper", "wallpapers", "walls", "walnut", "walt", "walter", "wan", "wang", "wanna", "want", "wanted", "wanting", "wants", "war", "warcraft", "ward", "ware", "warehouse", "warm", "warming", "warned", "warner", "warning", "warnings", "warrant", "warranties", "warranty", "warren", "warrior", "warriors", "wars", "was", "wash", "washer", "washing", "washington", "waste", "watch", "watched", "watches", "watching", "water", "waterproof", "waters", "watershed", "watson", "watt", "watts", "wav", "wave", "waves", "wax", "way", "wayne", "ways", "wb", "wc", "we", "weak", "wealth", "weapon", "weapons", "wear", "wearing", "weather", "web", "webcam", "webcams", "webcast", "weblog", "weblogs", "webmaster", "webmasters", "webpage", "webshots", "website", "websites", "webster", "wed", "wedding", "weddings", "wednesday", "weed", "week", "weekend", "weekends", "weekly", "weeks", "weight", "weighted", "weights", "weird", "welcome", "welding", "welfare", "well", "wellington", "wellness", "wells", "welsh", "wendy", "went", "were", "wesley", "west", "western", "westminster", "wet", "whale", "what", "whatever", "whats", "wheat", "wheel", "wheels", "when", "whenever", "where", "whereas", "wherever", "whether", "which", "while", "whilst", "white", "who", "whole", "wholesale", "whom", "whose", "why", "wi", "wichita", "wicked", "wide", "widely", "wider", "widescreen", "widespread", "width", "wife", "wifi", "wiki", "wikipedia", "wild", "wilderness", "wildlife", "wiley", "will", "william", "williams", "willing", "willow", "wilson", "win", "wind", "window", "windows", "winds", "windsor", "wine", "wines", "wing", "wings", "winner", "winners", "winning", "wins", "winston", "winter", "wire", "wired", "wireless", "wires", "wiring", "wisconsin", "wisdom", "wise", "wish", "wishes", "wishlist", "wit", "witch", "with", "withdrawal", "within", "without", "witness", "witnesses", "wives", "wizard", "wm", "wma", "wn", "wolf", "woman", "women", "womens", "won", "wonder", "wonderful", "wondering", "wood", "wooden", "woods", "wool", "worcester", "word", "wordpress", "words", "work", "worked", "worker", "workers", "workflow", "workforce", "working", "workout", "workplace", "works", "workshop", "workshops", "workstation", "world", "worldcat", "worlds", "worldsex", "worldwide", "worm", "worn", "worried", "worry", "worse", "worship", "worst", "worth", "worthy", "would", "wound", "wow", "wp", "wr", "wrap", "wrapped", "wrapping", "wrestling", "wright", "wrist", "write", "writer", "writers", "writes", "writing", "writings", "written", "wrong", "wrote", "ws", "wt", "wto", "wu", "wv", "ww", "www", "wx", "wy", "wyoming", "x", "xanax", "xbox", "xerox", "xhtml", "xi", "xl", "xml", "xnxx", "xp", "xx", "xxx", "y", "ya", "yacht", "yahoo", "yale", "yamaha", "yang", "yard", "yards", "yarn", "ye", "yea", "yeah", "year", "yearly", "years", "yeast", "yellow", "yemen", "yen", "yes", "yesterday", "yet", "yield", "yields", "yn", "yo", "yoga", "york", "yorkshire", "you", "young", "younger", "your", "yours", "yourself", "youth", "yr", "yrs", "yu", "yugoslavia", "yukon", "z", "za", "zambia", "zdnet", "zealand", "zen", "zero", "zimbabwe", "zinc", "zip", "zoloft", "zone", "zones", "zoning", "zoo", "zoom", "zoophilia", "zope", "zshops", "zu", "zum", "zus",\
    "the", "of", "and", "to", "a", "in", "for", "is", "on", "that", "by", "this", "with", "i", "you", "it", "not", "or", "be", "are", "from", "at", "as", "your", "all", "have", "new", "more", "an", "was", "we", "will", "home", "can", "us", "about", "if", "page", "my", "has", "search", "free", "but", "our", "one", "other", "do", "no", "information", "time", "they", "site", "he", "up", "may", "what", "which", "their", "news", "out", "use", "any", "there", "see", "only", "so", "his", "when", "contact", "here", "business", "who", "web", "also", "now", "help", "get", "pm", "view", "online", "c", "e", "first", "am", "been", "would", "how", "were", "me", "s", "services", "some", "these", "click", "its", "like", "service", "x", "than", "find", "price", "date", "back", "top", "people", "had", "list", "name", "just", "over", "state", "year", "day", "into", "email", "two", "health", "n", "world", "re", "next", "used", "go", "b", "work", "last", "most", "products", "music", "buy", "data", "make", "them", "should", "product", "system", "post", "her", "city", "t", "add", "policy", "number", "such", "please", "available", "copyright", "support", "message", "after", "best", "software", "then", "jan", "good", "video", "well", "d", "where", "info", "rights", "public", "books", "high", "school", "through", "m", "each", "links", "she", "review", "years", "order", "very", "privacy", "book", "items", "company", "r", "read", "group", "sex", "need", "many", "user", "said", "de", "does", "set", "under", "general", "research", "university", "january", "mail", "full", "map", "reviews", "program", "life", "know", "games", "way", "days", "management", "p", "part", "could", "great", "united", "hotel", "real", "f", "item", "international", "center", "ebay", "must", "store", "travel", "comments", "made", "development", "report", "off", "member", "details", "line", "terms", "before", "hotels", "did", "send", "right", "type", "because", "local", "those", "using", "results", "office", "education", "national", "car", "design", "take", "posted", "internet", "address", "community", "within", "states", "area", "want", "phone", "dvd", "shipping", "reserved", "subject", "between", "forum", "family", "l", "long", "based", "w", "code", "show", "o", "even", "black", "check", "special", "prices", "website", "index", "being", "women", "much", "sign", "file", "link", "open", "today", "technology", "south", "case", "project", "same", "pages", "uk", "version", "section", "own", "found", "sports", "house", "related", "security", "both", "g", "county", "american", "photo", "game", "members", "power", "while", "care", "network", "down", "computer", "systems", "three", "total", "place", "end", "following", "download", "h", "him", "without", "per", "access", "think", "north", "resources", "current", "posts", "big", "media", "law", "control", "water", "history", "pictures", "size", "art", "personal", "since", "including", "guide", "shop", "directory", "board", "location", "change", "white", "text", "small", "rating", "rate", "government", "children", "during", "usa", "return", "students", "v", "shopping", "account", "times", "sites", "level", "digital", "profile", "previous", "form", "events", "love", "old", "john", "main", "call", "hours", "image", "department", "title", "description", "non", "k", "y", "insurance", "another", "why", "shall", "property", "class", "cd", "still", "money", "quality", "every", "listing", "content", "country", "private", "little", "visit", "save", "tools", "low", "reply", "customer", "december", "compare", "movies", "include", "college", "value", "article", "york", "man", "card", "jobs", "provide", "j", "food", "source", "author", "different", "press", "u", "learn", "sale", "around", "print", "course", "job", "canada", "process", "teen", "room", "stock", "training", "too", "credit", "point", "join", "science", "men", "categories", "advanced", "west", "sales", "look", "english", "left", "team", "estate", "box", "conditions", "select", "windows", "photos", "gay", "thread", "week", "category", "note", "live", "large", "gallery", "table", "register", "however", "june", "october", "november", "market", "library", "really", "action", "start", "series", "model", "features", "air", "industry", "plan", "human", "provided", "tv", "yes", "required", "second", "hot", "accessories", "cost", "movie", "forums", "march", "la", "september", "better", "say", "questions", "july", "yahoo", "going", "medical",\
    "test", "friend", "come", "dec", "server", "pc", "study", "application", "cart", "staff", "articles", "san", "feedback", "again", "play", "looking", "issues", "april", "never", "users", "complete", "street", "topic", "comment", "financial", "things", "working", "against", "standard", "tax", "person", "below", "mobile", "less", "got", "blog", "party", "payment", "equipment", "login", "student", "let", "programs", "offers", "legal", "above", "recent", "park", "stores", "side", "act", "problem", "red", "give", "memory", "performance", "social", "q", "august", "quote", "language", "story", "sell", "options", "experience", "rates", "create", "key", "body", "young", "america", "important", "field", "few", "east", "paper", "single", "ii", "age", "activities", "club", "example", "girls", "additional", "password", "z", "latest", "something", "road", "gift", "question", "changes", "night", "ca", "hard", "texas", "oct", "pay", "four", "poker", "status", "browse", "issue", "range", "building", "seller", "court", "february", "always", "result", "audio", "light", "write", "war", "nov", "offer", "blue", "groups", "al", "easy", "given", "files", "event", "release", "analysis", "request", "fax", "china", "making", "picture", "needs", "possible", "might", "professional", "yet", "month", "major", "star", "areas", "future", "space", "committee", "hand", "sun", "cards", "problems", "london", "washington", "meeting", "rss", "become", "interest", "id", "child", "keep", "enter", "california", "share", "similar", "garden", "schools", "million", "added", "reference", "companies", "listed", "baby", "learning", "energy", "run", "delivery", "net", "popular", "term", "film", "stories", "put", "computers", "journal", "reports", "co", "try", "welcome", "central", "images", "president", "notice", "god", "original", "head", "radio", "until", "cell", "color", "self", "council", "away", "includes", "track", "australia", "discussion", "archive", "once", "others", "entertainment", "agreement", "format", "least", "society", "months", "log", "safety", "friends", "sure", "faq", "trade", "edition", "cars", "messages", "marketing", "tell", "further", "updated", "association", "able", "having", "provides", "david", "fun", "already", "green", "studies", "close", "common", "drive", "specific", "several", "gold", "feb", "living", "sep", "collection", "called", "short", "arts", "lot", "ask", "display", "limited", "powered", "solutions", "means", "director", "daily", "beach", "past", "natural", "whether", "due", "et", "electronics", "five", "upon", "period", "planning", "database", "says", "official", "weather", "mar", "land", "average", "done", "technical", "window", "france", "pro", "region", "island", "record", "direct", "microsoft", "conference", "environment", "records", "st", "district", "calendar", "costs", "style", "url", "front", "statement", "update", "parts", "aug", "ever", "downloads", "early", "miles", "sound", "resource", "present", "applications", "either", "ago", "document", "word", "works", "material", "bill", "apr", "written", "talk", "federal", "hosting", "rules", "final", "adult", "tickets", "thing", "centre", "requirements", "via", "cheap", "nude", "kids", "finance", "true", "minutes", "else", "mark", "third", "rock", "gifts", "europe", "reading", "topics", "bad", "individual", "tips", "plus", "auto", "cover", "usually", "edit", "together", "videos", "percent", "fast", "function", "fact", "unit", "getting", "global", "tech", "meet", "far", "economic", "en", "player", "projects", "lyrics", "often", "subscribe", "submit", "germany", "amount", "watch", "included", "feel", "though", "bank", "risk", "thanks", "everything", "deals", "various", "words", "linux", "jul", "production", "commercial", "james", "weight", "town", "heart", "advertising", "received", "choose", "treatment", "newsletter", "archives", "points", "knowledge", "magazine", "error", "camera", "jun", "girl", "currently", "construction", "toys", "registered", "clear", "golf", "receive", "domain", "methods", "chapter", "makes", "protection", "policies", "loan", "wide", "beauty", "manager", "india", "position", "taken", "sort", "listings", "models", "michael", "known", "half", "cases", "step", "engineering", "florida", "simple", "quick", "none", "wireless", "license", "paul", "friday", "lake", "whole", "annual", "published", "later", "basic", "sony", "shows", "corporate", "google", "church", "method", "purchase", "customers", "active", "response", "practice", "hardware", "figure", "materials", "fire", "holiday", "chat", "enough", "designed", "along", "among", "death", "writing", "speed", "html", "countries", "loss", "face", "brand", "discount", "higher", "effects", "created", "remember", "standards", "oil", "bit", "yellow", "political", "increase", "advertise", "kingdom", "base", "near", "environmental", "thought", "stuff", "french", "storage", "oh", "japan", "doing", "loans", "shoes", "entry", "stay",\
    "nature", "orders", "availability", "africa", "summary", "turn", "mean", "growth", "notes", "agency", "king", "monday", "european", "activity", "copy", "although", "drug", "pics", "western", "income", "force", "cash", "employment", "overall", "bay", "river", "commission", "ad", "package", "contents", "seen", "players", "engine", "port", "album", "regional", "stop", "supplies", "started", "administration", "bar", "institute", "views", "plans", "double", "dog", "build", "screen", "exchange", "types", "soon", "sponsored", "lines", "electronic", "continue", "across", "benefits", "needed", "season", "apply", "someone", "held", "ny", "anything", "printer", "condition", "effective", "believe", "organization", "effect", "asked", "eur", "mind", "sunday", "selection", "casino", "pdf", "lost", "tour", "menu", "volume", "cross", "anyone", "mortgage", "hope", "silver", "corporation", "wish", "inside", "solution", "mature", "role", "rather", "weeks", "addition", "came", "supply", "nothing", "certain", "usr", "executive", "running", "lower", "necessary", "union", "jewelry", "according", "dc", "clothing", "mon", "com", "particular", "fine", "names", "robert", "homepage", "hour", "gas", "skills", "six", "bush", "islands", "advice", "career", "military", "rental", "decision", "leave", "british", "teens", "pre", "huge", "sat", "woman", "facilities", "zip", "bid", "kind", "sellers", "middle", "move", "cable", "opportunities", "taking", "values", "division", "coming", "tuesday", "object", "lesbian", "appropriate", "machine", "logo", "length", "actually", "nice", "score", "statistics", "client", "ok", "returns", "capital", "follow", "sample", "investment", "sent", "shown", "saturday", "christmas", "england", "culture", "band", "flash", "ms", "lead", "george", "choice", "went", "starting", "registration", "fri", "thursday", "courses", "consumer", "hi", "airport", "foreign", "artist", "outside", "furniture", "levels", "channel", "letter", "mode", "phones", "ideas", "wednesday", "structure", "fund", "summer", "allow", "degree", "contract", "button", "releases", "wed", "homes", "super", "male", "matter", "custom", "virginia", "almost", "took", "located", "multiple", "asian", "distribution", "editor", "inn", "industrial", "cause", "potential", "song", "cnet", "ltd", "los", "hp", "focus", "late", "fall", "featured", "idea", "rooms", "female", "responsible", "inc", "communications", "win", "associated", "thomas", "primary", "cancer", "numbers", "reason", "tool", "browser", "spring", "foundation", "answer", "voice", "eg", "friendly", "schedule", "documents", "communication", "purpose", "feature", "bed", "comes", "police", "everyone", "independent", "ip", "approach", "cameras", "brown", "physical", "operating", "hill", "maps", "medicine", "deal", "hold", "ratings", "chicago", "forms", "glass", "happy", "tue", "smith", "wanted", "developed", "thank", "safe", "unique", "survey", "prior", "telephone", "sport", "ready", "feed", "animal", "sources", "mexico", "population", "pa", "regular", "secure", "navigation", "operations", "therefore", "ass", "simply", "evidence", "station", "christian", "round", "paypal", "favorite", "understand", "option", "master", "valley", "recently", "probably", "thu", "rentals", "sea", "built", "publications", "blood", "cut", "worldwide", "improve", "connection", "publisher", "hall", "larger", "anti", "networks", "earth", "parents", "nokia", "impact", "transfer", "introduction", "kitchen", "strong", "tel", "carolina", "wedding", "properties", "hospital", "ground", "overview", "ship", "accommodation", "owners", "disease", "tx", "excellent", "paid", "italy", "perfect", "hair", "opportunity", "kit", "classic", "basis", "command", "cities", "william", "express", "award", "distance", "tree", "peter", "assessment", "ensure", "thus", "wall", "ie", "involved", "el", "extra", "especially", "interface", "pussy", "partners", "budget", "rated", "guides", "success", "maximum", "ma", "operation", "existing", "quite", "selected", "boy", "amazon", "patients", "restaurants", "beautiful", "warning", "wine", "locations", "horse", "vote", "forward", "flowers", "stars", "significant", "lists", "technologies", "owner", "retail", "animals", "useful", "directly", "manufacturer", "ways", "est", "son", "providing", "rule", "mac", "housing", "takes", "iii", "gmt", "bring", "catalog", "searches", "max", "trying", "mother", "authority", "considered", "told", "xml", "traffic", "programme", "joined", "input", "strategy", "feet", "agent", "valid", "bin", "modern", "senior", "ireland", "sexy", "teaching", "door", "grand", "testing", "trial", "charge", "units", "instead", "canadian", "cool", "normal", "wrote", "enterprise", "ships", "entire", "educational", "md", "leading", "metal", "positive", "fl", "fitness", "chinese", "opinion", "mb", "asia", "football", "abstract", "uses", "output", "funds", "mr", "greater", "likely", "develop", "employees", "artists", "alternative", "processing", "responsibility", "resolution", "java", "guest", "seems", "publication", "pass", "relations", "trust", "van", "contains", "session", "multi", "photography", "republic", "fees",\
    "components", "vacation", "century", "academic", "assistance", "completed", "skin", "graphics", "indian", "prev", "ads", "mary", "il", "expected", "ring", "grade", "dating", "pacific", "mountain", "organizations", "pop", "filter", "mailing", "vehicle", "longer", "consider", "int", "northern", "behind", "panel", "floor", "german", "buying", "match", "proposed", "default", "require", "iraq", "boys", "outdoor", "deep", "morning", "otherwise", "allows", "rest", "protein", "plant", "reported", "hit", "transportation", "mm", "pool", "mini", "politics", "partner", "disclaimer", "authors", "boards", "faculty", "parties", "fish", "membership", "mission", "eye", "string", "sense", "modified", "pack", "released", "stage", "internal", "goods", "recommended", "born", "unless", "richard", "detailed", "japanese", "race", "approved", "background", "target", "except", "character", "usb", "maintenance", "ability", "maybe", "functions", "ed", "moving", "brands", "places", "php", "pretty", "trademarks", "phentermine", "spain", "southern", "yourself", "etc", "winter", "rape", "battery", "youth", "pressure", "submitted", "boston", "incest", "debt", "keywords", "medium", "television", "interested", "core", "break", "purposes", "throughout", "sets", "dance", "wood", "msn", "itself", "defined", "papers", "playing", "awards", "fee", "studio", "reader", "virtual", "device", "established", "answers", "rent", "las", "remote", "dark", "programming", "external", "apple", "le", "regarding", "instructions", "min", "offered", "theory", "enjoy", "remove", "aid", "surface", "minimum", "visual", "host", "variety", "teachers", "isbn", "martin", "manual", "block", "subjects", "agents", "increased", "repair", "fair", "civil", "steel", "understanding", "songs", "fixed", "wrong", "beginning", "hands", "associates", "finally", "az", "updates", "desktop", "classes", "paris", "ohio", "gets", "sector", "capacity", "requires", "jersey", "un", "fat", "fully", "father", "electric", "saw", "instruments", "quotes", "officer", "driver", "businesses", "dead", "respect", "unknown", "specified", "restaurant", "mike", "trip", "pst", "worth", "mi", "procedures", "poor", "teacher", "xxx", "eyes", "relationship", "workers", "farm", "georgia", "peace", "traditional", "campus", "tom", "showing", "creative", "coast", "benefit", "progress", "funding", "devices", "lord", "grant", "sub", "agree", "fiction", "hear", "sometimes", "watches", "careers", "beyond", "goes", "families", "led", "museum", "themselves", "fan", "transport", "interesting", "blogs", "wife", "evaluation", "accepted", "former", "implementation", "ten", "hits", "zone", "complex", "th", "cat", "galleries", "references", "die", "presented", "jack", "flat", "flow", "agencies", "literature", "respective", "parent", "spanish", "michigan", "columbia", "setting", "dr", "scale", "stand", "economy", "highest", "helpful", "monthly", "critical", "frame", "musical", "definition", "secretary", "angeles", "networking", "path", "australian", "employee", "chief", "gives", "kb", "bottom", "magazines", "packages", "detail", "francisco", "laws", "changed", "pet", "heard", "begin", "individuals", "colorado", "royal", "clean", "switch", "russian", "largest", "african", "guy", "titles", "relevant", "guidelines", "justice", "connect", "bible", "dev", "cup", "basket", "applied", "weekly", "vol", "installation", "described", "demand", "pp", "suite", "vegas", "na", "square", "chris", "attention", "advance", "skip", "diet", "army", "auction", "gear", "lee", "os", "difference", "allowed", "correct", "charles", "nation", "selling", "lots", "piece", "sheet", "firm", "seven", "older", "illinois", "regulations", "elements", "species", "jump", "cells", "module", "resort", "facility", "random", "pricing", "dvds", "certificate", "minister", "motion", "looks", "fashion", "directions", "visitors", "documentation", "monitor", "trading", "forest", "calls", "whose", "coverage", "couple", "giving", "chance", "vision", "ball", "ending", "clients", "actions", "listen", "discuss", "accept", "automotive", "naked", "goal", "successful", "sold", "wind", "communities", "clinical", "situation", "sciences", "markets", "lowest", "highly", "publishing", "appear", "emergency", "developing", "lives", "currency", "leather", "determine", "milf", "temperature", "palm", "announcements", "patient", "actual", "historical", "stone", "bob", "commerce", "ringtones", "perhaps", "persons", "difficult", "scientific", "satellite", "fit", "tests", "village", "accounts", "amateur", "ex", "met", "pain", "xbox", "particularly", "factors", "coffee", "www", "settings", "cum", "buyer", "cultural", "steve", "easily", "oral", "ford", "poster", "edge", "functional", "root", "au", "fi", "closed", "holidays", "ice", "pink", "zealand", "balance", "monitoring", "graduate", "replies", "shot", "nc", "architecture", "initial", "label", "thinking", "scott", "llc", "sec", "recommend", "canon", "hardcore", "league", "waste", "minute", "bus", "provider", "optional", "dictionary", "cold", "accounting", "manufacturing", "sections", "chair", "fishing", "effort", "phase", "fields", "bag", "fantasy", "po", "letters", "motor", "va", "professor", "context",\
    "install", "shirt", "apparel", "generally", "continued", "foot", "mass", "crime", "count", "breast", "techniques", "ibm", "rd", "johnson", "sc", "quickly", "dollars", "websites", "religion", "claim", "driving", "permission", "surgery", "patch", "heat", "wild", "measures", "generation", "kansas", "miss", "chemical", "doctor", "task", "reduce", "brought", "himself", "nor", "component", "enable", "exercise", "bug", "santa", "mid", "guarantee", "leader", "diamond", "israel", "se", "processes", "soft", "servers", "alone", "meetings", "seconds", "jones", "arizona", "keyword", "interests", "flight", "congress", "fuel", "username", "walk", "produced", "italian", "paperback", "classifieds", "wait", "supported", "pocket", "saint", "rose", "freedom", "argument", "competition", "creating", "jim", "drugs", "joint", "premium", "providers", "fresh", "characters", "attorney", "upgrade", "di", "factor", "growing", "thousands", "km", "stream", "apartments", "pick", "hearing", "eastern", "auctions", "therapy", "entries", "dates", "generated", "signed", "upper", "administrative", "serious", "prime", "samsung", "limit", "began", "louis", "steps", "errors", "shops", "bondage", "del", "efforts", "informed", "ga", "ac", "thoughts", "creek", "ft", "worked", "quantity", "urban", "practices", "sorted", "reporting", "essential", "myself", "tours", "platform", "load", "affiliate", "labor", "immediately", "admin", "nursing", "defense", "machines", "designated", "tags", "heavy", "covered", "recovery", "joe", "guys", "integrated", "configuration", "merchant", "comprehensive", "expert", "universal", "protect", "drop", "solid", "cds", "presentation", "languages", "became", "orange", "compliance", "vehicles", "prevent", "theme", "rich", "im", "campaign", "marine", "improvement", "vs", "guitar", "finding", "pennsylvania", "examples", "ipod", "saying", "spirit", "ar", "claims", "challenge", "motorola", "acceptance", "strategies", "mo", "seem", "affairs", "touch", "intended", "towards", "sa", "goals", "hire", "election", "suggest", "branch", "charges", "serve", "affiliates", "reasons", "magic", "mount", "smart", "talking", "gave", "ones", "latin", "multimedia", "xp", "avoid", "certified", "manage", "corner", "rank", "computing", "oregon", "element", "birth", "virus", "abuse", "interactive", "requests", "separate", "quarter", "procedure", "leadership", "tables", "define", "racing", "religious", "facts", "breakfast", "kong", "column", "plants", "faith", "chain", "developer", "identify", "avenue", "missing", "died", "approximately", "domestic", "sitemap", "recommendations", "moved", "houston", "reach", "comparison", "mental", "viewed", "moment", "extended", "sequence", "inch", "attack", "sorry", "centers", "opening", "damage", "lab", "reserve", "recipes", "cvs", "gamma", "plastic", "produce", "snow", "placed", "truth", "counter", "failure", "follows", "eu", "weekend", "dollar", "camp", "ontario", "automatically", "des", "minnesota", "films", "bridge", "native", "fill", "williams", "movement", "printing", "baseball", "owned", "approval", "draft", "chart", "played", "contacts", "cc", "jesus", "readers", "clubs", "lcd", "wa", "jackson", "equal", "adventure", "matching", "offering", "shirts", "profit", "leaders", "posters", "institutions", "assistant", "variable", "ave", "dj", "advertisement", "expect", "parking", "headlines", "yesterday", "compared", "determined", "wholesale", "workshop", "russia", "gone", "codes", "kinds", "extension", "seattle", "statements", "golden", "completely", "teams", "fort", "cm", "wi", "lighting", "senate", "forces", "funny", "brother", "gene", "turned", "portable", "tried", "electrical", "applicable", "disc", "returned", "pattern", "ct", "hentai", "boat", "named", "theatre", "laser", "earlier", "manufacturers", "sponsor", "classical", "icon", "warranty", "dedicated", "indiana", "direction", "harry", "basketball", "objects", "ends", "delete", "evening", "assembly", "nuclear", "taxes", "mouse", "signal", "criminal", "issued", "brain", "sexual", "wisconsin", "powerful", "dream", "obtained", "false", "da", "cast", "flower", "felt", "personnel", "passed", "supplied", "identified", "falls", "pic", "soul", "aids", "opinions", "promote", "stated", "stats", "hawaii", "professionals", "appears", "carry", "flag", "decided", "nj", "covers", "hr", "em", "advantage", "hello", "designs", "maintain", "tourism", "priority", "newsletters", "adults", "clips", "savings", "iv", "graphic", "atom", "payments", "rw", "estimated", "binding", "brief", "ended", "winning", "eight", "anonymous", "iron", "straight", "script", "served", "wants", "miscellaneous", "prepared", "void", "dining", "alert", "integration", "atlanta", "dakota", "tag", "interview", "mix", "framework", "disk", "installed", "queen", "vhs", "credits", "clearly", "fix", "handle", "sweet", "desk", "criteria", "pubmed", "dave", "massachusetts", "diego", "hong", "vice", "associate", "ne", "truck", "behavior", "enlarge", "ray", "frequently", "revenue", "measure", "changing", "votes", "du", "duty", "looked", "discussions", "bear", "gain", "festival", "laboratory", "ocean", "flights", "experts", "signs", "lack", "depth", "iowa", "whatever", "logged",\
    "laptop", "vintage", "train", "exactly", "dry", "explore", "maryland", "spa", "concept", "nearly", "eligible", "checkout", "reality", "forgot", "handling", "origin", "knew", "gaming", "feeds", "billion", "destination", "scotland", "faster", "intelligence", "dallas", "bought", "con", "ups", "nations", "route", "followed", "specifications", "broken", "tripadvisor", "frank", "alaska", "zoom", "blow", "battle", "residential", "anime", "speak", "decisions", "industries", "protocol", "query", "clip", "partnership", "editorial", "nt", "expression", "es", "equity", "provisions", "speech", "wire", "principles", "suggestions", "rural", "shared", "sounds", "replacement", "tape", "strategic", "judge", "spam", "economics", "acid", "bytes", "cent", "forced", "compatible", "fight", "apartment", "height", "null", "zero", "speaker", "filed", "gb", "netherlands", "obtain", "bc", "consulting", "recreation", "offices", "designer", "remain", "managed", "pr", "failed", "marriage", "roll", "korea", "banks", "fr", "participants", "secret", "bath", "aa", "kelly", "leads", "negative", "austin", "favorites", "toronto", "theater", "springs", "missouri", "andrew", "var", "perform", "healthy", "translation", "estimates", "font", "assets", "injury", "mt", "joseph", "ministry", "drivers", "lawyer", "figures", "married", "protected", "proposal", "sharing", "philadelphia", "portal", "waiting", "birthday", "beta", "fail", "gratis", "banking", "officials", "brian", "toward", "won", "slightly", "assist", "conduct", "contained", "lingerie", "legislation", "calling", "parameters", "jazz", "serving", "bags", "profiles", "miami", "comics", "matters", "houses", "doc", "postal", "relationships", "tennessee", "wear", "controls", "breaking", "combined", "ultimate", "wales", "representative", "frequency", "introduced", "minor", "finish", "departments", "residents", "noted", "displayed", "mom", "reduced", "physics", "rare", "spent", "performed", "extreme", "samples", "davis", "daniel", "bars", "reviewed", "row", "oz", "forecast", "removed", "helps", "singles", "administrator", "cycle", "amounts", "contain", "accuracy", "dual", "rise", "usd", "sleep", "mg", "bird", "pharmacy", "brazil", "creation", "static", "scene", "hunter", "addresses", "lady", "crystal", "famous", "writer", "chairman", "violence", "fans", "oklahoma", "speakers", "drink", "academy", "dynamic", "gender", "eat", "permanent", "agriculture", "dell", "cleaning", "constitutes", "portfolio", "practical", "delivered", "collectibles", "infrastructure", "exclusive", "seat", "concerns", "colour", "vendor", "originally", "intel", "utilities", "philosophy", "regulation", "officers", "reduction", "aim", "bids", "referred", "supports", "nutrition", "recording", "regions", "junior", "toll", "les", "cape", "ann", "rings", "meaning", "tip", "secondary", "wonderful", "mine", "ladies", "henry", "ticket", "announced", "guess", "agreed", "prevention", "whom", "ski", "soccer", "math", "import", "posting", "presence", "instant", "mentioned", "automatic", "healthcare", "viewing", "maintained", "ch", "increasing", "majority", "connected", "christ", "dan", "dogs", "sd", "directors", "aspects", "austria", "ahead", "moon", "participation", "scheme", "utility", "preview", "fly", "manner", "matrix", "containing", "combination", "devel", "amendment", "despite", "strength", "guaranteed", "turkey", "libraries", "proper", "distributed", "degrees", "singapore", "enterprises", "delta", "fear", "seeking", "inches", "phoenix", "rs", "convention", "shares", "principal", "daughter", "standing", "voyeur", "comfort", "colors", "wars", "cisco", "ordering", "kept", "alpha", "appeal", "cruise", "bonus", "certification", "previously", "hey", "bookmark", "buildings", "specials", "beat", "disney", "household", "batteries", "adobe", "smoking", "bbc", "becomes", "drives", "arms", "alabama", "tea", "improved", "trees", "avg", "achieve", "positions", "dress", "subscription", "dealer", "contemporary", "sky", "utah", "nearby", "rom", "carried", "happen", "exposure", "panasonic", "hide", "permalink", "signature", "gambling", "refer", "miller", "provision", "outdoors", "clothes", "caused", "luxury", "babes", "frames", "viagra", "certainly", "indeed", "newspaper", "toy", "circuit", "layer", "printed", "slow", "removal", "easier", "src", "liability", "trademark", "hip", "printers", "faqs", "nine", "adding", "kentucky", "mostly", "eric", "spot", "taylor", "trackback", "prints", "spend", "factory", "interior", "revised", "grow", "americans", "optical", "promotion", "relative", "amazing", "clock", "dot", "hiv", "identity", "suites", "conversion", "feeling", "hidden", "reasonable", "victoria", "serial", "relief", "revision", "broadband", "influence", "ratio", "pda", "importance", "rain", "onto", "dsl", "planet", "webmaster", "copies", "recipe", "zum", "permit", "seeing", "proof", "dna", "diff", "tennis", "bass", "prescription", "bedroom", "empty", "instance", "hole", "pets", "ride", "licensed", "orlando", "specifically", "tim", "bureau", "maine", "sql", "represent", "conservation", "pair", "ideal", "specs", "recorded", "don", "pieces", "finished", "parks", "dinner", "lawyers", "sydney", "stress", "cream", "ss", "runs", "trends", "yeah", "discover", "sexo", "ap", "patterns", "boxes", "louisiana", "hills", "javascript", "fourth",\
    "nm", "advisor", "mn", "marketplace", "nd", "evil", "aware", "wilson", "shape", "evolution", "irish", "certificates", "objectives", "stations", "suggested", "gps", "op", "remains", "acc", "greatest", "firms", "concerned", "euro", "operator", "structures", "generic", "encyclopedia", "usage", "cap", "ink", "charts", "continuing", "mixed", "census", "interracial", "peak", "tn", "competitive", "exist", "wheel", "transit", "suppliers", "salt", "compact", "poetry", "lights", "tracking", "angel", "bell", "keeping", "preparation", "attempt", "receiving", "matches", "accordance", "width", "noise", "engines", "forget", "array", "discussed", "accurate", "stephen", "elizabeth", "climate", "reservations", "pin", "playstation", "alcohol", "greek", "instruction", "managing", "annotation", "sister", "raw", "differences", "walking", "explain", "smaller", "newest", "establish", "gnu", "happened", "expressed", "jeff", "extent", "sharp", "lesbians", "ben", "lane", "paragraph", "kill", "mathematics", "aol", "compensation", "ce", "export", "managers", "aircraft", "modules", "sweden", "conflict", "conducted", "versions", "employer", "occur", "percentage", "knows", "mississippi", "describe", "concern", "backup", "requested", "citizens", "connecticut", "heritage", "personals", "immediate", "holding", "trouble", "spread", "coach", "kevin", "agricultural", "expand", "supporting", "audience", "assigned", "jordan", "collections", "ages", "participate", "plug", "specialist", "cook", "affect", "virgin", "experienced", "investigation", "raised", "hat", "institution", "directed", "dealers", "searching", "sporting", "helping", "perl", "affected", "lib", "bike", "totally", "plate", "expenses", "indicate", "blonde", "ab", "proceedings", "favourite", "transmission", "anderson", "utc", "characteristics", "der", "lose", "organic", "seek", "experiences", "albums", "cheats", "extremely", "verzeichnis", "contracts", "guests", "hosted", "diseases", "concerning", "developers", "equivalent", "chemistry", "tony", "neighborhood", "nevada", "kits", "thailand", "variables", "agenda", "anyway", "continues", "tracks", "advisory", "cam", "curriculum", "logic", "template", "prince", "circle", "soil", "grants", "anywhere", "psychology", "responses", "atlantic", "wet", "circumstances", "edward", "investor", "identification", "ram", "leaving", "wildlife", "appliances", "matt", "elementary", "cooking", "speaking", "sponsors", "fox", "unlimited", "respond", "sizes", "plain", "exit", "entered", "iran", "arm", "keys", "launch", "wave", "checking", "costa", "belgium", "printable", "holy", "acts", "guidance", "mesh", "trail", "enforcement", "symbol", "crafts", "highway", "buddy", "hardcover", "observed", "dean", "setup", "poll", "booking", "glossary", "fiscal", "celebrity", "styles", "denver", "unix", "filled", "bond", "channels", "ericsson", "appendix", "notify", "blues", "chocolate", "pub", "portion", "scope", "hampshire", "supplier", "cables", "cotton", "bluetooth", "controlled", "requirement", "authorities", "biology", "dental", "killed", "border", "ancient", "debate", "representatives", "starts", "pregnancy", "causes", "arkansas", "biography", "leisure", "attractions", "learned", "transactions", "notebook", "explorer", "historic", "attached", "opened", "tm", "husband", "disabled", "authorized", "crazy", "upcoming", "britain", "concert", "retirement", "scores", "financing", "efficiency", "sp", "comedy", "adopted", "efficient", "weblog", "linear", "commitment", "specialty", "bears", "jean", "hop", "carrier", "edited", "constant", "visa", "mouth", "jewish", "meter", "linked", "portland", "interviews", "concepts", "nh", "gun", "reflect", "pure", "deliver", "wonder", "hell", "lessons", "fruit", "begins", "qualified", "reform", "lens", "alerts", "treated", "discovery", "draw", "mysql", "classified", "relating", "assume", "confidence", "alliance", "fm", "confirm", "warm", "neither", "lewis", "howard", "offline", "leaves", "engineer", "lifestyle", "consistent", "replace", "clearance", "connections", "inventory", "converter", "suck", "organisation", "babe", "checks", "reached", "becoming", "safari", "objective", "indicated", "sugar", "crew", "legs", "sam", "stick", "securities", "allen", "pdt", "relation", "enabled", "genre", "slide", "montana", "volunteer", "tested", "rear", "democratic", "enhance", "switzerland", "exact", "bound", "parameter", "adapter", "processor", "node", "formal", "dimensions", "contribute", "lock", "hockey", "storm", "micro", "colleges", "laptops", "mile", "showed", "challenges", "editors", "mens", "threads", "bowl", "supreme", "brothers", "recognition", "presents", "ref", "tank", "submission", "dolls", "estimate", "encourage", "navy", "kid", "regulatory", "inspection", "consumers", "cancel", "limits", "territory", "transaction", "manchester", "weapons", "paint", "delay", "pilot", "outlet", "contributions", "continuous", "db", "czech", "resulting", "cambridge", "initiative", "novel", "pan", "execution", "disability", "increases", "ultra", "winner", "idaho", "contractor", "ph", "episode", "examination", "potter", "dish", "plays", "bulletin", "ia", "pt", "indicates", "modify", "oxford", "adam", "truly", "epinions", "painting", "committed", "extensive", "affordable", "universe", "candidate", "databases", "patent", "slot", "psp", "outstanding", "ha", "eating", "perspective", "planned", "watching", "lodge", "messenger", "mirror", "tournament", "consideration", "ds", "discounts", "sterling",\
    "sessions", "kernel", "boobs", "stocks", "buyers", "journals", "gray", "catalogue", "ea", "jennifer", "antonio", "charged", "broad", "taiwan", "und", "chosen", "demo", "greece", "lg", "swiss", "sarah", "clark", "labour", "hate", "terminal", "publishers", "nights", "behalf", "caribbean", "liquid", "rice", "nebraska", "loop", "salary", "reservation", "foods", "gourmet", "guard", "properly", "orleans", "saving", "nfl", "remaining", "empire", "resume", "twenty", "newly", "raise", "prepare", "avatar", "gary", "depending", "illegal", "expansion", "vary", "hundreds", "rome", "arab", "lincoln", "helped", "premier", "tomorrow", "purchased", "milk", "decide", "consent", "drama", "visiting", "performing", "downtown", "keyboard", "contest", "collected", "nw", "bands", "boot", "suitable", "ff", "absolutely", "millions", "lunch", "dildo", "audit", "push", "chamber", "guinea", "findings", "muscle", "featuring", "iso", "implement", "clicking", "scheduled", "polls", "typical", "tower", "yours", "sum", "misc", "calculator", "significantly", "chicken", "temporary", "attend", "shower", "alan", "sending", "jason", "tonight", "dear", "sufficient", "holdem", "shell", "province", "catholic", "oak", "vat", "awareness", "vancouver", "governor", "beer", "seemed", "contribution", "measurement", "swimming", "spyware", "formula", "constitution", "packaging", "solar", "jose", "catch", "jane", "pakistan", "ps", "reliable", "consultation", "northwest", "sir", "doubt", "earn", "finder", "unable", "periods", "classroom", "tasks", "democracy", "attacks", "kim", "wallpaper", "merchandise", "const", "resistance", "doors", "symptoms", "resorts", "biggest", "memorial", "visitor", "twin", "forth", "insert", "baltimore", "gateway", "ky", "dont", "alumni", "drawing", "candidates", "charlotte", "ordered", "biological", "fighting", "transition", "happens", "preferences", "spy", "romance", "instrument", "bruce", "split", "themes", "powers", "heaven", "br", "bits", "pregnant", "twice", "classification", "focused", "egypt", "physician", "hollywood", "bargain", "wikipedia", "cellular", "norway", "vermont", "asking", "blocks", "normally", "lo", "spiritual", "hunting", "diabetes", "suit", "ml", "shift", "chip", "res", "sit", "bodies", "photographs", "cutting", "wow", "simon", "writers", "marks", "flexible", "loved", "favourites", "mapping", "numerous", "relatively", "birds", "satisfaction", "represents", "char", "indexed", "pittsburgh", "superior", "preferred", "saved", "paying", "cartoon", "shots", "intellectual", "moore", "granted", "choices", "carbon", "spending", "comfortable", "magnetic", "interaction", "listening", "effectively", "registry", "crisis", "outlook", "massive", "denmark", "employed", "bright", "treat", "header", "cs", "poverty", "formed", "piano", "echo", "que", "grid", "sheets", "patrick", "experimental", "puerto", "revolution", "consolidation", "displays", "plasma", "allowing", "earnings", "voip", "mystery", "landscape", "dependent", "mechanical", "journey", "delaware", "bidding", "consultants", "risks", "banner", "applicant", "charter", "fig", "barbara", "cooperation", "counties", "acquisition", "ports", "implemented", "sf", "directories", "recognized", "dreams", "blogger", "notification", "kg", "licensing", "stands", "teach", "occurred", "textbooks", "rapid", "pull", "hairy", "diversity", "cleveland", "ut", "reverse", "deposit", "seminar", "investments", "latina", "nasa", "wheels", "specify", "accessibility", "dutch", "sensitive", "templates", "formats", "tab", "depends", "boots", "holds", "router", "concrete", "si", "editing", "poland", "folder", "womens", "css", "completion", "upload", "pulse", "universities", "technique", "contractors", "milfhunter", "voting", "courts", "notices", "subscriptions", "calculate", "mc", "detroit", "alexander", "broadcast", "converted", "metro", "toshiba", "anniversary", "improvements", "strip", "specification", "pearl", "accident", "nick", "accessible", "accessory", "resident", "plot", "qty", "possibly", "airline", "typically", "representation", "regard", "pump", "exists", "arrangements", "smooth", "conferences", "uniprotkb", "beastiality", "strike", "consumption", "birmingham", "flashing", "lp", "narrow", "afternoon", "threat", "surveys", "sitting", "putting", "consultant", "controller", "ownership", "committees", "legislative", "researchers", "vietnam", "trailer", "anne", "castle", "gardens", "missed", "malaysia", "unsubscribe", "antique", "labels", "willing", "bio", "molecular", "upskirt", "acting", "heads", "stored", "exam", "logos", "residence", "attorneys", "milfs", "antiques", "density", "hundred", "ryan", "operators", "strange", "sustainable", "philippines", "statistical", "beds", "breasts", "mention", "innovation", "pcs", "employers", "grey", "parallel", "honda", "amended", "operate", "bills", "bold", "bathroom", "stable", "opera", "definitions", "von", "doctors", "lesson", "cinema", "asset", "ag", "scan", "elections", "drinking", "reaction", "blank", "enhanced", "entitled", "severe", "generate", "stainless", "newspapers", "hospitals", "vi", "deluxe", "humor", "aged", "monitors", "exception", "lived", "duration", "bulk", "successfully", "indonesia", "pursuant", "sci", "fabric", "edt", "visits", "primarily", "tight", "domains", "capabilities", "pmid", "contrast", "recommendation", "flying", "recruitment", "sin", "berlin", "cute", "organized", "ba", "para", "siemens", "adoption", "improving", "cr",\
    "expensive", "meant", "capture", "pounds", "buffalo", "organisations", "plane", "pg", "explained", "seed", "programmes", "desire", "expertise", "mechanism", "camping", "ee", "jewellery", "meets", "welfare", "peer", "caught", "eventually", "marked", "driven", "measured", "medline", "bottle", "agreements", "considering", "innovative", "marshall", "massage", "rubber", "conclusion", "closing", "tampa", "thousand", "meat", "legend", "grace", "susan", "ing", "ks", "adams", "python", "monster", "alex", "bang", "villa", "bone", "columns", "disorders", "bugs", "collaboration", "hamilton", "detection", "ftp", "cookies", "inner", "formation", "tutorial", "med", "engineers", "entity", "cruises", "gate", "holder", "proposals", "moderator", "sw", "tutorials", "settlement", "portugal", "lawrence", "roman", "duties", "valuable", "erotic", "tone", "collectables", "ethics", "forever", "dragon", "busy", "captain", "fantastic", "imagine", "brings", "heating", "leg", "neck", "hd", "wing", "governments", "purchasing", "scripts", "abc", "stereo", "appointed", "taste", "dealing", "commit", "tiny", "operational", "rail", "airlines", "liberal", "livecam", "jay", "trips", "gap", "sides", "tube", "turns", "corresponding", "descriptions", "cache", "belt", "jacket", "determination", "animation", "oracle", "er", "matthew", "lease", "productions", "aviation", "hobbies", "proud", "excess", "disaster", "console", "commands", "jr", "telecommunications", "instructor", "giant", "achieved", "injuries", "shipped", "bestiality", "seats", "approaches", "biz", "alarm", "voltage", "anthony", "nintendo", "usual", "loading", "stamps", "appeared", "franklin", "angle", "rob", "vinyl", "highlights", "mining", "designers", "melbourne", "ongoing", "worst", "imaging", "betting", "scientists", "liberty", "wyoming", "blackjack", "argentina", "era", "convert", "possibility", "analyst", "commissioner", "dangerous", "garage", "exciting", "reliability", "thongs", "gcc", "unfortunately", "respectively", "volunteers", "attachment", "ringtone", "finland", "morgan", "derived", "pleasure", "honor", "asp", "oriented", "eagle", "desktops", "pants", "columbus", "nurse", "prayer", "appointment", "workshops", "hurricane", "quiet", "luck", "postage", "producer", "represented", "mortgages", "dial", "responsibilities", "cheese", "comic", "carefully", "jet", "productivity", "investors", "crown", "par", "underground", "diagnosis", "maker", "crack", "principle", "picks", "vacations", "gang", "semester", "calculated", "applies", "casinos", "appearance", "smoke", "apache", "filters", "incorporated", "nv", "craft", "cake", "notebooks", "apart", "fellow", "blind", "lounge", "mad", "algorithm", "semi", "coins", "andy", "gross", "strongly", "cafe", "valentine", "hilton", "ken", "proteins", "horror", "su", "exp", "familiar", "capable", "douglas", "debian", "till", "involving", "pen", "investing", "christopher", "admission", "epson", "shoe", "elected", "carrying", "victory", "sand", "madison", "terrorism", "joy", "editions", "cpu", "mainly", "ethnic", "ran", "parliament", "actor", "finds", "seal", "situations", "fifth", "allocated", "citizen", "vertical", "corrections", "structural", "municipal", "describes", "prize", "sr", "occurs", "jon", "absolute", "disabilities", "consists", "anytime", "substance", "prohibited", "addressed", "lies", "pipe", "soldiers", "nr", "guardian", "lecture", "simulation", "layout", "initiatives", "ill", "concentration", "classics", "lbs", "lay", "interpretation", "horses", "lol", "dirty", "deck", "wayne", "donate", "taught", "bankruptcy", "mp", "worker", "optimization", "alive", "temple", "substances", "prove", "discovered", "wings", "breaks", "genetic", "restrictions", "participating", "waters", "promise", "thin", "exhibition", "prefer", "ridge", "cabinet", "modem", "harris", "mph", "bringing", "sick", "dose", "evaluate", "tiffany", "tropical", "collect", "bet", "composition", "toyota", "streets", "nationwide", "vector", "definitely", "shaved", "turning", "buffer", "purple", "existence", "commentary", "larry", "limousines", "developments", "def", "immigration", "destinations", "lets", "mutual", "pipeline", "necessarily", "syntax", "li", "attribute", "prison", "skill", "chairs", "nl", "everyday", "apparently", "surrounding", "mountains", "moves", "popularity", "inquiry", "ethernet", "checked", "exhibit", "throw", "trend", "sierra", "visible", "cats", "desert", "postposted", "ya", "oldest", "rhode", "nba", "busty", "coordinator", "obviously", "mercury", "steven", "handbook", "greg", "navigate", "worse", "summit", "victims", "epa", "spaces", "fundamental", "burning", "escape", "coupons", "somewhat", "receiver", "substantial", "tr", "progressive", "cialis", "bb", "boats", "glance", "scottish", "championship", "arcade", "richmond", "sacramento", "impossible", "ron", "russell", "tells", "obvious", "fiber", "depression", "graph", "covering", "platinum", "judgment", "bedrooms", "talks", "filing", "foster", "modeling", "passing", "awarded", "testimonials", "trials", "tissue", "nz", "memorabilia", "clinton", "masters", "bonds", "cartridge", "alberta", "explanation", "folk", "org", "commons", "cincinnati", "subsection", "fraud", "electricity", "permitted", "spectrum", "arrival", "okay", "pottery", "emphasis", "roger", "aspect", "workplace", "awesome", "mexican", "confirmed", "counts", "priced", "wallpapers", "hist", "crash", "lift", "desired", "inter", "closer", "assumes",\
    "heights", "shadow", "riding", "infection", "firefox", "lisa", "expense", "grove", "eligibility", "venture", "clinic", "korean", "healing", "princess", "mall", "entering", "packet", "spray", "studios", "involvement", "dad", "buttons", "placement", "observations", "vbulletin", "funded", "thompson", "winners", "extend", "roads", "subsequent", "pat", "dublin", "rolling", "fell", "motorcycle", "yard", "disclosure", "establishment", "memories", "nelson", "te", "arrived", "creates", "faces", "tourist", "av", "mayor", "murder", "sean", "adequate", "senator", "yield", "presentations", "grades", "cartoons", "pour", "digest", "reg", "lodging", "tion", "dust", "hence", "wiki", "entirely", "replaced", "radar", "rescue", "undergraduate", "losses", "combat", "reducing", "stopped", "occupation", "lakes", "butt", "donations", "associations", "citysearch", "closely", "radiation", "diary", "seriously", "kings", "shooting", "kent", "adds", "nsw", "ear", "flags", "pci", "baker", "launched", "elsewhere", "pollution", "conservative", "guestbook", "shock", "effectiveness", "walls", "abroad", "ebony", "tie", "ward", "drawn", "arthur", "ian", "visited", "roof", "walker", "demonstrate", "atmosphere", "suggests", "kiss", "beast", "ra", "operated", "experiment", "targets", "overseas", "purchases", "dodge", "counsel", "federation", "pizza", "invited", "yards", "assignment", "chemicals", "gordon", "mod", "farmers", "rc", "queries", "bmw", "rush", "ukraine", "absence", "nearest", "cluster", "vendors", "mpeg", "whereas", "yoga", "serves", "woods", "surprise", "lamp", "rico", "partial", "shoppers", "phil", "everybody", "couples", "nashville", "ranking", "jokes", "cst", "http", "ceo", "simpson", "twiki", "sublime", "counseling", "palace", "acceptable", "satisfied", "glad", "wins", "measurements", "verify", "globe", "trusted", "copper", "milwaukee", "rack", "medication", "warehouse", "shareware", "ec", "rep", "kerry", "receipt", "supposed", "ordinary", "nobody", "ghost", "violation", "configure", "stability", "mit", "applying", "southwest", "boss", "pride", "institutional", "expectations", "independence", "knowing", "reporter", "metabolism", "keith", "champion", "cloudy", "linda", "ross", "personally", "chile", "anna", "plenty", "solo", "sentence", "throat", "ignore", "maria", "uniform", "excellence", "wealth", "tall", "rm", "somewhere", "vacuum", "dancing", "attributes", "recognize", "brass", "writes", "plaza", "pdas", "outcomes", "survival", "quest", "publish", "sri", "screening", "toe", "thumbnail", "trans", "jonathan", "whenever", "nova", "lifetime", "api", "pioneer", "booty", "forgotten", "acrobat", "plates", "acres", "venue", "athletic", "thermal", "essays", "behaviour", "vital", "telling", "fairly", "coastal", "config", "cf", "charity", "intelligent", "edinburgh", "vt", "excel", "modes", "obligation", "campbell", "wake", "stupid", "harbor", "hungary", "traveler", "urw", "segment", "realize", "regardless", "lan", "enemy", "puzzle", "rising", "aluminum", "wells", "wishlist", "opens", "insight", "sms", "shit", "restricted", "republican", "secrets", "lucky", "latter", "merchants", "thick", "trailers", "repeat", "syndrome", "philips", "attendance", "penalty", "drum", "glasses", "enables", "nec", "iraqi", "builder", "vista", "jessica", "chips", "terry", "flood", "foto", "ease", "arguments", "amsterdam", "orgy", "arena", "adventures", "pupils", "stewart", "announcement", "tabs", "outcome", "xx", "appreciate", "expanded", "casual", "grown", "polish", "lovely", "extras", "gm", "centres", "jerry", "clause", "smile", "lands", "ri", "troops", "indoor", "bulgaria", "armed", "broker", "charger", "regularly", "believed", "pine", "cooling", "tend", "gulf", "rt", "rick", "trucks", "cp", "mechanisms", "divorce", "laura", "shopper", "tokyo", "partly", "nikon", "customize", "tradition", "candy", "pills", "tiger", "donald", "folks", "sensor", "exposed", "telecom", "hunt", "angels", "deputy", "indicators", "sealed", "thai", "emissions", "physicians", "loaded", "fred", "complaint", "scenes", "experiments", "balls", "afghanistan", "dd", "boost", "spanking", "scholarship", "governance", "mill", "founded", "supplements", "chronic", "icons", "moral", "den", "catering", "aud", "finger", "keeps", "pound", "locate", "camcorder", "pl", "trained", "burn", "implementing", "roses", "labs", "ourselves", "bread", "tobacco", "wooden", "motors", "tough", "roberts", "incident", "gonna", "dynamics", "lie", "crm", "rf", "conversation", "decrease", "chest", "pension", "billy", "revenues", "emerging", "worship", "capability", "ak", "fe", "craig", "herself", "producing", "churches", "precision", "damages", "reserves", "contributed", "solve", "shorts", "reproduction", "minority", "td", "diverse", "amp", "ingredients", "sb", "ah", "johnny", "sole", "franchise", "recorder", "complaints", "facing", "sm", "nancy", "promotions", "tones", "passion", "rehabilitation", "maintaining", "sight", "laid", "clay", "defence", "patches", "weak", "refund", "usc", "towns", "environments", "trembl", "divided", "blvd", "reception", "amd", "wise", "emails", "cyprus", "wv", "odds", "correctly", "insider", "seminars", "consequences", "makers", "hearts", "geography", "appearing",\
    "integrity", "worry", "ns", "discrimination", "eve", "carter", "legacy", "marc", "pleased", "danger", "vitamin", "widely", "processed", "phrase", "genuine", "raising", "implications", "functionality", "paradise", "hybrid", "reads", "roles", "intermediate", "emotional", "sons", "leaf", "pad", "glory", "platforms", "ja", "bigger", "billing", "diesel", "versus", "combine", "overnight", "geographic", "exceed", "bs", "rod", "saudi", "fault", "cuba", "hrs", "preliminary", "districts", "introduce", "silk", "promotional", "kate", "chevrolet", "babies", "bi", "karen", "compiled", "romantic", "revealed", "specialists", "generator", "albert", "examine", "jimmy", "graham", "suspension", "bristol", "margaret", "compaq", "sad", "correction", "wolf", "slowly", "authentication", "communicate", "rugby", "supplement", "showtimes", "cal", "portions", "infant", "promoting", "sectors", "samuel", "fluid", "grounds", "fits", "kick", "regards", "meal", "ta", "hurt", "machinery", "bandwidth", "unlike", "equation", "baskets", "probability", "pot", "dimension", "wright", "img", "barry", "proven", "schedules", "admissions", "cached", "warren", "slip", "studied", "reviewer", "involves", "quarterly", "rpm", "profits", "devil", "grass", "comply", "marie", "florist", "illustrated", "cherry", "continental", "alternate", "deutsch", "achievement", "limitations", "kenya", "webcam", "cuts", "funeral", "nutten", "earrings", "enjoyed", "automated", "chapters", "pee", "charlie", "quebec", "nipples", "passenger", "convenient", "dennis", "mars", "francis", "tvs", "sized", "manga", "noticed", "socket", "silent", "literary", "egg", "mhz", "signals", "caps", "orientation", "pill", "theft", "childhood", "swing", "symbols", "lat", "meta", "humans", "analog", "facial", "choosing", "talent", "dated", "flexibility", "seeker", "wisdom", "shoot", "boundary", "mint", "packard", "offset", "payday", "philip", "elite", "gi", "spin", "holders", "believes", "swedish", "poems", "deadline", "jurisdiction", "robot", "displaying", "witness", "collins", "equipped", "stages", "encouraged", "sur", "winds", "powder", "broadway", "acquired", "assess", "wash", "cartridges", "stones", "entrance", "gnome", "roots", "declaration", "losing", "attempts", "gadgets", "noble", "glasgow", "automation", "impacts", "rev", "gospel", "advantages", "shore", "loves", "induced", "ll", "knight", "preparing", "loose", "aims", "recipient", "linking", "extensions", "appeals", "cl", "earned", "illness", "islamic", "athletics", "southeast", "ieee", "ho", "alternatives", "pending", "parker", "determining", "lebanon", "corp", "personalized", "kennedy", "gt", "sh", "conditioning", "teenage", "soap", "ae", "triple", "cooper", "nyc", "vincent", "jam", "secured", "unusual", "answered", "partnerships", "destruction", "slots", "increasingly", "migration", "disorder", "routine", "toolbar", "basically", "rocks", "conventional", "titans", "applicants", "wearing", "axis", "sought", "genes", "mounted", "habitat", "firewall", "median", "guns", "scanner", "herein", "occupational", "animated", "horny", "judicial", "rio", "hs", "adjustment", "hero", "integer", "treatments", "bachelor", "attitude", "camcorders", "engaged", "falling", "basics", "montreal", "carpet", "rv", "struct", "lenses", "binary", "genetics", "attended", "difficulty", "punk", "collective", "coalition", "pi", "dropped", "enrollment", "duke", "walter", "ai", "pace", "besides", "wage", "producers", "ot", "collector", "arc", "hosts", "interfaces", "advertisers", "moments", "atlas", "strings", "dawn", "representing", "observation", "feels", "torture", "carl", "deleted", "coat", "mitchell", "mrs", "rica", "restoration", "convenience", "returning", "ralph", "opposition", "container", "yr", "defendant", "warner", "confirmation", "app", "embedded", "inkjet", "supervisor", "wizard", "corps", "actors", "liver", "peripherals", "liable", "brochure", "morris", "bestsellers", "petition", "eminem", "recall", "antenna", "picked", "assumed", "departure", "minneapolis", "belief", "killing", "bikini", "memphis", "shoulder", "decor", "lookup", "texts", "harvard", "brokers", "roy", "ion", "diameter", "ottawa", "doll", "ic", "podcast", "tit", "seasons", "peru", "interactions", "refine", "bidder", "singer", "evans", "herald", "literacy", "fails", "aging", "nike", "intervention", "pissing", "fed", "plugin", "attraction", "diving", "invite", "modification", "alice", "latinas", "suppose", "customized", "reed", "involve", "moderate", "terror", "younger", "thirty", "mice", "opposite", "understood", "rapidly", "dealtime", "ban", "temp", "intro", "mercedes", "zus", "assurance", "fisting", "clerk", "happening", "vast", "mills", "outline", "amendments", "tramadol", "holland", "receives", "jeans", "metropolitan", "compilation", "verification", "fonts", "ent", "odd", "wrap", "refers", "mood", "favor", "veterans", "quiz", "mx", "sigma", "gr", "attractive", "xhtml", "occasion", "recordings", "jefferson", "victim", "demands", "sleeping", "careful", "ext", "beam", "gardening", "obligations", "arrive", "orchestra", "sunset", "tracked", "moreover", "minimal", "polyphonic", "lottery", "tops", "framed", "aside", "outsourcing", "licence", "adjustable", "allocation", "michelle", "essay", "discipline", "amy", "ts", "demonstrated", "dialogue", "identifying", "alphabetical", "camps", "declared", "dispatched", "aaron", "handheld", "trace",\
    "disposal", "shut", "florists", "packs", "ge", "installing", "switches", "romania", "voluntary", "ncaa", "thou", "consult", "phd", "greatly", "blogging", "mask", "cycling", "midnight", "ng", "commonly", "pe", "photographer", "inform", "turkish", "coal", "cry", "messaging", "pentium", "quantum", "murray", "intent", "tt", "zoo", "largely", "pleasant", "announce", "constructed", "additions", "requiring", "spoke", "aka", "arrow", "engagement", "sampling", "rough", "weird", "tee", "refinance", "lion", "inspired", "holes", "weddings", "blade", "suddenly", "oxygen", "cookie", "meals", "canyon", "goto", "meters", "merely", "calendars", "arrangement", "conclusions", "passes", "bibliography", "pointer", "compatibility", "stretch", "durham", "furthermore", "permits", "cooperative", "muslim", "xl", "neil", "sleeve", "netscape", "cleaner", "cricket", "beef", "feeding", "stroke", "township", "rankings", "measuring", "cad", "hats", "robin", "robinson", "jacksonville", "strap", "headquarters", "sharon", "crowd", "tcp", "transfers", "surf", "olympic", "transformation", "remained", "attachments", "dv", "dir", "entities", "customs", "administrators", "personality", "rainbow", "hook", "roulette", "decline", "gloves", "israeli", "medicare", "cord", "skiing", "cloud", "facilitate", "subscriber", "valve", "val", "hewlett", "explains", "proceed", "flickr", "feelings", "knife", "jamaica", "priorities", "shelf", "bookstore", "timing", "liked", "parenting", "adopt", "denied", "fotos", "incredible", "britney", "freeware", "donation", "outer", "crop", "deaths", "rivers", "commonwealth", "pharmaceutical", "manhattan", "tales", "katrina", "workforce", "islam", "nodes", "tu", "fy", "thumbs", "seeds", "cited", "lite", "ghz", "hub", "targeted", "organizational", "skype", "realized", "twelve", "founder", "decade", "gamecube", "rr", "dispute", "portuguese", "tired", "adverse", "everywhere", "excerpt", "eng", "steam", "discharge", "ef", "drinks", "ace", "voices", "acute", "halloween", "climbing", "stood", "sing", "tons", "perfume", "carol", "honest", "albany", "hazardous", "restore", "stack", "methodology", "somebody", "sue", "ep", "housewares", "reputation", "resistant", "democrats", "recycling", "hang", "gbp", "curve", "creator", "amber", "qualifications", "museums", "coding", "slideshow", "tracker", "variation", "passage", "transferred", "trunk", "hiking", "lb", "damn", "pierre", "jelsoft", "headset", "photograph", "oakland", "colombia", "waves", "camel", "distributor", "lamps", "underlying", "hood", "wrestling", "suicide", "archived", "photoshop", "jp", "chi", "bt", "arabia", "gathering", "projection", "juice", "chase", "mathematical", "logical", "sauce", "fame", "extract", "specialized", "diagnostic", "panama", "indianapolis", "af", "payable", "corporations", "courtesy", "criticism", "automobile", "confidential", "rfc", "statutory", "accommodations", "athens", "northeast", "downloaded", "judges", "sl", "seo", "retired", "isp", "remarks", "detected", "decades", "paintings", "walked", "arising", "nissan", "bracelet", "ins", "eggs", "juvenile", "injection", "yorkshire", "populations", "protective", "afraid", "acoustic", "railway", "cassette", "initially", "indicator", "pointed", "hb", "jpg", "causing", "mistake", "norton", "locked", "eliminate", "tc", "fusion", "mineral", "sunglasses", "ruby", "steering", "beads", "fortune", "preference", "canvas", "threshold", "parish", "claimed", "screens", "cemetery", "planner", "croatia", "flows", "stadium", "venezuela", "exploration", "mins", "fewer", "sequences", "coupon", "nurses", "ssl", "stem", "proxy", "astronomy", "lanka", "opt", "edwards", "drew", "contests", "flu", "translate", "announces", "mlb", "costume", "tagged", "berkeley", "voted", "killer", "bikes", "gates", "adjusted", "rap", "tune", "bishop", "pulled", "corn", "gp", "shaped", "compression", "seasonal", "establishing", "farmer", "counters", "puts", "constitutional", "grew", "perfectly", "tin", "slave", "instantly", "cultures", "norfolk", "coaching", "examined", "trek", "encoding", "litigation", "submissions", "oem", "heroes", "painted", "lycos", "ir", "zdnet", "broadcasting", "horizontal", "artwork", "cosmetic", "resulted", "portrait", "terrorist", "informational", "ethical", "carriers", "ecommerce", "mobility", "floral", "builders", "ties", "struggle", "schemes", "suffering", "neutral", "fisher", "rat", "spears", "prospective", "dildos", "bedding", "ultimately", "joining", "heading", "equally", "artificial", "bearing", "spectacular", "coordination", "connector", "brad", "combo", "seniors", "worlds", "guilty", "affiliated", "activation", "naturally", "haven", "tablet", "jury", "dos", "tail", "subscribers", "charm", "lawn", "violent", "mitsubishi", "underwear", "basin", "soup", "potentially", "ranch", "constraints", "crossing", "inclusive", "dimensional", "cottage", "drunk", "considerable", "crimes", "resolved", "mozilla", "byte", "toner", "nose", "latex", "branches", "anymore", "oclc", "delhi", "holdings", "alien", "locator", "selecting", "processors", "pantyhose", "plc", "broke", "nepal", "zimbabwe", "difficulties", "juan", "complexity", "msg", "constantly", "browsing", "resolve", "barcelona", "presidential", "documentary", "cod", "territories", "melissa", "moscow", "thesis", "thru", "jews", "nylon", "palestinian", "discs", "rocky", "bargains", "frequent", "trim", "nigeria", "ceiling", "pixels", "ensuring", "hispanic", "cv",\
    "cb", "legislature", "hospitality", "gen", "anybody", "procurement", "diamonds", "espn", "fleet", "untitled", "bunch", "totals", "marriott", "singing", "theoretical", "afford", "exercises", "starring", "referral", "nhl", "surveillance", "optimal", "quit", "distinct", "protocols", "lung", "highlight", "substitute", "inclusion", "hopefully", "brilliant", "turner", "sucking", "cents", "reuters", "ti", "fc", "gel", "todd", "spoken", "omega", "evaluated", "stayed", "civic", "assignments", "fw", "manuals", "doug", "sees", "termination", "watched", "saver", "thereof", "grill", "households", "gs", "redeem", "rogers", "grain", "aaa", "authentic", "regime", "wanna", "wishes", "bull", "montgomery", "architectural", "louisville", "depend", "differ", "macintosh", "movements", "ranging", "monica", "repairs", "breath", "amenities", "virtually", "cole", "mart", "candle", "hanging", "colored", "authorization", "tale", "verified", "lynn", "formerly", "projector", "bp", "situated", "comparative", "std", "seeks", "herbal", "loving", "strictly", "routing", "docs", "stanley", "psychological", "surprised", "retailer", "vitamins", "elegant", "gains", "renewal", "vid", "genealogy", "opposed", "deemed", "scoring", "expenditure", "panties", "brooklyn", "liverpool", "sisters", "critics", "connectivity", "spots", "oo", "algorithms", "hacker", "madrid", "similarly", "margin", "coin", "bbw", "solely", "fake", "salon", "collaborative", "norman", "fda", "excluding", "turbo", "headed", "voters", "cure", "madonna", "commander", "arch", "ni", "murphy", "thinks", "thats", "suggestion", "hdtv", "soldier", "phillips", "asin", "aimed", "justin", "bomb", "harm", "interval", "mirrors", "spotlight", "tricks", "reset", "brush", "investigate", "thy", "expansys", "panels", "repeated", "assault", "connecting", "spare", "logistics", "deer", "kodak", "tongue", "bowling", "tri", "danish", "pal", "monkey", "proportion", "filename", "skirt", "florence", "invest", "honey", "um", "analyses", "drawings", "significance", "scenario", "ye", "fs", "lovers", "atomic", "approx", "symposium", "arabic", "gauge", "essentials", "junction", "protecting", "nn", "faced", "mat", "rachel", "solving", "transmitted", "weekends", "screenshots", "produces", "oven", "ted", "intensive", "chains", "kingston", "sixth", "engage", "deviant", "noon", "switching", "quoted", "adapters", "correspondence", "farms", "imports", "supervision", "cheat", "bronze", "expenditures", "sandy", "separation", "testimony", "suspect", "celebrities", "macro", "sender", "mandatory", "boundaries", "crucial", "syndication", "gym", "celebration", "kde", "adjacent", "filtering", "tuition", "spouse", "exotic", "viewer", "signup", "threats", "luxembourg", "puzzles", "reaching", "vb", "damaged", "cams", "receptor", "piss", "laugh", "joel", "surgical", "destroy", "citation", "pitch", "autos", "yo", "premises", "perry", "proved", "offensive", "imperial", "dozen", "benjamin", "deployment", "teeth", "cloth", "studying", "colleagues", "stamp", "lotus", "salmon", "olympus", "separated", "proc", "cargo", "tan", "directive", "fx", "salem", "mate", "dl", "starter", "upgrades", "likes", "butter", "pepper", "weapon", "luggage", "burden", "chef", "tapes", "zones", "races", "isle", "stylish", "slim", "maple", "luke", "grocery", "offshore", "governing", "retailers", "depot", "kenneth", "comp", "alt", "pie", "blend", "harrison", "ls", "julie", "occasionally", "cbs", "attending", "emission", "pete", "spec", "finest", "realty", "janet", "bow", "penn", "recruiting", "apparent", "instructional", "phpbb", "autumn", "traveling", "probe", "midi", "permissions", "biotechnology", "toilet", "ranked", "jackets", "routes", "packed", "excited", "outreach", "helen", "mounting", "recover", "tied", "lopez", "balanced", "prescribed", "catherine", "timely", "talked", "upskirts", "debug", "delayed", "chuck", "reproduced", "hon", "dale", "explicit", "calculation", "villas", "ebook", "consolidated", "boob", "exclude", "peeing", "occasions", "brooks", "equations", "newton", "oils", "sept", "exceptional", "anxiety", "bingo", "whilst", "spatial", "respondents", "unto", "lt", "ceramic", "prompt", "precious", "minds", "annually", "considerations", "scanners", "atm", "xanax", "eq", "pays", "cox", "fingers", "sunny", "ebooks", "delivers", "je", "queensland", "necklace", "musicians", "leeds", "composite", "unavailable", "cedar", "arranged", "lang", "theaters", "advocacy", "raleigh", "stud", "fold", "essentially", "designing", "threaded", "uv", "qualify", "fingering", "blair", "hopes", "assessments", "cms", "mason", "diagram", "burns", "pumps", "footwear", "sg", "vic", "beijing", "peoples", "victor", "mario", "pos", "attach", "licenses", "utils", "removing", "advised", "brunswick", "spider", "phys", "ranges", "pairs", "sensitivity", "trails", "preservation", "hudson", "isolated", "calgary", "interim", "assisted", "divine", "streaming", "approve", "chose", "compound", "intensity", "technological", "syndicate", "abortion", "dialog", "venues", "blast", "wellness", "calcium", "newport", "antivirus", "addressing", "pole", "discounted", "indians", "shield", "harvest", "membrane", "prague", "previews", "bangladesh", "constitute", "locally", "concluded", "pickup", "desperate", "mothers", "nascar", "iceland", "demonstration", "governmental", "manufactured", "candles", "graduation",\
    "mega", "bend", "sailing", "variations", "moms", "sacred", "addiction", "morocco", "chrome", "tommy", "springfield", "refused", "brake", "exterior", "greeting", "ecology", "oliver", "congo", "glen", "botswana", "nav", "delays", "synthesis", "olive", "undefined", "unemployment", "cyber", "verizon", "scored", "enhancement", "newcastle", "clone", "velocity", "lambda", "relay", "composed", "tears", "performances", "oasis", "baseline", "cab", "angry", "fa", "societies", "silicon", "brazilian", "identical", "petroleum", "compete", "ist", "norwegian", "lover", "belong", "honolulu", "beatles", "lips", "escort", "retention", "exchanges", "pond", "rolls", "thomson", "barnes", "soundtrack", "wondering", "malta", "daddy", "lc", "ferry", "rabbit", "profession", "seating", "dam", "cnn", "separately", "physiology", "lil", "collecting", "das", "exports", "omaha", "tire", "participant", "scholarships", "recreational", "dominican", "chad", "electron", "loads", "friendship", "heather", "passport", "motel", "unions", "treasury", "warrant", "sys", "solaris", "frozen", "occupied", "josh", "royalty", "scales", "rally", "observer", "sunshine", "strain", "drag", "ceremony", "somehow", "arrested", "expanding", "provincial", "investigations", "icq", "ripe", "yamaha", "rely", "medications", "hebrew", "gained", "rochester", "dying", "laundry", "stuck", "solomon", "placing", "stops", "homework", "adjust", "assessed", "advertiser", "enabling", "encryption", "filling", "downloadable", "sophisticated", "imposed", "silence", "scsi", "focuses", "soviet", "possession", "cu", "laboratories", "treaty", "vocal", "trainer", "organ", "stronger", "volumes", "advances", "vegetables", "lemon", "toxic", "dns", "thumbnails", "darkness", "pty", "ws", "nuts", "nail", "bizrate", "vienna", "implied", "span", "stanford", "sox", "stockings", "joke", "respondent", "packing", "statute", "rejected", "satisfy", "destroyed", "shelter", "chapel", "gamespot", "manufacture", "layers", "wordpress", "guided", "vulnerability", "accountability", "celebrate", "accredited", "appliance", "compressed", "bahamas", "powell", "mixture", "zoophilia", "bench", "univ", "tub", "rider", "scheduling", "radius", "perspectives", "mortality", "logging", "hampton", "christians", "borders", "therapeutic", "pads", "butts", "inns", "bobby", "impressive", "sheep", "accordingly", "architect", "railroad", "lectures", "challenging", "wines", "nursery", "harder", "cups", "ash", "microwave", "cheapest", "accidents", "travesti", "relocation", "stuart", "contributors", "salvador", "ali", "salad", "np", "monroe", "tender", "violations", "foam", "temperatures", "paste", "clouds", "competitions", "discretion", "tft", "tanzania", "preserve", "jvc", "poem", "vibrator", "unsigned", "staying", "cosmetics", "easter", "theories", "repository", "praise", "jeremy", "venice", "jo", "concentrations", "vibrators", "estonia", "christianity", "veteran", "streams", "landing", "signing", "executed", "katie", "negotiations", "realistic", "dt", "cgi", "showcase", "integral", "asks", "relax", "namibia", "generating", "christina", "congressional", "synopsis", "hardly", "prairie", "reunion", "composer", "bean", "sword", "absent", "photographic", "sells", "ecuador", "hoping", "accessed", "spirits", "modifications", "coral", "pixel", "float", "colin", "bias", "imported", "paths", "bubble", "por", "acquire", "contrary", "millennium", "tribune", "vessel", "acids", "focusing", "viruses", "cheaper", "admitted", "dairy", "admit", "mem", "fancy", "equality", "samoa", "gc", "achieving", "tap", "stickers", "fisheries", "exceptions", "reactions", "leasing", "lauren", "beliefs", "ci", "macromedia", "companion", "squad", "analyze", "ashley", "scroll", "relate", "divisions", "swim", "wages", "additionally", "suffer", "forests", "fellowship", "nano", "invalid", "concerts", "martial", "males", "victorian", "retain", "colours", "execute", "tunnel", "genres", "cambodia", "patents", "copyrights", "yn", "chaos", "lithuania", "mastercard", "wheat", "chronicles", "obtaining", "beaver", "updating", "distribute", "readings", "decorative", "kijiji", "confused", "compiler", "enlargement", "eagles", "bases", "vii", "accused", "bee", "campaigns", "unity", "loud", "conjunction", "bride", "rats", "defines", "airports", "instances", "indigenous", "begun", "cfr", "brunette", "packets", "anchor", "socks", "validation", "parade", "corruption", "stat", "trigger", "incentives", "cholesterol", "gathered", "essex", "slovenia", "notified", "differential", "beaches", "folders", "dramatic", "surfaces", "terrible", "routers", "cruz", "pendant", "dresses", "baptist", "scientist", "starsmerchant", "hiring", "clocks", "arthritis", "bios", "females", "wallace", "nevertheless", "reflects", "taxation", "fever", "pmc", "cuisine", "surely", "practitioners", "transcript", "myspace", "theorem", "inflation", "thee", "nb", "ruth", "pray", "stylus", "compounds", "pope", "drums", "contracting", "topless", "arnold", "structured", "reasonably", "jeep", "chicks", "bare", "hung", "cattle", "mba", "radical", "graduates", "rover", "recommends", "controlling", "treasure", "reload", "distributors", "flame", "levitra", "tanks", "assuming", "monetary", "elderly", "pit", "arlington", "mono", "particles", "floating", "extraordinary", "tile", "indicating", "bolivia", "spell", "hottest", "stevens", "coordinate", "kuwait", "exclusively", "emily", "alleged", "limitation", "widescreen", "compile", "squirting", "webster", "struck", "rx", "illustration", "plymouth", "warnings", "construct",\
    "apps", "inquiries", "bridal", "annex", "mag", "gsm", "inspiration", "tribal", "curious", "affecting", "freight", "rebate", "meetup", "eclipse", "sudan", "ddr", "downloading", "rec", "shuttle", "aggregate", "stunning", "cycles", "affects", "forecasts", "detect", "actively", "ciao", "ampland", "knee", "prep", "pb", "complicated", "chem", "fastest", "butler", "shopzilla", "injured", "decorating", "payroll", "cookbook", "expressions", "ton", "courier", "uploaded", "shakespeare", "hints", "collapse", "americas", "connectors", "twinks", "unlikely", "oe", "gif", "pros", "conflicts", "techno", "beverage", "tribute", "wired", "elvis", "immune", "latvia", "travelers", "forestry", "barriers", "cant", "jd", "rarely", "gpl", "infected", "offerings", "martha", "genesis", "barrier", "argue", "incorrect", "trains", "metals", "bicycle", "furnishings", "letting", "arise", "guatemala", "celtic", "thereby", "irc", "jamie", "particle", "perception", "minerals", "advise", "humidity", "bottles", "boxing", "wy", "dm", "bangkok", "renaissance", "pathology", "sara", "bra", "ordinance", "hughes", "photographers", "bitch", "infections", "jeffrey", "chess", "operates", "brisbane", "configured", "survive", "oscar", "festivals", "menus", "joan", "possibilities", "duck", "reveal", "canal", "amino", "phi", "contributing", "herbs", "clinics", "mls", "cow", "manitoba", "analytical", "missions", "watson", "lying", "costumes", "strict", "dive", "saddam", "circulation", "drill", "offense", "threesome", "bryan", "cet", "protest", "assumption", "jerusalem", "hobby", "tries", "invention", "nickname", "fiji", "technician", "inline", "executives", "enquiries", "washing", "audi", "staffing", "cognitive", "exploring", "trick", "enquiry", "closure", "raid", "ppc", "timber", "volt", "intense", "div", "playlist", "registrar", "showers", "supporters", "ruling", "steady", "dirt", "statutes", "withdrawal", "myers", "drops", "predicted", "wider", "saskatchewan", "jc", "cancellation", "plugins", "enrolled", "sensors", "screw", "ministers", "publicly", "hourly", "blame", "geneva", "freebsd", "veterinary", "acer", "prostores", "reseller", "dist", "handed", "suffered", "intake", "informal", "relevance", "incentive", "butterfly", "tucson", "mechanics", "heavily", "swingers", "fifty", "headers", "mistakes", "numerical", "ons", "geek", "uncle", "defining", "xnxx", "counting", "reflection", "sink", "accompanied", "assure", "invitation", "devoted", "princeton", "jacob", "sodium", "randy", "spirituality", "hormone", "meanwhile", "proprietary", "timothy", "childrens", "brick", "grip", "naval", "thumbzilla", "medieval", "porcelain", "avi", "bridges", "pichunter", "captured", "watt", "thehun", "decent", "casting", "dayton", "translated", "shortly", "cameron", "columnists", "pins", "carlos", "reno", "donna", "andreas", "warrior", "diploma", "cabin", "innocent", "bdsm", "scanning", "ide", "consensus", "polo", "valium", "copying", "rpg", "delivering", "cordless", "patricia", "horn", "eddie", "uganda", "fired", "journalism", "pd", "prot", "trivia", "adidas", "perth", "frog", "grammar", "intention", "syria", "disagree", "klein", "harvey", "tires", "logs", "undertaken", "tgp", "hazard", "retro", "leo", "statewide", "semiconductor", "gregory", "episodes", "boolean", "circular", "anger", "diy", "mainland", "illustrations", "suits", "chances", "interact", "snap", "happiness", "arg", "substantially", "bizarre", "glenn", "ur", "auckland", "olympics", "fruits", "identifier", "geo", "ribbon", "calculations", "doe", "jpeg", "conducting", "startup", "suzuki", "trinidad", "ati", "kissing", "wal", "handy", "swap", "exempt", "crops", "reduces", "accomplished", "calculators", "geometry", "impression", "abs", "slovakia", "flip", "guild", "correlation", "gorgeous", "capitol", "sim", "dishes", "rna", "barbados", "chrysler", "nervous", "refuse", "extends", "fragrance", "mcdonald", "replica", "plumbing", "brussels", "tribe", "neighbors", "trades", "superb", "buzz", "transparent", "nuke", "rid", "trinity", "charleston", "handled", "legends", "boom", "calm", "champions", "floors", "selections", "projectors", "inappropriate", "exhaust", "comparing", "shanghai", "speaks", "burton", "vocational", "davidson", "copied", "scotia", "farming", "gibson", "pharmacies", "fork", "troy", "ln", "roller", "introducing", "batch", "organize", "appreciated", "alter", "nicole", "latino", "ghana", "edges", "uc", "mixing", "handles", "skilled", "fitted", "albuquerque", "harmony", "distinguished", "asthma", "projected", "assumptions", "shareholders", "twins", "developmental", "rip", "zope", "regulated", "triangle", "amend", "anticipated", "oriental", "reward", "windsor", "zambia", "completing", "gmbh", "buf", "ld", "hydrogen", "webshots", "sprint", "comparable", "chick", "advocate", "sims", "confusion", "copyrighted", "tray", "inputs", "warranties", "genome", "escorts", "documented", "thong", "medal", "paperbacks", "coaches", "vessels", "harbour", "walks", "sucks", "sol", "keyboards", "sage", "knives", "eco", "vulnerable", "arrange", "artistic", "bat", "honors", "booth", "indie", "reflected", "unified", "bones", "breed", "detector", "ignored", "polar", "fallen", "precise", "sussex", "respiratory", "notifications", "msgid", "mainstream", "invoice", "evaluating", "lip", "subcommittee", "sap", "gather", "suse", "maternity", "backed",\
    "alfred", "colonial", "mf", "carey", "motels", "forming", "embassy", "cave", "journalists", "danny", "rebecca", "slight", "proceeds", "indirect", "amongst", "wool", "foundations", "msgstr", "arrest", "volleyball", "mw", "adipex", "horizon", "nu", "deeply", "toolbox", "ict", "marina", "liabilities", "prizes", "bosnia", "browsers", "decreased", "patio", "dp", "tolerance", "surfing", "creativity", "lloyd", "describing", "optics", "pursue", "lightning", "overcome", "eyed", "ou", "quotations", "grab", "inspector", "attract", "brighton", "beans", "bookmarks", "ellis", "disable", "snake", "succeed", "leonard", "lending", "oops", "reminder", "nipple", "xi", "searched", "behavioral", "riverside", "bathrooms", "plains", "sku", "ht", "raymond", "insights", "abilities", "initiated", "sullivan", "za", "midwest", "karaoke", "trap", "lonely", "fool", "ve", "nonprofit", "lancaster", "suspended", "hereby", "observe", "julia", "containers", "attitudes", "karl", "berry", "collar", "simultaneously", "racial", "integrate", "bermuda", "amanda", "sociology", "mobiles", "screenshot", "exhibitions", "kelkoo", "confident", "retrieved", "exhibits", "officially", "consortium", "dies", "terrace", "bacteria", "pts", "replied", "seafood", "novels", "rh", "rrp", "recipients", "playboy", "ought", "delicious", "traditions", "fg", "jail", "safely", "finite", "kidney", "periodically", "fixes", "sends", "durable", "mazda", "allied", "throws", "moisture", "hungarian", "roster", "referring", "symantec", "spencer", "wichita", "nasdaq", "uruguay", "ooo", "hz", "transform", "timer", "tablets", "tuning", "gotten", "educators", "tyler", "futures", "vegetable", "verse", "highs", "humanities", "independently", "wanting", "custody", "scratch", "launches", "ipaq", "alignment", "henderson", "bk", "britannica", "comm", "ellen", "competitors", "nhs", "rocket", "aye", "bullet", "towers", "racks", "lace", "nasty", "visibility", "latitude", "consciousness", "ste", "tumor", "ugly", "deposits", "beverly", "mistress", "encounter", "trustees", "watts", "duncan", "reprints", "hart", "bernard", "resolutions", "ment", "accessing", "forty", "tubes", "attempted", "col", "midlands", "priest", "floyd", "ronald", "analysts", "queue", "dx", "sk", "trance", "locale", "nicholas", "biol", "yu", "bundle", "hammer", "invasion", "witnesses", "runner", "rows", "administered", "notion", "sq", "skins", "mailed", "oc", "fujitsu", "spelling", "arctic", "exams", "rewards", "beneath", "strengthen", "defend", "aj", "frederick", "medicaid", "treo", "infrared", "seventh", "gods", "une", "welsh", "belly", "aggressive", "tex", "advertisements", "quarters", "stolen", "cia", "sublimedirectory", "soonest", "haiti", "disturbed", "determines", "sculpture", "poly", "ears", "dod", "wp", "fist", "naturals", "neo", "motivation", "lenders", "pharmacology", "fitting", "fixtures", "bloggers", "mere", "agrees", "passengers", "quantities", "petersburg", "consistently", "powerpoint", "cons", "surplus", "elder", "sonic", "obituaries", "cheers", "dig", "taxi", "punishment", "appreciation", "subsequently", "om", "belarus", "nat", "zoning", "gravity", "providence", "thumb", "restriction", "incorporate", "backgrounds", "treasurer", "guitars", "essence", "flooring", "lightweight", "ethiopia", "tp", "mighty", "athletes", "humanity", "transcription", "jm", "holmes", "complications", "scholars", "dpi", "scripting", "gis", "remembered", "galaxy", "chester", "snapshot", "caring", "loc", "worn", "synthetic", "shaw", "vp", "segments", "testament", "expo", "dominant", "twist", "specifics", "itunes", "stomach", "partially", "buried", "cn", "newbie", "minimize", "darwin", "ranks", "wilderness", "debut", "generations", "tournaments", "bradley", "deny", "anatomy", "bali", "judy", "sponsorship", "headphones", "fraction", "trio", "proceeding", "cube", "defects", "volkswagen", "uncertainty", "breakdown", "milton", "marker", "reconstruction", "subsidiary", "strengths", "clarity", "rugs", "sandra", "adelaide", "encouraging", "furnished", "monaco", "settled", "folding", "emirates", "terrorists", "airfare", "comparisons", "beneficial", "distributions", "vaccine", "belize", "crap", "fate", "viewpicture", "promised", "volvo", "penny", "robust", "bookings", "threatened", "minolta", "republicans", "discusses", "gui", "porter", "gras", "jungle", "ver", "rn", "responded", "rim", "abstracts", "zen", "ivory", "alpine", "dis", "prediction", "pharmaceuticals", "andale", "fabulous", "remix", "alias", "thesaurus", "individually", "battlefield", "literally", "newer", "kay", "ecological", "spice", "oval", "implies", "cg", "soma", "ser", "cooler", "appraisal", "consisting", "maritime", "periodic", "submitting", "overhead", "ascii", "prospect", "shipment", "breeding", "citations", "geographical", "donor", "mozambique", "tension", "href", "benz", "trash", "shapes", "wifi", "tier", "fwd", "earl", "manor", "envelope", "diane", "homeland", "disclaimers", "championships", "excluded", "andrea", "breeds", "rapids", "disco", "sheffield", "bailey", "aus", "endif", "finishing", "emotions", "wellington", "incoming", "prospects", "lexmark", "cleaners", "bulgarian", "hwy", "eternal", "cashiers", "guam", "cite", "aboriginal", "remarkable", "rotation", "nam", "preventing", "productive", "boulevard", "eugene", "ix", "gdp", "pig", "metric", "compliant", "minus", "penalties", "bennett", "imagination", "hotmail", "refurbished", "joshua", "armenia", "varied",\
    "grande", "closest", "activated", "actress", "mess", "conferencing", "assign", "armstrong", "politicians", "trackbacks", "lit", "accommodate", "tigers", "aurora", "una", "slides", "milan", "premiere", "lender", "villages", "shade", "chorus", "christine", "rhythm", "digit", "argued", "dietary", "symphony", "clarke", "sudden", "accepting", "precipitation", "marilyn", "lions", "findlaw", "ada", "pools", "tb", "lyric", "claire", "isolation", "speeds", "sustained", "matched", "approximate", "rope", "carroll", "rational", "programmer", "fighters", "chambers", "dump", "greetings", "inherited", "warming", "incomplete", "vocals", "chronicle", "fountain", "chubby", "grave", "legitimate", "biographies", "burner", "yrs", "foo", "investigator", "gba", "plaintiff", "finnish", "gentle", "bm", "prisoners", "deeper", "muslims", "hose", "mediterranean", "nightlife", "footage", "howto", "worthy", "reveals", "architects", "saints", "entrepreneur", "carries", "sig", "freelance", "duo", "excessive", "devon", "screensaver", "helena", "saves", "regarded", "valuation", "unexpected", "cigarette", "fog", "characteristic", "marion", "lobby", "egyptian", "tunisia", "metallica", "outlined", "consequently", "headline", "treating", "punch", "appointments", "str", "gotta", "cowboy", "narrative", "bahrain", "enormous", "karma", "consist", "betty", "queens", "academics", "pubs", "quantitative", "lucas", "screensavers", "subdivision", "tribes", "vip", "defeat", "clicks", "distinction", "honduras", "naughty", "hazards", "insured", "harper", "livestock", "mardi", "exemption", "tenant", "sustainability", "cabinets", "tattoo", "shake", "algebra", "shadows", "holly", "formatting", "silly", "nutritional", "yea", "mercy", "hartford", "freely", "marcus", "sunrise", "wrapping", "mild", "fur", "nicaragua", "weblogs", "timeline", "tar", "belongs", "rj", "readily", "affiliation", "soc", "fence", "nudist", "infinite", "diana", "ensures", "relatives", "lindsay", "clan", "legally", "shame", "satisfactory", "revolutionary", "bracelets", "sync", "civilian", "telephony", "mesa", "fatal", "remedy", "realtors", "breathing", "briefly", "thickness", "adjustments", "graphical", "genius", "discussing", "aerospace", "fighter", "meaningful", "flesh", "retreat", "adapted", "barely", "wherever", "estates", "rug", "democrat", "borough", "maintains", "failing", "shortcuts", "ka", "retained", "voyeurweb", "pamela", "andrews", "marble", "extending", "jesse", "specifies", "hull", "logitech", "surrey", "briefing", "belkin", "dem", "accreditation", "wav", "blackberry", "highland", "meditation", "modular", "microphone", "macedonia", "combining", "brandon", "instrumental", "giants", "organizing", "shed", "balloon", "moderators", "winston", "memo", "ham", "solved", "tide", "kazakhstan", "hawaiian", "standings", "partition", "invisible", "gratuit", "consoles", "funk", "fbi", "qatar", "magnet", "translations", "porsche", "cayman", "jaguar", "reel", "sheer", "commodity", "posing", "wang", "kilometers", "rp", "bind", "thanksgiving", "rand", "hopkins", "urgent", "guarantees", "infants", "gothic", "cylinder", "witch", "buck", "indication", "eh", "congratulations", "tba", "cohen", "sie", "usgs", "puppy", "kathy", "acre", "graphs", "surround", "cigarettes", "revenge", "expires", "enemies", "lows", "controllers", "aqua", "chen", "emma", "consultancy", "finances", "accepts", "enjoying", "conventions", "eva", "patrol", "smell", "pest", "hc", "italiano", "coordinates", "rca", "fp", "carnival", "roughly", "sticker", "promises", "responding", "reef", "physically", "divide", "stakeholders", "hydrocodone", "gst", "consecutive", "cornell", "satin", "bon", "deserve", "attempting", "mailto", "promo", "jj", "representations", "chan", "worried", "tunes", "garbage", "competing", "combines", "mas", "beth", "bradford", "len", "phrases", "kai", "peninsula", "chelsea", "boring", "reynolds", "dom", "jill", "accurately", "speeches", "reaches", "schema", "considers", "sofa", "catalogs", "ministries", "vacancies", "quizzes", "parliamentary", "obj", "prefix", "lucia", "savannah", "barrel", "typing", "nerve", "dans", "planets", "deficit", "boulder", "pointing", "renew", "coupled", "viii", "myanmar", "metadata", "harold", "circuits", "floppy", "texture", "handbags", "jar", "ev", "somerset", "incurred", "acknowledge", "thoroughly", "antigua", "nottingham", "thunder", "tent", "caution", "identifies", "questionnaire", "qualification", "locks", "modelling", "namely", "miniature", "dept", "hack", "dare", "euros", "interstate", "pirates", "aerial", "hawk", "consequence", "rebel", "systematic", "perceived", "origins", "hired", "makeup", "textile", "lamb", "madagascar", "nathan", "tobago", "presenting", "cos", "troubleshooting", "uzbekistan", "indexes", "pac", "rl", "erp", "centuries", "gl", "magnitude", "ui", "richardson", "hindu", "dh", "fragrances", "vocabulary", "licking", "earthquake", "vpn", "fundraising", "fcc", "markers", "weights", "albania", "geological", "assessing", "lasting", "wicked", "eds", "introduces", "kills", "roommate", "webcams", "pushed", "webmasters", "ro", "df", "computational", "acdbentity", "participated", "junk", "handhelds", "wax", "lucy", "answering", "hans", "impressed", "slope", "reggae", "failures", "poet", "conspiracy", "surname", "theology", "nails", "evident", "whats", "rides", "rehab", "epic", "saturn", "organizer", "nut", "allergy", "sake", "twisted", "combinations", "preceding", "merit", "enzyme", "cumulative", "zshops", "planes",\
    "edmonton", "tackle", "disks", "condo", "pokemon", "amplifier", "ambien", "arbitrary", "prominent", "retrieve", "lexington", "vernon", "sans", "worldcat", "titanium", "irs", "fairy", "builds", "contacted", "shaft", "lean", "bye", "cdt", "recorders", "occasional", "leslie", "casio", "deutsche", "ana", "postings", "innovations", "kitty", "postcards", "dude", "drain", "monte", "fires", "algeria", "blessed", "luis", "reviewing", "cardiff", "cornwall", "favors", "potato", "panic", "explicitly", "sticks", "leone", "transsexual", "ez", "citizenship", "excuse", "reforms", "basement", "onion", "strand", "pf", "sandwich", "uw", "lawsuit", "alto", "informative", "girlfriend", "bloomberg", "cheque", "hierarchy", "influenced", "banners", "reject", "eau", "abandoned", "bd", "circles", "italic", "beats", "merry", "mil", "scuba", "gore", "complement", "cult", "dash", "passive", "mauritius", "valued", "cage", "checklist", "requesting", "courage", "verde", "lauderdale", "scenarios", "gazette", "hitachi", "divx", "extraction", "batman", "elevation", "hearings", "coleman", "hugh", "lap", "utilization", "beverages", "calibration", "jake", "eval", "efficiently", "anaheim", "ping", "textbook", "dried", "entertaining", "prerequisite", "luther", "frontier", "settle", "stopping", "refugees", "knights", "hypothesis", "palmer", "medicines", "flux", "derby", "sao", "peaceful", "altered", "pontiac", "regression", "doctrine", "scenic", "trainers", "muze", "enhancements", "renewable", "intersection", "passwords", "sewing", "consistency", "collectors", "conclude", "recognised", "munich", "oman", "celebs", "gmc", "propose", "hh", "azerbaijan", "lighter", "rage", "adsl", "uh", "prix", "astrology", "advisors", "pavilion", "tactics", "trusts", "occurring", "supplemental", "travelling", "talented", "annie", "pillow", "induction", "derek", "precisely", "shorter", "harley", "spreading", "provinces", "relying", "finals", "paraguay", "steal", "parcel", "refined", "fd", "bo", "fifteen", "widespread", "incidence", "fears", "predict", "boutique", "acrylic", "rolled", "tuner", "avon", "incidents", "peterson", "rays", "asn", "shannon", "toddler", "enhancing", "flavor", "alike", "walt", "homeless", "horrible", "hungry", "metallic", "acne", "blocked", "interference", "warriors", "palestine", "listprice", "libs", "undo", "cadillac", "atmospheric", "malawi", "wm", "pk", "sagem", "knowledgestorm", "dana", "halo", "ppm", "curtis", "parental", "referenced", "strikes", "lesser", "publicity", "marathon", "ant", "proposition", "pressing", "gasoline", "apt", "dressed", "scout", "belfast", "exec", "dealt", "niagara", "inf", "eos", "warcraft", "charms", "catalyst", "trader", "bucks", "allowance", "vcr", "denial", "uri", "designation", "thrown", "prepaid", "raises", "gem", "duplicate", "electro", "criterion", "badge", "wrist", "civilization", "analyzed", "vietnamese", "heath", "tremendous", "ballot", "lexus", "varying", "remedies", "validity", "trustee", "maui", "weighted", "angola", "squirt", "performs", "plastics", "realm", "corrected", "jenny", "helmet", "salaries", "postcard", "elephant", "yemen", "encountered", "tsunami", "scholar", "nickel", "internationally", "surrounded", "psi", "buses", "expedia", "geology", "pct", "wb", "creatures", "coating", "commented", "wallet", "cleared", "smilies", "vids", "accomplish", "boating", "drainage", "shakira", "corners", "broader", "vegetarian", "rouge", "yeast", "yale", "newfoundland", "sn", "qld", "pas", "clearing", "investigated", "dk", "ambassador", "coated", "intend", "stephanie", "contacting", "vegetation", "doom", "findarticles", "louise", "kenny", "specially", "owen", "routines", "hitting", "yukon", "beings", "bite", "issn", "aquatic", "reliance", "habits", "striking", "myth", "infectious", "podcasts", "singh", "gig", "gilbert", "sas", "ferrari", "continuity", "brook", "fu", "outputs", "phenomenon", "ensemble", "insulin", "assured", "biblical", "weed", "conscious", "accent", "mysimon", "eleven", "wives", "ambient", "utilize", "mileage", "oecd", "prostate", "adaptor", "auburn", "unlock", "hyundai", "pledge", "vampire", "angela", "relates", "nitrogen", "xerox", "dice", "merger", "softball", "referrals", "quad", "dock", "differently", "firewire", "mods", "nextel", "framing", "organised", "musician", "blocking", "rwanda", "sorts", "integrating", "vsnet", "limiting", "dispatch", "revisions", "papua", "restored", "hint", "armor", "riders", "chargers", "remark", "dozens", "varies", "msie", "reasoning", "wn", "liz", "rendered", "picking", "charitable", "guards", "annotated", "ccd", "sv", "convinced", "openings", "buys", "burlington", "replacing", "researcher", "watershed", "councils", "occupations", "acknowledged", "nudity", "kruger", "pockets", "granny", "pork", "zu", "equilibrium", "viral", "inquire", "pipes", "characterized", "laden", "aruba", "cottages", "realtor", "merge", "privilege", "edgar", "develops", "qualifying", "chassis", "dubai", "estimation", "barn", "pushing", "llp", "fleece", "pediatric", "boc", "fare", "dg", "asus", "pierce", "allan", "dressing", "techrepublic", "vg", "bald", "filme", "craps", "fuji", "frost", "leon", "institutes", "mold", "dame", "fo", "sally", "yacht", "tracy", "prefers", "drilling", "brochures", "herb", "tmp", "alot", "ate", "breach", "whale", "traveller", "appropriations",\
    "suspected", "tomatoes", "benchmark", "beginners", "instructors", "highlighted", "bedford", "stationery", "idle", "mustang", "unauthorized", "clusters", "antibody", "competent", "momentum", "fin", "wiring", "io", "pastor", "mud", "calvin", "uni", "shark", "contributor", "demonstrates", "phases", "grateful", "emerald", "gradually", "laughing", "grows", "cliff", "desirable", "tract", "ul", "ballet", "ol", "journalist", "abraham", "js", "bumper", "afterwards", "webpage", "religions", "garlic", "hostels", "shine", "senegal", "explosion", "pn", "banned", "wendy", "briefs", "signatures", "diffs", "cove", "mumbai", "ozone", "disciplines", "casa", "mu", "daughters", "conversations", "radios", "tariff", "nvidia", "opponent", "pasta", "simplified", "muscles", "serum", "wrapped", "swift", "motherboard", "runtime", "inbox", "focal", "bibliographic", "vagina", "eden", "distant", "incl", "champagne", "ala", "decimal", "hq", "deviation", "superintendent", "propecia", "dip", "nbc", "samba", "hostel", "housewives", "employ", "mongolia", "penguin", "magical", "influences", "inspections", "irrigation", "miracle", "manually", "reprint", "reid", "wt", "hydraulic", "centered", "robertson", "flex", "yearly", "penetration", "wound", "belle", "rosa", "conviction", "hash", "omissions", "writings", "hamburg", "lazy", "mv", "mpg", "retrieval", "qualities", "cindy", "lolita", "fathers", "carb", "charging", "cas", "marvel", "lined", "cio", "dow", "prototype", "importantly", "rb", "petite", "apparatus", "upc", "terrain", "dui", "pens", "explaining", "yen", "strips", "gossip", "rangers", "nomination", "empirical", "mh", "rotary", "worm", "dependence", "discrete", "beginner", "boxed", "lid", "sexuality", "polyester", "cubic", "deaf", "commitments", "suggesting", "sapphire", "kinase", "skirts", "mats", "remainder", "crawford", "labeled", "privileges", "televisions", "specializing", "marking", "commodities", "pvc", "serbia", "sheriff", "griffin", "declined", "guyana", "spies", "blah", "mime", "neighbor", "motorcycles", "elect", "highways", "thinkpad", "concentrate", "intimate", "reproductive", "preston", "deadly", "feof", "bunny", "chevy", "molecules", "rounds", "longest", "refrigerator", "tions", "intervals", "sentences", "dentists", "usda", "exclusion", "workstation", "holocaust", "keen", "flyer", "peas", "dosage", "receivers", "urls", "customise", "disposition", "variance", "navigator", "investigators", "cameroon", "baking", "marijuana", "adaptive", "computed", "needle", "baths", "enb", "gg", "cathedral", "brakes", "og", "nirvana", "ko", "fairfield", "owns", "til", "invision", "sticky", "destiny", "generous", "madness", "emacs", "climb","blowing", "fascinating", "landscapes", "heated", "lafayette", "jackie", "wto", "computation", "hay", "cardiovascular", "ww", "sparc", "cardiac", "salvation", "dover", "adrian", "predictions", "accompanying", "vatican", "brutal", "learners", "gd", "selective", "arbitration", "configuring", "token", "editorials", "zinc", "sacrifice", "seekers", "guru", "isa", "removable", "convergence", "yields", "gibraltar", "levy", "suited", "numeric", "anthropology", "skating", "kinda", "aberdeen", "emperor", "grad", "malpractice", "dylan", "bras", "belts", "blacks", "educated", "rebates", "reporters", "burke", "proudly", "pix", "necessity", "rendering", "mic", "inserted", "pulling", "basename", "kyle", "obesity", "curves", "suburban", "touring", "clara", "vertex", "bw", "hepatitis", "nationally", "tomato", "andorra", "waterproof", "expired", "mj", "travels", "flush", "waiver", "pale", "specialties", "hayes", "humanitarian", "invitations", "functioning", "delight", "survivor", "garcia", "cingular", "economies", "alexandria", "bacterial", "moses", "counted", "undertake", "declare", "continuously", "johns", "valves", "gaps", "impaired", "achievements", "donors", "tear", "jewel", "teddy", "lf", "convertible", "ata", "teaches", "ventures", "nil", "bufing", "stranger", "tragedy", "julian", "nest", "pam", "dryer", "painful", "velvet", "tribunal", "ruled", "nato", "pensions", "prayers", "funky", "secretariat", "nowhere", "cop", "paragraphs", "gale", "joins", "adolescent", "nominations", "wesley", "dim", "lately", "cancelled", "scary", "mattress", "mpegs", "brunei", "likewise", "banana", "introductory", "slovak", "cakes", "stan", "reservoir", "occurrence", "idol", "bloody", "mixer", "remind", "wc", "worcester", "sbjct", "demographic", "charming", "mai", "tooth", "disciplinary", "annoying", "respected", "stays", "disclose", "affair", "drove", "washer", "upset", "restrict", "springer", "beside", "mines", "portraits", "rebound", "logan", "mentor", "interpreted", "evaluations", "fought", "baghdad", "elimination", "metres", "hypothetical", "immigrants", "complimentary", "helicopter", "pencil", "freeze", "hk", "performer", "abu", "titled", "commissions", "sphere", "powerseller", "moss", "ratios", "concord", "graduated", "endorsed", "ty", "surprising", "walnut", "lance", "ladder", "italia", "unnecessary", "dramatically", "liberia", "sherman", "cork", "maximize", "cj", "hansen", "senators", "workout", "mali", "yugoslavia", "bleeding", "characterization", "colon", "likelihood", "lanes", "purse", "fundamentals", "contamination", "mtv", "endangered", "compromise", "optimize", "stating", "dome", "caroline", "leu", "expiration", "namespace", "align", "peripheral", "bless", "engaging", "negotiation", "crest", "opponents", "triumph", "nominated", "confidentiality", "electoral", "changelog",\
    "welding", "orgasm", "deferred", "alternatively", "heel", "alloy", "condos", "plots", "polished", "yang", "gently", "greensboro", "tulsa", "locking", "casey", "controversial", "draws", "fridge", "blanket", "bloom", "qc", "simpsons", "lou", "elliott", "recovered", "fraser", "justify", "upgrading", "blades", "pgp", "loops", "surge", "frontpage", "trauma", "aw", "tahoe", "advert", "possess", "demanding", "defensive", "sip", "flashers", "subaru", "forbidden", "tf", "vanilla", "programmers", "pj", "monitored", "installations", "deutschland", "picnic", "souls", "arrivals", "spank", "cw", "practitioner", "motivated", "wr", "dumb", "smithsonian", "hollow", "vault", "securely", "examining", "fioricet", "groove", "revelation", "rg", "pursuit", "delegation", "wires", "bl", "dictionaries", "mails", "backing", "greenhouse", "sleeps", "vc", "blake", "transparency", "dee", "travis", "wx", "endless", "figured", "orbit", "currencies", "niger", "bacon", "survivors", "positioning", "heater", "colony", "cannon", "circus", "promoted", "forbes", "mae", "moldova", "mel", "descending", "paxil", "spine", "trout", "enclosed", "feat", "temporarily", "ntsc", "cooked", "thriller", "transmit", "apnic", "fatty", "gerald", "pressed", "frequencies", "scanned", "reflections", "hunger", "mariah", "sic", "municipality", "usps", "joyce", "detective", "surgeon", "cement", "experiencing", "fireplace", "endorsement", "bg", "planners", "disputes", "textiles", "missile", "intranet", "closes", "seq", "psychiatry", "persistent", "deborah", "conf", "marco", "assists", "summaries", "glow", "gabriel", "auditor", "wma", "aquarium", "violin", "prophet", "cir", "bracket", "looksmart", "isaac", "oxide", "oaks", "magnificent", "erik", "colleague", "naples", "promptly", "modems", "adaptation", "hu", "harmful", "paintball", "prozac", "sexually", "enclosure", "acm", "dividend", "newark", "kw", "paso", "glucose", "phantom", "norm", "playback", "supervisors", "westminster", "turtle", "ips", "distances", "absorption", "treasures", "dsc", "warned", "neural", "ware", "fossil", "mia", "hometown", "badly", "transcripts", "apollo", "wan", "disappointed", "persian", "continually", "communist", "collectible", "handmade", "greene", "entrepreneurs", "robots", "grenada", "creations", "jade", "scoop", "acquisitions", "foul", "keno", "gtk", "earning", "mailman", "sanyo", "nested", "biodiversity", "excitement", "somalia", "movers", "verbal", "blink", "presently", "seas", "carlo", "workflow", "mysterious", "novelty", "bryant", "tiles", "voyuer", "librarian", "subsidiaries", "switched", "stockholm", "tamil", "garmin", "ru", "pose", "fuzzy", "indonesian", "grams", "therapist", "richards", "mrna", "budgets", "toolkit", "promising", "relaxation", "goat", "render", "carmen", "ira", "sen", "thereafter", "hardwood", "erotica", "temporal", "sail", "forge", "commissioners", "dense", "dts", "brave", "forwarding", "qt", "awful", "nightmare", "airplane", "reductions", "southampton", "istanbul", "impose", "organisms", "sega", "telescope", "viewers", "asbestos", "portsmouth", "cdna", "meyer", "enters", "pod", "savage", "advancement", "wu", "harassment", "willow", "resumes", "bolt", "gage", "throwing", "existed", "generators", "lu", "wagon", "barbie", "dat", "favour", "soa", "knock", "urge", "smtp", "generates", "potatoes", "thorough", "replication", "inexpensive", "kurt", "receptors", "peers", "roland", "optimum", "neon", "interventions", "quilt", "huntington", "creature", "ours", "mounts", "syracuse", "internship", "lone", "refresh", "aluminium", "snowboard", "beastality", "webcast", "michel", "evanescence", "subtle", "coordinated", "notre", "shipments", "maldives", "stripes", "firmware", "antarctica", "cope", "shepherd", "lm", "canberra", "cradle", "chancellor", "mambo", "lime", "kirk", "flour", "controversy", "legendary", "bool", "sympathy", "choir", "avoiding", "beautifully", "blond", "expects", "cho", "jumping", "fabrics", "antibodies", "polymer", "hygiene", "wit", "poultry", "virtue", "burst", "examinations", "surgeons", "bouquet", "immunology", "promotes", "mandate", "wiley", "departmental", "bbs", "spas", "ind", "corpus", "johnston", "terminology", "gentleman", "fibre", "reproduce", "convicted", "shades", "jets", "indices", "roommates", "adware", "qui", "intl", "threatening", "spokesman", "zoloft", "activists", "frankfurt", "prisoner", "daisy", "halifax", "encourages", "ultram", "cursor", "assembled", "earliest", "donated", "stuffed", "restructuring", "insects", "terminals", "crude", "morrison", "maiden", "simulations", "cz", "sufficiently", "examines", "viking", "myrtle", "bored", "cleanup", "yarn", "knit", "conditional", "mug", "crossword", "bother", "budapest", "conceptual", "knitting", "attacked", "hl", "bhutan", "liechtenstein", "mating", "compute", "redhead", "arrives", "translator", "automobiles", "tractor", "allah", "continent", "ob", "unwrap", "fares", "longitude", "resist", "challenged", "telecharger", "hoped", "pike", "safer", "insertion", "instrumentation", "ids", "hugo", "wagner", "constraint", "groundwater", "touched", "strengthening", "cologne", "gzip", "wishing", "ranger", "smallest", "insulation", "newman", "marsh", "ricky", "ctrl", "scared", "theta", "infringement", "bent", "laos", "subjective", "monsters", "asylum", "lightbox", "robbie", "stake", "cocktail", "outlets", "swaziland", "varieties", "arbor", "mediawiki", "configurations", "poison", 
    "how are you", "i am fine", "youre welcome", "i dont know", "maybe", "hi", "hello", "whats up", "im thinking of you", "i miss you", "i love you", "i love you deeply",\
    "i love you so much", "i love you always", "i love you much", "where are you", "ill come over", "come over here", "lets meet", "playing", "just joking", "youre in my mind", "whenever", "i saw you", "we were together", "we met", "we met a while ago", "we just met", "you saw me", "im studying", "im in school", "im travelling", "im in transit", "im at work", "im playing", "im shopping", "im at the grocery", "im at the parlor", "im at home", "where you are", "i adore you", "you are adored", "you are special", "am i special", "do you love me?", "yes", "no", "maybe", "lets meet again", "i hope to see you again", "what are you thinking", "youre always in my mind", "in the depths of soul", "in as much as I want", "nevertheless", "coming up with it", "i don't know this", "thinking of it", "thinking of you", "thinking of us", "i never want to but", "carry me all the way", "i am happy", "starting", "i never know how", "as much as i would", "killing me softly", "killing us", "the quietest weather", "gray clouds above", "i see the clear sky", "while the sky is bluest", "i've never been apart", "how would i know", "will i see you again", "it came up to me", "i was surprised", "surprising", "i would", "come to me", "start with this", "a few words", "lenten season is upon us", "i love", "thinking", "stop", "i wish i would have", "consider me", "i am looking for food", "while i am clothed", "walking the distance", "i still end up with you", "consider my wish", "halfed tree", "searching", "unsure", "not minding everyone", "listening to music", "on my computer", "typing", "eating", "sleeping", "thinking", "never missing", "stopping", "staring", "resting", "excruciating pain", "this sadness", "while im without", "collecting", "listening", "happiness", "the surf", "inspired", "rocking the music", "travelling", "playing", "while music plays", "stirring things up", "taking a bath", "walking on the shore", "grinding", "i never knew how", "i be at it", "considered everything", "i died", "i slept", "its wrapped", "made a union", "the sky bleeds", "music is spoken", "chilled", "i am spoiled", "this bringeth happiness", "its up to me", "the weather is", "i stay awake", "pillows", "grains", "half of the time", "it ends here", "i take flight", "distance is", "i like this", "forever", "lets meet", "gathered my wits", "what is?", "what is ?", "ouch!", "**", "that?", "ok", "ok bye", "really?", "why not..", "aww why?", "tell me!", "what s it?", "don't do that to me", "hi sir", "oh uhm..", "I honestly don't know", "I know", "this", "did you see", "good boy", "good pinsan", "do you have a gf?", "*kisses*", "feel good!", "like this", "like thus", "what are you doing to me?", "shall we talk about something else?", "oh yes..", "because", "I might consider it", "yes you :)", "you and me", "I like that more", "me?", "I agree", "I love you more", "I will", "IDK", "stuff", "sorry you cant do this here", "I love it", "oh no", ""\
                     "Ace of Hearts", "Two of Hearts", "Three of Hearts", "Four of Hearts", "Five of Hearts", "Six of Hearts", "Seven of Hearts", "Eight of Hearts", "Nine of Hearts", "Ten of Hearts", "Jack of Hearts", "Queen Of Hearts", "King of Hearts", "Ace of Clubs", "Two of Clubs", "Three of Clubs", "Four of Clubs", "Five of Clubs", "Six of Clubs", "Seven of Clubs", "Eight of Clubs", "Nine of Clubs", "Ten of Clubs", "Jack of Clubs", "Queen Of Clubs", "King of Clubs", "Ace of Diamonds", "Two of Diamonds", "Three of Diamonds", "Four of Diamonds", "Five of Diamonds", "Six of Diamonds", "Seven of Diamonds", "Eight of Diamonds", "Nine of Diamonds", "Ten of Diamonds", "Jack of Diamonds", "Queen Of Diamonds", "King of Diamonds", "Ace of Spades", "Two of Spades", "Three of Spades", "Four of Spades", "Five of Spades", "Six of Spades", "Seven of Spades", "Eight of Spades", "Nine of Spades", "Ten of Spades", "Jack of Spades", "Queen Of Spades", "King of Spades", "Joker", "Joker", "empty bottle", "bottle of wine", "wine glass", "bottle of iced tea", "energy drink", "lemon juice", "pack of green peas", "shirt", "bed", "headphones", "earphones", "blanket", "tablet", "kindle", "pills", "pack of coffee beans", "cup of coffee", "junkfood", "medicine", "spoon", "fork", "Nintendo Switch", "laptop", "mobile phone", "electric fan", "chair", "guitar", "keyboard", "piano", "tv", "monitor", "oil", "hashish", "marijuana", "cigarette", "vape", "pillow", "dog food", "bike", "car", "scooter", "skateboard", "printer", "shards of glass", "garbage", "strips of sleather", "food", "bottle of water", "bible", "Dhammapada", "yoga mat", "helmet", "chewing gum", "vitamins", "shirt", "sweater", "pants", "working pants", "skirt", "underwear", "parachute", "gun", "knife", "sword", "katana", "oatmeal", "chain", "slippers", "shoes", "book", "wires", "credit card", "stove", "oven", "hat", "bucket hat", "baseball cap", "beanie", "hoodie", "necklace", "ring", "gold ring", "diamond ring", "diamond", "diamonds", "painting", "pencil", "ballpoint pen", "sketchpad", "crayon", "box of crayons", "paint", "spray paint", "fruit", "lettuce", "carrot", "watermelon", "orange", "apple", "banana", "pear", "gold", "gold bar", "pistol", "lantern", "lamp", "umbrella", "newspaper", "Sega", "ecstasy", "Nintendo 64", "calculator", "brownies", "pie", "loaf bread", "aviator shades", "shutter shades", "CD", "floppy disk", "mp3 player", "walkman", "cassette", "ticket", "food stub", "ski mask", "spear", "nunchucks", "frying pan", "beans", "charger", "guitar pick", "mic", "digicam", "GoPro", "night vision goggles", "sniper rifle", "DS4 Playstation controller", "CDJ", "Raybans", "smartwatch", "modem", "axe", "Canada", "Sweden", "China", "Beijing", "New York", "California", "L.A.", "San Francisco", "Detroit", "Colorado", "Newark", "New Jersey", "Australia", "Gold Coast", "Thailand", "North Korea", "Pyongyang", "Seoul", "Tokyo", "Osaka", "Japan", "Fujian", "Kyoto", "Manila", "Palawan", "Siargao", "Sultan Kudarat", "Davao", "Sydney", "Poland", "Uzbekistan", "Kyrgystan", "Turkey", "Iraq", "Iran", "Bolivia", "Iceland", "Lithuania", "Greenland", "UK", "France", "Spain", "Rome", "Greece", "Amsterdam", "Netherlands", "Boracay", "Indonesia", "Russia", "Ukraine", "Africa", "Antarctica", "Alaska", "South Carolina", "North Carolina", "Philadelphia", "Brooklyn", "Mexico", "Brazil", "Taiwan", "Burma", "Cambodia", "Vietnam", "India", "Bangladesh", "New Delhi", "Bombay", "Philippines", "Africa and African America", "Aikido", "Animal and Imitative Systems in Chinese Martial Arts", "Archery, Japanese", "Baguazhang (Pa Kua Ch' uan)", "Boxing, Chinese", "Boxing, Chinese Shaolin Styles", "Boxing, European", "Brazilian Jiu Jitsu", "Budo, Bujutsu, and Bugei", "Capoeira", "China", "Chivalry", "Combatives: Military and Police Martial Art Training", "Dueling", "Europe", "External vs. Internal Chinese Martial Arts", "Folklore in the Martial Arts", "Form/Xing/Kata/Pattern Practice", "Gladiators", "Gunfighters","Hapkido", "Heralds", "Iaido", "India", "Japan", "Japanese Martial Arts, Chinese Influences on", "Jeet Kune Do", "Judo", "Kajukenbo", "Kalarippayattu", "Karate, Japanese", "Karate, Okinawan", "Kendo", "Kenpo", "Ki/Qi", "Knights", "Kobudo, Okinawan", "Korea", "Korean Martial Arts, Chinese Influences On", "Koryu Bugei, Japanese", "Krav Maga", "Kung Fu/Gungfu/Gongfu", "Masters of Defense", "Medicine, Traditional Chinese", "Meditation", "Middle East", "Mongolia", "Muay Thai", "Ninjutsu", "Okinawa", "Orders of Knighthood, Secular", "Pacific Islands", "Pankration", "Performing Arts", "Philippines", "Political Conflict and the Martial Arts", "Rank", "Religion and Spiritual Development: Ancient Mediterranean and Medieval West", "Religion and Spiritual Development: China", "Religion and Spiritual Development: India", "Religion and Spiritual Development: Japan", "Sambo", "Samurai", "Savate", "Silat", "Social Uses of the Martial Arts", "Southeast Asia", "Stage Combat", "Stickfighting, Non-Asian", "Sword, Japanese", "Swordsmanship, European Medieval", "Swordsmanship, European Renaissance", "Swordsmanship, Japanese", "Swordsmanship, Korean/Hankuk Haedong Kumdo", "T'aek'kyon", "Taekwondo", "Taijiquan (Tai Chi Ch'uan)", "Thaing", "Thang-Ta", "Training Area", "Varma Ati", "Vovinam/Viet Vo Dao", "Warrior Monks, Japanese/Sohei", "Women in the Martial Arts", "Women in the Martial Arts: Britain and North America", "Women in the Martial Arts: China", "Women in the Martial Arts: Japan", "Wrestling and Grappling: China", "Wrestling and Grappling: Europe", "Wrestling and Grappling: India", "Wrestling and Grappling: Japan", "Wrestling, Professional", "Written Texts: China", "Written Texts: India", "Written Texts: Japan", "Xingyiquan (Hsing I Ch'uan)", "Yongchun/Wing Chun", "Backside 180", "Backside 360", "Backside Caballerial", "Backside Half Cab", "Fakie Ollie", "Frontside 180", "Frontside 360", "Frontside Caballerial", "Frontside Half Cab", "Kickturn", "Nollie", "Nollie Backside 180", "Nollie Backside 360", "Nollie Frontside 180", "Nollie Frontside 360", "Ollie", "Ollie North", "Ollie South", "Switch Backside 180", "Switch Backside 360", "Switch Frontside 180", "Switch Frontside 360", "Switch Ollie", "Tic-Tac", "360 Flip", "360 Hardflip", "360 Ollie Heelflip", "360 Ollie Kickflip", "360 Pop Shove-it", "360 Shuvit", "540 Flip", "720 Flip", "Alpha Flip", "Anti Casper Flip", "Backside Bigspin", "Backside Flip", "Backside Half Cab Heelflip", "Backside Half Cab Kickflip", "Backside Heelflip", "Backside Kickflip", "Big Heelflip", "Bigflip", "Biggerflip", "Biggerspin", "Bigspin", "Bubble Flip", "Bullflip", "Caballerial Flip", "Camel Flip", "Casper Flip", "Daydream Flip", "De Comply", "Disco Flip", "Double Heelflip", "Double Kickflip", "Dragon Flip", "Fakie 360 Flip", "Fakie 360 Hardflip", "Fakie Backside Bigspin", "Fakie Backside Pop Shove-it", "Fakie Frontside Bigspin", "Fakie Frontside Pop Shove-it", "Fakie Hardflip", "Fakie Heelflip", "Fakie Inward Heelflip", "Fakie Kickflip", "Fakie Varial Heelflip", "Fakie Varial Kickflip", "Feather Flip", "Fingerflip", "Forward Flip", "Front Foot Impossible", "Frontside 360 Pop Shove it", "Frontside Bigspin", "Frontside Flip", "Frontside Half Cab Heelflip", "Frontside Half Cab Kickflip", "Frontside Heelflip", "Frontside Kickflip", "Frontside Pop Shove-it", "Gazelle Flip", "Gazelle Spin", "Ghetto Bird", "Gingersnap", "Grape Flip", "Half Cab", "Handstand Flip", "Hardflip", "Haslam Flip", "Heelflip", "Hospital Flip", "Illusion Flip", "Impossible", "Inward Heelflip", "Jesus Flip", "Kickback Flip", "Kickflip", "Kiwi Flip", "Laser Flip", "Late Kickflip", "Nerd Flip", "Nightmare Flip", "No Comply", "540", "720", "900", "Airwalk", "Benihana", "Cannonball", "Christ Air", "Crossbone", "Delmar Indy", "Indy", "Indy Grab", "Invert", "Japan Air", "Judo Air", "Madonna", "McTwist", "Melancholy Grab", "Melon", "Method Air", "Mute Air", "Nose Grab", "Rocket Air", "Sal Flip", "Seatbelt Grab", "Stiffy", "Superman Grab", "Varial", "Egg Plant", "Manual", "Nose Manual", "Varial Heelflip", "Varial Kickflip",\
                     "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "Abstract Art", "Abstract Expressionism", "Academicism", "Analytical Cubism", "Art Deco", "Art Nouveau", "Ashcan School", "Banksy", "Baroque", "Byzantine Art", "Classicism", "Cloisonnism", "Color Field", "Conceptual Art", "Constructivism", "Cubism", "Cubo-Futurism", "Dadaism", "Dutch Golden Age", "Early Netherlandish", "Early Renaissance", "Expressionism", "Fauvism", "Futurism", "Geometric Abstract Art", "Gothic Art", "High Renaissance", "Hudson River School", "Impressionism", "Italian Renaissance", "Kitsch", "Luminism", "Mannerism", "Metaphysical Art", "Minimalism", "Modernism", "Naive Art/ Primitivism", "Neo-Baroque", "Neo-Classicism", "Neo-Dada", "Neo Expressionism", "Neoplasticism", "New Realism", "Northern Renaissance", "Op-Art", "Orientalism", "Orphism", "Pointilism", "Pop Art", "Pop Surrealism", "Post-Impressionism", "Pre-Raphaelites", "Precisionism", "Proto Renaissance", "Purism", "Realism", "Regionalism", "Renaissance", "Rococo", "Romanticism", "Social Realism", "Socialist Realism", "Suprematism", "Surrealism", "Symbolism", "Synthetic Cubism", "Synthetism", "Tenebrism", "Tonalism", "Tubism", "Ukiyo-E", "Verism", "Alternative", "Anime", "Blues", "Classical", "Comedy", "Commercials", "Country", "Dance", "Easy Listening", "Electronic", "Enka", "French Pop", "Folk Music", "German Folk", "German Pop", "Fitness and Workout", "Hip-Hop/Rap", "Holiday Music", "Indie Pop", "Industrial", "Inspirational", "Instrumental", "Jazz", "K-Pop", "Karaoke", "Latin", "Metal", "New Age", "Opera", "Pop", "R&B/Soul", "Reggae", "Rock", "Soundtracks", "Spoken Word", "Tex-Mex/Tejano", "Vocal", "World", "You met", "You fought with", "You fought with", "You defeated", "You defeated","You defeated", "You were sent to the hospital by", "You were defeated by", "You healed", "You were healed by", "You jailed", "You pranked", "You were pranked by", "You were jailed by", "you were beat by", "you were K.Ode by", "a stranger", "a child", "an emo", "a doctor", "a soldier", "a police", "a homeless person", "a mom", "a gamer", "a dancer", "an artist", "a peasant", "a prince", "a princess", "a King", "a Queen", "a lawyer", "a vendor", "an alien", "a Mexican", "a nurse", "a lizard", "a woman", "a girl", "a boy", "an optometrist", "a physician", "a psychologist", "a psychiatrist", "a teacher", "White Tara", "Green Tara", "a ninja", "a gangster", "Dollars", "Rupies", "Yen", "Pesos", "Pounds", "Coins", "Arcade Coins", "Mickey Mouse Money", "Francs", "Shekels", "Tugriks", "Indian Rupees", "Singapore Dollars", "Rubles", "Dinars", "Yuans", "Bahts", "Afghanis", "Riyals", "Kronas", "Riels", "DDOS attacks", "Botnets", "Credit Card Numbers", "E-mail addresses", "Business Addresses", "Home Addresses", "Passwords", "Mobile Numbers", "Telephone Numbers", "STD", "spits", "garbage", "sickness", "nudes", "hate", "likes", "Canada", "Sweden", "China", "Beijing", "New York", "California", "L.A.", "San Francisco", "Detroit", "Colorado", "Newark", "New Jersey", "Australia", "Gold Coast", "Thailand", "North Korea", "Pyongyang", "Seoul", "Tokyo", "Osaka", "Japan", "Fujian", "Kyoto", "Manila", "Palawan", "Siargao", "Sultan Kudarat", "Davao", "Sydney", "Poland", "Uzbekistan", "Kyrgystan", "Turkey", "Iraq", "Iran", "Bolivia", "Iceland", "Lithuania", "Greenland", "UK", "France", "Spain", "Rome", "Greece", "Amsterdam", "Netherlands", "Boracay", "Indonesia", "Russia", "Ukraine", "Africa", "Antarctica", "Alaska", "South Carolina", "North Carolina", "Philadelphia", "Brooklyn", "Mexico", "Brazil", "Taiwan", "Burma", "Cambodia", "Vietnam", "India", "Bangladesh", "New Delhi", "Bombay", "Philippines", "Italy", "Belgium", "Denmark", "Colombia", "Argentina", "Albania", "Algeria", "Andora", "Angola", "Antigua and Barbuda", "Armenia", "Austria", "Azerbaijan", "Bahamas", "Bahrain", "Belarus", "Belize", "Benin", "Bhutan", "Bosnia", "Botswana", "Brunei", "Bulgaria", "Burkina Faso", "Burundi", "Cabo Verde", "Cameroon", "Chad", "Chile", "Costa Rica", "Croatia", "Cuba", "Cyprus", "Czechia", "Congo", "Djibouti", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador", "Guinea", "Estonia", "Swaziland", "Ethiopia", "Fiji", "Gabon", "Gambia", "Ghana", "Guatemala", "Guyana", "Haiti", "Honduras", "Hungary", "Israel", "Italy", "Jamaica", "Kenya", "Jordan", "Laos", "Latvia", "Lebanon", "Liberia", "Liechtenstein", "Luxembourg", "Madagascar", "Malawi", "Malaysia", "Maldives", "Mali", "Malta", "Mauritiana", "Mauritius", "Micronesia", "Moldova", "Monaco", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nauru", "Nepal", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "Oman", "Pakistan", "Palau", "Palestine State", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Portugal", "Qatar", "Romania", "Rwanda", "Saint Kitts and Nevis", "Saint Lucia", "Saint Vincent and the Grenadines", "Samoa", "San Marino", "Sao Tome and Principe", "Senegal", "Serbia", "Seychelles", "Sierra Leone", "Slovakia", "Slovenia", "Solomon Islands", "South Africa", "South Korea", "South Sudan", "Sri Lanka", "Sudan", "Suriname", "Syria", "Tajikistan", "Tanzania", "Togo", "Tonga", "Trinidad and Tobago", "Tunisia", "Turkmenistan", "Tuvalu", "Uganda", "Ukraine", "Uruguay", "Uzbekistan", "Vanuatu", "Venezuela", "Yemen", "Zambia", "Zimbabwe", "samurai helmet", "bike helmet", "motorcycle helmet", "astronaut helmet", "pilot helmet", "aviator hat", "baseball cap", "backwards baseball cap", "trucker cap", "backwards trucker cap", "construction helmet", "miner helmet", "skate helmet", "ski mask", "facemask", "beanie", "birthday party hat", "pantyhose", "f13th mask", "jabbawockee mask", "none", "poring hat", "beehive", "idea bubble", "speech bubble", "bucket hat", "black bucket hat", "beige bucket hat", "orange bucket hat", "blue bucket hat", "american football helmet", "rugby helmet", "emo hair", "mohawk", "blonded semi-balded", "skinhead", "tropika", "glasses", "raybans", "shades", "spectacles", "night-vision goggles", "pilot goggles", "black-rimmed glasses", "nostril piercing", "tibetan headgear", "sikh headgear", "muslim hat", "skullcap", "muslim skullhat", "long hair", "salt and pepper", "blonde", "headphones", "earphones", "visor hat", "headband", "cat headband", "rabbit headband", "afro", "curly curls", "facial mask", "face paint", "warpaint", "unipaint", "maked-up", "bush headgear", "soldier helmet", "buddhahead", "game-night drink", "cig", "tobacco", "spliff", "straw", "british army guard headgear", "police helmet", "police mask", "hanja mask", "java mask", "african continent mask", "feather", "chef hat", "indian chief headgear", "black paint", "hijab", "knight armor", "police armor", "samurai armor", "karate uniform", "police uniform", "soldier uniform", "korean robe", "japanese robe", "barong", "polo", "shirt", "black shirt", "sweater", "tanktop", "backpack", "slingbag", "none", "chest hair", "kevlar", "press vest", "bush gear", "hoodie", "white hoodie", "blue hoodie", "tight shirt", "nikes", "puma", "adidas", "coca-cola retro shirt", "rasta shirt", "sash", "soccer uniform", "american football armor", "football shirt", "soccer shirt", "referee shirt", "pacemaker", "bra", "bikini", "chest bag", "tuxedo", "suit", "bowtie", "tie", "apron", "chef uniform", "red paint", "black paint", "astronaut suit", "diving suit", "rashguard", "jersey", "bathrobe", "farmer gear", "lanyard", "muslim clothing", "sikh clothing", "tourguide uniform", "boyscout uniform", "girlscout uniform", "black sweater", "scarf", "shawl", "green hoodie", "pink hoodie", "jacket", "windbreaker", "varsity jacket", "jock jacket", "vest", "coat", "sword", "samurai", "club", "knife", "machete", "ice cream", "food", "coffee", "pizza", "camera", "gun", "staff", "ruler", "katana", "arnis", "nunchucks", "cat", "tablet", "phone", "iphone", "android", "fruitshake", "vape", "bong", "spliff", "joint", "beer", "champagne", "chainsaw", "folder", "testpaper", "pen", "macbook", "laptop", "linux computer", "pencil", "paintbrush", "tire pump", "fire extinguisher", "measuring device", "scalpel", "diamond cutter", "diamond", "diamonds", "trash", "water", "none", "empty-hand", "spraypaint", "smartwatch", "dynamite", "c4", "whisker", "whiskey", "liquor", "flask", "leaf", "feather", "book", "novel", "junkfood", "rifle", "sniper", "handgun", "laser", "keys", "guitar", "electric guitar", "classical guitar", "ukulele", "keyboard", "burger", "twig", "plank", "paddel", "coins", "money", "dollar bills", "fruit", "vegetable", "ps4 controller", "xbox controller", "ipod", "yarn", "spear", "bow", "tights", "shorts", "cycling shorts", "skirt", "bushwear", "pants", "leggings", "elephant pants", "skinny jeans", "jeans", "none", "trunks", "pants", "pants", "pants", "holster", "bruise", "slacks", "hiking pants", "karate pants", "taekwondo pants", "mma shorts", "briefs", "sleather pants", "slippers", "hotel slippers", "shoes", "shoes", "shoes", "shoes", "boots", "beige boots", "black army boots", "nikes", "adidas", "puma", "converse", "chucks", "none", "socks", "clogs", "leather shoes", "white shoes", "skateboard", "longboard", "sneakers", "new balance", "world balance", "fluffy shoes", "fluffy slippers", "sandals", "You walk in a field", "You encounter an animal", "You encounter a monster", "You encounter an enemy", "You encounter a friend", "You encounter an ally", "You enter an alley", "It is night time", "The sun just rised", "It is dawn", "It is dusk", "You enter the university", "You sit down on your computer", "You just chill", "You chill in a cafe", "You feel sleepy", "You are hungry", "You walk on", "You run straight", "You run in loops", "You are tired", "You are bullied", "You are sent to the hospital", "You go on a roadtrip", "You hike", "You mine", "You are out of money", "You just earned your salary", "You spend your time waiting", "You just nearly died", "You do your assignment", "You paint", "You hum", "You rap", "You sing", "You hear someone singing", "You compose rap", "You compose a classical track", "You feel lonely", "You feel happy", "You feel ecstatic", "You yearn for something", "You feel you should meditate", "You feel you should pray", "You walk in a church", "You walk in a temple", "You walk in a mosque", "You walk in a forest", "You walk in a jungle", "You walk along the road", "You're in the city", "You ride a bus", "You ride a cab", "You take out the trash", "You find a job", "Someone gave you work", "You worship", "You're in transit", "You surf the internet", "You got hacked", "You got scammed", "You exercise", "You were commissioned in the army", "You were commisioned in the police force", "You were commissioned in the airforce", "You were commissioned in the marines", "You have a mission", "You feel inspired", "You feel uninspired", "You feel creative block", "You feel like dancing", "You hear music", "You watch TV", "You hear the radio", "You are fatigued", "You enter war", "You meet someone", "You view film showing schedules", "You browse through courses", "You walk into a market", "You think of getting souvenirs", "You explore the place", "red", "crimson", "maroon", "scarlet", "orange", "amber", "rust", "salmon", "green", "emerald", "lime", "olive", "yellow", "gold", "lemon", "mustard", "blue", "azure", "indigo", "teal", "purple", "lavender", "magenta", "violet", "brown", "beige", "chocolate", "sienna", "gray", "charcoal", "silver", "slate", "black", "ebony", "jet", "onyx", "white", "alabaster", "ivory", "pearl", "pink", "sky blue", "neon green", "neon yellow", "neon orange", "neon blue", "touchdown", "touchdown", "touchdown", "first down", "first down", "first down", "first down", "second down", "second down", "second down", "third down", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "there are 3 guards ahead of you", "there are 3 guards ahead of you", "there are 3 guards ahead of you", "there are 4 guards ahead of you", "there are 2 guards ahead of you", "there are 2 guards ahead of you", "there are 2 guards ahead of you", "there is 1 guard ahead of you", "there is 1 guard ahead of you",\
                      "species", "practice", "natural", "measure", "present", "form", "order", "quality", "condition", "state", "action", "element", "part", "division", "subject", "ground", "power", "station", "register", "person", "place", "ordinary", "strong", "under", "make", "light", "exercise", "exchange", "parallel", "charge", "support", "judgment", "substance", "figure", "strength", "sound", "service", "quantity", "standard", "right", "point", "character", "strike", "discharge", "force", "return", "spring", "square", "between", "without", "water", "spirit", "distance", "contract", "positive", "position", "straight", "moderate", "double", "superior", "certain", "compound", "interest", "language", "passage", "business", "through", "manner", "relation", "general", "process", "strain", "delicate", "bearing", "property", "advance", "account", "original", "religion", "round", "over", "principal", "sharp", "surface", "line", "degree", "report", "course", "matter", "sentence", "body", "express", "close", "quarter", "head", "negative", "take", "plant", "argument", "increase", "house", "movement", "table", "balance", "separate", "small", "back", "entrance", "settle", "reason", "machine", "common", "material", "scale", "authority", "capable", "anything", "regular", "stock", "break", "opposite", "into", "distress", "work", "standing", "cross", "color", "number", "stroke", "convert", "radical", "relative", "function", "stand", "press", "question", "peculiar", "progress", "together", "touch", "capacity", "physical", "horse", "specific", "external", "produce", "incapable", "passion", "represent", "promise", "tender", "issue", "family", "range", "domestic", "shoulder", "change", "approach", "transfer", "carriage", "feeling", "security", "something", "direction", "pressure", "frame", "like", "free", "company", "inferior", "distinct", "variety", "solution", "capital", "grain", "deposit", "circular", "receive", "pleasure", "particular", "office", "faculty", "motion", "personal", "country", "narrow", "occasion", "open", "addition", "second", "complete", "short", "ancient", "contrary", "serve", "disorder", "crown", "mark", "weight", "large", "white", "tongue", "mountain", "address", "vessel", "throw", "science", "system", "turn", "object", "temper", "internal", "base", "pass", "familiar", "principle", "another", "that", "hold", "compass", "pitch", "influence", "enter", "command", "reduce", "level", "surprise", "time", "bottom", "face", "flower", "extreme", "raise", "purpose", "nature", "answer", "down", "against", "stick", "clear", "record", "article", "discourse", "string", "shell", "side", "fall", "backward", "determine", "several", "forward", "period", "absolute", "taste", "draw", "waste", "running", "spread", "chamber", "cause", "official", "province", "flat", "instrument", "native", "conduct", "maintain", "descent", "block", "presence", "simple", "lead", "weather", "direct", "which", "opinion", "justice", "guard", "master", "appearance", "season", "regard", "check", "shoot", "society", "liquid", "rule", "pattern", "sphere", "directly", "cast", "life", "definite", "private", "give", "knowledge", "cover", "weak", "draught", "section", "sovereign", "stop", "organic", "screw", "violence", "decision", "render", "beat", "rise", "current", "affection", "evidence", "great", "court", "silver", "hand", "correct", "roll", "honor", "wind", "plate", "channel", "single", "keep", "heat", "cylinder", "divide", "release", "after", "respect", "military", "stomach", "some", "root", "timber", "structure", "school", "exterior", "syllable", "piece", "feather", "pledge", "supply", "christian", "branch", "religious", "necessary", "father", "execution", "affected", "knot", "carry", "other", "circle", "kind", "worship", "style", "example", "effect", "obscure", "well", "violent", "horn", "english", "drive", "outside", "better", "church", "mixture", "with", "equal", "reproach", "bear", "volatile", "equivalent", "slender", "remove", "being", "preserve", "grace", "earth", "elevation", "design", "stream", "furnish", "dress", "little", "writing", "spiritual", "black", "twist", "picture", "from", "smooth", "estate", "fine", "anchor", "joint", "heart", "expression", "reach", "center", "contest", "trust", "special", "shall", "friend", "high", "call", "train", "traverse", "irregular", "wrong", "sign", "watch", "catch", "animal", "stone", "dependent", "before", "relief", "thought", "fortune", "will", "active", "formation", "valuable", "soft", "about", "operation", "bank", "heavy", "solid", "ring", "proportion", "symbol", "opposition", "apparent", "abstract", "portion", "dignity", "revolution", "post", "voluntary", "length", "market", "harmony", "prepare", "perform", "land", "board", "shaft", "neglect", "iron", "value", "attempt", "hard", "judge", "proper", "mouth", "moral", "district", "interior", "genus", "union", "purple", "husband", "wing", "broken", "foreign", "divine", "perfect", "last", "compact", "escape", "extract", "demand", "flexible", "still", "wheel", "long", "burden", "labor", "note", "interval", "column", "destitute", "reference", "letter", "control", "freedom", "swallow", "medicine", "history", "difference", "people", "strip", "contempt", "handle", "decline", "good", "liberty", "brilliant", "fashion", "engage", "rest", "impression", "offensive", "drawing", "purchase", "minute", "metal", "texture", "doctrine", "cutting", "lower", "paper", "sight", "hollow", "follow", "judicial", "formal", "salt", "blow", "member", "fellow", "mean", "mother", "thread", "corrupt", "failure", "associate", "relieve", "display", "full", "distant", "disease", "sense", "liberal", "intended", "gather", "play", "blood", "swell", "stuff", "bill", "opening", "quarrel", "world", "secure", "stage", "government", "plane", "public", "composition", "allowance", "thing", "establish", "essential", "gentle", "consider", "examine", "attack", "benefit", "height", "exhibit", "movable", "voice", "tropical", "platform", "alternate", "have", "catholic", "bound", "advantage", "bright", "thrust", "marble", "mercury", "alcohol", "making", "throat", "foot", "shelter", "elastic", "slight", "painting", "inclose", "stem", "reduction", "vegetable", "breast", "drum", "guide", "generation", "study", "within", "succession", "dressing", "powerful", "staff", "notice", "downward", "upright", "favor", "thick", "trade", "extend", "custom", "faith", "mechanical", "turning", "front", "agreement", "glass", "extension", "normal", "green", "exposure", "medium", "product", "application", "term", "vertical", "shape", "choice", "more", "somewhat", "chance", "result", "residence", "party", "wear", "confidence", "soldier", "continue", "powder", "found", "learning", "situation", "bitter", "struggle", "finger", "shield", "officer", "rough", "field", "space", "privilege", "delicacy", "manifest", "sacred", "race", "organ", "behind", "breath", "belonging", "phrase", "border", "marine", "breathing", "flesh", "stretch", "musical", "imperfect", "keeping", "trouble", "fresh", "different", "image", "plaster", "numerous", "existence", "surround", "commerce", "passing", "rank", "around", "mill", "popular", "counter", "fruit", "praise", "hence", "beneath", "loose", "hammer", "amount", "pack", "secondary", "sweet", "meeting", "tone", "inclined", "refuse", "game", "floating", "mineral", "devotion", "memory", "individual", "withdraw", "size", "severe", "declare", "warrant", "desire", "fish", "provide", "title", "smoke", "suffer", "social", "bond", "virtue", "doubtful", "speech", "sympathy", "ready", "feed", "metallic", "fast", "step", "leave", "poison", "worthy", "entire", "easily", "steel", "colored", "disguise", "variable", "speaking", "rising", "indicate", "band", "primary", "agitation", "worm", "quick", "flight", "discipline", "careless", "secret", "lock", "profession", "affect", "minister", "excess", "flourish", "pole", "tooth", "situated", "mind", "disgrace", "censure", "estimate", "treat", "dead", "chemical", "grave", "deliver", "tail", "drop", "attention", "surrender", "hydrogen", "american", "sheet", "building", "preparation", "attend", "plain", "fabric", "limit", "appear", "fasten", "bind", "swelling", "show", "striking", "witness", "ornament", "possession", "bishop", "name", "collect", "hinder", "beyond", "beginning", "case", "covenant", "marriage", "foul", "yield", "type", "handsome", "uniform", "whatever", "earnest", "proof", "himself", "segment", "former", "critical", "difficulty", "proceed", "walk", "restrain", "prince", "setting", "trick", "leader", "female", "universal", "floor", "fire", "false", "depression", "seal", "class", "similar", "stamp", "sleep", "destroy", "following", "resemble", "formerly", "match", "management", "growth", "suit", "patient", "aggregate", "various", "south", "projection", "habit", "tissue", "dispute", "move", "sacrifice", "become", "agreeable", "credit", "partial", "chain", "broad", "northern", "heavenly", "pipe", "arrangement", "impulse", "sport", "apply", "live", "tension", "write", "above", "wood", "furnace", "circuit", "token", "decree", "trial", "shade", "child", "engaged", "imitation", "meet", "truth", "fair", "offer", "supreme", "constant", "sensible", "properly", "share", "device", "pair", "sugar", "solemn", "restore", "commission", "happiness", "word", "exact", "criminal", "model", "belief", "delivery", "spot", "suitable", "commonly", "ceremony", "convey", "search", "behavior", "printing", "measured", "frequent", "ball", "profit", "especially", "whole", "admit", "muscular", "thin", "singular", "related", "vapor", "crowd", "quiet", "method", "living", "first", "fault", "skin", "reverse", "college", "royal", "chief", "want", "battle", "appetite", "disposition", "recover", "beam", "drink", "reverence", "converse", "essence", "same", "deprive", "deep", "nervous", "wide", "hawk", "compose", "skeleton", "error", "nucleus", "proposition", "bend", "ship", "drinking", "difficult", "whip", "important", "swimming", "hanging", "empty", "wash", "obligation", "cotton", "nerve", "generally", "prayer", "century", "view", "servant", "coloring", "exertion", "incline", "unite", "observation", "middle", "community", "territory", "bone", "story", "colorless", "shallow", "solitary", "doubt", "acid", "slip", "speak", "deceive", "apparatus", "flow", "even", "dominion", "introduce", "severity", "region", "intimate", "becoming", "meaning", "philosophy", "extremity", "gravity", "forth", "diameter", "near", "scratch", "assembly", "east", "shoe", "prevent", "success", "spindle", "what", "activity", "bolt", "extensive", "brief", "project", "book", "cunning", "drift", "accident", "indirect", "protection", "evil", "group", "burning", "yellow", "fancy", "particle", "confusion", "document", "energy", "exhaust", "series", "reception", "utter", "yielding", "remote", "stiff", "wild", "discover", "policy", "angle", "below", "tree", "literary", "rate", "pursuit", "clothing", "engine", "trunk", "claim", "previous", "grant", "tribe", "extinct", "obtain", "furniture", "sequence", "imperial", "petition", "rope", "pleasing", "remedy", "oblique", "warm", "composed", "fill", "blue", "economy", "sprinkle", "smell", "promote", "money", "resolve", "covering", "needle", "blind", "acute", "foolish", "fossil", "european", "worth", "combine", "companion", "volume", "rather", "gain", "exciting", "look", "soil", "outward", "bring", "skill", "west", "duty", "sulphur", "expose", "noble", "posture", "lose", "follower", "distinction", "brush", "copper", "diminish", "sort", "attachment", "sensation", "inside", "aspect", "stain", "affinity", "slide", "southern", "edge", "perception", "conclusion", "unequal", "priest", "boiling", "steam", "lord", "consent", "float", "tincture", "collection", "beak", "rock", "mine", "wearing", "decay", "moisture", "stern", "confine", "average", "burn", "scheme", "pale", "while", "declaration", "contain", "plunder", "actual", "accent", "mass", "equality", "bladder", "young", "curve", "intense", "star", "loss", "reading", "spiral", "political", "assault", "prospect", "tendency", "remain", "made", "contraction", "brain", "evolution", "experience", "further", "complex", "sponge", "worthless", "develop", "extent", "except", "payment", "election", "sometimes", "vision", "screen", "seize", "pain", "sufficient", "dwelling", "manage", "sensitive", "hundred", "music", "modern", "horizon", "town", "birth", "lime", "appeal", "kingdom", "constitution", "inclosure", "suspension", "suffering", "rich", "room", "collar", "elevated", "prominent", "coarse", "bent", "descend", "holding", "love", "treatise", "instruct", "perceive", "pointed", "sudden", "adjacent", "formed", "agree", "split", "license", "reflection", "shut", "dissolve", "battery", "variation", "start", "price", "load", "necessity", "coming", "vehicle", "axis", "sweep", "wall", "sustain", "vote", "driving", "flavor", "breed", "prepared", "anterior", "saddle", "pride", "divinity", "aromatic", "lively", "foundation", "dark", "continued", "derivative", "minor", "nation", "conveyance", "utterance", "legal", "mistress", "corner", "rent", "occupation", "reputation", "sail", "taking", "grass", "crescent", "mistake", "dull", "mode", "visible", "precious", "undergo", "toward", "engraving", "moving", "list", "home", "currency", "port", "wicked", "vein", "only", "membrane", "towards", "dispose", "wound", "rapid", "hook", "seat", "bargain", "copy", "sink", "partially", "otherwise", "overcome", "stalk", "feel", "corn", "trumpet", "true", "courage", "grand", "carrying", "connection", "coast", "successive", "stay", "painful", "lost", "advocate", "king", "motive", "velocity", "expansion", "margin", "dance", "track", "where", "independent", "north", "bore", "honorable", "theory", "wanting", "seed", "arch", "composite", "leaf", "comparison", "soul", "poor", "calendar", "death", "satisfy", "artificial", "statement", "such", "indian", "reward", "travel", "likeness", "reserve", "restraint", "intellect", "courtesy", "cold", "delay", "describe", "idea", "fight", "reasoning", "central", "partition", "milk", "literature", "organism", "fold", "equation", "male", "shadow", "easy", "fear", "forest", "verse", "just", "absence", "tertiary", "according", "feast", "freight", "department", "outline", "artifice", "captain", "resistance", "chase", "diamond", "forming", "student", "slow", "given", "trespass", "merchant", "primitive", "defend", "sexual", "amorphous", "appropriate", "temple", "invest", "dishonor", "civil", "development", "lateral", "print", "outer", "adjective", "cord", "blade", "darkness", "retreat", "challenge", "shot", "silence", "alkaloid", "fail", "night", "roman", "strongly", "thousand", "profound", "danger", "ultimate", "harbor", "nothing", "execute", "sour", "desert", "attach", "concern", "employment", "bridge", "pile", "duration", "regulate", "innocent", "future", "permanent", "leather", "main", "governor", "comfort", "flag", "real", "calling", "encounter", "bell", "grow", "half", "posterior", "signature", "erect", "humor", "morality", "mutual", "proceeding", "able", "cheat", "friendly", "insect", "either", "treatment", "attendant", "vocal", "shining", "sucker", "leading", "deeply", "find", "flowing", "settlement", "council", "infinite", "divided", "skillful", "exceed", "pleasant", "speed", "altitude", "winding", "content", "commit", "bankrupt", "careful", "continuous", "consequence", "excite", "exhibition", "noise", "concrete", "breeding", "incident", "much", "annual", "skilled", "hair", "prove", "remark", "admission", "enlarge", "provided", "breathe", "hearing", "raising", "attribute", "firm", "arrange", "meal", "sand", "dish", "strange", "fourth", "atlantic", "congress", "barrel", "western", "mental", "aperture", "lodge", "pull", "sterling", "come", "inserted", "contact", "sing", "prefix", "prejudice", "provision", "talk", "counsel", "void", "nose", "chest", "vulgar", "strap", "wanton", "latin", "card", "analysis", "institution", "ridicule", "covered", "brace", "third", "pronounce", "limited",\
                       "enough", "overthrow", "crack", "coin", "adherent", "observe", "coat", "flame", "dorsal", "capsule", "impress", "guilty", "delight", "best", "stranger", "nobility", "possess", "duck", "conception", "electricity", "uncertain", "affecting", "rational", "clothes", "also", "wonder", "summer", "involve", "request", "reaction", "envelop", "breach", "excellent", "obstruct", "atmosphere", "mantle", "remember", "again", "receiver", "consonant", "blank", "devoted", "blast", "nice", "improper", "excuse", "intention", "embrace", "agent", "limb", "excellence", "injury", "faithful", "protect", "chiefly", "production", "pastoral", "isomeric", "trifling", "sentiment", "appendix", "temporary", "test", "drill", "burst", "temporal", "when", "beating", "rolling", "orderly", "sitting", "tract", "send", "neck", "author", "strict", "less", "benefice", "woman", "away", "enterprise", "help", "overflow", "testimony", "join", "excitement", "stable", "cannon", "dash", "idle", "luminous", "originally", "doctor", "resolution", "appoint", "crystal", "beauty", "assurance", "shake", "eastern", "torture", "damage", "shock", "morbid", "rounded", "aside", "vigorous", "ascertain", "window", "read", "designate", "effort", "repair", "compare", "binding", "boat", "fever", "impregnate", "machinery", "moment", "keeper", "pungent", "whistle", "penetrate", "finish", "having", "elegant", "irritate", "fillet", "cluster", "pregnant", "winter", "woolen", "gross", "german", "ferment", "signal", "rude", "offering", "dust", "angular", "tune", "stupid", "institute", "vital", "writer", "source", "because", "obedience", "ruin", "eccentric", "occupy", "crystalline", "across", "communion", "appendage", "ventral", "oppose", "memorial", "cradle", "lightly", "cloth", "include", "symmetry", "triumph", "esteem", "riding", "assume", "subdue", "sorrow", "propriety", "impure", "very", "sounding", "secular", "adjust", "plan", "scatter", "scent", "tube", "fanciful", "possible", "suspend", "marked", "stigma", "creature", "disperse", "twisted", "depth", "african", "liable", "profane", "tool", "fence", "fore", "instance", "cure", "river", "desolate", "contrast", "measuring", "disclose", "heaven", "kindness", "performance", "shed", "march", "rare", "fragrant", "parish", "cloud", "rendering", "servile", "malignant", "transport", "romance", "origin", "self", "lady", "twelve", "vagabond", "lace", "pick", "romantic", "ocean", "depress", "penalty", "eruption", "survey", "sonorous", "perennial", "shore", "journey", "casting", "succeed", "improve", "analogous", "poisonous", "steep", "shooting", "tenant", "hostile", "speaker", "venture", "endeavor", "tear", "peace", "hang", "advanced", "stake", "suppress", "steady", "gate", "page", "liquor", "varnish", "bivalve", "intellectual", "vice", "sublime", "wooden", "intensity", "alphabet", "elevate", "tenacious", "conversion", "jack", "event", "employ", "thunder", "radiant", "muscle", "moon", "spoken", "gradual", "apple", "inactive", "defeat", "rustic", "understand", "degrade", "deck", "ancestor", "putting", "agency", "constituent", "conflict", "favorable", "generous", "antecedent", "storm", "indefinite", "disposed", "bite", "customary", "distemper", "wire", "subordinate", "restless", "apart", "ease", "polish", "debate", "indulge", "deviation", "arrest", "hole", "serpent", "determination", "bark", "brown", "whisper", "beforehand", "slippery", "auxiliary", "prime", "orange", "early", "flood", "layer", "vicious", "bonnet", "digest", "accord", "latter", "scrape", "swing", "cherry", "monkey", "leap", "renounce", "awkward", "raised", "giving", "continent", "reserved", "hazard", "warp", "beautiful", "score", "invention", "girdle", "exclusive", "yard", "prostrate", "horizontal", "parting", "abuse", "citizen", "receptacle", "electric", "lantern", "bastard", "pound", "terminal", "belong", "inhabitant", "hide", "upper", "mechanic", "pigment", "reality", "traffic", "treasury", "poetry", "deed", "premise", "believe", "ridge", "flash", "shackle", "endure", "meridian", "inflated", "prize", "usage", "think", "fishing", "scene", "termination", "injure", "recognize", "fact", "solidity", "loud", "anatomy", "reciprocal", "charity", "journal", "eating", "review", "gallery", "understanding", "hardness", "chapter", "humble", "pointing", "confirm", "pure", "lean", "fracture", "year", "distinguish", "entertain", "garden", "their", "plunge", "adhesion", "purity", "industry", "exception", "discovery", "combined", "push", "entirely", "paint", "inquiry", "trace", "sole", "mystery", "importance", "torment", "forcible", "care", "past", "genius", "bottle", "twenty", "suffix", "immovable", "fibrous", "clean", "silent", "association", "sanction", "pierce", "wander", "gathering", "tread", "naked", "gift", "glance", "relish", "acting", "trim", "departure", "emotion", "reckoning", "grade", "wave", "concave", "immediate", "royalty", "ability", "induction", "three", "validity", "apartment", "crime", "along", "fleet", "triangle", "bird", "crossing", "mischief", "sword", "implement", "polished", "ignorant", "protest", "grief", "coal", "disposal", "intrigue", "punishment", "anger", "mount", "soluble", "stripe", "squeeze", "transmit", "violation", "plot", "multiply", "probable", "patience", "decrease", "chestnut", "begin", "showing", "rupture", "depart", "paragraph", "concerning", "national", "visionary", "farm", "eager", "reflect", "expand", "curious", "qualify", "molecule", "preceding", "upward", "slope", "harsh", "gravel", "wholly", "valence", "windlass", "human", "itself", "bold", "massive", "construction", "alloy", "crust", "cake", "terminate", "left", "parasite", "medical", "harness", "weapon", "tell",\
                          "fountain", "consideration", "favorite", "wrongly", "vehement", "going", "groove", "electrical", "mature", "counterfeit", "inversion", "faint", "drag", "testament", "ruffle", "undertake", "repose", "health", "fleshy", "communicate", "many", "assistant", "food", "virgin", "versed", "destruction", "prick", "temperature", "allow", "verbal", "transparent", "collective", "revolve", "combination", "fantastic", "during", "weakness", "lack", "wrinkle", "version", "alliance", "antiquity", "serious", "tenth", "store", "roof", "information", "than", "retire", "gold", "siphon", "separation", "wedge", "crest", "vibrate", "conical", "procure", "numbers", "filling", "pocket", "spur", "angles", "greek", "substitute", "runner", "feeding", "correction", "splendid", "venomous", "founder", "dolphin", "oxygen", "tackle", "dislike", "distribute", "entangle", "charm", "magnetic", "inheritance", "brick", "publicly", "slightly", "disturb", "corruption", "gallant", "deliberate", "canvas", "gray", "hedge", "indulgence", "healthy", "drain", "insolent", "bodily", "wise", "conceit", "telescope", "daughter", "yellowish", "pursue", "identical", "spider", "falsehood", "globe", "resemblance", "description", "readily", "savage", "arbitrary", "academy", "snow", "politics", "looking", "agitate", "thorough", "connect", "secretion", "afford", "articulate", "cell", "deficient", "strengthen", "recess", "bridle", "splendor", "impose", "emblem", "sting", "remarkable", "truss", "explain", "hope", "resist", "slander", "partisan", "trap", "aquatic", "fresh-water", "hood", "disdain", "removed", "adventure", "summary", "count", "whether", "literal", "pasture", "chloride", "throne", "garment", "guardian", "rose", "discount", "lasting", "cease", "sharpen", "quicken", "receipt", "morally", "habitual", "ecstasy", "defense", "alone", "heap", "edible", "beast", "palm", "dimension", "gospel", "fluid", "island", "deal", "operate", "cattle", "suppose", "concord", "cream", "queen", "ethereal", "there", "roller", "patent", "rubber", "rail", "patron", "should", "brass", "appointment", "vigor", "passive", "vascular", "beetle", "fabulous", "prodigal", "abandon", "apprehension", "fertile", "french", "imagination", "discuss", "welcome", "distrust", "contend", "lift", "dishonest", "finding", "imposing", "erroneous", "utmost", "useful", "pertaining", "diffuse", "carbon", "overlook", "blossom", "obtained", "cushion", "notion", "dispatch", "cabbage", "fortress", "equivocal", "basket", "holy", "steward", "youth", "washing", "sluggish", "messenger", "maturity", "infamous", "shorten", "else", "dexterous", "apparel", "mourning", "crooked", "propose", "rigorous", "rush", "stubborn", "dependence", "disturbance", "trench", "till", "radiate", "sailing", "eight", "infusion", "solemnity", "fret", "highly", "charter", "gloomy", "scraping", "next", "knife", "nitrogen", "tide", "magnitude", "linen", "persuade", "final", "residue", "bending", "spar", "imaginary", "flying", "accept", "bread", "attitude", "knight", "bloom", "assign", "generate", "driver", "file", "foliage", "festival", "parade", "experiment", "eminence", "conquer", "translate", "pretty", "sect", "allied", "melancholy", "breadth", "flatter", "venereal", "repeat", "abdomen", "silly", "monument", "song", "deduction", "submit", "inflame", "concert", "flush", "disgust", "fragment", "acceptance", "inspire", "neutral", "piercing", "knowing", "household", "stump", "cement", "enforce", "medicinal", "adverse", "oriental", "embarrass", "club", "instead", "enemy", "soften", "obstinate", "offspring", "please", "enamel", "shame", "practical", "examination", "beard", "road", "boundary", "warmth", "publish", "decorate", "shift", "stall", "sterile", "noxious", "sweeten", "tobacco", "obsolete", "bronze", "recital", "scholar", "theology", "distillation", "disk", "assumed", "rack", "animate", "christ", "paradise", "jurisdiction", "shrink", "touching", "recompense", "inherent", "alarm", "sincere", "conquest", "arms", "perch", "politic", "paddle", "intestine", "meat", "repetition", "abusive", "spear", "honorary", "relating", "reed", "disorderly", "plural", "immediately", "produced", "prudent", "dividing", "glory", "caution", "litter", "fixed", "rain", "were", "useless", "defective", "shine", "hospital", "injurious", "wretched", "funeral", "enjoyment", "access", "major", "defect", "brother", "empire", "procession", "accurate", "lessen", "seven", "explosive", "cheerful", "embryo", "dirty", "fellowship", "sickness", "rotation", "secretary", "wisdom", "temperate", "instruction", "transient", "resolute", "solicit", "weaken", "tarnish", "nail", "abortive", "mounted", "straw", "learned", "commander", "strive", "doubling", "hill", "chlorine", "butter", "dangerous", "catching", "infant", "greenish", "recall", "abundant", "sulphuric", "refer", "explanation", "nearly", "vexation", "perfection", "four", "castle", "confuse", "farther", "administer", "instant", "spoil", "junction", "mast", "ministry", "eclipse", "rake", "suborder", "prolific", "forbear", "tribunal", "irritation", "boom", "divination", "vacant", "sinister", "inspired", "sensibility", "exist", "stated", "graduate", "intercourse", "gland", "chapel", "calm", "perverse", "modest", "spell", "legitimate", "mortgage", "ardent", "manifold", "league", "blunt", "frequently", "limitation", "framework", "worse", "stitch", "fund", "equally", "shrill", "larva", "inflammation", "bundle", "immature", "pepper", "called", "frontal", "culture", "date", "planet", "condemn", "nasal", "willing", "disciple", "wine", "expense", "marshal", "cowardly", "riddle", "smart", "contrivance", "shank", "cutter", "director", "hasty", "gauge", "merit", "elementary", "sheep", "trail", "trimming", "marking", "always", "ticket", "precipitate", "interpret", "saving", "depressed", "regiment", "decoration", "permit", "abroad", "specious", "subtile", "cipher", "combat", "arsenic", "tough", "sentinel", "adequate", "import", "spare", "digestion", "adorn", "then", "wealth", "manual", "eternal", "opponent", "believer", "compress", "lake", "refine", "fidelity", "armed", "valve", "sullen", "spend", "conformity", "lifeless", "prosecute", "patch", "panel", "defile", "grating", "transverse", "engagement", "tumult", "malicious", "flowering", "most", "belt", "fitting", "slate", "adoption", "heel", "sweeping", "hydrous", "angry", "resort", "locality", "closely", "comb", "reversed", "heating", "grammar", "magazine", "clay", "morning", "vault", "diagonal", "couple", "boot", "engraved", "emission", "bloody", "university", "portable", "thorax", "juice", "spotted", "exclude", "abnormal", "attain", "logical", "fruitful", "removal", "doing", "sell", "mournful", "skull", "this", "monstrous", "elaborate", "canon", "endless", "seventh", "defensive", "orchestra", "simplicity", "transform", "confound", "pool", "violate", "likely", "vesicle", "precise", "scientific", "treasure", "creation", "inward", "masonry", "attraction", "belly", "adversary", "gripe", "each", "pencil", "egyptian", "delegate", "garrison", "variance", "corolla", "alienate", "accessory", "inner", "temperament", "done", "sore", "constrain", "exempt", "associated", "recovery", "late", "complaint", "melting", "dialect", "shrub", "prison", "deserving", "rightful", "excursion", "entreaty", "refined", "debt", "denial", "oily", "avoid", "inverted", "proverb", "metameric", "anxiety", "cleavage", "chimney", "laughter", "excessive", "metrical", "twitch", "improvement", "arrogant", "traveler",\
                            "universe", "chemistry", "peduncle", "abatement", "canal", "multitude", "resident", "safety", "derision", "sweat", "rider", "reckon", "dread", "superficial", "depend", "tend", "player", "mortal", "enthusiasm", "president", "barbarous", "evening", "devise", "genuine", "surrounding", "imitate", "convenient", "revolving", "honey", "hardened", "bruise", "thinking", "children", "conform", "tribute", "contention", "ride", "they", "uncover", "steal", "honest", "mushroom", "nest", "harmonize", "disable", "creep", "thus", "mortar", "chair", "extremely", "consistency", "verge", "disquiet", "vanity", "defiance", "mask", "strait", "rouse", "fringe", "mate", "bass", "safe", "flounder", "compensation", "quickly", "conceal", "bull", "prisoner", "build", "resembling", "pardon", "city", "crustacea", "starch", "heavily", "usual", "platinum", "bush", "decided", "nurse", "omission", "surety", "accidental", "clumsy", "proposal", "punish", "contents", "british", "exposition", "gigantic", "warranty", "rear", "fiction", "collision", "armor", "plank", "crop", "attorney", "radiated", "encircle", "passionate", "antelope", "scotch", "accomplish", "supposed", "emit", "hesitate", "pedestal", "pearl", "bandage", "fatigue", "submission", "training", "partake", "rapidity", "every", "worldly", "incense", "attached", "probably", "engrave", "distribution", "plead", "wait", "inform", "door", "ribbon", "impart", "mail", "swift", "premium", "yoke", "narcotic", "trifle", "unfold", "lesson", "glucoside", "kernel", "reconcile", "profuse", "conceive", "visit", "plastic", "defendant", "cavity", "silicate", "inhabit", "continuance", "crude", "graceful", "charcoal", "india", "slave", "destructive", "ether", "adhere", "ditch", "estimation", "chinese", "solvent", "persuasion", "oxidation", "entertainment", "spectrum", "detail", "disunite", "tower", "reliance", "urge", "mixed", "hall", "immortal", "beverage", "weigh", "flour", "constitute", "tack", "lance", "intermediate", "sale", "area", "vent", "publication", "coating", "audience", "particularly", "unit", "compel", "augment", "laying", "interfere", "index", "garland", "entry", "rectitude", "discord", "deformity", "consist", "dullness", "happy", "cool", "know", "exactly", "united", "farthest", "tubular", "grasp", "infernal", "construct", "treaty", "regarded", "narrowly", "toll", "kill", "kindred", "learn", "fortunate", "sensual", "railway", "efficacy", "uniformity", "remainder", "employed", "integrity", "helmet", "operculum", "conscience", "incision", "stout", "devote", "naturally", "dragon", "divest", "exclamation", "indented", "enlargement", "imagine", "orthodox", "conductor", "frustrate", "occur", "dialogue", "mollusca", "curtain", "poetical", "loop", "infectious", "bare", "rabble", "weed", "crab", "watery", "income", "feeble", "lease", "adjustment", "confession", "enormous", "born", "array", "crush", "stress", "volcanic", "humanity", "perplex", "requital", "plaintiff", "boil", "revenue", "often", "wagon", "susceptible", "sanskrit", "noisy", "speculation", "suture", "contrive", "cant", "olive", "finished", "forge", "dexterity", "showy", "indifferent", "require", "pervert", "tasteless", "proclaim", "mechanism", "discussion", "slacken", "deposition", "manufacture", "deity", "blemish", "strained", "writ", "criticism", "affair", "out", "scattered", "inference", "alkaline", "mostly", "cardinal", "winged", "army", "slice", "crank", "keen", "essay", "retain", "prey", "abundance", "periodical", "pillar", "sacrament", "pink", "retort", "purify", "goodness", "hind", "refusal", "conspicuous", "friendship", "expedition", "widely", "deadly", "objection", "partly", "rapacious", "perfume", "sauce", "poem", "couch", "spin", "response", "subjected", "stuffing", "recoil", "pine", "conclude", "falling", "tonic", "legislative", "formality", "expectation", "blame", "staple", "revive", "globular", "unnatural", "forehead", "escutcheon", "alcoholic", "monthly", "recite", "brood", "astringent", "fineness", "arranged", "seam", "supporter", "tumble", "branches", "fastening", "assent", "proud", "govern", "bosom", "artful", "eminent", "diminution", "sick", "unity", "headlong", "cautious", "mistaken", "derive", "homology", "inflict", "sulphide", "humility", "teach", "truck", "pouch", "neat", "prohibit", "grind", "pavement", "advice", "pluck", "hour", "kindly", "monarch", "tumor", "mingle", "turbulent", "predicate", "however", "representation", "watchful", "intent", "painted", "ordnance", "scorn", "chatter", "sediment", "cognizance", "literally", "derivation", "gentleman",\
                             "abrupt", "subtle", "craft", "fool", "bestow", "tight", "spleen", "facing", "portrait", "keel", "procedure", "vibration", "valued", "harangue", "frank", "rust", "coach", "wreck", "path", "earthy", "authentic", "once", "palliate", "oxide", "working", "pacific", "aversion", "pyroxene", "grains", "spanish", "heave", "chorus", "magnesia", "tenor", "productive", "mitigate", "denoting", "definition", "gall", "carbonate", "inclosed", "bulk", "taint", "pillage", "slowly", "healing", "effective", "foil", "pressing", "unctuous", "nitrogenous", "calcium", "hydrocarbon", "suggestion", "quotient", "integral", "gradually", "extended", "unlucky", "stir", "spirited", "convent", "majority", "parent", "harvest", "statue", "ligament", "reflected", "existing", "noted", "ecliptic", "equitable", "anxious", "neither", "farewell", "bail", "flute", "must", "facility", "ensign", "italian", "barren", "solitude", "refrain", "accuracy", "charitable", "clock", "weary", "silvery", "deception", "wheat", "nobleman", "antimony", "pronoun", "received", "chancery", "expedient", "flock", "repeated", "saffron", "exemption", "kindle", "stool", "breaking", "thicken", "abate", "boast", "harden", "prose", "ward", "devil", "celestial", "leguminous", "throwing", "voyage", "diminutive", "explode", "fugitive", "including", "regularly", "fastened", "sermon", "snap", "dreadful", "custody", "cruel", "oppress", "magical", "silk", "galley", "uncommon", "executive", "denote", "seek", "warning", "elephant", "livery", "salmon", "designed", "statute", "education", "bringing", "modesty", "typical", "prostitute", "initial", "humming", "heathen", "confused", "adhesive", "sickly", "required", "throng", "attract", "teaching", "packing", "occupied", "ornamental", "quill", "tyrant", "hydrate", "oath", "snatch", "vagrant", "tunnel", "inflamed", "stirring", "alumina", "meanness", "cable", "problem", "incumbent", "insipid", "spout", "narrative", "orator", "punch", "attended", "articulation", "default", "poverty", "lighter", "five", "paste", "viscous", "analogy", "clearing", "imposition", "curse", "quadrate", "flattery", "insult", "justify", "disregard", "parliament", "vinegar", "cleave", "delineate", "borough", "diversion", "dealer", "pour", "whitish", "imitative", "boiler", "spurious", "vain", "ending", "camphor", "puzzle", "included", "pause", "contracted", "adjectively", "fondness", "indies", "squirrel", "month", "crane", "sketch", "controversy", "guarantee", "chastity", "unlimited", "fighting", "pretend", "surpass", "button", "overseer", "unusual", "flank", "stony", "efficient", "rarely", "mankind", "spice", "guilt", "assemble", "though", "formula", "teacher", "dainty", "innocence", "vitreous", "clergyman", "animation", "apron", "cycle", "serving", "equity", "scripture", "violet", "containing", "hear", "stopping", "consisting", "decomposition", "lightning", "latitude", "ideal", "hire", "elbow", "purse", "gossip", "capillary", "trivial", "pompous", "feature", "cheer", "suspense", "rigid", "optical", "available", "malice", "whose", "critic", "brave", "neighbor", "link", "stratagem", "spire", "seeing", "prudence", "assertion", "worry", "both", "extravagant", "harmonious", "partner", "acquire", "decisive", "valley", "backbone", "sportive", "granular", "random", "asiatic", "diligence", "cordial", "bath", "vowel", "dealing", "brighten", "dense", "tortoise", "sculpture", "shearing", "reptile", "bible", "seizure", "indent", "pulse", "wool", "wish", "univalve", "lash", "withhold", "suspicion", "adherence", "acknowledge", "firmness", "celebrate", "scramble", "until", "nickname", "discern", "undue", "murder", "diurnal", "hebrew", "evergreen", "shepherd", "impudent", "detached", "jointed", "cask", "alive", "comparative", "frolic", "mouse", "signify", "announce", "quickness", "orifice", "accompany", "explosion", "clothe", "caustic", "choose", "pace", "mirror", "cohesion", "artillery", "insert", "mobile", "conversation", "symptom", "grease", "polarity", "offset", "deer", "furious", "emphasis", "been", "transact", "calamity", "resolved", "producing", "contingent", "complexion", "puff", "sagacious", "classical", "deluge", "rattle", "rash", "expert", "expressive", "footing", "cone", "austere", "competent", "plausible", "studious", "breech", "spelling", "retail", "petty", "reasonable", "buffalo", "bubble", "insanity", "idleness", "proceeds", "curl", "ascend", "wife", "reform", "creeping", "balloon", "create", "rage", "entreat", "insertion", "offend", "rove", "shifting", "twelfth", "inspect", "decide", "figurative", "miss", "athletic",\
                              "directed", "exceeding", "ambition", "absorb", "tangent", "bait", "haughty", "intercept", "translation", "crisp", "darken", "stability", "factor", "octave", "insnare", "propagate", "evident", "tenure", "auditory", "forked", "obstacle", "muzzle", "intricate", "grate", "peevish", "applied", "summons", "golden", "locomotive", "incorrect", "intensive", "insoluble", "collected", "amusement", "vary", "attentive", "smile", "reproduce", "cleft", "dropping", "pectoral", "ceiling", "indigo", "ruminant", "artless", "message", "pity", "ravenous", "rapidly", "quadrant", "lying", "invite", "merry", "pliable", "animated", "liability", "assuming", "sprout", "affirmative", "barter", "suggest", "elder", "monster", "tending", "ethylene", "rampart", "scope", "yarn", "reign", "lofty", "rubbish", "foremost", "melt", "to", "eighteen", "teeth", "feathered", "formally", "objective", "reckless", "deaden", "spruce", "molasses", "sheath", "fond", "secrecy", "entrails", "digestive", "commercial", "horror", "geometry", "provoke", "identity", "themselves", "abide", "valid", "winning", "satisfaction", "foliated", "cultivate", "insurance", "shower", "dejection", "street", "bench", "notch", "sanctuary", "threaten", "core", "thirst", "crimson", "isolated", "fate", "potassium", "sphenoid", "gloss", "initiate", "killing", "remembrance", "acuteness", "digging", "fraud", "endowment", "commanding", "stale", "resin", "tally", "select", "weaving", "bowl", "sloping", "exalt", "interrupt", "wither", "foresight", "circulation", "gill", "igneous", "obscurity", "distill", "inscribe", "bondage", "hastily", "notation", "firearm", "mute", "oppressive", "pericarp", "communication", "creeper", "forfeit", "apprehend", "fully", "gracious", "divert", "derived", "railroad", "interchange", "originate", "obstinacy", "neuter", "sack", "capture", "fencing", "inquire", "pope", "greatly", "wolf", "degraded", "dejected", "guidance", "aerial", "rhyme", "desirable", "insensible", "discordant", "ligature", "adopted", "sanguine", "spasmodic", "physician", "luster", "salute", "broach", "fork", "gear", "graduated", "adultery", "warlike", "obstruction", "liver", "smallpox", "lighten", "loosen", "rigor", "deformed", "climate", "admitted", "hunting", "fifteenth", "reject", "concerned", "butcher", "cessation", "approve", "turkish", "fare", "saturated", "impair", "shroud", "clamor", "disjoint", "fourteen", "epidemic", "clergy", "muddy", "laugh", "shrewd", "observance", "act", "singing", "snuff", "cricket", "geology", "insane", "subsequent", "missile", "on", "beggar", "cane", "eagle", "abruptly", "deceitful", "reddish", "cathedral", "sixteenth", "senate", "buck", "nourish", "displace", "relate", "candidate", "plump", "slack", "artery", "sodium", "powdered", "ascent", "gloom", "lowering", "resinous", "tradition", "governing", "boiled", "induce", "arise", "meditate", "voltaic", "harmless", "shedding", "ripple", "uneasy", "fissure", "merchandise", "victory", "conference", "paid", "uneasiness", "instinct", "unworthy", "rival", "wasteful", "preliminary", "branching", "boasting", "brittle", "honesty", "need", "indistinct", "inspiration", "giddy", "rescue", "absent", "buffoon", "convex", "frontier", "argue", "thickness", "marginal", "throughout", "untimely", "exquisite", "rogue", "potter", "qualities", "nonsense", "stealing", "lining", "relax", "infuse", "ruling", "additional", "streak", "immerse", "preference", "network", "condense", "tablet", "tinge", "onward", "smother", "grasping", "ammonia", "jupiter", "doublet", "mission", "fission", "anew", "causing", "sleeve", "authorized", "amber", "excrement", "damp", "affront", "offense", "cherish", "restrict", "budding", "confederate", "sever", "ambush", "growing", "irritable", "local", "homage", "regret", "vitality", "meadow", "northwest", "spongy", "leaves", "elsewhere", "police", "placenta", "component", "spirituous", "accustom", "therefore", "intelligence", "actually", "consistent", "destiny", "cloak", "forbid", "disappear", "cylindrical", "written", "fifth", "urine", "haste", "already", "scarf", "durable", "grievous", "arrival", "fierce", "whirl", "afflict", "built", "furrow", "sorrowful", "plume", "aniline", "tick", "connected", "serpentine", "spit", "epoch", "magnify", "drunken", "torpedo", "conscious", "fortify", "session", "vertebra", "shipping", "saint", "petroleum", "assist", "curb", "observer", "asunder", "qualified", "occurrence", "cleaning", "offender", "mediate", "occurring", "negligent", "beaten", "illustration", "mock", "stormy", "verb", "figured", "assemblage", "drying", "murmur", "deviate", "kitchen", "zinc", "anticipate", "servitude", "creditor", "privy", "dock", "monopoly", "newspaper", "retard", "licensed", "terrestrial", "boastful", "sliding", "ragged", "furnished", "wrought", "frightful", "whence", "stratum", "differ", "gratify", "conjecture", "ownership", "whimsical", "mere", "fundamental", "variant", "arboreal", "subjection", "strife", "subscribe", "ointment", "symmetrical", "exactness", "glossy", "liking", "sprightly", "collapse", "pudding", "cultivation", "disfavor", "dart", "renew", "consign", "tremulous", "distinguished", "pleading", "saline", "recent", "limestone", "vindicate", "inch", "heroic", "preface", "magistrate", "inflection", "unlike", "cruelty", "semblance", "mention", "parapet", "readiness", "used", "abode", "troop", "jacket", "equator", "invisible", "hindrance", "anthozoa", "spike", "refractory", "narration", "magnetism", "naval", "bitumen", "impetuous", "germinal", "measurement", "unjust", "mole", "chosen", "willow", "retract", "obvious", "combining", "prosperity", "allay", "stocking", "lymphatic", "adapted", "protract", "sober", "explore", "abounding", "commotion", "pricking", "affix", "dipping", "nutrition", "pigeon", "forcing", "feminine", "palate", "cartilage", "republic", "rebuke", "walking", "reclaim", "duplicate", "arrive", "quit", "quartz", "scallop", "guess", "trump", "homologous", "sixteen", "grieve", "removing", "slaughter", "extracted", "suspect", "engineer", "aldehyde", "titmouse", "carried", "stringed", "arrogance", "studied", "tractable", "reveal", "observing", "distaste", "delicious", "retired", "cancer", "hinge", "obscene", "preacher", "illustrate", "triple", "bolster", "cheek", "fullness", "applause", "surgeon", "voracious", "moth", "quite", "save", "carving", "deny", "grapple", "diet", "vehemence", "tartar", "vassal", "parcel", "tabernacle", "dream", "opaque", "cathartic", "herring", "opposed", "abdominal", "steamer", "tiller", "admiration", "breeches", "obedient", "thrusting", "bluster", "owner", "certainty", "sway", "respond", "scarlet", "goose", "ashes", "martial", "salient", "manganese", "accession", "glutinous", "declivity", "popularly", "invalid", "grateful", "correspond", "practiced", "bias", "nocturnal", "calcareous", "tumultuous", "performer", "dispense", "quietly", "discretion", "proboscis", "frost", "skirt", "laudable", "separated", "pulp", "harm", "privacy", "brought", "sternum", "cost", "rifle", "awake", "tallow", "jump", "vomit", "thirty", "bracket", "terror", "swim", "freezing", "persian", "recently", "unstable", "inequality", "see", "truly", "ripe", "reply", "overhang", "misfortune", "performed", "oyster", "citation", "dilute", "confess", "specially", "extraordinary", "expressed", "contained", "breeze", "contribute", "tent", "contagious", "package", "infect", "volunteer", "percussion", "warbler", "captive", "ingredient", "failing", "secrete", "technical", "knitting", "goddess", "trousers", "puncture", "cheese", "tapering", "ingenious", "windpipe", "workman", "mammalia", "collateral", "shave", "painter", "harass", "reel", "countenance", "frivolous", "evacuate", "ignorance", "happen", "mosaic", "for", "collectively", "slavery", "mackerel", "navigation", "brisk", "savor", "blister", "developed", "claw", "episcopal", "undivided", "redress", "sparkle", "stumble", "coffee", "boisterous", "reproof", "ramble", "encourage", "twice", "thrush", "triangular", "tapeworm", "fitness", "lodging", "appointed", "confer", "manure", "basic", "patriarch", "parties", "phenomena", "expel", "dried", "idiom", "theme", "stimulate", "admitting", "drapery", "genera", "countries", "stamens", "previously", "involving", "separating", "murderous", "seizing", "successful", "frighten", "set", "hoop", "printed", "supported", "spiritless", "plumb", "shoal", "pavilion", "endurance", "encumber", "pendent", "turkey", "conviction", "receiving", "faction", "limber", "disagree", "stupefy", "prevail", "enlarged", "cage", "clasp", "conveying", "mammals", "protoplasm", "engross", "exert", "emperor", "extending", "porous", "consequent", "horseback", "froth", "settled", "bachelor", "reduced", "landscape", "knock", "republican", "partaking", "suspended", "edifice", "capability", "buckle", "vanish", "righteous", "lawful", "maiden", "telltale", "cellular", "convict", "soothe", "snail", "brake", "sparrow", "vast", "chaff", "camp", "filament", "chill", "glassy", "tracing", "elect", "accusation", "fishes", "envy", "hunger", "polite", "lumber", "freely", "flashing", "discredit", "profess", "accretion", "brightness", "moist", "affirm", "illuminate", "melody", "tire", "pliant", "effusion", "exclusion", "text", "blessed", "enrich", "utensil", "frugality", "revenge", "park", "implied", "in", "corona", "differential", "fusion", "impotent", "dissection", "tragedy", "woody", "cleanse", "deceit", "longer", "yearly", "almost", "pendulum", "twin", "indicator", "respiration", "infantry", "hail", "consume", "distrain", "reducing", "chord", "spectator", "illegal", "swiftness", "lever", "prosperous", "colony", "selection", "illusion", "ventilate", "parietal", "arctic", "bismuth", "cranium", "formative", "flax", "solar", "undertaking", "behave", "urinary", "assistance", "but", "worsted", "coral", "humorous", "nineteen", "sameness", "resentment", "gaseous", "lion", "sure", "grecian", "textile", "stagger", "vivacity", "iniquity", "summon", "clause", "velvet", "smear", "encompass", "swollen", "fashionable", "intrude", "deprived", "garnish", "composing", "loom", "preaching", "eloquence", "decayed", "silurian", "parchment", "infection", "magnesium", "prelude", "discontent", "thumb", "tympanum", "distract", "team", "rehearse", "dictate", "abortion", "seminary", "skip", "manager", "selfish", "loathing", "suck", "obsequious", "pyramid", "observant", "establishment", "penance", "trinity", "busy", "springing", "weeping", "gayety", "rugged", "stave", "total", "flask", "concurrence", "mood", "chart", "inscription", "clerk", "viscid", "baptism", "calculus", "enduring", "foretell", "reprove", "eucharist", "madness", "stupidity", "catalogue", "hurry", "atom", "collation", "pillow", "calculate", "eject", "housing", "peel", "location", "inhuman", "tuft", "least", "substantial", "sustained", "thwart", "unlawful", "cabinet", "ventricle", "rigging", "determined", "trip", "assize", "driven", "carpet", "hurt", "smoky", "pump", "longing", "radius", "ambiguous", "exalted", "albumin", "oppression", "frugal", "gothic", "stately", "hooked", "shears", "porcelain", "benzene", "franchise", "although", "fraction", "flavored", "substitution", "distinctly", "entitle", "transit", "since", "nine", "risk", "ghost", "divorce", "prophecy", "representative", "changeable", "bohemian", "unable", "explicit", "advise", "greedy", "squander", "requisite", "enroll", "revolt", "scold", "foreshow", "evaporate", "warfare", "pearly", "vertebral", "swiftly", "stereotype", "herb", "impartial", "hardy", "authorize", "corrosive", "laborious", "infinity", "absorption", "conjunction", "cloister", "reservoir", "acrid", "commodity", "million", "uterus", "eleventh", "fifteen", "pretender", "diatonic", "jury", "hydroxyl", "varieties", "surgery", "commons", "upon", "invent", "responsible", "requite", "prompt", "those", "haul", "reside", "lathe", "allege", "consort", "mentally", "licentious", "excavate", "bury", "babble", "feudal", "canvass", "comprehend", "dissolute", "pension", "blessing", "switch", "effeminate", "repeating", "educate", "balsam", "shuffle", "stifle", "outrage", "invasion", "appease", "tilt", "stoop", "vexatious", "wager", "orbit", "resound", "drawn", "subdued", "dagger", "indication", "pickle", "hackney", "hearty", "relapse", "concealed", "tame", "speculum", "persistent", "blanch", "carbonic", "prickly", "syllogism", "luxury", "childish", "provincial", "knit", "forced", "wasting", "dismiss", "designation", "corporation", "coupling", "venus", "ballast", "lavish", "recording", "phenomenon", "boring", "curvature", "bully", "ruff", "bowsprit", "bastion", "braid", "consult", "harrow", "hasten", "deputy", "suspicious", "betray", "puppet", "playing", "privately", "famous", "assert", "chisel", "permission", "reformed", "ratio", "mustard", "hissing", "hurtful", "leaning", "reversal", "committee", "treason", "villain", "corresponding", "resulting", "treble", "pushing", "examining", "ductile", "affirmation", "flux", "guttural", "remission", "congregation", "annoy", "criticise", "said", "mortify", "heedless", "tabular", "shiver", "uneven", "displeasure", "antique", "fatal", "characteristic", "zigzag", "audible", "reversion", "canker", "shark", "respecting", "surveyor", "pistil", "premature", "agility", "sulphate", "wreath", "inflate", "presage", "lustful", "eighth", "capstan", "confined", "rendered", "chalk", "engender", "twofold", "attractive", "fell", "diligent", "burlesque", "vacancy", "bustle", "misery", "luxurious", "holland", "silicon", "antagonist", "fright", "concretion", "overpower", "dissent", "lover", "introduction", "abandoned", "pottery", "hunt", "lives", "desperate", "roving", "birch", "density", "bunch", "overturn", "revival", "turnpike", "operative", "finishing", "spine", "dismount", "headdress", "veil", "overwhelm", "unhappy", "coarsely", "perplexity", "ellipse", "oration", "tributary", "informal", "herbaceous", "sanctity", "undo", "restoration", "artist", "vicinity", "soak", "vacation", "median", "pivot", "mohammedan", "negligence", "uniformly", "echo", "modify", "testify", "absurd", "seaweed", "collector", "projectile", "aberration", "piston", "saturate", "fallow", "marrow", "vomiting", "infirm", "testing", "enjoy", "languish", "precedent", "stationary", "rudder", "inanimate", "payable", "seventy", "clutch", "china", "peaceful", "sister", "sucking", "preach", "prosecution", "jaundice", "gradient", "hypothesis", "adjoining", "penitent", "comment", "concealment", "perpetual", "airy", "rostrum", "dying", "accuse", "talking", "inherit", "tumbler", "thrown", "palatine", "defraud", "basin", "calmness", "symphony", "rudimentary", "negotiate", "wandering", "quail", "revelation", "greatness", "answerable", "besides", "widow", "alter", "falsify", "autumn", "oval", "crossbow", "recede", "broker", "hatch", "erection", "adjunct", "tense", "habitation", "umbrella", "inclining", "manuscript", "realize", "mild", "folly", "ascending", "patronage", "wedlock", "getting", "snake", "coordinate", "abridge", "dismal", "senior", "oblong", "sequester", "organization", "diseased", "vacuum", "bryozoa", "immersion", "focus", "plait", "founded", "offered", "dioxide", "unfeeling", "fluke", "chicken", "eleven", "maintenance", "puddling", "moisten", "hound", "russian", "perforated", "retainer", "olfactory", "roundish", "warehouse", "granite", "frozen", "launch", "quarry", "splinter", "gunpowder", "molding", "heighten", "surveying", "trough", "searching", "stab", "elevator", "extraction", "refinement", "crotchet", "use", "mound", "rhythm", "ivory", "desirous", "attainment", "rectify", "indolent", "jerk", "umbilicus", "smack", "muse", "auction", "allegiance", "define", "apparently", "tarsus", "inability", "baggage", "boarding", "folding", "junior", "might", "clamp", "changed", "possessed", "passable", "bromine", "sent", "spill", "delirium", "coffin", "trickery", "withered", "polar", "utterly", "stagnant", "phosphorus", "coalesce", "consecrate", "straddle", "submissive", "shatter", "ulcer", "toss", "shameful", "daily", "disengage", "ruler", "bearer", "bony", "calyx", "wickedness", "placed", "changing", "felicity", "poll", "vocation", "attendance", "falsely", "clip", "wonderful", "potash", "bodies", "substantive", "liberate", "ritual", "prevailing", "telegraph", "carrier", "courteous", "waist", "herd", "aspirate", "intend", "potent", "enhance" \
                              "inconsistency", "analyse", "analysis", "analyst", "analytic", "analytical", "analytically", "analyze", "approachable", "area", "assess", "assessable", "assessment", "assume", "assumed", "assuming", "assumption", "authoritative", "authoritatively", "authority", "availability", "available", "beneficial", "beneficiary", "blinker", "concept", "conception", "conceptual", "conceptualize", "conceptually", "consist", "consistency", "consistent", "consistently", "constituency", "constitute", "constitution", "constitutive", "context", "contextual", "contextualization", "contextualize", "contextually", "contractor", "create", "creation", "creator", "data", "definable", "define", "definition", "derivation", "derive", "disestablish", "disestablishment", "dissimilar", "dissimilarity", "distribute", "distribution", "distributional", "distributive", "distributor", "economic", "economical", "economically", "economics", "economist", "economy", "environment", "environmental", "environmentalism", "environmentalist", "environmentally", "establish", "established", "establishment", "estimation", "evident", "evidential", "evidently", "exporter", "financial", "financially", "financier", "formula", "formula milk", "formulate", "formulation", "functional", "functionally", "ID", "identifiable", "identification", "identify", "identity", "illegality", "income", "inconsistent", "indicate", "individualist", "insignificance", "methodological", "redistribution", "responsively", "blinker", "indication", "indicator", "indiscreet", "indiscreetly", "individualism", "individuality", "individually", "insignificant", "interpret", "interpretable", "interpretation", "invariable", "invariably", "involve", "involved", "involvement", "isolating", "labor", "legal", "legality", "legally", "legislate", "legislation", "legislative", "legislator", "legislature", "majority", "method", "methodical", "methodically", "methodology", "misinterpret", "misinterpretation", "occur", "occurrence", "percentage", "periodic", "periodical", "periodically", "policy", "principle", "principled", "procedural", "procedure", "proceed", "proceeding", "proceeds", "reassess", "reassessment", "recreate", "recreation", "redefine", "redefinition", "redistribute", "reformulate", "reformulation", "reinterpret", "reinterpretation", "reoccur", "require", "requirement", "respond", "respondent", "response", "responsive", "restructure", "restructuring", "role", "sector", "significance", "significant", "significantly", "signify", "similar", "similarity", "similarly", "specific", "specifically", "specification", "specificity", "specifics", "structural", "structurally", "theoretical", "theoretically", "theoretician", "theorist", "theory", "unapproachable", "unavailability", "unavailable", "unconstitutional", "unconstitutionally", "undefined", "uneconomic", "uneconomical",\
     "unidentifiable", "uninvolved", "unprincipled", "unresponsive", "unstructured", "variability", "variance", "variant", "variation", "varied", "vary", "inappropriacy", "deregulation", "distinctly", "evaluation", "insecurely", "abnormal", "abnormally", "achievable", "achieve", "achievement", "acquire", "acquisition", "admin", "administration", "administrative", "administratively", "administrator", "affect", "affective", "affectively", "appropriacy", "aspect", "assistance", "categorization", "categorize", "category", "chapter", "commissioner", "community", "complexity", "computable", "computation", "computational", "compute", "computer", "computing", "conclude", "conclusion", "conclusive", "conclusively", "consequence", "consequent", "consequently", "construction", "constructive", "constructively", "consume", "consumer", "consumption", "creditor", "cultural", "culturally", "cultured", "restrictive", "deregulate", "distinct", "distinction", "distinctive", "distinctively", "element", "equate", "equation", "evaluate", "finality", "finalization", "finalize", "finally", "inappropriate", "inconclusive", "inconclusively", "indistinct", "indistinctly", "injure", "injured", "injury", "insecure", "institution", "institutional", "institutionalization", "institutionalize", "institutionalized", "institutionally", "invest", "investment", "investor", "irrelevance", "irrelevancy", "irrelevant", "irrelevantly", "item", "itemize", "journal", "maintain", "maintenance", "previously", "relevance", "resourcefully", "selectively", "strategical", "restrictive", "nontraditional", "normalcy", "normality", "normalization", "normalize", "normally", "obtain", "obtainable", "participant", "participate", "participation", "participatory", "perceive", "perception", "police commissioner", "positively", "previous", "primarily", "purchaser", "purchasing", "reconstruct", "reconstruction", "reevaluate", "re-evaluation", "refocus", "region", "regional", "regionally", "regulate", "regulator", "regulatory", "reinvest", "reinvestment", "relevant", "reside", "residence", "residency", "residential", "resourceful", "restrict", "restricted", "restriction", "restrictively", "security", "seek", "selection", "selective", "selector", "sought", "strategic", "strategist", "strategy", "textual", "tradition", "traditional", "traditionalist", "traditionally", "transferability", "transferable", "transference", "unaffected", "unassisted", "uncultured", "under-resourced", "uninjured", "unobtainable", "unrestricted", "conventionality", "insufficiency", "interactively", "alternatively", "circumstance", "commentary", "commentator", "compensate", "compensation", "compensatory", "component", "consensus", "considerable", "considerably", "constancy", "constantly", "constrain", "constraint", "contribute", "contribution", "contributor", "convene", "convention", "conventional", "coordination", "corporate", "corporation", "correspond", "correspondence", "corresponding", "correspondingly", "criterion", "deduce", "deducible", "deduction", "demo", "demonstrable", "demonstrably", "demonstrate", "demonstration", "demonstrator", "disproportion", "disproportionate", "disproportionately", "documentation", "dominance", "dominant", "dominate", "domination", "emphasis", "emphasize", "emphatic", "emphatically", "ensure", "exclude", "excluding", "exclusion", "exclusionary", "framework", "funder", "funding", "illustrate", "illustration", "illustrative", "immigrant", "immigrate", "immigration", "immigration control", "imply", "inconstancy", "inconstant", "initially", "insufficient", "interact", "interaction", "interactive", "invalidate", "invalidation", "invalidity", "justifiable", "justifiably", "justification", "justified", "justify", "linkage", "locate", "located", "location", "maximization", "maximize", "minority", "negate", "nuclear reactor", "outcome", "partnership", "philosopher", "philosophic", "reliability", "technological", "unconventionality", "philosophic", "philosophical", "philosophize", "philosophizing", "philosophy", "physically", "proportion", "proportional", "proportionally", "proportionate", "proportionately", "publish", "publisher", "publishing", "react", "reaction", "reactionary", "reactivate", "reactivation", "reactive", "reactor", "registration", "reliable", "reliance", "reliant", "relocate", "relocation", "rely", "removable", "removal", "schematic", "schematically", "sequential", "sequentially", "sexism", "sexual", "sexuality", "sexually", "specifiable", "specify", "sufficiency", "sufficient", "sufficiently", "technical", "technically", "technique", "technology", "unconstrained", "unconventional", "unjustified", "unpublished", "unreliability", "unreliable", "unspecified", "valid", "validate", "validation", "validity", "validly", "volume", "adequacy", "cyclical", "domesticated", "predictability", "accessibility", "accessible", "adequate", "annually", "apparent", "apparently", "approximately", "approximation", "attitude", "attributable", "civil", "civilly", "commit", "commitment", "committed", "communicable", "communicate", "communication", "communicative", "concentrated", "concentration", "confer", "conference", "contrasting", "contrastive", "cyclic", "debatable", "despite", "dimension", "-dimensional", "domesticate", "emerge", "emergence", "emergent", "erroneous", "erroneously", "error", "ethnicity", "goal", "hence", "hypothesis", "hypothesize", "hypothetical", "hypothetically", "implicate", "implication", "impose", "imposition", "inaccessibility", "inaccessible", "inadequacy", "inadequate", "inadequately", "integrate", "integrated", "integration", "internal", "internalization", "internalize", "internally", "investigate", "investigation", "investigative", "investigator", "investigatory", "mechanism", "multidimensional", "obvious", "obviously", "obviousness", "occupancy", "occupant", "occupation", "occupational", "occupationally", "occupied", "occupier", "occupy", "optional", "parameter", "predict", "predictable", "prediction", "principally", "professionalism", "professionally", "projection", "promote", "promoter", "promotion", "regime", "resolution", "statistical", "statistic", "unpredictability", "retain", "retainer", "retention", "retentive", "series", "statistician", "status", "stressed", "stressed out", "stressful", "subsequent", "subsequently", "summarize", "summation", "uncommunicative", "undertake", "undertaking", "undertook", "unparalleled", "unpredictable", "unresolved", "unstressed", "discretely", "enforceable", "expansively", "illogicality", "imprecisely", "liberation", "academe", "academia", "academy", "adjust", "adjustment", "alter", "alterable", "alteration", "amend", "amendment", "aware", "awareness", "capacity", "challenged", "challenger", "challenging", "clause", "consult", "consultancy", "consultant", "consultation", "consultative", "discrete", "discretion", "discretionary", "enable", "energetic", "energetically", "energy", "enforce", "enforced", "entity", "evolution", "evolutionarily", "evolutionary", "evolve", "expand", "expansion", "expansionism", "expansionist", "expansive", "exposed", "exposure", "external", "externalization", "externalize", "externally", "facilitate", "facilitation", "facilitator", "facility", "fundamentally", "generate", "generation", "illogical", "image", "imagery", "imprecise", "incapacitate", "indiscretion", "instability", "liberalism", "liberalization", "liberalize", "liberate", "liberated", "licence", "licensed", "logic", "logical", "logically", "logician", "margin", "marginally", "mental", "mentality", "mentally", "modification", "modify", "notion", "orientate", "orientation", "perspective", "precise", "precisely", "precision", "primacy", "psychological", "stylishly", "sustainability", "psychologically", "psychologist", "psychology", "pursue", "pursuit", "ratio", "readjust", "readjustment", "redraft", "reorient", "reorientation", "revenue", "social security", "stability", "stabilization", "stabilize", "styling", "stylish", "stylization", "stylized", "sustain", "sustainable", "sustenance", "symbol", "symbolic", "symbolically", "symbolism", "symbolist", "symbolize", "transition", "transitional", "transitory", "trend", "unalterable", "unaltered", "unaware", "unawareness", "unlicensed", "unmodified", "unstable", "unsustainable", "version", "welfare", "whereas", "motivated", "enhanced", "explicitly", "flexibility", "inaccuracy", "inflexibility", "irrationality", "abstraction", "accuracy", "accurate", "accurately", "acknowledge", "allocate", "allocation", "assign", "assignment", "attach", "attached", "attachment", "authorship", "bonding", "brevity", "briefing", "briefly", "capability", "capable", "capably", "citation", "cite", "cooperate", "cooperation", "discriminate", "discrimination", "diverse", "diversification", "diversify", "diversity", "domain", "edit", "edition", "editor", "editorship", "enhance", "estate", "exceed", "expertise", "explicit", "federal", "federally", "federation", "fee", "flexible", "furthermore", "gender", "ignorance", "ignorant", "ignorantly", "ignore", "inaccurate", "incapable", "incentive", "incidence", "incident", "incidentally", "incorporate", "incorporation", "inflexible", "inhibit", "inhibition", "initiation", "initiative", "initiator", "instruct", "instructive", "instructively", "instructor", "intelligence", "intelligent", "intelligently", "intermission", "interval", "irrational", "lecturer", "migrant", "migrate", "migration", "migratory", "ministerial", "ministry", "motivate", "neutrality", "rationality", "neutralization", "neutralize", "nevertheless", "precede", "precedence", "precedent", "presumably", "presume", "presumption", "presumptuous", "rational", "rationalism", "rationalization", "rationalize", "reassign", "reassignment", "recommence", "recoverable", "recovery", "recovery room", "reveal", "revealing", "revealingly", "revelation", "subsidization", "subsidize", "subsidy", "traceable", "transform", "transformation", "transformational", "transportation", "unassigned", "unattached", "underlie", "underlying", "unintelligent", "unmotivated", "unprecedented", "unprecedentedly", "utilization", "utilize", "ideological", "invisibility", "adapt", "adaptability", "adaptable", "adaptation", "adaption", "adaptive", "adulthood", "advocacy", "classical", "classically", "comprehensively", "comprise", "confirm", "confirmation", "conversion", "coupling", "decade", "definitely", "definitive", "definitively", "deniable", "denial", "deny", "differentiate", "differentiation", "disposable", "disposal", "dispose", "disposed", "eliminate", "elimination", "empirical", "empirically", "empiricism", "empiricist", "equip", "equipment", "extraction", "finite", "foundation", "global", "globalization", "globally", "globe", "graded", "hierarchical", "hierarchically", "hierarchy", "identical", "identically", "ideology", "indefinite", "indefinitely", "infer", "inference", "infinitely", "innovate", "innovation", "innovative", "innovator", "innovatory", "insertion", "intervene", "intervention", "invisible", "irreversible", "irreversibly", "isolate", "isolated", "isolation", "isolationism", "isolationist", "media", "mode", "paradigm", "paradigmatic", "phenomenal", "phenomenon", "prioritization", "prioritize", "priority", "prohibit", "prohibition", "prohibitive", "prohibitively", "publication", "quotation", "reversal", "reversibility", "reversible", "simulate", "simulated", "simulation", "solely", "somewhat", "submission", "uniquely", "submit", "succession", "successive", "successively", "successor", "survival", "survive", "survivor", "thesis", "topic", "topical", "topicality", "transmission", "transmit", "ultimately", "unaided", "undeniable", "undeniably", "unique", "visibility", "visible", "visibly", "voluntarily", "arbitrarily", "abandoned", "abandonment", "accompaniment", "accompany", "accumulate", "accumulation", "ambiguity", "ambiguous", "ambiguously", "append", "appendix", "appreciable", "appreciably", "appreciate", "appreciation", "arbitrary", "automate", "automation", "biased", "clarification", "clarify", "clarity", "commodity", "complementary", "conform", "conformability", "conformable", "conformance", "conformation", "conformist", "conformity", "contradict", "contradiction", "contradictory", "crucial", "crucially", "currency", "denotation", "denotational", "denote", "detect", "detectable", "detection", "detective", "detector", "deviate", "deviation", "displace", "displacement", "drama", "dramatic", "dramatically", "dramatist", "dramatization", "dramatize", "eventual", "eventuality", "eventually", "exhibition", "exploitation", "fluctuate", "fluctuation", "guideline", "implicit", "implicitly", "induce", "induction", "inevitability", "inevitable", "inevitably", "infrastructural", "infrastructure", "inspect", "inspection", "inspector", "intense", "intensely", "intensification", "intensify", "intensity", "intensive", "intensively", "manipulate", "manipulation", "manipulative", "minimization", "minimize", "nonconformism", "Nonconformist", "nonconformist", "nonconformity", "nuclear", "paragraph", "paragraphing", "practitioner", "predominance", "predominant", "predominantly", "predominate", "predominately", "prospective", "reinforce", "reinforcement", "reschedule", "rescheduling", "restoration", "restore", "revise", "revision", "surveyor", "terminate", "termination", "thematic", "thematically", "thereby", "unaccompanied", "unambiguous", "unambiguously", "unappreciated", "unbiased", "uncharted", "unscheduled", "vehicle", "via", "virtual", "virtually", "visualization", "visualize", "vol.", "widespread", "incoherence", "rigidity", "accommodate", "accommodation", "analogous", "analogy", "anticipate", "anticipation", "anticipatory", "assurance", "assure", "assured", "assuredly", "attain", "attainable", "attainment", "behalf", "bulky", "cease", "ceaseless", "ceaselessly", "coherence", "coherent", "coherently", "coincide", "coincidence", "coincident", "coincidental", "coincidentally", "commence", "commencement", "compatibility", "compatible", "compatibly", "concurrent", "concurrently", "confine", "confined", "controversial", "controversially", "controversy", "conversely", "device", "devote", "devotion", "diminish", "diminution", "distort", "distortion", "duration", "erode", "erosion", "ethic", "ethical", "ethically", "found", "immature", "immaturity", "incoherent", "incompatibility", "incompatible", "inherent", "inherently", "insight", "insightful", "integral", "integrally", "maturation", "maturational", "maturity", "mediate", "mediation", "minimal", "minimalism", "minimalist", "minimally", "mutual", "mutuality", "mutually", "passivity", "protocol", "qualitative", "qualitatively", "refine", "refined", "refinement", "relax", "relaxation", "relaxed", "relaxing", "restrain", "restrained", "restraint", "rev", "revolution", "revolutionize", "rigid", "scenario", "temporarily", "violation", "self-assurance", "self-assured", "sphere", "spherical", "spherically", "supplemental", "supplementary", "suspend", "suspension", "temporary", "unanticipated", "unattainable", "unconfined", "uncontroversial", "undiminished", "unethical", "unethically", "unfounded", "unification", "unify", "unrestrained", "violate", "vision", "reluctance", "straightforwardly", "adjacent", "albeit", "assemble", "assembly", "collapsible", "colleague", "compilation", "compile", "conceivable", "conceivably", "conceive", "convince", "convinced", "convincing", "convincingly", "depress", "depressed", "depressing", "depressingly", "depression", "enormity", "enormous", "enormously", "forthcoming", "inclination", "inclined", "inconceivable", "inconceivably", "integrity", "intrinsic", "intrinsically", "invoke", "likewise", "nonetheless", "odd", "oddness", "odds", "ongoing", "persist", "persistence", "persistent", "persistently", "reluctant", "so-called", "straightforward", "unconvinced", "undergo", "whereby", \
     "Acting", "Actuarial Foundations", "Actuarial Science", "Administrative Sciences", "Administrative Sciences", "Advanced Information Technology", "Advertising", "African American & Black Diaspora Studies", "African American Studies", "African Languages & Literatures", "African Studies", "American & New England Studies", "American Law", "American Studies", "Anatomy & Neurobiology", "Ancient Greek", "Ancient Greek & Latin", "Ancient Greek/Literary Translation", "Anglican & Episcopal Studies", "Anthropology", "Anthropology with a Specialization in Anthropology, Health & Medicine", "Anthropology with a Specialization in Biological Anthropology", "Anthropology with a Specialization in Sociocultural Anthropology", "Anthropology & Religion", "Applied Biomechanics", "Applied Biostatistics", "Applied Business Analytics", "Applied Data Analytics", "Applied Human Development", "Arabic", "Archaeological & Environmental Sciences", "Archaeological & Environmental Sciences/Archaeology", "Archaeology", "Architectural Studies", "Art", "Art Education", "Art Education with Initial License", "Art History", "Art & Architecture, History of", "Artificial Intelligence", "Arts Administration", "Arts Leadership", "Arts Management", "Arts Marketing", "Asian Legal Studies", "Asian Studies", "Astronomy", "Astronomy & Physics", "Astrophysics & Space Physics", "Autism Spectrum Disorders", "Autism & Emotional/Behavioral Disorders", "Banking & Financial Law", "Behavior & Health", "Behavioral Neuroscience", "Bilingual Education/Teaching English to Speakers of Other Languages", "Biochemistry", "Biochemistry & Molecular Biology; Biotechnology", "Bioimaging", "Bioinformatics", "Bioinformatics", "Biology", "Biology with a Specialization in Behavioral Biology", "Biology with a Specialization in Cell Biology, Molecular Biology & Genetics", "Biology with a Specialization in Ecology & Conservation Biology", "Biology with a Specialization in Neurobiology", "Biology Education", "Biomedical Engineering", "Biomedical Forensic Sciences", "Biomedical Research Technologies", "Biomedical Sciences", "Biostatistics", "Business Administration", "Business Administration & Law", "Business Administration & Management", "Business Administration & Medicine", "Business Administration & Public Health", "Business Analytics", "Chemistry", "Chemistry & Physics", "Chemistry: Biochemistry", "Chemistry: Chemical Biology", "Teaching of Chemistry", "Child Life & Family-Centered Care", "Chinese", "Chinese Language & Literature", "Chinese/Literary Translation", "Chronic & Non-Communicable Diseases", "Cinema & Media Production", "Cinema & Media Studies", "City Planning", "Civic Science Communication", "Classical Civilization", "Classical Studies", "Classical Studies/Philosophy", "Classics & Archaeology", "Classics & Philosophy", "Classics & Religion", "Climate Change and Health", "Clinical Research", "Cognitive & Neural Systems", "Commercial Theater Development", "Community Assessment, Program Design, Implementation & Evaluation", "Comparative Literature", "Comparative Literature/Literary Translation", "Composition", "Composition & Music Theory", "Computer Engineering", "Computer Information Systems", "Computer Networks", "Computer Science & Economics", "Computer Science", "Computing & Data Sciences", "Conducting", "Core Curriculum", "Core Independent Studies", "Corporate Finance", "Costume Design & Production", "Counseling", "Counseling Psychology & Applied Human Development", "Creative Writing", "Criminal Justice", "Curriculum & Teaching", "Cybercrime Investigation & Cybersecurity", "Dance", "Data Analytics", "Data Science", "Database Management & Business Intelligence", "Deaf Education", "Deaf Studies", "Dental Biomaterials", "Dental Medicine", "Dental Public Health", "Dermatology", "Developmental Studies", "Directing", "Early Childhood Education", "Earth & Environment", "Earth & Environmental Sciences", "Economic Policy", "Economics", "Economics, Global Development", "Economics & Mathematics", "Economics & Mathematics/Economics", "Editorial Studies", "Education", "Education for Equity & Social Justice", "Education & Human Development", "Education & Human Development/Applied Human Development", "Education & Human Development/Educational Policy Studies", "Education & Human Development/TESOL & Applied Linguistics", "Education & Human Development/TESOL Multilingual Learner Education", "Educational Leadership & Policy Studies", "Educational Studies", "Electrical Engineering", "Electrical & Computer Engineering", "Elementary Education", "Emerging Media Studies", "Emotional & Behavioral Challenges in Schools", "Endodontics", "Energy & Environment", "Engineering Science", "English", "English & American Literature", "English & Law", "English Education", "Enterprise Risk Management", "Enterprise Risk Management & Compliance", "Environmental Analysis & Policy", "Environmental Health", "Environmental Remote Sensing & GIS", "Epidemiology", "Epidemiology & Biostatistics", "Estate Planning", "Esthetic, Digital, and Operative Dentistry", "European Law", "European Studies", "Evangelism", "Event Management", "Event Management & Public Relations", "Faith & Ecological Justice", "Film", "Film & Television", "Film & Television Studies", "Finance", "Financial Management", "Financial Planning", "Financial Services Compliance", "Financial Technology", "Forensic Anthropology", "Foundations of Health Communication", "French & Linguistics", "French Language & Literature", "French Studies", "French Studies/French Language & Literature", "French Studies/Literary Translation", "Gastronomy", "Genealogical Research", "General Science Education", "Genetic Counseling", "Genetic Counseling/Master of Public Health", "Genetics & Genomics", "Geoarchaeology", "Geriatric Dental Medicine", "German", "German Language & Literature", "German/Literary Translation", "Global Education Leadership Program", "Global Health", "Global Health Program Design, Monitoring & Evaluation", "Global Marketing Management", "Global Medieval Studies", "Global Policy", "Graphic Design", "Greek—Ancient", "Greek—Modern", "Health Care Emergency Management", "Healthcare Management", "Healthcare Promotion, Media & Marketing", "Health Communication", "Health Communication & Promotion", "Health Equity", "Health Informatics", "Health Policy & Law", "Health Professions Education", "Health Science", "Health Services & Policy Research", "Hebrew", "Higher Education Leadership", "Hindi-Urdu", "Hispanic Language & Literatures", "Historical Performance", "History", "History of Art & Architecture", "History & Law", "Holocaust, Genocide & Human Rights Studies", "Hospitality", "Hospitality Administration", "Hospitality Administration & Gastronomy", "Hospitality & Communication", "Hospitality Management", "Hospitality Management (Advanced)", "Human Development & Education", "Human Physiology", "Human Resources Management", "Human Rights & Social Justice", "Immunology Training", "Independent Major", "Infectious Disease", "Information Security", "Information Technology", "Information Technology Project Management", "Innovation & Entrepreneurship", "Insurance Management", "Intellectual Property & Information Law", "Interdisciplinary Studies", "International Business Law", "International & European Business Law", "International Affairs", "International Business Management", "International Commercial & Investment Arbitration", "International Finance", "International Relations", "International Relations/International Affairs", "International Relations & Business Administration", "International Relations & Law", "Investment Analysis", "Italian", "Italian & Linguistics", "Italian Studies", "Japanese & Linguistics", "Japanese Language & Literature", "Japanese/Literary Translation", "Jewish Studies", "Journalism", "Korean Language & Literature", "Korean", "Language & Literacy Education", "Latin", "Latin American Studies", "Latin/Literary Translation", "Law", "Law—American", "Law—Asian Legal Studies", "Law—Banking & Financial", "Law—European", "Law—Intellectual Property & Information", "Law—International Business", "Law—Taxation", "Law & Business Administration", "Law & English", "Law & History", "Law & International Relations", "Law & Philosophy", "Law & Preservation Studies", "Law & Public Health", "Leadership, Policy & Advocacy for Early Childhood Well-Being", "Lighting Design", "Linguistics", "Linguistics & African Languages", "Linguistics & Computer Science", "Linguistics & Philosophy", "Linguistics and Speech, Language & Hearing Sciences", "Linguistics and Speech, Language & Hearing Sciences", "Literacy Instruction & Intervention", "Literary Translation", "Management Studies", "Management Studies", "Marine Science", "Materials Science & Engineering", "Maternal & Child Health", "Mathematical Finance", "Mathematical Finance & Financial Technology", "Mathematics (includes Statistics)", "Mathematics", "Mathematics/Biostatistics", "Mathematics & Computer Science", "Mathematics & Mathematics Education", "Mathematics & Philosophy", "Mathematics & Physics", "Mathematics Education", "Mechanical Engineering", "Media Science", "Media Ventures", "Medical Anthropology", "Medical Anthropology & Cross-Cultural Practice", "Medical Sciences", "Medical Sciences and Mental Health Counseling & Behavioral Medicine", "Medical Sciences & Public Health", "Medicine", "Medicine & Law", "Medicine/Business Administration", "Medicine & Public Health", "Early Medical School Selection Program", "Mental Health & Substance Use", "Mental Health Counseling & Behavioral Medicine", "Microbiology", "Middle East & North Africa Studies", "Middle Eastern and South Asian Languages & Literatures", "Modern Foreign Language Education", "Modern Greek", "Modular Medical/Dental Integrated Curriculum", "Molecular Biology, Cell Biology & Biochemistry", "Molecular Medicine", "Museum Education", "Museum Studies", "Music", "Musicology", "Music Education", "Music Ministry", "Music Performance", "Music Theory", "Muslim Cultures", "Muslim Societies", "Muslim Studies", "Myth Studies", "Neuroscience", "Neuroscience & Computational Neuroscience", "Nutrition", "Nutrition/Dietetics", "Nutrition & Metabolism", "Occupational Therapy", "Opera", "Oral Biology", "Oral Health Sciences", "Oral & Maxillofacial Surgery", "Orofacial & Skeletal Biology", "Orthodontics & Dentofacial Orthopedics", "Painting", "Paralegal Studies", "Path 2 Path Program", "Pathology & Laboratory Medicine", "Pediatric Dentistry", "Performance, Music", "Periodontology", "Persian Cultural Studies", "Pharmaceutical Development, Delivery & Access", "Pharmacology & Experimental Therapeutics", "Philosophy", "Philosophy & Neuroscience", "Philosophy & Physics", "Philosophy & Political Science", "Philosophy & Psychology", "Philosophy & Religion", "Physical Therapy", "Physician Assistant Program", "Physics", "Physics & Computer Science", "Physics Education", "Physiology or Biophysics", "Playwriting", "Political Science", "Population Health Research", "Portuguese & Brazilian Cultural Studies", "Premedical Studies", "Preservation Studies", "Printmaking", "Print Media & Photography", "Product Design & Manufacture", "Production Management", "Professional Fundraising", "Program Management", "Project Management", "Project, Program & Portfolio Management", "Prosthodontics", "Psychology", "Public Anthropology", "Public Health", "Public Health & Genetic Counseling", "Public Health & Law", "Public Health & Management", "Public Health & Medical Sciences", "Public Health & Medicine", "Public Health & Social Work", "Public Policy Analysis", "Public Relations", "Reading Education", "Real Estate", "Rehabilitation Sciences", "Religion", "Religion & Public Leadership", "Religion in Science & Medicine", "Religious Education", "Religious Studies", "Remote Sensing & Geospatial Sciences", "Robotics & Autonomous Systems", "Russian", "Russian Language & Literature", "Scene Design", "Scene Painting", "Science Education", "Screenwriting", "Sculpture", "Sex, Sexuality & Gender", "Social Studies Education", "Social Work, Clinical Practice", "Social Work, Macro Practice", "Social Work", "Sociology", "Sociology & Social Work", "Social Work & Education", "Social Work & Public Health", "Social Work & Theology", "Software Development", "Sound Design", "Spanish", "Spanish & Linguistics", "Spanish/Literary Translation", "Special Education", "Speech, Language & Hearing Sciences", "Speech-Language Pathology", " Spirituality Studies", "Stage Management", "Statistical Practice", "Statistics", "Statistics & Computer Science", "Strategic Management in Criminal Justice", "Supply Chain Management", "Sustainable Energy", "Systems Engineering", "Tax Law", "Teaching English to Speakers of Other Languages", "Teaching Language, Literature & Film", "Teaching Science Education", "Teaching Students with Moderate Disabilities", "Teaching Students with Severe Disabilities", "Teaching Writing", "Technical Production", "Telecommunication", "Television", "Theatre Arts", "Theatre Education", "Theatre–Stage Management", "Theatre–Technical Production", "Theology", "Theology & Latinx Studies", "Theology & Social Work", "Theology—Divinity & Sacred Music", "Theology—Sacred Music", "Theology—Sacred Theology", "Theology—Theological Studies", "Theology—Transformational Leadership", "Transactional Skills", "Turkish Cultural Studies", "Urban Affairs", "Urban Policy & Planning", "Urban Studies", "Visual Arts", "Visual & Digital Health Communication", "Visual Narrative", "Web Application Development", "Women’s, Gender & Sexuality Studies", "World Language Education", ]

    acadlist = ["inconsistency", "analyse", "analysis", "analyst", "analytic", "analytical", "analytically", "analyze", "approachable", "area", "assess", "assessable", "assessment", "assume", "assumed", "assuming", "assumption", "authoritative", "authoritatively", "authority", "availability", "available", "beneficial", "beneficiary", "blinker", "concept", "conception", "conceptual", "conceptualize", "conceptually", "consist", "consistency", "consistent", "consistently", "constituency", "constitute", "constitution", "constitutive", "context", "contextual", "contextualization", "contextualize", "contextually", "contractor", "create", "creation", "creator", "data", "definable", "define", "definition", "derivation", "derive", "disestablish", "disestablishment", "dissimilar", "dissimilarity", "distribute", "distribution", "distributional", "distributive", "distributor", "economic", "economical", "economically", "economics", "economist", "economy", "environment", "environmental", "environmentalism", "environmentalist", "environmentally", "establish", "established", "establishment", "estimation", "evident", "evidential", "evidently", "exporter", "financial", "financially", "financier", "formula", "formula milk", "formulate", "formulation", "functional", "functionally", "ID", "identifiable", "identification", "identify", "identity", "illegality", "income", "inconsistent", "indicate", "individualist", "insignificance", "methodological", "redistribution", "responsively", "blinker", "indication", "indicator", "indiscreet", "indiscreetly", "individualism", "individuality", "individually", "insignificant", "interpret", "interpretable", "interpretation", "invariable", "invariably", "involve", "involved", "involvement", "isolating", "labor", "legal", "legality", "legally", "legislate", "legislation", "legislative", "legislator", "legislature", "majority", "method", "methodical", "methodically", "methodology", "misinterpret", "misinterpretation", "occur", "occurrence", "percentage", "periodic", "periodical", "periodically", "policy", "principle", "principled", "procedural", "procedure", "proceed", "proceeding", "proceeds", "reassess", "reassessment", "recreate", "recreation", "redefine", "redefinition", "redistribute", "reformulate", "reformulation", "reinterpret", "reinterpretation", "reoccur", "require", "requirement", "respond", "respondent", "response", "responsive", "restructure", "restructuring", "role", "sector", "significance", "significant", "significantly", "signify", "similar", "similarity", "similarly", "specific", "specifically", "specification", "specificity", "specifics", "structural", "structurally", "theoretical", "theoretically", "theoretician", "theorist", "theory", "unapproachable", "unavailability", "unavailable", "unconstitutional", "unconstitutionally", "undefined", "uneconomic", "uneconomical",\
     "unidentifiable", "uninvolved", "unprincipled", "unresponsive", "unstructured", "variability", "variance", "variant", "variation", "varied", "vary", "inappropriacy", "deregulation", "distinctly", "evaluation", "insecurely", "abnormal", "abnormally", "achievable", "achieve", "achievement", "acquire", "acquisition", "admin", "administration", "administrative", "administratively", "administrator", "affect", "affective", "affectively", "appropriacy", "aspect", "assistance", "categorization", "categorize", "category", "chapter", "commissioner", "community", "complexity", "computable", "computation", "computational", "compute", "computer", "computing", "conclude", "conclusion", "conclusive", "conclusively", "consequence", "consequent", "consequently", "construction", "constructive", "constructively", "consume", "consumer", "consumption", "creditor", "cultural", "culturally", "cultured", "restrictive", "deregulate", "distinct", "distinction", "distinctive", "distinctively", "element", "equate", "equation", "evaluate", "finality", "finalization", "finalize", "finally", "inappropriate", "inconclusive", "inconclusively", "indistinct", "indistinctly", "injure", "injured", "injury", "insecure", "institution", "institutional", "institutionalization", "institutionalize", "institutionalized", "institutionally", "invest", "investment", "investor", "irrelevance", "irrelevancy", "irrelevant", "irrelevantly", "item", "itemize", "journal", "maintain", "maintenance", "previously", "relevance", "resourcefully", "selectively", "strategical", "restrictive", "nontraditional", "normalcy", "normality", "normalization", "normalize", "normally", "obtain", "obtainable", "participant", "participate", "participation", "participatory", "perceive", "perception", "police commissioner", "positively", "previous", "primarily", "purchaser", "purchasing", "reconstruct", "reconstruction", "reevaluate", "re-evaluation", "refocus", "region", "regional", "regionally", "regulate", "regulator", "regulatory", "reinvest", "reinvestment", "relevant", "reside", "residence", "residency", "residential", "resourceful", "restrict", "restricted", "restriction", "restrictively", "security", "seek", "selection", "selective", "selector", "sought", "strategic", "strategist", "strategy", "textual", "tradition", "traditional", "traditionalist", "traditionally", "transferability", "transferable", "transference", "unaffected", "unassisted", "uncultured", "under-resourced", "uninjured", "unobtainable", "unrestricted", "conventionality", "insufficiency", "interactively", "alternatively", "circumstance", "commentary", "commentator", "compensate", "compensation", "compensatory", "component", "consensus", "considerable", "considerably", "constancy", "constantly", "constrain", "constraint", "contribute", "contribution", "contributor", "convene", "convention", "conventional", "coordination", "corporate", "corporation", "correspond", "correspondence", "corresponding", "correspondingly", "criterion", "deduce", "deducible", "deduction", "demo", "demonstrable", "demonstrably", "demonstrate", "demonstration", "demonstrator", "disproportion", "disproportionate", "disproportionately", "documentation", "dominance", "dominant", "dominate", "domination", "emphasis", "emphasize", "emphatic", "emphatically", "ensure", "exclude", "excluding", "exclusion", "exclusionary", "framework", "funder", "funding", "illustrate", "illustration", "illustrative", "immigrant", "immigrate", "immigration", "immigration control", "imply", "inconstancy", "inconstant", "initially", "insufficient", "interact", "interaction", "interactive", "invalidate", "invalidation", "invalidity", "justifiable", "justifiably", "justification", "justified", "justify", "linkage", "locate", "located", "location", "maximization", "maximize", "minority", "negate", "nuclear reactor", "outcome", "partnership", "philosopher", "philosophic", "reliability", "technological", "unconventionality", "philosophic", "philosophical", "philosophize", "philosophizing", "philosophy", "physically", "proportion", "proportional", "proportionally", "proportionate", "proportionately", "publish", "publisher", "publishing", "react", "reaction", "reactionary", "reactivate", "reactivation", "reactive", "reactor", "registration", "reliable", "reliance", "reliant", "relocate", "relocation", "rely", "removable", "removal", "schematic", "schematically", "sequential", "sequentially", "sexism", "sexual", "sexuality", "sexually", "specifiable", "specify", "sufficiency", "sufficient", "sufficiently", "technical", "technically", "technique", "technology", "unconstrained", "unconventional", "unjustified", "unpublished", "unreliability", "unreliable", "unspecified", "valid", "validate", "validation", "validity", "validly", "volume", "adequacy", "cyclical", "domesticated", "predictability", "accessibility", "accessible", "adequate", "annually", "apparent", "apparently", "approximately", "approximation", "attitude", "attributable", "civil", "civilly", "commit", "commitment", "committed", "communicable", "communicate", "communication", "communicative", "concentrated", "concentration", "confer", "conference", "contrasting", "contrastive", "cyclic", "debatable", "despite", "dimension", "-dimensional", "domesticate", "emerge", "emergence", "emergent", "erroneous", "erroneously", "error", "ethnicity", "goal", "hence", "hypothesis", "hypothesize", "hypothetical", "hypothetically", "implicate", "implication", "impose", "imposition", "inaccessibility", "inaccessible", "inadequacy", "inadequate", "inadequately", "integrate", "integrated", "integration", "internal", "internalization", "internalize", "internally", "investigate", "investigation", "investigative", "investigator", "investigatory", "mechanism", "multidimensional", "obvious", "obviously", "obviousness", "occupancy", "occupant", "occupation", "occupational", "occupationally", "occupied", "occupier", "occupy", "optional", "parameter", "predict", "predictable", "prediction", "principally", "professionalism", "professionally", "projection", "promote", "promoter", "promotion", "regime", "resolution", "statistical", "statistic", "unpredictability", "retain", "retainer", "retention", "retentive", "series", "statistician", "status", "stressed", "stressed out", "stressful", "subsequent", "subsequently", "summarize", "summation", "uncommunicative", "undertake", "undertaking", "undertook", "unparalleled", "unpredictable", "unresolved", "unstressed", "discretely", "enforceable", "expansively", "illogicality", "imprecisely", "liberation", "academe", "academia", "academy", "adjust", "adjustment", "alter", "alterable", "alteration", "amend", "amendment", "aware", "awareness", "capacity", "challenged", "challenger", "challenging", "clause", "consult", "consultancy", "consultant", "consultation", "consultative", "discrete", "discretion", "discretionary", "enable", "energetic", "energetically", "energy", "enforce", "enforced", "entity", "evolution", "evolutionarily", "evolutionary", "evolve", "expand", "expansion", "expansionism", "expansionist", "expansive", "exposed", "exposure", "external", "externalization", "externalize", "externally", "facilitate", "facilitation", "facilitator", "facility", "fundamentally", "generate", "generation", "illogical", "image", "imagery", "imprecise", "incapacitate", "indiscretion", "instability", "liberalism", "liberalization", "liberalize", "liberate", "liberated", "licence", "licensed", "logic", "logical", "logically", "logician", "margin", "marginally", "mental", "mentality", "mentally", "modification", "modify", "notion", "orientate", "orientation", "perspective", "precise", "precisely", "precision", "primacy", "psychological", "stylishly", "sustainability", "psychologically", "psychologist", "psychology", "pursue", "pursuit", "ratio", "readjust", "readjustment", "redraft", "reorient", "reorientation", "revenue", "social security", "stability", "stabilization", "stabilize", "styling", "stylish", "stylization", "stylized", "sustain", "sustainable", "sustenance", "symbol", "symbolic", "symbolically", "symbolism", "symbolist", "symbolize", "transition", "transitional", "transitory", "trend", "unalterable", "unaltered", "unaware", "unawareness", "unlicensed", "unmodified", "unstable", "unsustainable", "version", "welfare", "whereas", "motivated", "enhanced", "explicitly", "flexibility", "inaccuracy", "inflexibility", "irrationality", "abstraction", "accuracy", "accurate", "accurately", "acknowledge", "allocate", "allocation", "assign", "assignment", "attach", "attached", "attachment", "authorship", "bonding", "brevity", "briefing", "briefly", "capability", "capable", "capably", "citation", "cite", "cooperate", "cooperation", "discriminate", "discrimination", "diverse", "diversification", "diversify", "diversity", "domain", "edit", "edition", "editor", "editorship", "enhance", "estate", "exceed", "expertise", "explicit", "federal", "federally", "federation", "fee", "flexible", "furthermore", "gender", "ignorance", "ignorant", "ignorantly", "ignore", "inaccurate", "incapable", "incentive", "incidence", "incident", "incidentally", "incorporate", "incorporation", "inflexible", "inhibit", "inhibition", "initiation", "initiative", "initiator", "instruct", "instructive", "instructively", "instructor", "intelligence", "intelligent", "intelligently", "intermission", "interval", "irrational", "lecturer", "migrant", "migrate", "migration", "migratory", "ministerial", "ministry", "motivate", "neutrality", "rationality", "neutralization", "neutralize", "nevertheless", "precede", "precedence", "precedent", "presumably", "presume", "presumption", "presumptuous", "rational", "rationalism", "rationalization", "rationalize", "reassign", "reassignment", "recommence", "recoverable", "recovery", "recovery room", "reveal", "revealing", "revealingly", "revelation", "subsidization", "subsidize", "subsidy", "traceable", "transform", "transformation", "transformational", "transportation", "unassigned", "unattached", "underlie", "underlying", "unintelligent", "unmotivated", "unprecedented", "unprecedentedly", "utilization", "utilize", "ideological", "invisibility", "adapt", "adaptability", "adaptable", "adaptation", "adaption", "adaptive", "adulthood", "advocacy", "classical", "classically", "comprehensively", "comprise", "confirm", "confirmation", "conversion", "coupling", "decade", "definitely", "definitive", "definitively", "deniable", "denial", "deny", "differentiate", "differentiation", "disposable", "disposal", "dispose", "disposed", "eliminate", "elimination", "empirical", "empirically", "empiricism", "empiricist", "equip", "equipment", "extraction", "finite", "foundation", "global", "globalization", "globally", "globe", "graded", "hierarchical", "hierarchically", "hierarchy", "identical", "identically", "ideology", "indefinite", "indefinitely", "infer", "inference", "infinitely", "innovate", "innovation", "innovative", "innovator", "innovatory", "insertion", "intervene", "intervention", "invisible", "irreversible", "irreversibly", "isolate", "isolated", "isolation", "isolationism", "isolationist", "media", "mode", "paradigm", "paradigmatic", "phenomenal", "phenomenon", "prioritization", "prioritize", "priority", "prohibit", "prohibition", "prohibitive", "prohibitively", "publication", "quotation", "reversal", "reversibility", "reversible", "simulate", "simulated", "simulation", "solely", "somewhat", "submission", "uniquely", "submit", "succession", "successive", "successively", "successor", "survival", "survive", "survivor", "thesis", "topic", "topical", "topicality", "transmission", "transmit", "ultimately", "unaided", "undeniable", "undeniably", "unique", "visibility", "visible", "visibly", "voluntarily", "arbitrarily", "abandoned", "abandonment", "accompaniment", "accompany", "accumulate", "accumulation", "ambiguity", "ambiguous", "ambiguously", "append", "appendix", "appreciable", "appreciably", "appreciate", "appreciation", "arbitrary", "automate", "automation", "biased", "clarification", "clarify", "clarity", "commodity", "complementary", "conform", "conformability", "conformable", "conformance", "conformation", "conformist", "conformity", "contradict", "contradiction", "contradictory", "crucial", "crucially", "currency", "denotation", "denotational", "denote", "detect", "detectable", "detection", "detective", "detector", "deviate", "deviation", "displace", "displacement", "drama", "dramatic", "dramatically", "dramatist", "dramatization", "dramatize", "eventual", "eventuality", "eventually", "exhibition", "exploitation", "fluctuate", "fluctuation", "guideline", "implicit", "implicitly", "induce", "induction", "inevitability", "inevitable", "inevitably", "infrastructural", "infrastructure", "inspect", "inspection", "inspector", "intense", "intensely", "intensification", "intensify", "intensity", "intensive", "intensively", "manipulate", "manipulation", "manipulative", "minimization", "minimize", "nonconformism", "Nonconformist", "nonconformist", "nonconformity", "nuclear", "paragraph", "paragraphing", "practitioner", "predominance", "predominant", "predominantly", "predominate", "predominately", "prospective", "reinforce", "reinforcement", "reschedule", "rescheduling", "restoration", "restore", "revise", "revision", "surveyor", "terminate", "termination", "thematic", "thematically", "thereby", "unaccompanied", "unambiguous", "unambiguously", "unappreciated", "unbiased", "uncharted", "unscheduled", "vehicle", "via", "virtual", "virtually", "visualization", "visualize", "vol.", "widespread", "incoherence", "rigidity", "accommodate", "accommodation", "analogous", "analogy", "anticipate", "anticipation", "anticipatory", "assurance", "assure", "assured", "assuredly", "attain", "attainable", "attainment", "behalf", "bulky", "cease", "ceaseless", "ceaselessly", "coherence", "coherent", "coherently", "coincide", "coincidence", "coincident", "coincidental", "coincidentally", "commence", "commencement", "compatibility", "compatible", "compatibly", "concurrent", "concurrently", "confine", "confined", "controversial", "controversially", "controversy", "conversely", "device", "devote", "devotion", "diminish", "diminution", "distort", "distortion", "duration", "erode", "erosion", "ethic", "ethical", "ethically", "found", "immature", "immaturity", "incoherent", "incompatibility", "incompatible", "inherent", "inherently", "insight", "insightful", "integral", "integrally", "maturation", "maturational", "maturity", "mediate", "mediation", "minimal", "minimalism", "minimalist", "minimally", "mutual", "mutuality", "mutually", "passivity", "protocol", "qualitative", "qualitatively", "refine", "refined", "refinement", "relax", "relaxation", "relaxed", "relaxing", "restrain", "restrained", "restraint", "rev", "revolution", "revolutionize", "rigid", "scenario", "temporarily", "violation", "self-assurance", "self-assured", "sphere", "spherical", "spherically", "supplemental", "supplementary", "suspend", "suspension", "temporary", "unanticipated", "unattainable", "unconfined", "uncontroversial", "undiminished", "unethical", "unethically", "unfounded", "unification", "unify", "unrestrained", "violate", "vision", "reluctance", "straightforwardly", "adjacent", "albeit", "assemble", "assembly", "collapsible", "colleague", "compilation", "compile", "conceivable", "conceivably", "conceive", "convince", "convinced", "convincing", "convincingly", "depress", "depressed", "depressing", "depressingly", "depression", "enormity", "enormous", "enormously", "forthcoming", "inclination", "inclined", "inconceivable", "inconceivably", "integrity", "intrinsic", "intrinsically", "invoke", "likewise", "nonetheless", "odd", "oddness", "odds", "ongoing", "persist", "persistence", "persistent", "persistently", "reluctant", "so-called", "straightforward", "unconvinced", "undergo", "whereby"]

    dhammapada1 = ["1. All that we are is the result of what we have thought: it is founded on our thoughts, it is made up of our thoughts. If a man speaks or acts with an evil thought, pain follows him, as the wheel follows the foot of the ox that draws the carriage.", "2. All that we are is the result of what we have thought: it is founded on our thoughts, it is made up of our thoughts. If a man speaks or acts with a pure thought, happiness follows him, like a shadow that never leaves him.", "3. 'He abused me, he beat me, he defeated me, he robbed me,'—in those who harbour such thoughts hatred will never cease.", "4. 'He abused me, he beat me, he defeated me, he robbed me,'—in those who do not harbour such thoughts hatred will cease.", "5. For hatred does not cease by hatred at any time: hatred ceases by love, this is an old rule.", "6. The world does not know that we must all come to an end here;—but those who know it, their quarrels cease at once.", "7. He who lives looking for pleasures only, his senses uncontrolled, immoderate in his food, idle, and weak, Mara (the tempter) will certainly overthrow him, as the wind throws down a weak tree.", "8. He who lives without looking for pleasures, his senses well controlled, moderate in his food, faithful and strong, him Mara will certainly not overthrow, any more than the wind throws down a rocky mountain.", "9. He who wishes to put on the yellow dress without having cleansed himself from sin, who disregards temperance and truth, is unworthy of the yellow dress.", "10. But he who has cleansed himself from sin, is well grounded in all virtues, and regards also temperance and truth, he is indeed worthy of the yellow dress.", "11. They who imagine truth in untruth, and see untruth in truth, never arrive at truth, but follow vain desires.", "12. They who know truth in truth, and untruth in untruth, arrive at truth, and follow true desires.", "13. As rain breaks through an ill-thatched house, passion will break through an unreflecting mind.", "14. As rain does not break through a well-thatched house, passion will not break through a well-reflecting mind.", "15. The evil-doer mourns in this world, and he mourns in the next; he mourns in both. He mourns and suffers when he sees the evil of his own work.", "16. The virtuous man delights in this world, and he delights in the next; he delights in both. He delights and rejoices, when he sees the purity of his own work.", "17. The evil-doer suffers in this world, and he suffers in the next; he suffers in both. He suffers when he thinks of the evil he has done; he suffers more when going on the evil path.", "18. The virtuous man is happy in this world, and he is happy in the next; he is happy in both. He is happy when he thinks of the good he has done; he is still more happy when going on the good path.", "19. The thoughtless man, even if he can recite a large portion (of the law), but is not a doer of it, has no share in the priesthood, but is like a cowherd counting the cows of others.", "20. The follower of the law, even if he can recite only a small portion (of the law), but, having forsaken passion and hatred and foolishness, possesses true knowledge and serenity of mind, he, caring for nothing in this world or that to come, has indeed a share in the priesthood.", "21. Earnestness is the path of immortality (Nirvana), thoughtlessness the path of death. Those who are in earnest do not die, those who are thoughtless are as if dead already", "22. Those who are advanced in earnestness, having understood this clearly, delight in earnestness, and rejoice in the knowledge of the Ariyas (the elect).", "23. These wise people, meditative, steady, always possessed of strong powers, attain to Nirvana, the highest happiness.", "24. If an earnest person has roused himself, if he is not forgetful, if his deeds are pure, if he acts with consideration, if he restrains himself, and lives according to law,—then his glory will increase.", "25. By rousing himself, by earnestness, by restraint and control, the wise man may make for himself an island which no flood can overwhelm.", "26. Fools follow after vanity, men of evil wisdom. The wise man keeps earnestness as his best jewel.", "27. Follow not after vanity, nor after the enjoyment of love and lust! He who is earnest and meditative, obtains ample joy.", "28. When the learned man drives away vanity by earnestness, he, the wise, climbing the terraced heights of wisdom, looks down upon the fools, serene he looks upon the toiling crowd, as one that stands on a mountain looks down upon them that stand upon the plain.", "29. Earnest among the thoughtless, awake among the sleepers, the wise man advances like a racer, leaving behind the hack.", "30. By earnestness did Maghavan (Indra) rise to the lordship of the gods. People praise earnestness; thoughtlessness is always blamed.", "31. A Bhikshu (mendicant) who delights in earnestness, who looks with fear on thoughtlessness, moves about like fire, burning all his fetters, small or large.", "32. A Bhikshu (mendicant) who delights in reflection, who looks with fear on thoughtlessness, cannot fall away (from his perfect state)—he is close upon Nirvana.", "33. As a fletcher makes straight his arrow, a wise man makes straight his trembling and unsteady thought, which is difficult to guard, difficult to hold back.", "34. As a fish taken from his watery home and thrown on dry ground, our thought trembles all over in order to escape the dominion of Mara (the tempter).", "35. It is good to tame the mind, which is difficult to hold in and flighty, rushing wherever it listeth; a tamed mind brings happiness.", "36. Let the wise man guard his thoughts, for they are difficult to perceive, very artful, and they rush wherever they list: thoughts well guarded bring happiness.", "37. Those who bridle their mind which travels far, moves about alone, is without a body, and hides in the chamber (of the heart), will be free from the bonds of Mara (the tempter).", "38. If a man's thoughts are unsteady, if he does not know the true law, if his peace of mind is troubled, his knowledge will never be perfect.", "39. If a man's thoughts are not dissipated, if his mind is not perplexed, if he has ceased to think of good or evil, then there is no fear for him while he is watchful.", "40. Knowing that this body is (fragile) like a jar, and making this thought firm like a fortress, one should attack Mara (the tempter) with the weapon of knowledge, one should watch him when conquered, and should never rest.", "41. Before long, alas! this body will lie on the earth, despised, without understanding, like a useless log.", "42. Whatever a hater may do to a hater, or an enemy to an enemy, a wrongly-directed mind will do us greater mischief.", "43. Not a mother, not a father will do so much, nor any other relative; a well-directed mind will do us greater service.", "44. Who shall overcome this earth, and the world of Yama (the lord of the departed), and the world of the gods? Who shall find out the plainly shown path of virtue, as a clever man finds out the (right) flower?", "45. The disciple will overcome the earth, and the world of Yama, and the world of the gods. The disciple will find out the plainly shown path of virtue, as a clever man finds out the (right) flower.", "46. He who knows that this body is like froth, and has learnt that it is as unsubstantial as a mirage, will break the flower-pointed arrow of Mara, and never see the king of death.", "47. Death carries off a man who is gathering flowers and whose mind is distracted, as a flood carries off a sleeping village.", "48. Death subdues a man who is gathering flowers, and whose mind is distracted, before he is satiated in his pleasures.", "49. As the bee collects nectar and departs without injuring the flower, or its colour or scent, so let a sage dwell in his village.", "50. Not the perversities of others, not their sins of commission or omission, but his own misdeeds and negligences should a sage take notice of.", "51. Like a beautiful flower, full of colour, but without scent, are the fine but fruitless words of him who does not act accordingly.", "52. But, like a beautiful flower, full of colour and full of scent, are the fine and fruitful words of him who acts accordingly.", "53. As many kinds of wreaths can be made from a heap of flowers, so many good things may be achieved by a mortal when once he is born.", "54. The scent of flowers does not travel against the wind, nor (that of) sandal-wood, or of Tagara and Mallika flowers; but the odour of good people travels even against the wind; a good man pervades every place.", "55. Sandal-wood or Tagara, a lotus-flower, or a Vassiki, among these sorts of perfumes, the perfume of virtue is unsurpassed.", "56. Mean is the scent that comes from Tagara and sandal-wood;—the perfume of those who possess virtue rises up to the gods as the highest.", "57. Of the people who possess these virtues, who live without thoughtlessness, and who are emancipated through true knowledge, Mara, the tempter, never finds the way.", "58, 59. As on a heap of rubbish cast upon the highway the lily will grow full of sweet perfume and delight, thus the disciple of the truly enlightened Buddha shines forth by his knowledge among those who are like rubbish, among the people that walk in darkness.", "60. Long is the night to him who is awake; long is a mile to him who is tired; long is life to the foolish who do not know the true law.", "61. If a traveller does not meet with one who is his better, or his equal, let him firmly keep to his solitary journey; there is no companionship with a fool.", "62. 'These sons belong to me, and this wealth belongs to me,' with such thoughts a fool is tormented. He himself does not belong to himself; how much less sons and wealth?", "63. The fool who knows his foolishness, is wise at least so far. But a fool who thinks himself wise, he is called a fool indeed.", "64. If a fool be associated with a wise man even all his life, he will perceive the truth as little as a spoon perceives the taste of soup.", "65. If an intelligent man be associated for one minute only with a wise man, he will soon perceive the truth, as the tongue perceives the taste of soup.", "66. Fools of little understanding have themselves for their greatest enemies, for they do evil deeds which must bear bitter fruits.", "67. That deed is not well done of which a man must repent, and the reward of which he receives crying and with a tearful face.", "68. No, that deed is well done of which a man does not repent, and the reward of which he receives gladly and cheerfully.", "69. As long as the evil deed done does not bear fruit, the fool thinks it is like honey; but when it ripens, then the fool suffers grief.", "70. Let a fool month after month eat his food (like an ascetic) with the tip of a blade of Kusa grass, yet he is not worth the sixteenth particle of those who have well weighed the law.", "71. An evil deed, like newly-drawn milk, does not turn (suddenly); smouldering, like fire covered by ashes, it follows the fool.", "72. And when the evil deed, after it has become known, brings sorrow to the fool, then it destroys his bright lot, nay, it cleaves his head.", "73. Let the fool wish for a false reputation, for precedence among the Bhikshus, for lordship in the convents, for worship among other people!", "74. 'May both the layman and he who has left the world think that this is done by me; may they be subject to me in everything which is to be done or is not to be done,' thus is the mind of the fool, and his desire and pride increase.", "75. 'One is the road that leads to wealth, another the road that leads to Nirvana;' if the Bhikshu, the disciple of Buddha, has learnt this, he will not yearn for honour, he will strive after separation from the world.", "be better, not worse, for those who follow him.", "77. Let him admonish, let him teach, let him forbid what is improper!—he will be beloved of the good, by the bad he will be hated.", "78. Do not have evil-doers for friends, do not have low people for friends: have virtuous people for friends, have for friends the best of men.", "79. He who drinks in the law lives happily with a serene mind: the sage rejoices always in the law, as preached by the elect (Ariyas).", "80. Well-makers lead the water (wherever they like); fletchers bend the arrow; carpenters bend a log of wood; wise people fashion themselves.", "81. As a solid rock is not shaken by the wind, wise people falter not amidst blame and praise.", "82. Wise people, after they have listened to the laws, become serene, like a deep, smooth, and still lake.", "83. Good people walk on whatever befall, the good do not prattle, longing for pleasure; whether touched by happiness or sorrow wise people never appear elated or depressed.", "84. If, whether for his own sake, or for the sake of others, a man wishes neither for a son, nor for wealth, nor for lordship, and if he does not wish for his own success by unfair means, then he is good, wise, and virtuous.", "85. Few are there among men who arrive at the other shore (become Arhats); the other people here run up and down the shore.", "86. But those who, when the law has been well preached to them, follow the law, will pass across the dominion of death, however difficult to overcome.", "87, 88. A wise man should leave the dark state (of ordinary life), and follow the bright state (of the Bhikshu). After going from his home to a homeless state, he should in his retirement look for enjoyment where there seemed to be no enjoyment. Leaving all pleasures behind, and calling nothing his own, the wise man should purge himself from all the troubles of the mind.", "89. Those whose mind is well grounded in the (seven) elements of knowledge, who without clinging to anything, rejoice in freedom from attachment, whose appetites have been conquered, and who are full of light, are free (even) in this world.", "90. There is no suffering for him who has finished his journey, and abandoned grief, who has freed himself on all sides, and thrown off all fetters.", "91. They depart with their thoughts well-collected, they are not happy in their abode; like swans who have left their lake, they leave their house and home.", "92. Men who have no riches, who live on recognised food, who have perceived void and unconditioned freedom (Nirvana), their path is difficult to understand, like that of birds in the air.", "93. He whose appetites are stilled, who is not absorbed in enjoyment, who has perceived void and unconditioned freedom (Nirvana), his path is difficult to understand, like that of birds in the air.", "94. The gods even envy him whose senses, like horses well broken in by the driver, have been subdued, who is free from pride, and free from appetites.", "95. Such a one who does his duty is tolerant like the earth, like Indra's bolt; he is like a lake without mud; no new births are in store for him.", "96. His thought is quiet, quiet are his word and deed, when he has obtained freedom by true knowledge, when he has thus become a quiet man.", "97. The man who is free from credulity, but knows the uncreated, who has cut all ties, removed all temptations, renounced all desires, he is the greatest of men.", "98. In a hamlet or in a forest, in the deep water or on the dry land, wherever venerable persons (Arhanta) dwell, that place is delightful.", "99. Forests are delightful; where the world finds no delight, there the passionless will find delight, for they look not for pleasures.", "100. Even though a speech be a thousand (of words), but made up of senseless words, one word of sense is better, which if a man hears, he becomes quiet.", "101. Even though a Gatha (poem) be a thousand (of words), but made up of senseless words, one word of a Gatha is better, which if a man hears, he becomes quiet.", "102. Though a man recite a hundred Gathas made up of senseless words, one word of the law is better, which if a man hears, he becomes quiet.", "103. If one man conquer in battle a thousand times thousand men, and if another conquer himself, he is the greatest of conquerors.", \
                    "104, 105. One's own self conquered is better than all other people; not even a god, a Gandharva, not Mara with Brahman could change into defeat the victory of a man who has vanquished himself, and always lives under restraint.", "106. If a man for a hundred years sacrifice month after month with a thousand, and if he but for one moment pay homage to a man whose soul is grounded (in true knowledge), better is that homage than sacrifice for a hundred years.", "107. If a man for a hundred years worship Agni (fire) in the forest, and if he but for one moment pay homage to a man whose soul is grounded (in true knowledge), better is that homage than sacrifice for a hundred years.", "108. Whatever a man sacrifice in this world as an offering or as an oblation for a whole year in order to gain merit, the whole of it is not worth a quarter (a farthing); reverence shown to the righteous is better.", "109. He who always greets and constantly reveres the aged, four things will increase to him, viz. life, beauty, happiness, power.", "110. But he who lives a hundred years, vicious and unrestrained, a life of one day is better if a man is virtuous and reflecting.", "111. And he who lives a hundred years, ignorant and unrestrained, a life of one day is better if a man is wise and reflecting.", "112. And he who lives a hundred years, idle and weak, a life of one day is better if a man has attained firm strength.", "113. And he who lives a hundred years, not seeing beginning and end, a life of one day is better if a man sees beginning and end.", "114. And he who lives a hundred years, not seeing the immortal place, a life of one day is better if a man sees the immortal place.", "115. And he who lives a hundred years, not seeing the highest law, a life of one day is better if a man sees the highest law.", "116. If a man would hasten towards the good, he should keep his thought away from evil; if a man does what is good slothfully, his mind delights in evil.", "117. If a man commits a sin, let him not do it again; let him not delight in sin: pain is the outcome of evil.", "118. If a man does what is good, let him do it again; let him delight in it: happiness is the outcome of good.", "119. Even an evil-doer sees happiness as long as his evil deed has not ripened; but when his evil deed has ripened, then does the evil-doer see evil.", "120. Even a good man sees evil days, as long as his good deed has not ripened; but when his good deed has ripened, then does the good man see happy days.", "121. Let no man think lightly of evil, saying in his heart, It will not come nigh unto me. Even by the falling of water-drops a water-pot is filled; the fool becomes full of evil, even if he gather it little by little.", "122. Let no man think lightly of good, saying in his heart, It will not come nigh unto me. Even by the falling of water-drops a water-pot is filled; the wise man becomes full of good, even if he gather it little by little.", "123. Let a man avoid evil deeds, as a merchant, if he has few companions and carries much wealth, avoids a dangerous road; as a man who loves life avoids poison.", "124. He who has no wound on his hand, may touch poison with his hand; poison does not affect one who has no wound; nor is there evil for one who does not commit evil.", "125. If a man offend a harmless, pure, and innocent person, the evil falls back upon that fool, like light dust thrown up against the wind.", "126. Some people are born again; evil-doers go to hell; righteous people go to heaven; those who are free from all worldly desires attain Nirvana.", "127. Not in the sky, not in the midst of the sea, not if we enter into the clefts of the mountains, is there known a spot in the whole world where death could not overcome (the mortal).", "129. All men tremble at punishment, all men fear death; remember that you are like unto them, and do not kill, nor cause slaughter.", "130. All men tremble at punishment, all men love life; remember that thou art like unto them, and do not kill, nor cause slaughter.", "131. He who seeking his own happiness punishes or kills beings who also long for happiness, will not find happiness after death.", "132. He who seeking his own happiness does not punish or kill beings who also long for happiness, will find happiness after death.", "133. Do not speak harshly to anybody; those who are spoken to will answer thee in the same way. Angry speech is painful, blows for blows will touch thee.", "134. If, like a shattered metal plate (gong), thou utter not, then thou hast reached Nirvana; contention is not known to thee.", "135. As a cowherd with his staff drives his cows into the stable, so do Age and Death drive the life of men.", "136. A fool does not know when he commits his evil deeds: but the wicked man burns by his own deeds, as if burnt by fire.", "137. He who inflicts pain on innocent and harmless persons, will soon come to one of these ten states:", "138. He will have cruel suffering, loss, injury of the body, heavy affliction, or loss of mind,", "139. Or a misfortune coming from the king, or a fearful accusation, or loss of relations, or destruction of treasures,", "140. Or lightning-fire will burn his houses; and when his body is destroyed, the fool will go to hell.", "141. Not nakedness, not platted hair, not dirt, not fasting, or lying on the earth, not rubbing with dust, not sitting motionless, can purify a mortal who has not overcome desires.", "142. He who, though dressed in fine apparel, exercises tranquillity, is quiet, subdued, restrained, chaste, and has ceased to find fault with all other beings, he indeed is a Brahmana, an ascetic (sramana), a friar (bhikshu).", "143. Is there in this world any man so restrained by humility that he does not mind reproof, as a well-trained horse the whip?", "144. Like a well-trained horse when touched by the whip, be ye active and lively, and by faith, by virtue, by energy, by meditation, by discernment of the law you will overcome this great pain (of reproof), perfect in knowledge and in behaviour, and never forgetful.", "145. Well-makers lead the water (wherever they like); fletchers bend the arrow; carpenters bend a log of wood; good people fashion themselves.", "146. How is there laughter, how is there joy, as this world is always burning? Why do you not seek a light, ye who are surrounded by darkness?", "147. Look at this dressed-up lump, covered with wounds, joined together, sickly, full of many thoughts, which has no strength, no hold!", "148. This body is wasted, full of sickness, and frail; this heap of corruption breaks to pieces, life indeed ends in death.", "149. Those white bones, like gourds thrown away in the autumn, what pleasure is there in looking at them?", "150. After a stronghold has been made of the bones, it is covered with flesh and blood, and there dwell in it old age and death, pride and deceit.", "151. The brilliant chariots of kings are destroyed, the body also approaches destruction, but the virtue of good people never approaches destruction,—thus do the good say to the good.", "152. A man who has learnt little, grows old like an ox; his flesh grows, but his knowledge does not grow.", "153, 154. Looking for the maker of this tabernacle, I shall have to run through a course of many births, so long as I do not find (him); and painful is birth again and again. But now, maker of the tabernacle, thou hast been seen; thou shalt not make up this tabernacle again. All thy rafters are broken, thy ridge-pole is sundered; the mind, approaching the Eternal (visankhara, nirvana), has attained to the extinction of all desires.", "155. Men who have not observed proper discipline, and have not gained treasure in their youth, perish like old herons in a lake without fish.", "156. Men who have not observed proper discipline, and have not gained treasure in their youth, lie, like broken bows, sighing after the past.", "157. If a man hold himself dear, let him watch himself carefully; during one at least out of the three watches a wise man should be watchful.", "158. Let each man direct himself first to what is proper, then let him teach others; thus a wise man will not suffer.", "159. If a man make himself as he teaches others to be, then, being himself well subdued, he may subdue (others); one's own self is indeed difficult to subdue.", "160. Self is the lord of self, who else could be the lord? With self well subdued, a man finds a lord such as few can find.", "161. The evil done by oneself, self-begotten, self-bred, crushes the foolish, as a diamond breaks a precious stone.", "162. He whose wickedness is very great brings himself down to that state where his enemy wishes him to be, as a creeper does with the tree which it surrounds.", "163. Bad deeds, and deeds hurtful to ourselves, are easy to do; what is beneficial and good, that is very difficult to do.", "164. The foolish man who scorns the rule of the venerable (Arahat), of the elect (Ariya), of the virtuous, and follows false doctrine, he bears fruit to his own destruction, like the fruits of the Katthaka reed.", "165. By oneself the evil is done, by oneself one suffers; by oneself evil is left undone, by oneself one is purified. Purity and impurity belong to oneself, no one can purify another.", "166. Let no one forget his own duty for the sake of another's, however great; let a man, after he has discerned his own duty, be always attentive to his duty.", "167. Do not follow the evil law! Do not live on in thoughtlessness! Do not follow false doctrine! Be not a friend of the world.", "168. Rouse thyself! do not be idle! Follow the law of virtue! The virtuous rests in bliss in this world and in the next.", "169. Follow the law of virtue; do not follow that of sin. The virtuous rests in bliss in this world and in the next.", "170. Look upon the world as a bubble, look upon it as a mirage: the king of death does not see him who thus looks down upon the world.", "171. Come, look at this glittering world, like unto a royal chariot; the foolish are immersed in it, but the wise do not touch it.", "172. He who formerly was reckless and afterwards became sober, brightens up this world, like the moon when freed from clouds.", "173. He whose evil deeds are covered by good deeds, brightens up this world, like the moon when freed from clouds.", "174. This world is dark, few only can see here; a few only go to heaven, like birds escaped from the net.", "175. The swans go on the path of the sun, they go through the ether by means of their miraculous power; the wise are led out of this world, when they have conquered Mara and his train.", "176. If a man has transgressed one law, and speaks lies, and scoffs at another world, there is no evil he will not do.", "177. The uncharitable do not go to the world of the gods; fools only do not praise liberality; a wise man rejoices in liberality, and through it becomes blessed in the other world.", "178. Better than sovereignty over the earth, better than going to heaven, better than lordship over all worlds, is the reward of the first step in holiness.", "179. He whose conquest is not conquered again, into whose conquest no one in this world enters, by what track can you lead him, the Awakened, the Omniscient, the trackless?", "180. He whom no desire with its snares and poisons can lead astray, by what track can you lead him, the Awakened, the Omniscient, the trackless?", "181. Even the gods envy those who are awakened and not forgetful, who are given to meditation, who are wise, and who delight in the repose of retirement (from the world).", "182. Difficult (to obtain) is the conception of men, difficult is the life of mortals, difficult is the hearing of the True Law, difficult is the birth of the Awakened (the attainment of Buddhahood).", "183. Not to commit any sin, to do good, and to purify one's mind, that is the teaching of (all) the Awakened.", "184. The Awakened call patience the highest penance, long-suffering the highest Nirvana; for he is not an anchorite (pravragita) who strikes others, he is not an ascetic (sramana) who insults others.", "185. Not to blame, not to strike, to live restrained under the law, to be moderate in eating, to sleep and sit alone, and to dwell on the highest thoughts,—this is the teaching of the Awakened.", "186. There is no satisfying lusts, even by a shower of gold pieces; he who knows that lusts have a short taste and cause pain, he is wise;", "187. Even in heavenly pleasures he finds no satisfaction, the disciple who is fully awakened delights only in the destruction of all desires.", "188. Men, driven by fear, go to many a refuge, to mountains and forests, to groves and sacred trees.", "189. But that is not a safe refuge, that is not the best refuge; a man is not delivered from all pains after having gone to that refuge.", "190. He who takes refuge with Buddha, the Law, and the Church; he who, with clear understanding, sees the four holy truths:—", "191. Viz. pain, the origin of pain, the destruction of pain, and the eightfold holy way that leads to the quieting of pain;—", "192. That is the safe refuge, that is the best refuge; having gone to that refuge, a man is delivered from all pain.", "193. A supernatural person (a Buddha) is not easily found, he is not born everywhere. Wherever such a sage is born, that race prospers.", "194. Happy is the arising of the awakened, happy is the teaching of the True Law, happy is peace in the church, happy is the devotion of those who are at peace.", "195, 196. He who pays homage to those who deserve homage, whether the awakened (Buddha) or their disciples, those who have overcome the host (of evils), and crossed the flood of sorrow, he who pays homage to such as have found deliverance and know no fear, his merit can never be measured by anybody.", "197. Let us live happily then, not hating those who hate us! among men who hate us let us dwell free from hatred!", "198. Let us live happily then, free from ailments among the ailing! among men who are ailing let us dwell free from ailments!", "199. Let us live happily then, free from greed among the greedy! among men who are greedy let us dwell free from greed!", "200. Let us live happily then, though we call nothing our own! We shall be like the bright gods, feeding on happiness!", "201. Victory breeds hatred, for the conquered is unhappy. He who has given up both victory and defeat, he, the contented, is happy.", "202. There is no fire like passion; there is no losing throw like hatred; there is no pain like this body; there is no happiness higher than rest.", "203. Hunger is the worst of diseases, the body the greatest of pains; if one knows this truly, that is Nirvana, the highest happiness.", "204. Health is the greatest of gifts, contentedness the best riches; trust is the best of relationships, Nirvana the highest happiness.", "205. He who has tasted the sweetness of solitude and tranquillity, is free from fear and free from sin, while he tastes the sweetness of drinking in the law.", "206. The sight of the elect (Arya) is good, to live with them is always happiness; if a man does not see fools, he will be truly happy.", "207. He who walks in the company of fools suffers a long way; company with fools, as with an enemy, is always painful; company with the wise is pleasure, like meeting with kinsfolk.", "208. Therefore, one ought to follow the wise, the intelligent, the learned, the much enduring, the dutiful, the elect; one ought to follow a good and wise man, as the moon follows the path of the stars.", "209. He who gives himself to vanity, and does not give himself to meditation, forgetting the real aim (of life) and grasping at pleasure, will in time envy him who has exerted himself in meditation.", "210. Let no man ever look for what is pleasant, or what is unpleasant. Not to see what is pleasant is pain, and it is pain to see what is unpleasant.", "211. Let, therefore, no man love anything; loss of the beloved is evil. Those who love nothing and hate nothing, have no fetters.", "212. From pleasure comes grief, from pleasure comes fear; he who is free from pleasure knows neither grief nor fear.", "213. From affection comes grief, from affection comes fear; he who is free from affection knows neither grief nor fear.", \
                         "214. From lust comes grief, from lust comes fear; he who is free from lust knows neither grief nor fear.", "215. From love comes grief, from love comes fear; he who is free from love knows neither grief nor fear.", "216. From greed comes grief, from greed comes fear; he who is free from greed knows neither grief nor fear.", "217. He who possesses virtue and intelligence, who is just, speaks the truth, and does what is his own business, him the world will hold dear.", "218. He in whom a desire for the Ineffable (Nirvana) has sprung up, who is satisfied in his mind, and whose thoughts are not bewildered by love, he is called urdhvamsrotas (carried upwards by the stream).", "219. Kinsmen, friends, and lovers salute a man who has been long away, and returns safe from afar.", "220. In like manner his good works receive him who has done good, and has gone from this world to the other;—as kinsmen receive a friend on his return.", "221. Let a man leave anger, let him forsake pride, let him overcome all bondage! No sufferings befall the man who is not attached to name and form, and who calls nothing his own.", "222. He who holds back rising anger like a rolling chariot, him I call a real driver; other people are but holding the reins.", "223. Let a man overcome anger by love, let him overcome evil by good; let him overcome the greedy by liberality, the liar by truth!", "224. Speak the truth, do not yield to anger; give, if thou art asked for little; by these three steps thou wilt go near the gods.", "225. The sages who injure nobody, and who always control their body, they will go to the unchangeable place (Nirvana), where, if they have gone, they will suffer no more.", "226. Those who are ever watchful, who study day and night, and who strive after Nirvana, their passions will come to an end.", "227. This is an old saying, O Atula, this is not only of to-day: `They blame him who sits silent, they blame him who speaks much, they also blame him who says little; there is no one on earth who is not blamed.'", "228. There never was, there never will be, nor is there now, a man who is always blamed, or a man who is always praised.", "229, 230. But he whom those who discriminate praise continually day after day, as without blemish, wise, rich in knowledge and virtue, who would dare to blame him, like a coin made of gold from the Gambu river? Even the gods praise him, he is praised even by Brahman.", "231. Beware of bodily anger, and control thy body! Leave the sins of the body, and with thy body practise virtue!", "232. Beware of the anger of the tongue, and control thy tongue! Leave the sins of the tongue, and practise virtue with thy tongue!", "233. Beware of the anger of the mind, and control thy mind! Leave the sins of the mind, and practise virtue with thy mind!", "234. The wise who control their body, who control their tongue, the wise who control their mind, are indeed well controlled.", "235. Thou art now like a sear leaf, the messengers of death (Yama) have come near to thee; thou standest at the door of thy departure, and thou hast no provision for thy journey.", "236. Make thyself an island, work hard, be wise! When thy impurities are blown away, and thou art free from guilt, thou wilt enter into the heavenly world of the elect (Ariya).", "237. Thy life has come to an end, thou art come near to death (Yama), there is no resting-place for thee on the road, and thou hast no provision for thy journey.", "238. Make thyself an island, work hard, be wise! When thy impurities are blown away, and thou art free from guilt, thou wilt not enter again into birth and decay.", "239. Let a wise man blow off the impurities of his self, as a smith blows off the impurities of silver one by one, little by little, and from time to time.", "240. As the impurity which springs from the iron, when it springs from it, destroys it; thus do a transgressor's own works lead him to the evil path.", "241. The taint of prayers is non-repetition; the taint of houses, non-repair; the taint of the body is sloth; the taint of a watchman, thoughtlessness.", "42. Bad conduct is the taint of woman, greediness the taint of a benefactor; tainted are all evil ways in this world and in the next.", "243. But there is a taint worse than all taints,—ignorance is the greatest taint. O mendicants! throw off that taint, and become taintless!", "244. Life is easy to live for a man who is without shame, a crow hero, a mischief-maker, an insulting, bold, and wretched fellow.", "245. But life is hard to live for a modest man, who always looks for what is pure, who is disinterested, quiet, spotless, and intelligent.", "246. He who destroys life, who speaks untruth, who in this world takes what is not given him, who goes to another man's wife;", "247. And the man who gives himself to drinking intoxicating liquors, he, even in this world, digs up his own root.", "248. O man, know this, that the unrestrained are in a bad state; take care that greediness and vice do not bring thee to grief for a long time!", "249. The world gives according to their faith or according to their pleasure: if a man frets about the food and the drink given to others, he will find no rest either by day or by night.", "250. He in whom that feeling is destroyed, and taken out with the very root, finds rest by day and by night.", "251. There is no fire like passion, there is no shark like hatred, there is no snare like folly, there is no torrent like greed.", "252. The fault of others is easily perceived, but that of oneself is difficult to perceive; a man winnows his neighbour's faults like chaff, but his own fault he hides, as a cheat hides the bad die from the gambler.", "253. If a man looks after the faults of others, and is always inclined to be offended, his own passions will grow, and he is far from the destruction of passions.", "254. There is no path through the air, a man is not a Samana by outward acts. The world delights in vanity, the Tathagatas (the Buddhas) are free from vanity.", "255. There is no path through the air, a man is not a Samana by outward acts. No creatures are eternal; but the awakened (Buddha) are never shaken.", "256, 257. A man is not just if he carries a matter by violence; no, he who distinguishes both right and wrong, who is learned and leads others, not by violence, but by law and equity, and who is guarded by the law and intelligent, he is called just.", "258. A man is not learned because he talks much; he who is patient, free from hatred and fear, he is called learned.", "259. A man is not a supporter of the law because he talks much; even if a man has learnt little, but sees the law bodily, he is a supporter of the law, a man who never neglects the law.", "260. A man is not an elder because his head is grey; his age may be ripe, but he is called `Old-in-vain.'", "261. He in whom there is truth, virtue, love, restraint, moderation, he who is free from impurity and is wise, he is called an elder.", "262. An envious greedy, dishonest man does not become respectable by means of much talking only, or by the beauty of his complexion.", "263. He in whom all this is destroyed, and taken out with the very root, he, when freed from hatred and wise, is called respectable.", "264. Not by tonsure does an undisciplined man who speaks falsehood become a Samana; can a man be a Samana who is still held captive by desire and greediness?", "265. He who always quiets the evil, whether small or large, he is called a Samana (a quiet man), because he has quieted all evil.", "266. A man is not a mendicant (Bhikshu) simply because he asks others for alms; he who adopts the whole law is a Bhikshu, not he who only begs.", "267. He who is above good and evil, who is chaste, who with knowledge passes through the world, he indeed is called a Bhikshu.", "268, 269. A man is not a Muni because he observes silence (mona, i.e. mauna), if he is foolish and ignorant; but the wise who, taking the balance, chooses the good and avoids evil, he is a Muni, and is a Muni thereby; he who in this world weighs both sides is called a Muni.", "270. A man is not an elect (Ariya) because he injures living creatures; because he has pity on all living creatures, therefore is a man called Ariya.", "271, 272. Not only by discipline and vows, not only by much learning, not by entering into a trance, not by sleeping alone, do I earn the happiness of release which no worldling can know. Bhikshu, be not confident as long as thou hast not attained the extinction of desires.", "273. The best of ways is the eightfold; the best of truths the four words; the best of virtues passionlessness; the best of men he who has eyes to see.", "274. This is the way, there is no other that leads to the purifying of intelligence. Go on this way! Everything else is the deceit of Mara (the tempter).", "275. If you go on this way, you will make an end of pain! The way was preached by me, when I had understood the removal of the thorns (in the flesh).", "276. You yourself must make an effort. The Tathagatas (Buddhas) are only preachers. The thoughtful who enter the way are freed from the bondage of Mara.", "277. `All created things perish,' he who knows and sees this becomes passive in pain; this is the way to purity.", "278. `All created things are grief and pain,' he who knows and sees this becomes passive in pain; this is the way that leads to purity.", "279. `All forms are unreal,' he who knows and sees this becomes passive in pain; this is the way that leads to purity.", "280. He who does not rouse himself when it is time to rise, who, though young and strong, is full of sloth, whose will and thought are weak, that lazy and idle man will never find the way to knowledge.", "281. Watching his speech, well restrained in mind, let a man never commit any wrong with his body! Let a man but keep these three roads of action clear, and he will achieve the way which is taught by the wise.", "282. Through zeal knowledge is gotten, through lack of zeal knowledge is lost; let a man who knows this double path of gain and loss thus place himself that knowledge may grow.", "283. Cut down the whole forest (of lust), not a tree only! Danger comes out of the forest (of lust). When you have cut down both the forest (of lust) and its undergrowth, then, Bhikshus, you will be rid of the forest and free!", "284. So long as the love of man towards women, even the smallest, is not destroyed, so long is his mind in bondage, as the calf that drinks milk is to its mother.", "285. Cut out the love of self, like an autumn lotus, with thy hand! Cherish the road of peace. Nirvana has been shown by Sugata (Buddha).", "286. `Here I shall dwell in the rain, here in winter and summer,' thus the fool meditates, and does not think of his death.", "287. Death comes and carries off that man, praised for his children and flocks, his mind distracted, as a flood carries off a sleeping village.", "288. Sons are no help, nor a father, nor relations; there is no help from kinsfolk for one whom death has seized.", "289. A wise and good man who knows the meaning of this, should quickly clear the way that leads to Nirvana.", "290. If by leaving a small pleasure one sees a great pleasure, let a wise man leave the small pleasure, and look to the great.", "291. He who, by causing pain to others, wishes to obtain pleasure for himself, he, entangled in the bonds of hatred, will never be free from hatred.", "292. What ought to be done is neglected, what ought not to be done is done; the desires of unruly, thoughtless people are always increasing.", "293. But they whose whole watchfulness is always directed to their body, who do not follow what ought not to be done, and who steadfastly do what ought to be done, the desires of such watchful and wise people will come to an end.", "294. A true Brahmana goes scatheless, though he have killed father and mother, and two valiant kings, though he has destroyed a kingdom with all its subjects.", "295. A true Brahmana goes scatheless, though he have killed father and mother, and two holy kings, and an eminent man besides.", "296. The disciples of Gotama (Buddha) are always well awake, and their thoughts day and night are always set on Buddha.", "297. The disciples of Gotama are always well awake, and their thoughts day and night are always set on the law.", "298. The disciples of Gotama are always well awake, and their thoughts day and night are always set on the church.", "299. The disciples of Gotama are always well awake, and their thoughts day and night are always set on their body.", "300. The disciples of Gotama are always well awake, and their mind day and night always delights in compassion.", "301. The disciples of Gotama are always well awake, and their mind day and night always delights in meditation.", "302. It is hard to leave the world (to become a friar), it is hard to enjoy the world; hard is the monastery, painful are the houses; painful it is to dwell with equals (to share everything in common) and the itinerant mendicant is beset with pain. Therefore let no man be an itinerant mendicant and he will not be beset with pain.", "303. Whatever place a faithful, virtuous, celebrated, and wealthy man chooses, there he is respected.", "304. Good people shine from afar, like the snowy mountains; bad people are not seen, like arrows shot by night.", "305. He alone who, without ceasing, practises the duty of sitting alone and sleeping alone, he, subduing himself, will rejoice in the destruction of all desires alone, as if living in a forest.", "306. He who says what is not, goes to hell; he also who, having done a thing, says I have not done it. After death both are equal, they are men with evil deeds in the next world.", "307. Many men whose shoulders are covered with the yellow gown are ill-conditioned and unrestrained; such evil-doers by their evil deeds go to hell.", "308. Better it would be to swallow a heated iron ball, like flaring fire, than that a bad unrestrained fellow should live on the charity of the land.", "309. Four things does a wreckless man gain who covets his neighbour's wife,—a bad reputation, an uncomfortable bed, thirdly, punishment, and lastly, hell.", "310. There is bad reputation, and the evil way (to hell), there is the short pleasure of the frightened in the arms of the frightened, and the king imposes heavy punishment; therefore let no man think of his neighbour's wife.", "311. As a grass-blade, if badly grasped, cuts the arm, badly-practised asceticism leads to hell.", "312. An act carelessly performed, a broken vow, and hesitating obedience to discipline, all this brings no great reward.", "313. If anything is to be done, let a man do it, let him attack it vigorously! A careless pilgrim only scatters the dust of his passions more widely.", "314. An evil deed is better left undone, for a man repents of it afterwards; a good deed is better done, for having done it, one does not repent.", "315. Like a well-guarded frontier fort, with defences within and without, so let a man guard himself. Not a moment should escape, for they who allow the right moment to pass, suffer pain when they are in hell.", "316. They who are ashamed of what they ought not to be ashamed of, and are not ashamed of what they ought to be ashamed of, such men, embracing false doctrines enter the evil path.", "317. They who fear when they ought not to fear, and fear not when they ought to fear, such men, embracing false doctrines, enter the evil path.", "318. They who forbid when there is nothing to be forbidden, and forbid not when there is something to be forbidden, such men, embracing false doctrines, enter the evil path.", "319. They who know what is forbidden as forbidden, and what is not forbidden as not forbidden, such men, embracing the true doctrine, enter the good path.", "320. Silently shall I endure abuse as the elephant in battle endures the arrow sent from the bow: for the world is ill-natured.", "321. They lead a tamed elephant to battle, the king mounts a tamed elephant; the tamed is the best among men, he who silently endures abuse.", "322. Mules are good, if tamed, and noble Sindhu horses, and elephants with large tusks; but he who tames himself is better still.", \
                            "323. For with these animals does no man reach the untrodden country (Nirvana), where a tamed man goes on a tamed animal, viz. on his own well-tamed self.", "324. The elephant called Dhanapalaka, his temples running with sap, and difficult to hold, does not eat a morsel when bound; the elephant longs for the elephant grove.", "325. If a man becomes fat and a great eater, if he is sleepy and rolls himself about, that fool, like a hog fed on wash, is born again and again.", "326. This mind of mine went formerly wandering about as it liked, as it listed, as it pleased; but I shall now hold it in thoroughly, as the rider who holds the hook holds in the furious elephant.", "327. Be not thoughtless, watch your thoughts! Draw yourself out of the evil way, like an elephant sunk in mud.", "328. If a man find a prudent companion who walks with him, is wise, and lives soberly, he may walk with him, overcoming all dangers, happy, but considerate.", "329. If a man find no prudent companion who walks with him, is wise, and lives soberly, let him walk alone, like a king who has left his conquered country behind,—like an elephant in the forest.", "330. It is better to live alone, there is no companionship with a fool; let a man walk alone, let him commit no sin, with few wishes, like an elephant in the forest.", "331. If an occasion arises, friends are pleasant; enjoyment is pleasant, whatever be the cause; a good work is pleasant in the hour of death; the giving up of all grief is pleasant.", "332. Pleasant in the world is the state of a mother, pleasant the state of a father, pleasant the state of a Samana, pleasant the state of a Brahmana.", "333. Pleasant is virtue lasting to old age, pleasant is a faith firmly rooted; pleasant is attainment of intelligence, pleasant is avoiding of sins.", "334. The thirst of a thoughtless man grows like a creeper; he runs from life to life, like a monkey seeking fruit in the forest.", "335. Whomsoever this fierce thirst overcomes, full of poison, in this world, his sufferings increase like the abounding Birana grass.", "336. He who overcomes this fierce thirst, difficult to be conquered in this world, sufferings fall off from him, like water-drops from a lotus leaf.", "337. This salutary word I tell you, `Do ye, as many as are here assembled, dig up the root of thirst, as he who wants the sweet-scented Usira root must dig up the Birana grass, that Mara (the tempter) may not crush you again and again, as the stream crushes the reeds.'", "338. As a tree, even though it has been cut down, is firm so long as its root is safe, and grows again, thus, unless the feeders of thirst are destroyed, the pain (of life) will return again and again.", "339. He whose thirst running towards pleasure is exceeding strong in the thirty-six channels, the waves will carry away that misguided man, viz. his desires which are set on passion.", "340. The channels run everywhere, the creeper (of passion) stands sprouting; if you see the creeper springing up, cut its root by means of knowledge.", "341. A creature's pleasures are extravagant and luxurious; sunk in lust and looking for pleasure, men undergo (again and again) birth and decay.", "342. Men, driven on by thirst, run about like a snared hare; held in fetters and bonds, they undergo pain for a long time, again and again.", "343. Men, driven on by thirst, run about like a snared hare; let therefore the mendicant drive out thirst, by striving after passionlessness for himself.", "344. He who having got rid of the forest (of lust) (i.e. after having reached Nirvana) gives himself over to forest-life (i.e. to lust), and who, when removed from the forest (i.e. from lust), runs to the forest (i.e. to lust), look at that man! though free, he runs into bondage.", "345. Wise people do not call that a strong fetter which is made of iron, wood, or hemp; far stronger is the care for precious stones and rings, for sons and a wife.", "346. That fetter wise people call strong which drags down, yields, but is difficult to undo; after having cut this at last, people leave the world, free from cares, and leaving desires and pleasures behind.", "347. Those who are slaves to passions, run down with the stream (of desires), as a spider runs down the web which he has made himself; when they have cut this, at last, wise people leave the world free from cares, leaving all affection behind.", "348. Give up what is before, give up what is behind, give up what is in the middle, when thou goest to the other shore of existence; if thy mind is altogether free, thou wilt not again enter into birth and decay.", "349. If a man is tossed about by doubts, full of strong passions, and yearning only for what is delightful, his thirst will grow more and more, and he will indeed make his fetters strong.", "350. If a man delights in quieting doubts, and, always reflecting, dwells on what is not delightful (the impurity of the body, &c.), he certainly will remove, nay, he will cut the fetter of Mara.", "351. He who has reached the consummation, who does not tremble, who is without thirst and without sin, he has broken all the thorns of life: this will be his last body.", "352. He who is without thirst and without affection, who understands the words and their interpretation, who knows the order of letters (those which are before and which are after), he has received his last body, he is called the great sage, the great man.", "353. `I have conquered all, I know all, in all conditions of life I am free from taint; I have left all, and through the destruction of thirst I am free; having learnt myself, whom shall I teach?'", "354. The gift of the law exceeds all gifts; the sweetness of the law exceeds all sweetness; the delight in the law exceeds all delights; the extinction of thirst overcomes all pain.", "355. Pleasures destroy the foolish, if they look not for the other shore; the foolish by his thirst for pleasures destroys himself, as if he were his own enemy.", "356. The fields are damaged by weeds, mankind is damaged by passion: therefore a gift bestowed on the passionless brings great reward.", "357. The fields are damaged by weeds, mankind is damaged by hatred: therefore a gift bestowed on those who do not hate brings great reward.", "358. The fields are damaged by weeds, mankind is damaged by vanity: therefore a gift bestowed on those who are free from vanity brings great reward.", "359. The fields are damaged by weeds, mankind is damaged by lust: therefore a gift bestowed on those who are free from lust brings great reward.", "360. Restraint in the eye is good, good is restraint in the ear, in the nose restraint is good, good is restraint in the tongue.", "361. In the body restraint is good, good is restraint in speech, in thought restraint is good, good is restraint in all things. A Bhikshu, restrained in all things, is freed from all pain.", "362. He who controls his hand, he who controls his feet, he who controls his speech, he who is well controlled, he who delights inwardly, who is collected, who is solitary and content, him they call Bhikshu.", "363. The Bhikshu who controls his mouth, who speaks wisely and calmly, who teaches the meaning and the law, his word is sweet.", "364. He who dwells in the law, delights in the law, meditates on the law, follows the law, that Bhikshu will never fall away from the true law.", "365. Let him not despise what he has received, nor ever envy others: a mendicant who envies others does not obtain peace of mind.", "366. A Bhikshu who, though he receives little, does not despise what he has received, even the gods will praise him, if his life is pure, and if he is not slothful.", "367. He who never identifies himself with name and form, and does not grieve over what is no more, he indeed is called a Bhikshu.", "368. The Bhikshu who acts with kindness, who is calm in the doctrine of Buddha, will reach the quiet place (Nirvana), cessation of natural desires, and happiness.", "369. O Bhikshu, empty this boat! if emptied, it will go quickly; having cut off passion and hatred thou wilt go to Nirvana.", "370. Cut off the five (senses), leave the five, rise above the five. A Bhikshu, who has escaped from the five fetters, he is called Oghatinna, `saved from the flood.'", "371. Meditate, O Bhikshu, and be not heedless! Do not direct thy thought to what gives pleasure that thou mayest not for thy heedlessness have to swallow the iron ball (in hell), and that thou mayest not cry out when burning, `This is pain.'", "372. Without knowledge there is no meditation, without meditation there is no knowledge: he who has knowledge and meditation is near unto Nirvana.", "373. A Bhikshu who has entered his empty house, and whose mind is tranquil, feels a more than human delight when he sees the law clearly.", "374. As soon as he has considered the origin and destruction of the elements (khandha) of the body, he finds happiness and joy which belong to those who know the immortal (Nirvana).", "375. And this is the beginning here for a wise Bhikshu: watchfulness over the senses, contentedness, restraint under the law; keep noble friends whose life is pure, and who are not slothful.", "376. Let him live in charity, let him be perfect in his duties; then in the fulness of delight he will make an end of suffering.", "377. As the Vassika plant sheds its withered flowers, men should shed passion and hatred, O ye Bhikshus!", "378. The Bhikshu whose body and tongue and mind are quieted, who is collected, and has rejected the baits of the world, he is called quiet.", "379. Rouse thyself by thyself, examine thyself by thyself, thus self-protected and attentive wilt thou live happily, O Bhikshu!", "380. For self is the lord of self, self is the refuge of self; therefore curb thyself as the merchant curbs a good horse.", "381. The Bhikshu, full of delight, who is calm in the doctrine of Buddha will reach the quiet place (Nirvana), cessation of natural desires, and happiness.", "382. He who, even as a young Bhikshu, applies himself to the doctrine of Buddha, brightens up this world, like the moon when free from clouds.", "383. Stop the stream valiantly, drive away the desires, O Brahmana! When you have understood the destruction of all that was made, you will understand that which was not made.", "384. If the Brahmana has reached the other shore in both laws (in restraint and contemplation), all bonds vanish from him who has obtained knowledge.", "385. He for whom there is neither this nor that shore, nor both, him, the fearless and unshackled, I call indeed a Brahmana.", "386. He who is thoughtful, blameless, settled, dutiful, without passions, and who has attained the highest end, him I call indeed a Brahmana.", "387. The sun is bright by day, the moon shines by night, the warrior is bright in his armour, the Brahmana is bright in his meditation; but Buddha, the Awakened, is bright with splendour day and night.", "388. Because a man is rid of evil, therefore he is called Brahmana; because he walks quietly, therefore he is called Samana; because he has sent away his own impurities, therefore he is called Pravragita (Pabbagita, a pilgrim).", "389. No one should attack a Brahmana, but no Brahmana (if attacked) should let himself fly at his aggressor! Woe to him who strikes a Brahmana, more woe to him who flies at his aggressor!", "390. It advantages a Brahmana not a little if he holds his mind back from the pleasures of life; when all wish to injure has vanished, pain will cease.", "391. Him I call indeed a Brahmana who does not offend by body, word, or thought, and is controlled on these three points.", "392. After a man has once understood the law as taught by the Well-awakened (Buddha), let him worship it carefully, as the Brahmana worships the sacrificial fire.", "393. A man does not become a Brahmana by his platted hair, by his family, or by birth; in whom there is truth and righteousness, he is blessed, he is a Brahmana.", "394. What is the use of platted hair, O fool! what of the raiment of goat-skins? Within thee there is ravening, but the outside thou makest clean.", "395. The man who wears dirty raiments, who is emaciated and covered with veins, who lives alone in the forest, and meditates, him I call indeed a Brahmana.", "396. I do not call a man a Brahmana because of his origin or of his mother. He is indeed arrogant, and he is wealthy: but the poor, who is free from all attachments, him I call indeed a Brahmana.", "397. Him I call indeed a Brahmana who has cut all fetters, who never trembles, is independent and unshackled.", "398. Him I call indeed a Brahmana who has cut the strap and the thong, the chain with all that pertains to it, who has burst the bar, and is awakened.", "399. Him I call indeed a Brahmana who, though he has committed no offence, endures reproach, bonds, and stripes, who has endurance for his force, and strength for his army.", "400. Him I call indeed a Brahmana who is free from anger, dutiful, virtuous, without appetite, who is subdued, and has received his last body.", "401. Him I call indeed a Brahmana who does not cling to pleasures, like water on a lotus leaf, like a mustard seed on the point of a needle.", "402. Him I call indeed a Brahmana who, even here, knows the end of his suffering, has put down his burden, and is unshackled.", "403. Him I call indeed a Brahmana whose knowledge is deep, who possesses wisdom, who knows the right way and the wrong, and has attained the highest end.", "404. Him I call indeed a Brahmana who keeps aloof both from laymen and from mendicants, who frequents no houses, and has but few desires.", "405. Him I call indeed a Brahmana who finds no fault with other beings, whether feeble or strong, and does not kill nor cause slaughter.", "406. Him I call indeed a Brahmana who is tolerant with the intolerant, mild with fault-finders, and free from passion among the passionate.", "407. Him I call indeed a Brahmana from whom anger and hatred, pride and envy have dropt like a mustard seed from the point of a needle.", "408. Him I call indeed a Brahmana who utters true speech, instructive and free from harshness, so that he offend no one.", "409. Him I call indeed a Brahmana who takes nothing in the world that is not given him, be it long or short, small or large, good or bad.", "410. Him I call indeed a Brahmana who fosters no desires for this world or for the next, has no inclinations, and is unshackled.", "411. Him I call indeed a Brahmana who has no interests, and when he has understood (the truth), does not say How, how? and who has reached the depth of the Immortal.", "412. Him I call indeed a Brahmana who in this world is above good and evil, above the bondage of both, free from grief from sin, and from impurity.", "413. Him I call indeed a Brahmana who is bright like the moon, pure, serene, undisturbed, and in whom all gaiety is extinct.", "414. Him I call indeed a Brahmana who has traversed this miry road, the impassable world and its vanity, who has gone through, and reached the other shore, is thoughtful, guileless, free from doubts, free from attachment, and content.", "415. Him I call indeed a Brahmana who in this world, leaving all desires, travels about without a home, and in whom all concupiscence is extinct.", "416. Him I call indeed a Brahmana who, leaving all longings, travels about without a home, and in whom all covetousness is extinct.", "417. Him I call indeed a Brahmana who, after leaving all bondage to men, has risen above all bondage to the gods, and is free from all and every bondage.", "418. Him I call indeed a Brahmana who has left what gives pleasure and what gives pain, who is cold, and free from all germs (of renewed life), the hero who has conquered all the worlds.", "419. Him I call indeed a Brahmana who knows the destruction and the return of beings everywhere, who is free from bondage, welfaring (Sugata), and awakened (Buddha).", "420. Him I call indeed a Brahmana whose path the gods do not know, nor spirits (Gandharvas), nor men, whose passions are extinct, and who is an Arhat (venerable).", "421. Him I call indeed a Brahmana who calls nothing his own, whether it be before, behind, or between, who is poor, and free from the love of the world." \
                                "422. Him I call indeed a Brahmana, the manly, the noble, the hero, the great sage, the conqueror, the impassible, the accomplished, the awakened.", "423. Him I call indeed a Brahmana who knows his former abodes, who sees heaven and hell, has reached the end of births, is perfect in knowledge, a sage, and whose perfections are all perfect."]
        
    medicals1 = ["Abdomen: The part of the body between the chest and pelvis.", "Abortion: 1. Induced abortion is a procedure done to end pregnancy. 2. Spontaneous abortion is a naturally occurring abortion (also called…", "Abrasion: A wound caused by scraping the skin. A 'skinned knee' is a common example.", "abscess: A swollen, inflamed area where pus gathers.", "Absorption: To take in substances through the skin or mucous membranes.", "Abstinence: To hold back or restrain. For example, to refrain from the use of drugs or alcohol, or from having sexual…", "Acclimation: The process of getting used to a new climate or altitude.", "Achilles' tendon: The strong tendon at the back of the ankle that attaches the calf muscle to the heel.", "Acidosis: An abnormal condition in the body in which excessive acid lowers the pH of the blood and body tissues.", "Acne: A skin disorder usually found in adolescents and young adults.", "Acoustic: Having to do with sound and hearing.", "Acromegaly: A condition that occurs when the pituitary gland produces too much growth hormone. In adults, this can cause overgrowth of…", "actinic keratosis: Scaly, pink, gray or tan patches or bumps on the face or scalp, or on the back of the hands…", "acupuncture: An ancient Chinese method to relieve pain or treat disease by inserting needles into various parts of the body.", "Acute: 1. Of short course. 2. Severe, but of a short duration. Not chronic.", "Addiction: Strong dependence or habitual use of a substance or practice, despite the negative consequences of its use.", "Addison's disease: An ailment characterized by underfunctioning of the adrenal glands. Characterized by anemia, weakness, low blood pressure and brownish discoloration of…", "adenitis: Swelling of a gland.", "adenoids: Glandular tissue in the back of the throat that may swell, especially during childhood, obstruct breathing and speaking, and lead…", "adenoma: A noncancerous tumor of glandular tissue.", "adenovirus: One of the viruses that cause the common cold.", "ADH: Antidiuretic hormone. One of the hormones produced by the pituitary gland. A shortage of this hormone causes increased loss of…", "adhesion: The sticking of one surface to another. This can occur when scar tissue causes organs or loops of intestine to…", "adipose fatty cells: Special cells in which fat is stored when a person’s caloric intake is greater than that required by one's…", "adrenal glands: Located on top of the kidneys, these glands produce hormones helpful in regulating the body’s metabolism.", "adrenaline: Epinephrine. One of several hormones produced by the adrenal glands.", "aerobic: Requiring the use of oxygen. Exercise that conditions the heart and lungs by increasing the efficiency of oxygen intake by…", "afterbirth: The placenta, which is attached to the fetus by the umbilical cord and must be delivered after the baby.", "AIDS: Acquired immunodeficiency syndrome. A disease of the immune system caused by the HIV virus.", "airway: The passage by which air enters and exits the lungs.", "albinism: The absence of all normal body pigmentation at birth, a condition that can occur in all races.", "albino: A person with albinism.", "albumin: A water-soluble protein found in milk, egg, muscle, blood and many vegetable tissues and fluids.", "aldosteronism: A condition resulting when the adrenal glands produce too much of the hormone aldosterone, which regulates fluids and salt in…", "alimentary: Having to do with food or nutrition. The alimentary tract is the digestive tract.", "allergen: A substance capable of producing an allergic reaction.", "allergy: An exaggerated immune response to substances in the environment.", "alopecia: Hair loss, especially of the head.", "alpha1-antitrypsin deficiency: Congenital lack of an enzyme that leads to cirrhosis of the liver and obstructive lung disease.", "altitude sickness: A potentially fatal illness caused by being at altitudes high enough to reduce the amount of oxygen available to the…", "alveoli: The sacs in the lungs at the ends of the smallest airways where oxygen is exchanged for carbon dioxide in…", "amblyopia: Impaired vision without an apparent cause.", "ambulatory: Able to walk. Not confined to bed.", "amenorrhea: Absence of menstrual periods.", "amnesia: Partial or total loss of memory, usually as the result of psychological trauma or stress, or physical damage to the…", "amnion: The membrane enclosing a developing fetus; it’s filled with a protective liquid called amniotic fluid.", "amputation: The surgical removal of a limb or other appendage because of damage by trauma or as a treatment for a…", "anaerobic exercise: Brief, intense exercise that leads to an oxygen debt in a certain area of tissue. Weight lifting is an…", "anaphylaxis: The most severe form of allergy, in which the person’s heart and lungs are unable to keep working, and death…", "androgen: Any substance that produces male characteristics. Testosterone and androsterone are natural androgens.", "anemia: A decreased ability of the blood to carry oxygen because of a reduction in either the number or quality of…", "anesthesia: Drug-induced loss of feeling or sensation.", "anesthetic: An agent used to produce anesthesia.", "aneurysm: A thin sac caused by a weakened area in the walls of blood vessels or the heart. As an aneurysm…", "angina pectoris: Chest pain caused by decreased oxygen delivery to the heart muscle.", "angioma: A noncancerous tumor made up of many blood vessels.", "anhidrosis: Absence of sweating. An inability to sweat greatly interferes with the body’s ability to control its internal temperature.", "ankylosis: Abnormal stiffening of a joint.", "anomaly: Deviation from normal.", "anorchism: Congenital absence of both testes.", "anorexia nervosa: An eating disorder manifested primarily by a loss of desire or willingness to eat for a variety of psychological…", "anosmia: Loss of the sense of smell.", "antepartum: Occurring before delivery of a baby.", "antibody: A protein produced by the body to neutralize an invading foreign agent or antigen, such as a virus.", "antidote: An agent used to counteract a poison.", "antigen: A foreign agent capable of starting an immune response or causing the body to produce antibodies.", "antiserum: A serum that contains antibodies. Serum from a person or animal with immunity to a certain disease can, in some…", "anus: The opening of the rectum.", "anxiety: A feeling of nervousness, uneasiness, apprehension or dread.", "aorta: The large artery that carries blood from the heart to the rest of body.", "apathy: Lack of emotions.", "Apgar score: A scoring method from zero to 10 for describing the health of an infant at birth, based on heart rate,…", "aphagia: Inability to swallow.", "aphasia: A partial or total loss of the power to use or understand words.", "aphthous ulcers: A painful sore in the mouth. Also called a canker sore.", "apnea: Temporary pause in breathing.", "appendectomy: Surgical removal of the appendix.", "appendix: A finger-like appendage near the junction of the large intestine and the small intestine.", "areola: The dark area of the breast surrounding the nipple.", "arteriosclerosis: Commonly called 'hardening of the arteries.' An abnormal thickening and loss of elasticity of the wall of the arteries.", "arteriovenous malformation: Abnormal group of dilated blood vessels, most often occurring in the brain.", "artery: A vessel that carries blood away from the heart to various parts of the body.", "arthralgia: Pain in a joint.", "arthritis: Inflammation of a joint", "asbestos: A fibrous material used to make fireproof materials, electrical insulation, roofing and filters. Asbestos has been linked to a type…", "ascites: Abnormal buildup of fluid in the abdomen that causes distention.", "ascorbic acid: Vitamin C.", "asthma: A chronic disorder characterized by shortness of breath, wheezing, coughing and tightness of the chest.", "astigmatism: An irregularity in the curvature of the lens of the eye, resulting in a blurry or distorted image.", "atelectasis: Collapsed lung. May occur following surgery or after a rib fracture.", "atherosclerosis: A form of arteriosclerosis caused by fatty deposits in the arteries.", "athlete's foot: A fungal infection of the skin of the feet.", "atopy: A predisposition to allergy that’s inherited from parents. Included disorders are asthma, hay fever and eczema.", "atria: The upper chambers of the heart that receive blood from the veins and pass it to the lower chambers of…", "atrophy: A decrease in the normal size of an organ. Wasting away.", "autoimmune disease: A condition in which antibodies form against one’s own cells.", "autotransfusion: A transfusion using the patient’s own blood.", "axilla: The armpit.", "bacteremia: The presence of bacteria in the blood.", "bacteria: Single-celled microorganisms with one of three basic shapes: rod-like (bacilli), spherical (cocci) and spiral (spirilla). Bacteria are commonly thought of…", "bacteriuria: The presence of bacteria in the urine.", "Baker's cyst: A swelling of the knee caused by an escape of fluid from a sac behind the knee.", "ballism: Quick, jerking movements that occur in people with chorea.", "barium: A chalky substance used in x-ray studies of the digestive tract to highlight abnormalities.", "barotrauma: Injury caused by pressure differences between the atmosphere and the air-filled spaces in the body. The most common of these…", "Bartholin cyst: A cyst caused by an infection of the glands on the vaginal wall.", "BCG (bacille Calmette-Guerin) vaccine: A vaccine that offers some protection against tuberculosis. It’s now rarely used in the U.S. because it doesn’t give total…", "bedsore: An ulcer caused by chafing or by the pressure of the body against the bed.", "Bell's palsy: A usually temporary loss of feeling or movement of the face, usually on one side, causing an inability to close…", "bends: A condition that results from rapidly decreasing atmospheric pressure on the body. Symptoms include joint pain, chest pain, shortness of…", "benign: A nonlife-threatening condition. Not malignant. Not cancerous.", "benign familial tremor: An inherited disorder that causes a slow tremor in the hands, head and voice. It may affect only one side…", "beriberi: A deficiency disease caused by dietary insufficiency of vitamin B1 (thiamine). Symptoms include general weakness and painful rigidity.", "biceps: A muscle having two heads. The most familiar is the large muscle in the front of the upper arm responsible…", "bicuspid: A tooth named for the two-pointed projections on the crown.", "bifocals: Eyeglasses with divided lenses. The two parts of each lens have different strengths, allowing the wearer to focus the eye…", "bile: A clear yellow fluid produced by the liver and stored in the gallbladder. Aids in digestion.", "bilirubin: A pigment produced in the liver by the breakdown of hemoglobin from old red blood cells. Bilirubin is normally eliminated…", "binocular: Using both eyes at the same time. Binocular vision is the most important element of depth perception.", "biopsy: Removal and exam of a tissue sample taken from a living body. This procedure helps determine if the tissue is…", "bipolar affective disorder: A psychiatric disorder in which the affected person has both depressed and happy, energetic (manic) episodes. This is a newer…", "blackhead: A dark-topped plug of fatty material in the opening of a hair follicle. The color is the result of exposure…", "blackout: 1. Short-term loss of vision and consciousness. 2. In an alcoholic person, loss of memory for a period of…", "bladder: The organ that temporarily stores a substance. Commonly used in reference to the urinary bladder, which holds urine until it’s…", "blepharitis: Inflammation of the eyelid.", "blepharoplasty: Plastic surgery on the eyelid.", "blindness: Loss of vision. Legally, visual acuity less than 20/200 with glasses.", "blister: Buildup of watery or bloody fluid under the skin.", "blood: The fluid circulating through the heart, arteries and veins. Blood is responsible for transporting oxygen to body tissues, carrying waste…", "blood poisoning: Infection within the circulatory system. A potentially life-threatening condition that requires prompt treatment.", "blood pressure: The pressure exerted by the blood against the walls of the blood vessels.", "boil: A skin infection characterized by a localized buildup of pus.", "bone marrow: The tissue within the cavity of the bones where new blood cells are made.", "Borrelia: A class of disease-causing bacteria that includes the organisms that cause relapsing fever and Lyme disease.", "botulism: An extremely dangerous form of food poisoning caused by the toxin of Clostridium botulinum.", "bovine: Having to do with cattle. For example, bovine insulin is insulin obtained from cattle.", "bowel: The tube involved in digestion and extending from the stomach to the anus. Consists of the small intestine and the…", "Bowen's disease: A precancerous skin condition that first appears as psoriasis-like scaling.", "bowleg: A deformity of the legs in which the space between the knees is greater than normal.", "brace: A device used to support a body part, correct or prevent deformities, or control movement.", "bradycardia: Slow heart rate and pulse, usually slower than 60 beats per minute.", "Braxton Hicks contractions: Contractions of the uterus during pregnancy that are sometimes mistaken for labor. Also called false labor.", "breasts: Milk-secreting glands protruding from the upper front part of a woman’s body.", "breech birth: A birth in which the feet or buttocks of the baby appear first through the birth canal.", "bridge: A structure that joins two parts. For example, a dental bridge contains artificial teeth and joins the natural teeth at…", "Bright's disease: Nephritis. A group of kidney diseases manifested by albumin in the urine and edema (swelling).", "bronchi: The tubular passages, also called bronchial tubes, that carry air into the lungs.", "bronchiolitis: An infection of the bronchioles, the tiny air tubes in the lungs.", "bronchitis: Inflammation of the bronchi.", "bronchospasm: Contraction of the muscle in the walls of the bronchi.", "bronze diabetes: A disorder of iron metabolism resulting in iron pigment deposits in the skin and other body tissues that causes a…", "brucellosis: An infection characterized by fluctuating fever, headache, anemia and vague physical discomfort that’s transmitted to humans from domesticated goats, pigs…", "bruise: Discoloration of the skin due to a buildup of blood in the underlying soft tissues. Also called a contusion.", "bruxism: Grinding of the teeth.", "bubo: A swollen, infected lymph node (especially in the groin). The node may enlarge enough that it begins to drain through…", "Buerger's disease: Blockage of medium-sized blood vessels in the hands and feet by clotting and inflammation. This process causes severe pain and…", "bulimia: An eating disorder characterized by binge eating followed by vomiting or use of laxatives. Usually caused by a variety of…", "bunion: Localized swelling of the big toe at its joint with the foot.", "bursa: A small, fluid-filled sac that allows one part of a joint to move freely over another part.", "bursitis: Inflammation of a bursa.", "cachexia: A generally weakened, emaciated condition of the body.", "caffeine: A bitter-tasting, water-soluble compound that acts as a central nervous system stimulant and has a mild diuretic (increasing urination)…", "calciferol: Vitamin D.", "calcification: Calcium salt deposits in soft tissues.", "calculus: A small, hard mass or stone formed in the body, as in a kidney or gallbladder, or a hard coating…", "callus: 1. Localized thickening of the skin. 2. A fibrous band formed around the site of a fracture that seals the…", "calorie: The amount of energy needed to raise the temperature of one kilogram of water one degree. Commonly used to express…", "Calve-Perthes: A disease in children affecting the growth plate of the head of the thigh, caused by interference in the blood…", "camphor: An agent derived from a cinnamon tree that’s used to relieve pain and itching.", "cancer: Abnormal cells with uncontrolled cell growth.",\
                 "Candida: The class of yeast that causes thrush and vaginal yeast infections.", "canker: An open sore on the lip or skin inside the mouth.", "capillary: A small, blood-containing vessel connecting the veins and arteries.", "carbohydrates: A group of energy-storage molecules that includes sugars and starches. Carbohydrates contain four calories per gram.", "carbon dioxide: An odorless, colorless gas produced as the end product of aerobic respiration.", "carbon monoxide: An odorless, colorless, poisonous gas produced from the incomplete combustion of carbon. Prevents the blood from carrying oxygen.", "carbuncle: A hard, painful, pus-filled infection of the skin. Carbuncles are larger than boils and frequently have more than one…", "carcinogen: A cancer-causing substance.", "carcinoma: A cancerous tumor.", "cardiac: Having to do with the heart or, less commonly, the upper portion of the stomach.", "cardiomegaly: Enlargement of the heart.", "cardiovascular: Having to do with the heart and blood vessels.", "caries: Decay of the teeth or bone.", "carotene: The fat-soluble pigment in carrots, tomatoes and other vegetables, egg yolks, milk fat and other substances that can be converted…", "carotid: The main artery in the neck.", "Carpal: Having to do with the wrist.", "carpal tunnel syndrome: Pain, numbness and tingling of the fingers caused by compression of the median nerve at the wrist.", "carrier: Someone who’s capable of transmitting a disease (especially an infectious or genetic disorder) to another person but who usually has…", "cartilage: Elastic connective tissue on the joint surfaces of bone and some parts of the skeleton, including the nose and…", "castor oil: An oil extracted from the castor bean plant that’s irritating to the intestine and promotes bowel movements.", "castration: To remove the gonads, such as the testicles, making the male unable to have children.", "cat-scratch fever: A bacterial infection acquired through the scratch of a cat or other animal.", "catalepsy: A condition in which the body and limbs stay in the position in which they’re placed.", "cataract: An opaque area in the lens of the eye.", "catheter: A tube used to drain or inject fluids.", "cauliflower ear: A trauma-induced deformity of the ear caused by repeated cartilage and soft-tissue injury.", "caustic: A chemical that can cause burns.", "cauterize: To purposely burn with a hot instrument or caustic substance to destroy tissue, such as a wart.", "cavity: A hollow place or hole within the body.", "CBC: Complete blood cell count.", "cecum: The first part of the large intestine just below the small intestine or ileum.", "celiac: Having to do with the abdomen.", "cell: The basic unit of organization of all living organisms.", "cellulitis: Infection of the skin.", "cellulose: A complex carbohydrate. Cellulose is a source of dietary fiber because it can’t be digested.", "cephalalgia: Headache.", "cerebellum: The part of the brain that coordinates muscular movements.", "cerebrum: The main part of the brain.", "cerumen: Earwax.", "cervical: Having to do with the neck (cervical spine) or the cervix of the uterus.", "cervix: The neck-like portion of an organ, especially the part of the uterus that extends into the vagina.", "cesarean section: Delivery of a baby through an incision in the abdominal wall and uterus.", "chalazion: A chronic, small swelling on the rim of the eyelid.", "chancre: The painless ulcer of primary syphilis that appears on the genitals.", "chancroid: A sexually transmitted disease that causes soft, painful open sores in the genital area. Not syphilis. Characterized by swelling of…", "charley horse: Painful stiffness from muscular strain in an arm or leg.", "cheilosis: A condition in which cracks or sores occur at the corners of the mouth.", "chickenpox: A viral disease that usually begins with fever and cough, followed by a rash that progresses from red bumps to…", "chilblain: Painful redness of the fingers, toes or ears caused by exposure to cold.", "childbed fever: This is a severe illness marked by fever that’s caused by an infection in mothers after giving birth. Also called…", "chill: A cold sensation with shivering that sometimes occurs before a fever.", "chiropractic: An approach to health care based on the assumption that most diseases are caused by pressure on the nerves. This…", "Chlamydia: A microorganism, Chlamydia trachomatis, that’s a frequent cause of sexually transmitted disease. It can also cause pneumonia and eye…", "chloasma: Dark coloring of the skin often seen during pregnancy and at menopause. Also occurs in Addison’s disease.", "chlorination: The addition of chlorine to kill harmful microorganisms in water or sewage.", "cholecystitis: Inflammation of the gallbladder.", "cholera: Watery diarrhea caused by drinking water or eating food that’s con-taminated with Vibrio cholere. The disease is spread through the…", "cholesteatoma: A tumor-like mass that sometimes forms as a result of a chronic middle ear infection.", "cholesterol: A fat-like substance that, if present in the blood in large amounts, is associated with the development of heart…", "chondritis: Inflammation of the cartilage.", "chondromalacia: Softening of cartilage.", "chorea: A nervous system disorder characterized by involuntary spasms of the limbs or facial muscles. A hereditary form is called Huntington’s…", "chromosomes: The DNA-containing cellular structures that carry genetic information.", "chronic: Persistent. Ongoing. Lasting a long time.", "cilia: Short, hair-like structures extending from certain cells.", "circadian: A repetitive pattern or fluctuation with a 24-hour cycle.", "circulation: The flow of blood through the body. Includes the heart, arteries, veins and capillaries.", "circumcision: Surgical removal of the foreskin of the penis.", "cirrhosis: Inflammatory disease of the liver characterized by scarring and shrinkage.", "claudication: Pain in the legs while walking that’s caused by blockage of the arteries.", "claustrophobia: Fear of closed spaces.", "clavicle: Collarbone.", "clawhand: A condition of the hand causing distorted fingers resulting from nerve injury.", "cleft lip or palate: A congenital split of the upper lip or roof of the mouth.", "clitoris: A small, sensitive erectile organ located in the female at the top of the vulva.", "Clostridium: A genus of bacteria that includes the agents capable of causing food poisoning and tetanus.", "clot: A jelly-like mass of blood.", "clubfoot: A deformity in which the foot is turned inward from its normal position.", "coal tar: A by-product of coal used in the treatment of some skin conditions, such as psoriasis.", "cobalamin: Vitamin B12.", "cocaine: A drug that is made from coca leaves. It can be used by a doctor as a topical anesthetic. It’s…", "coccyx: The tailbone.", "cochlea: The portion of the inner ear that senses sound.", "coitus: Sexual intercourse.", "cold: An upper respiratory infection.", "cold sore: Herpes simplex infection of the lip.", "colic: 1. A sudden, spasmodic abdominal pain. 2. In infants, a pattern of excessive crying, apparent abdominal pain and irritability.", "collagen: A protein formed in the connective tissue of the body.", "colon: The large intestine.", "Colorado tick fever: A viral illness spread by ticks. Characterized by headache, backache and fever that begins to break and then returns midway…", "colostomy: Surgery that makes an opening to the intestine through the surface of the abdomen. The opening empties the bowels.", "colostrum: An antibody-rich fluid released by the breasts for a short time after the birth of a baby, before the true…", "comedo: A dark-topped plug of fatty material in the opening of a hair follicle. The color is the result of exposure…", "communicable disease: A disease spread through direct contact with an infected person or substance.", "compress: A dressing used to apply pressure or medicine to an area. Useful in applying heat or cold.", "compulsion: An overwhelming urge to perform an act. Often used to describe ritual or repetitive behaviors.", "conception: Fertilization. The union of sperm and egg", "concussion: A loss of consciousness because of a head injury.", "condom: A sheath worn over the penis or inside the vagina (female condom) during intercourse to protect against pregnancy and…", "Cone: The light-sensing structure on the retina of the eye capable of detecting color.", "congenital: Present at birth.", "conjunctiva: The membrane lining the eyelids and covering the eyeball.", "conjunctivitis: Inflammation of the conjunctiva. Also called pink eye.", "connective tissue: Fibrous tissue with a wide variety of connecting and supporting functions within and between body organs.", "conscious: Mentally awake and aware. Knowing what one is doing and why.", "constipation: A condition in which the stool becomes too hard for easy elimination.", "consumption: 1. Using up. 2. Wasting of the body; especially used in reference to advanced tuberculosis.", "contagious: Easily transmitted by direct or indirect contact.", "contraception: The intentional prevention of conception or impregnation. Also called birth control.", "contraction: A shortening or increase in tension.", "contracture: Deformity caused by abnormal shortening of the muscles.", "contrast medium: A substance used in x-ray studies to aid in showing internal structures.", "contusion: Bruise.", "convulsion: A seizure.", "cor pulmonale: Increased blood pressure in the lungs, causing chest pain, shortness of breath, swelling in the feet and fluid in the…", "cornea: The clear, external part of the eye.", "corns: A hardened area of skin on the foot caused by persistent friction or pressure.", "coronary arteries: The blood vessels encircling the heart that provide the heart muscle with oxygen.", "corticosteroid hormones: Hormones produced by the adrenal glands.", "coryza: Runny nose.", "costochondritis: Inflammation of the cartilage-containing joints where the ribs join the breastbone (sternum).", "coxsackievirus: A virus that can cause inflammation of the heart, brain or eye, or hand-foot-and-mouth disease.", "cramp: A painful muscle spasm.", "craniotomy: A surgical opening of the skull.", "cranium: The skull, or bony structure of the head, that protects the brain.", "creatinine: A substance formed from the making of creatine, an important nitrogen compound made in the body. Common in blood, urine…", "cretinism: Physical and mental retardation due to congenital lack of thyroid hormone.", "Crohn's disease: Chronic inflammation of the digestive tract, especially of the lower small intestine and colon.", "croup: Obstruction of the upper respiratory tract at or below the larynx (voice box), resulting in a hoarse, barking cough.", "crowning: The first appearance of a baby’s scalp during the birth process.", "cryosurgery: Destruction of tissue using extreme cold. A procedure used to treat skin lesions.", "CT: Computed tomographic scan.", "culdocentesis: A procedure to remove pus or blood from the abdomen through the vagina.", "Cushing's syndrome: A disorder caused by overactivity of the pituitary gland.", "cuspid: A tooth with one point, or “canine” tooth.", "cutaneous: Having to do with the skin.", "cyanosis: Bluish discoloration of the skin caused by lack of oxygen in the blood.", "cyst: A sac or pocket in the body containing fluid or semisolid material.", "cystitis: Inflammation of the bladder.", "cytology: The study of cells.", "cytomegalovirus: A virus that infects cells and causes them to become enlarged. Babies infected with the virus develop mental and sensory…", "D and C: Dilatation and curettage. A surgical procedure in which the uterine lining is removed by scraping.", "dacryocystitis: Inflammation of the sac that collects tears for drainage from the eye.", "dandruff: Little scales or flakes of dead skin on the scalp. Also called seborrheic dermatitis.", "debridement: Removal of foreign material or dead tissue.", "decalcification: Loss of calcium from the bones or teeth.", "decidua: The mucus lining of the uterus that’s passed after childbirth or during the menstrual period.", "decubitus: A skin ulcer or bedsore.", "defibrillator: A machine that delivers an electrical shock to an irregularly beating heart to restore normal rhythm.", "degenerative joint disease: A common form of arthritis in which tissue changes occur in one or more joints, such as swelling, lumps or…", "dehydration: Excessive loss of body water resulting in weakness, dizziness and other symptoms. It can be life-threatening if not treated, especially…", "delirium: An abnormal mental state characterized by excitement and hallucinations.", "deltoid: The triangular muscle of the shoulder.", "delusion: A false belief.", "dementia: Progressive mental deterioration.", "dentition: Arrangement of the teeth.", "dependence: A state of absolute need, both physical and psychological.", "depilatory: A substance that temporarily removes hair from the skin.", "depression: Decreased functional activity. Sinking of spirits. Intense sadness, beyond what’s normally expected.", "dermabrasion: A procedure that removes scars, tattoos or other skin defects with fine sandpaper or a high-speed brush.", "dermatitis: Inflammation of the skin.", "dermatology: A medical specialty that deals with the skin.", "desensitization: Reducing or eliminating sensitivity to a particular substance.", "desquamation: The shedding of cells from the surface of the skin or mucous membranes.", "devascularization: Interruption of blood circulation to part of the body.", "dextrose: A simple sugar. Glucose.", "diabetes insipidus: Loss of water through the kidneys as a result of decreased production of the pituitary hormone vasopressin (an antidiuretic…", "diabetes mellitus: A disorder of carbohydrate metabolism resulting from insulin deficiency. Characterized by high blood sugar levels that result in weakness, frequent…", "diagnose: To identify a disease.", "diagnosis: The process of identifying a disease or medical condition.", "dialysis: A treatment to remove certain molecules from the blood, particularly in people with kidney failure.", "diaphoresis: Excessive sweating.", "diaphragm: 1. The dome-shaped respiratory muscle separating the chest from the abdomen. 2. A barrier contraceptive device molded to fit over…", "diarrhea: Production of feces in increased volume and with greater fluidity than normal.", "diastole: The relaxation phase of the heartbeat.", "diastolic: Diastolic blood pressure is the pressure when your heart relaxing between beats and filling with blood.", "diet: The total food consumed by an individual. A therapeutic diet is a prescription of required or restricted foods.", "dietitian: An expert who is trained in the use of diet and nutrition to maintain or restore health.", "digestion: The mechanical and chemical conversion of food into simpler compounds that can be absorbed by the body.", "digit: A finger or toe.", "dilation: The process of expanding or enlarging.", "diphtheria: An infectious disease of childhood characterized by fever, sore throat and the presence of 'dirty' (white, gray, brown) membranes in…", "diplopia: Double vision.", "discoid lupus erythematosus: A round, red, scaling rash on the nose, forehead, cheeks, scalp or other areas of the body. It may be…", "disinfectant: A chemical agent used to destroy microorganisms on inanimate objects.", "disk: A round, flat structure, particularly the fibrous cartilage layer between two vertebrae (the bones that make up the spine). Also…", "diskectomy: Removal of an intervertebral disk of the spine.", "dislocation: Displacement of a bone from a joint.", "disorientation: Mental confusion, especially of time, place or person.", "distal: A location farther from a point of reference. For example, the foot is distal to the knee, relative to the…", "diuresis: Increased elimination of urine.", "diverticula: Pouches or sacs opening out from a main cavity or tubular organ of the body.", "diverticulitis: Inflammation of small pouches that may form on the wall of the colon.", "diverticulosis: A condition in which pouches form on the wall of the colon.", "dorsal: Toward the back.", "douche: A flow of liquid or vapor directed onto or into a part of the body.",\
                  "Down syndrome: A genetic disorder characterized by some degree of mental retardation and by various physical malformations, such as slanted eyes and…", "DPT: A vaccine containing antigens from diphtheria, pertussis and tetanus.", "dressing: A bandage for an external wound.", "dropsy: Abnormal buildup of fluid in tissues or a body cavity.", "duct: A channel or passage through which fluids move.", "duodenal: Having to do with the duodenum.", "duodenum: The first part of the small intestine that begins at the stomach and is the entry point for the pancreatic…", "Dupuytren's contracture: Scarring of the palmar ligament in the hand, causing progressive curling of one or more fingers and a thickening of…", "dwarfism: A deficiency of growth hormone resulting in short stature.", "dysentery: Infection of the intestine resulting in severe diarrhea and cramps, frequently associated with blood or mucus in the stools.", "dysmenorrhea: Painful menstruation.", "dyspepsia: Indigestion.", "dysphagia: Difficulty swallowing.", "dyspnea: Labored breathing.", "eardrum: The tympanic membrane that’s visible in the ear. It vibrates in response to sound waves.", "ecchymosis: A collection of blood in the tissues causing a black and blue, or yellow, area.", "ECG: Electrocardiogram.", "eclampsia: An attack of convulsions. Particularly used to describe toxemia (toxins in the blood) of pregnancy.", "ectopic pregnancy: When the fertilized egg is implanted and develops outside of the uterus.", "ectropion: An outward turning of the eyelid.", "eczema: A rash characterized by itching, scaling, swelling and oozing. A common allergic reaction.", "edema: Buildup of excessive fluid around the cells in the body.", "EEG: Electroencephalogram.", "effacement: Thinning of the cervix during labor.", "effusion: Buildup of fluid in a part of the body, particularly a joint.", "ejaculation: The sudden ejection of semen from the male body. Climax.", "EKG: Electrocardiogram.", "electroconvulsive: A type of therapy used to treat severe, unresponsive depression by passing electrical current through the brain.", "electrolysis: Destruction of tissue through the use of electricity; often used to permanently remove unwanted hair from the body.", "electrolytes: Compounds that separate into charged particles in water. The main electrolytes in the human body are sodium, potassium, bicarbonate, chloride,…", "elephantiasis: A chronic disease characterized by the enlargement of certain parts of the body and by the hardening and ulceration of…", "embolism: The obstruction of a blood vessel by a clot or mass of foreign material.", "emesis: Ejecting the contents of the stomach through the mouth.", "emphysema: Chronic lung disease characterized by loss of elasticity of lung tissue and resulting in trapped air in the lung.", "empyema: Buildup of pus in a cavity of the body.", "encephalitis: A serious infection resulting in inflammation of the brain.", "encopresis: Fecal incontinence. Inability to hold feces.", "endocarditis: Inflammation or infection of the inside of the heart, often including the heart valves.", "endocrine glands: Glands that are ductless and release their secretions directly into the bloodstream.", "endometriosis: A condition in which cells from the lining of the uterus are found in other locations within the pelvic cavity…", "enema: 1. Introduction of fluid into the rectum to bring about a bowel movement. 2. The solution introduced into the rectum…", "ENT: The medical specialty of the ear, nose and throat.", "enteritis: An inflammation of the intestines that usually causes cramps and diarrhea.", "enuresis: Bedwetting.", "eosinophil: A type of white blood cell that becomes more abundant in the bloodstream in certain parasitic and allergic conditions.", "epidemiology: The study of the causes and control of diseases in human populations.", "epidermis: The outermost layer of skin.", "epididymis: The elongated structure behind each testicle where sperm are stored.", "epiglottis: The flap of cartilage at the base of the tongue that closes the trachea during swallowing to keep food or…", "epilepsy: A disorder of the central nervous system that causes convulsions, or seizures.", "epinephrine: Adrenaline, a hormone produced in the core of the adrenal glands that’s sometimes used to treat asthma and allergic…", "episiotomy: An incision of the perineum (the area between the vagina and anus in women), often performed during labor to minimize…", "epistaxis: Nosebleed.", "epithelium: The layer of cells covering internal and external surfaces of the body.", "erysipelas: A febrile (fever-associated) skin infection caused by a group A hemolytic streptococci.", "erythema: Redness of the skin.", "erythema infectiosum: A viral infection most common in children that begins with a red, warm rash on the face, along with some…", "erythema multiforme: An eruption of flat or raised spots of skin as a result of hypersensitivity to certain drugs or allergies.", "erythema nodosum: The sudden appearance of tender raised nodes on the lower limbs as a result of an infection, hypersensitivity to certain…", "erythrocyte: Red blood cell.", "Escherichia coli: A type of common bacteria normally found in the colon. Some strains that cause diarrhea are acquired during travel.", "esophagitis: Inflammation of the esophagus, often caused from a reflux of acid from the stomach.", "esophagus: The tube through which food passes from the pharynx to the stomach.", "estrogen: Female sex hormone.", "eustachian tube: The narrow tube connecting the nose and middle ear to allow air pressure in the middle ear to equalize with…", "exacerbate: Cause something to increase in severity. To make more intense, irritate.", "exanthem: Skin rash.", "excise: To remove by cutting.", "exocrine glands: Glands that secrete chemicals externally, either through a tube or duct.", "expectorant: A substance that loosens mucus so it’s more easily cleared from the respiratory passages.", "faint: Temporary loss of consciousness because of an insufficient blood supply to the brain.", "fallopian tube: The tubal passageway connecting the ovary to the uterus.", "familial cholesterolemia: An inherited disorder causing abnormally high levels of cholesterol in the blood.", "fascia: Fibrous sheets of tissue connecting or covering the muscles.", "fat: A major energy source for animals and humans. Fat contains nine calories per gram.", "fatigue: Physical or mental exhaustion. Weariness.", "feces: Body waste expelled from the rectum. Also called bowel movement or stool.", "femoral: Having to do with the femur.", "femur: The thigh bone.", "fertility: The ability to have children.", "fertilization: The process of joining the male’s sperm and the female’s ovum (egg).", "fetal: Having to do with the fetus.", "fetus: The unborn baby from the end of the eighth week after fertilization of the egg to birth.", "fever: Abnormally high body temperature.", "fiber: 1. A slender, thread-like structure of organ tissue. 2. In the diet, strands of complex carbohydrates (cellulose) that aren’t…", "fibrillation: A rapid, uncoordinated series of contractions of some part of the heart muscle causing irregular heartbeats. Atrial fibrillation is the…", "fibrin: A serum protein that’s essential for the clotting process.", "fibroid: A noncancerous tumor of the uterus composed of muscle fibers. Also called uterine myoma.", "fibromyalgia: A painful condition with multiple sensitive areas, called 'tender points,' affecting fibrous tissues, muscles, tendons and ligaments.", "fibrositis: Inflammation of fibrous tissues.", "fibula: The long, thin, outer bone of the lower leg.", "fissure: A narrow slit.", "fistula: An abnormal passage from an abscess, cavity or hollow organ to the skin or another abscess.", "flaccid: Soft and flabby. Often used to describe complete paralysis (loss of movement) without muscle spasm.", "flatfoot: A condition in which the normal arch of the foot is absent.", "flatulence: Excessive production of gas in the intestines or stomach.", "fluorescein: A compound used as a diagnostic aid to show injuries of the cornea or retina of the eye.", "folic acid: Folacin. One of the B-group vitamins essential for forming red blood cells.", "folliculitis: Inflammation of the hair follicles.", "fontanelle: A soft spot in the skull of an infant formed by the normal separation between the bony plates of the…", "foreskin: A loose fold of skin covering the tip of the penis.", "fracture: Broken, especially a broken bone.", "fraternal twins: Twins formed from two separate eggs that were fertilized at the same time. They may be the same or different…", "frenulum: A fold of skin or mucous membrane that limits the movement of a body part. For example, the frenulum linguae…", "frigidity: An inability to be sexually aroused.", "fructose: Fruit sugar.", "fungus: A group of organisms that includes yeasts, molds and mushrooms.", "galactorrhea: Excessive production of breast milk.", "galactosemia: A disease present at birth caused by a genetic lack of an enzyme needed to metabolize galactose into glucose. May…", "gall: The bile produced in the liver and stored in the gallbladder.", "gallbladder: The storage sac for bile, located below the liver.", "gallstone: A stone-like mass that forms in the gallbladder.", "gamma globulin: Blood protein that contains most antibodies. Used in the temporary prevention of hepatitis and as treatment for disorders with antibody…", "ganglion cyst: A benign, knot-like, cystic tumor on a tendon sheath.", "gangrene: The decay of body tissue in a part of the body where the blood supply is obstructed by injury or…", "gastric: Having to do with the stomach.", "gastritis: Inflammation of the stomach lining.", "gastroenteritis: Inflammation of the stomach and the intestines, usually producing symptoms of nausea, vomiting and diarrhea.", "gastrointestinal: Having to do with the stomach and intestines.", "gene: A unit of heredity located on a chromosome.", "generic: 1. General; typical; not specific. 2. Medicine that’s not a name brand.", "genetic: Hereditary. Having to do with the genes.", "genitalia: The reproductive organs.", "genitourinary system: The genitals and urinary organs.", "geriatrics: The branch of medicine devoted to the elderly.", "germ: A disease-causing microorganism.", "German measles: A mild childhood disease that causes fever and rash. Although rubella is mild in childhood, it’s dangerous to pregnant women…", "gestation: The period of development within the uterus from conception to birth.", "giantism: Abnormal growth of the body due to an excessive amount of growth hormone produced by the pituitary gland.", "giardiasis: A diarrheal illness caused by infection with Giardia lamblia, a parasitic protozoan.", "gingiva: The gums.", "gingivitis: Inflammation of the gums.", "gland: An organ that releases a chemical. Endocrine glands are ductless and secrete hormones directly into the bloodstream. Exocrine glands secrete…", "glaucoma: An eye disease, characterized by increased pressure within the eye, that can result in blindness if not treated.", "glomerulonephritis: When the filtering units in the kidneys, called the glomeruli, are damaged, the kidneys don’t function properly and waste and…", "glossitis: Inflammation of the tongue.", "glucose: Dextrose. A simple six-carbon sugar naturally found in fruits, honey and blood.", "goiter: Enlargement of the thyroid gland.", "gonad: A sex gland (ovary or testis).", "gonorrhea: A highly contagious, sexually transmitted bacterial disease of the genital/urinary system.", "gout: A form of arthritis caused by deposits of uric acid crystals in the joints, usually the feet, hands and, especially,…", "graft: A piece of skin or other tissue used as a transplant.", "Gram's stain: A stain used as the first step in identifying bacteria.", "grand mal: A major epileptic seizure characterized by convulsions, unconsciousness and sometimes loss of urinary or bowel continence. Usually followed by a…", "Graves' disease: Overactive thyroid gland function (hyperthyroidism). Sometimes associated with protrusion of the eyes.", "groin: The region of the body where the thigh and lower abdomen meet.", "Guillain-Barre syndrome: A rare but reversible reaction to a viral illness or immunization that causes partial to complete loss of movement of…", "gynecology: The branch of medicine that deals with the study and treatment of reproductive diseases in women.", "gynecomastia: Overdevelopment of male breast tissue. Usually benign and temporary.", "halitosis: Bad breath.", "hallucination: The sensory perception of sights, sounds or objects that don’t really exist.", "hammer: The malleus, a hammer-shaped bone in the middle ear.", "hamstring: The tendon located in the back of the knee and lower thigh.", "hand-foot-and-mouth disease: A viral infection characterized by a blister-like rash of the hands, feet and mouth.", "hangnail: A loose piece of skin at one side of a fingernail.", "Hansen's disease: Leprosy.", "harelip: Cleft lip or palate.", "Hashimoto's thyroiditis: A degenerative autoimmune disease of the thyroid gland that ultimately results in a marked reduction in the amount of thyroid…", "hay fever: Allergic sensitivity to certain mold spores and pollens. Allergic reaction includes sneezing, itchy eyes, sore throat and runny nose.", "heart: The hollow, muscular organ responsible for pumping blood through the circulatory system.", "heart block: A condition in which electrical impulses aren’t properly transmitted from the heart’s upper to the lower chambers.", "heart failure: Inability of the heart to adequately pump blood.", "heartburn: Indigestion. A burning sensation in the chest caused by a reflux of acid into the esophagus or too much acid…", "heat exhaustion: Headache, profuse sweating, weakness, muscle cramps, nausea and vomiting caused by excessive exposure to heat.", "heat stroke: A serious failure of the body’s heat-regulating mechanism resulting from excessive exposure to intense heat. Also called sunstroke.", "hemangioma: A tumor or swelling that’s composed of blood vessels.", "hematemesis: The vomiting of blood.", "hematology: The branch of medicine that pertains to blood and the organs involved in forming blood.", "hematoma: A tumor-like mass of coagulated blood in the soft tissues. A contusion or bruise.", "hematuria: The presence of blood in the urine.", "hemiplegia: Paralysis (loss of feeling or movement) of one side of the body.", "hemochromatosis: A disorder of iron metabolism characterized by excessive amounts of iron in the skin, liver and other tissues.", "hemoglobin: The oxygen-carrying molecule in red blood cells.", "hemolysis: The destruction of red blood cells.", "hemophilia: An inherited disorder, nearly always in males, in which one of the normal blood-clotting factors is deficient.", "hemoptysisA cough that produces blood.", "hemorrhage: Severe bleeding, usually from damage to a blood vessel.", "hemorrhoid: An enlarged vein inside or just outside the rectum.", "hemostasis: Control of bleeding.", "hepatic: Having to do with the liver.", "hepatitis: Inflammation or infection of the liver.", "heredity: Transmission of genetic traits from parents to children.", "hermaphrodite: A person with both male and female sex organs.", "hernia: An abnormal protrusion of part of an organ through an abnormal opening.", "herpes: A recurring viral skin infection characterized by clusters of small blisters. Typically, sores are located near the mouth (fever blisters…", "heterosexual: Having to do with the opposite sex.", "hexachlorophene: A detergent that kills germs.", "hiccup: A sudden, involuntary spasm of the diaphragm. The sound of hiccups is caused by the sudden intake of air.", "hidradenitis: Inflammation of the sweat glands.", "hip: The part of the body surrounding the joint between the femur and pelvic bones.", "hirsutism: Excessive hair growth, usually on the face and chest. Often caused by an imbalance in hormones.", "histamine: A substance released from certain cells in response to allergens, associated with the development of allergic symptoms, including itchy eyes,…", "histoplasmosis: A fungal disease caused by inhaling the spores of Histoplasma capsulatum.",\
                   "HIV: Human immunodeficiency virus. A virus that slowly destroys the immune system. The virus that causes AIDS.", "hives: A skin reaction characterized by swelling, itching and burning.", "Hodgkin's disease: A progressive form of lymphoma usually characterized by weakness, swollen lymph nodes, sweating, fever and weight loss.", "homeopathy: Medical treatment based on the theory that certain diseases can be cured by giving very small doses of substances that,…", "homogenize: To make more uniform in quality or consistency.", "homosexual: Having to do with the same sex.", "hordeolum: Inflammation of a gland on the eyelid. Also called a stye.", "hormone: A substance formed in an organ of the body and carried by body fluids to another organ or tissue, where…", "host: An organism that harbors and provides sustenance for another organism.", "housemaid's knee: Swelling just below the kneecap, caused by the buildup of fluid in response to the constant pressure of kneeling.", "humerus: The bone in the upper arm.", "humidifier: A device for adding moisture to the air.", "Huntington's chorea: A hereditary form of chorea (sudden, jerky motions of the arms or other parts of the body) that usually affects…", "hydatid: A cyst containing watery fluid and the larvae of certain tapeworms.", "hydatid disease: Infection with the larvae (cysts) of certain tapeworms.", "hydatidiform mole: A cystic tumor of the placental tissues of an abnormal pregnancy. Complications of this disorder include bleeding and infection.", "hydrocele: A painless swelling of the scrotum caused by the buildup of fluid in the outer covering of the testes.", "hydrocephalus: An enlargement of the head caused by the buildup of fluid within the ventricles of the brain. Also called 'water…", "hygiene: The science of health and its maintenance.", "hymen: The membrane partly or completely closing the opening to the vagina.", "hyperbaric: Characterized by greater-than-normal pressure. Hyperbaric oxygen is a therapeutic treatment designed to increase blood oxygen by delivering oxygen in a…", "hyperemesis gravidarum: Excessive morning sickness.", "hyperglycemic: High blood sugar.", "hyperparathyroidism: A condition caused by the overexcretion of parathyroid hormone resulting in changes in the bone and an elevated level of…", "hypertension: Abnormally high blood pressure.", "hyperthyroidism: Overproduction of thyroid hormone.", "hyperventilation: Rapid or deep breathing producing faintness, numbness, chest pain, apprehension and tingling, and spasms of the extremities.", "hypnosis: A sleep-like state induced by the suggestions of a hypnotist.", "hypnotic: 1. Having to do with hypnosis. 2. Causing sleep.", "hypochondriac: Abnormal anxiety about one’s health, often to the point of believing one is suffering from a serious disease.", "hypodermic: Beneath the skin.", "hypoglycemia: Low blood sugar.", "hypoparathyroidism: Parathyroid hormone insufficiency due to lack of secretion of the parathyroid gland.", "hypopituitarism: Deficient activity of the pituitary gland causing slowed growth in children, fatigue and decreased appetite in adults, and cessation of…", "hyposensitization: To treat with frequent, small injections of an antigen to decrease the symptoms of an allergy to that antigen. Also…", "hypospadias: An abnormal opening of the urethra on the underside of the penis or into the vagina.", "hypothalamus: The portion of the brain responsible for temperature regulation and control of the pituitary gland.", "hypothermia: Low body temperature.", "hypothyroidism: A condition of low thyroid hormone production resulting in weight gain, hair loss, sluggishness and thickening of the skin.", "hypoxia: An abnormal condition resulting from decreased availability of oxygen in the body tissues.", "hysterectomy: Surgical removal of all or part of the uterus.", "hysteria: 1. Wild, uncontrolled excitement or other feelings. 2. A disorder in which anxiety is converted into physical symptoms that have…", "iatrogenic: Resulting from medical treatment.", "ichthyosis: An inherited skin disorder that produces dry, rough, scaly skin.", "identical twins: Twins formed from a single egg. They are of the same gender and have the same genetic makeup. Also called…", "idiopathic: Without a known cause.", "ileitis: Inflammation of the lower part of the small intestine.", "ileum: The lower part of the small intestine.", "ileus: Lack of movement of digested food and juices through the gastrointestinal tract. May be due to a blockage of the…", "ilium: The flared portion of the pelvis. The hip bone.", "IM: Intramuscular.", "immune: Resistant to a particular disease.", "immunity: Resistance of the body to infection.", "immunization: The process of making an individual immune by vaccination or inoculation.", "immunoglobulin: A serum protein involved in immunity. An antibody.", "impetigo: Skin infection characterized by erupting sores. Caused by staphylococcus or streptococcus bacteria.", "impotence: Inability of a male to achieve erection and orgasm.", "in situ: In its original place. Carcinoma in situ means cancer that hasn’t spread to other locations.", "incision: A cut.", "incisor: Any of the front four teeth on either the upper or lower jaw.", "incompetent: 1. Unable to make rational decisions. 2. Not functioning properly.", "incontinence: Inability to hold urine or feces.", "incubate: To provide the proper conditions for growth.", "indigestion: Upper abdominal discomfort usually experienced after a meal due to incomplete digestion.", "induration: The process of hardening. An abnormally hard spot.", "infarct: An area of dead or dying tissue produced by lack of blood flow to or from that area. For example,…", "infection: Causing disease, especially by the presence of foreign microorganisms in the body, including bacteria, viruses or parasites.", "infectious disease: A disease that can be spread from one person to another.", "infertility: Inability to produce children.", "inflammation: Swelling, redness, warmth and pain. A body tissue’s protective response to injury.", "influenza: A contagious and infectious respiratory illness usually occurring in the winter.", "ingrown nail: Edges of the nail become trapped under the skin, causing inflammation and, sometimes, infection.", "injection: A fluid introduced into the body by a syringe and needle.", "innate: Inborn, hereditary.", "inoculation: The injection of a disease agent into the body to cause a mild form of the disease and build…", "inoperable: Not curable through surgery.", "insanity: Any form or degree of mental disturbance or unsoundness of mind, permanent or temporary, that makes a person incapable of…", "insemination: To deposit sperm in the vagina.", "insomnia: An inability to fall asleep or to remain asleep.", "insulin: The hormone produced by the pancreas for regulating carbohydrate metabolism. Used in the treatment of diabetes mellitus.", "integument: Skin.", "intercourse: The exchange of communication between individuals. Sexual intercourse is the sexual joining of two people; coitus.", "intestine: The tube involved in digestion and extending from the stomach to the anus. Consists of the small intestine and the…", "intoxication: Poisoning, or the state of being affected by a poisonous substance. Often used to describe drunkenness.", "intracellular: Within a cell.", "intradermal: Within the skin.", "intramuscular: Within the muscle.", "intrauterine: Within the womb.", "intravenous: Within a vein. Intravenous infusion means to direct fluids through a needle or catheter directly into a vein.", "intussusception: Telescoping a section of the intestine into an adjoining section.", "iris: The colored portion of the eye. It’s a muscle that controls the amount of light entering the pupil.", "iritis: Inflammation of the iris.", "irrigation: Washing of a body cavity or wound with a stream of water.", "ischemia: A lack of blood supply to a body part.", "IUD: Intrauterine device. Used for contraception.", "IV: Intravenous.", "IVP: Intravenous pyelography.", "jaundice: Yellow discoloration of the skin and eyes caused by the buildup of bile in the blood.", "jejunum: The middle part of the small intestine, located between the duodenum and ileum.", "joint: The joining of two or more bones. In general, joints allow flexibility and mobility. However, some joints (for example, those…", "jugular: Of the neck or throat, as in jugular veins.", "Kaposi's sarcoma: Bluish-purple nodules of the skin that often bleed. These frequently occur in people who have AIDS.", "keloid: Excessive growth of scar tissue on the skin.", "keratin: The main protein of skin, hair and nails.", "keratitis: Inflammation of the cornea of the eye.", "keratoconus: A deformity of the cornea in which the cornea resembles the end of a football.", "ketones: The initial breakdown products of fatty acid metabolism. Unavailability of carbohydrates from starvation or uncontrolled diabetes mellitus increases the production…", "kidney: A pair of organs in the upper abdominal cavity that separate the body’s water and waste products from the blood…", "knee: The complex hinge joint of the upper and lower leg involving the femur, tibia and patella.", "knock-knee: A deformity in which the knees rub together or touch each other in walking.", "labia: Lip-shaped structures; often used to describe the outer folds of the female genitalia.", "labyrinth: The system of interconnecting canals and cavities in the inner ear. Plays an important role in hearing and in…", "laceration: A wound caused by a cut from a sharp instrument or the tearing of body tissue.", "lacrimation: Discharge of tears. 'Watering' eyes.", "lactase: An enzyme that converts the milk sugar lactose into glucose and galactose.", "lactation: Secretion of milk by the breasts.", "lactose: Milk sugar.", "laryngitis: Inflammation of the larynx, resulting in a temporary loss of voice.", "larynx: The voice box.", "lateral: Toward the side, sideways.", "lavage: Washing out of an organ, especially the stomach.", "Legg-Calve-Perthes disease: Perthes disease A disease in which the blood supply to the femur is reduced, causing the bone to collapse.", "lens: 1. A curved glass used to bring together or spread rays of light. 2. The transparent organ lying behind the…", "leprosy: A progressive infectious disease that attacks the skin, flesh and nerves; characterized by nodules, ulcers, scaly scabs, deformities and the…", "lesion: Any damage to a tissue. Marks, spots, moles or other problems of the skin.", "lethargy: A lack of energy; sluggishness, dullness or apathy.", "leukemia: Cancer of the tissues in the bone marrow, spleen and lymph nodes.", "leukocytes: White blood cells, the blood cells responsible for fighting infection.", "leukopenia: A lower than normal number of leukocytes in the blood.", "leukopheresis: Selective removal of the white blood cells from a donor’s blood. The other components of the blood are then returned…", "leukoplakia: Thick, white patches in the mouth that may become malignant.", "lichen: Any of various skin diseases characterized by sores and enlarged skin markings.", "ligament: A tough band of connective tissue connecting bones or holding organs in place.", "ligature: A wire or thread used to tie off blood vessels or to close incisions or wounds.", "lightening: The feeling of decreased abdominal pressure during the last few weeks of pregnancy caused by the uterus dropping into the…", "limbus: Margin, or border. The margin of the cornea where it contacts the sclera.", "lingua: Tongue.", "lipid: Cholesterol, triglycerides and related substances.", "lipocyte: A fat cell.", "lipolysis: The splitting up, or destruction, of fat.", "lipoma: Fatty tumor.", "lipoprotein: Any of a group of proteins combined with a lipid that allow lipids to be transported in the circulatory…", "liposuction: A surgical procedure that changes body shape by removing fat cells.", "litholysis: Breaking up of a stone, such as a gallstone.", "lithotripsy: A procedure to break up kidney stones into smaller pieces that can more easily pass out of the body.", "liver: The large organ in the upper right abdomen that functions in digestion and storage of food, disposal of worn-out red…", "lobe: 1. The fleshy lower part of the ear. 2. A well-defined portion of an organ.", "lobectomy: Surgical removal of the lobe of an organ.", "lobotomy: A surgical operation in which a lobe of the brain, especially the frontal lobe of the cerebrum, is cut into…", "lochia: The discharge from the vagina that occurs for several days to weeks after childbirth.", "lockjaw: Tetanus infection.", "loins: The portion of the back between the rib cage and pelvis.", "lordosis: Forward curvature of the spine, producing a hollow in the back.", "LSD: Lysergic acid diethylamide. A hallucinogenic drug.", "lumbago: Pain in the lower back.", "lumbar: Having to do with the lower back, the loins.", "lungs: The main respiratory organs in the chest where blood is oxygenated.", "lupus erythematosus: A usually chronic inflammatory disease that causes abnormalities of blood vessels and connective tissue in various parts of the…", "luteinizing hormone: A hormone secreted by the anterior pituitary gland, responsible for stimulating ovulation in the female and testosterone production in the…", "Lyme disease: A disease spread by deer ticks characterized at first by a skin rash, headache and fever, and later by arthritis…", "lymph: Consists primarily of a clear, yellowish fluid and white blood cells. Found in the lymphatic system.", "lymph node: Any of many small, compact structures lying in groups along the course of the lymphatic vessels and producing lymphocytes.", "lymphadenitis: Inflammation of the lymph nodes.", "lymphangitis: Inflammation of a lymphatic vessel.", "lymphatic system: The vessels and structures involved in carrying lymph from the tissues to the blood.", "lymphedema: Swelling of tissue because of the buildup of too much lymph fluid.", "lymphocyte: A type of leukocyte (white blood cell) involved in the production of antibodies and the development of immunity.", "lymphoma: A malignant tumor of the lymphoid tissues.", "macrophage: A large cell that engulfs and digests foreign material.", "macula: The central part of the retina with the highest density of light receptors. Responsible for detailed vision.", "macule: A discolored, flat spot of skin.", "malady: Illness.", "malaria: An infectious disease of the tropics characterized by high fever and chills. The fever typically recurs every third day. Some…", "malignancy: A tendency to worsen to a more serious illness or death. Commonly used to describe cancer.", "malingering: Deliberate exaggeration of the symptoms of an illness or injury for gain. For example, pretending to be ill in order…", "malleolus: The rounded bony prominence on either side of the ankle.", "malleus: A small bone in the middle ear, often called the hammer.", "malnutrition: Poor nourishment resulting from an inadequate or improper diet.", "malocclusion: Improper meeting of the upper and lower teeth.", "malunion: Improper healing of the pieces of a broken bone.", "mammary: Having to do with the breast.", "mandible: The lower jaw.", "mania: A mental disorder. Characterized by extreme excitement and energy.", "manic-depressive: A mental disorder marked by alternating periods of excitability and depression. Also called bipolar affective disorder.", "marijuana: A drug derived from the leaves of the Cannabis sativa plant. Makes the user feel euphoric.", "marrow: The soft, sponge-like material inside the bones.", "masculinization: Development of male sex characteristics in a female.", "masochism: Pleasure from personal, psychological or physical pain.", "mastectomy: Surgical removal of the breast.", "mastitis: Inflammation of the breast.", "mastoid: A bony, rounded projection of the skull located behind each ear.", "mastoiditis: An infection of the mastoid bone that can cause redness, warmth, swelling and pain behind the ear, sometimes with drainage…", "masturbation: Sexual self-stimulation.", "maxillae: The pair of bones forming the upper jaw.", "measles: A highly contagious viral disease occurring most frequently in childhood and characterized by small, red spots on the skin, high…"\
                    "Meckel's diverticulum: A sac that may form in the small intestine, present at birth.", "meconium: The greenish fecal matter in a fetus, forming the first bowel movement of a newborn infant.", "median nerve: The nerve that stimulates some of the muscles of the hand and wrist.", "mediastinum: The tissues and organs located directly behind the sternum between the lungs. Contains the heart and its large vessels, the…", "medulla: The inner part of an organ. The adrenal medulla is the center of the adrenal gland where epinephrine (adrenaline) is…", "medulla oblongata: The part of the brain just above the spinal cord that includes the control centers for breathing, circulation and…", "meibomian gland: A type of gland of the eyelid’s inner surface. Inflammation of a meibomian gland can produce a swelling called a…", "melancholia: A mental state characterized by extreme sadness. A severe form of depression.", "melanin: A brownish-black pigment normally found in skin, hair and parts of the eye.", "melanoma: A dark-colored tumor, especially malignant melanoma, that is a form of skin cancer that can spread from one part of…", "melasma: Dark coloring of the skin often seen during pregnancy and at menopause. Also occurs in Addison’s disease.", "melena: Black-colored feces caused by the presence of blood.", "membrane: A thin layer of tissue covering an organ.", "menarche: A woman’s first menstrual period.", "Meniere's syndrome: A disorder of the inner ear characterized by dizziness, ringing in the ears and progressive hearing loss.", "meninges: The three membranes covering the brain and spinal cord.", "meningioma: Tumor of the meninges, usually benign and slow-growing.", "meningitis: Inflammation of the meninges as the result of infection by bacteria or viruses. Symptoms include high fever, headache, stiff neck…", "meniscus: The cartilage in the knee joint.", "menopause: The time at which the menstrual cycle gradually stops. Sometimes referred to as the 'change of life.'", "menorrhagia: Heavy bleeding during menstruation.", "menstruation: The periodic discharge of blood and tissues from the uterus. This usually occurs about every four weeks in a woman…", "metabolism: The chemical and physical processes involved in building up, storing and using materials required for life.", "metacarpal: Any of the five bones that make up the hand and join the wrist to the fingers.", "metaphysis: The wider portion at the end of a long bone where growth occurs in infants and children.", "metastasis: The spread of a disease from its primary site in the body to another location in the body. Usually refers…", "metatarsal: Any of the five bones of the foot directly jointed to each of the toes.", "metra: Uterus.", "metritis: Inflammation of the uterus.", "metrorrhagia: Uterine bleeding, usually of normal amount occurring at irregular intervals.", "microbe: A microorganism, such as bacterium.", "microbiology: The study of living microbes, including bacteria, protozoa and molds.", "microencephaly: Having an abnormally small brain.", "microorganism: A microscopic plant or animal.", "midwife: A person who helps women at childbirth, but who isn’t a nurse or physician.", "migraine: A group of symptoms that includes a severe headache, usually on one side of the head, and often accompanied by…", "milia: Pinhead-sized whitish skin lesions found on the face or trunk of some newborn infants.", "miliaria: Prickly heat or 'heat rash' as a result of inflammation of the sweat glands and characterized by small, white or…", "miscarriage: Natural loss of a fetus from the womb before it is sufficiently developed to survive. Also called spontaneous abortion.", "mitral valve: The valve of the heart between the left atrium and left ventricle that prevents the flow of blood back into…", "mittelschmerz: Pelvic pain between periods, corresponding to the release of an ovum (egg) by an ovary.", "mole: 1. A fleshy, pigmented skin blemish. 2. A mass of uterine tissue formed by a failure of the normal fertilization…", "molluscum contagiosum: A viral infection of the skin characterized by lesions with depressed centers containing a curd-like substance.", "mongolism: A condition present at birth characterized by mental deficiency, a broad face and slanting eyes. Also called Down syndrome.", "monocyte: A large white blood cell leukocyte.", "mononucleosis: An infection with Epstein-Barr virus. Also called 'mono.'", "morbid: 1. Pathologic or abnormal. 2. Having to do with, or characterized by, disease.", "morning sickness: Nausea and vomiting occurring during pregnancy.", "MRI: Magnetic resonance imaging.", "mucosa: The membrane covering canals and cavities that open on the outside of the body, such as the gastrointestinal tract and…", "mumps: A viral disease of childhood characterized by swelling of the parotid (salivary) glands and fever.", "murmur: An extra heart sound that may be normal or abnormal.", "muscle: Tissue made up of bundles of long, slender cells that contract when stimulated.", "mutation: A damaged gene that may produce a disease or deficiency.", "mute: An inability or unwillingness to speak.", "myalgia: Muscle pain.", "myasthenia gravis: A chronic disease characterized by muscular weakness and fatigue.", "myelin: The fat-like substance that insulates certain nerve fibers.", "myocarditis: Inflammation of the heart muscle.", "myoma: A tumor of muscle cells.", "myopia: Nearsightedness.", "myositis: Inflammation of a muscle.", "myringotomy: An incision in the eardrum to relieve pressure or release fluid.", "narcissistic: Self-centered, being “in love” with oneself.", "narcolepsy: Frequent and uncontrolled desire for sleep.", "nausea: A feeling of sickness in the stomach, sometimes followed by the urge to vomit.", "nebulizer: A device that produces a very fine vapor to be inhaled.", "necrosis: Death of a cell or tissue.", "nematode: A roundworm that may infest the digestive tract of humans.", "neoplasm: A new growth, tumor.", "ephrectomy: Surgical removal of a kidney.", "nephritis: Inflammation of a kidney.", "nephropathy: Disease of the kidneys. Swelling or breakdown of the kidney.", "nephrosis: A disease of the kidney that causes malfunction but no inflammation. Also called nephrotic syndrome.", "nerve: A cord-like structure made up of special tissue for carrying electrical impulses from one part of the body to…", "neuralgia: Pain along the course of a nerve.", "neuritis: Inflammation of a nerve.", "neurofibromatosis: An inherited disorder that causes dark spots on the skin and tumors of the skin, peripheral, optic and acoustic…", "neurology: The branch of medicine that pertains to the nervous system.", "neuroma: A benign but sometimes painful tumor growing on a nerve.", "neuron: A nerve cell.", "neuropathy: Disease of the nervous system or of an individual nerve.", "neurosis: An emotional disorder that can interfere with a person’s ability to lead a normal life.", "neutrophilA mature white blood cell with a three- to five-lobed nucleus.", "nevus: A mole or other colored spot on the skin.", "nicotine: A highly toxic and addictive component of tobacco. While the amounts obtained from smoking may not be enough to be…", "night blindness: A reduced ability to see in dim light. May be caused by a vitamin-A deficiency or glaucoma.", "nit: The egg of a louse.", "nocturia: Excessive urination at night.", "node: A swelling, knot or knob.", "nonunion: Failure of the ends of a broken bone to mend.", "norepinephrine: A hormone produced by the adrenal medulla and certain sympathetic nerve fibers.", "nosocomial: Having to do with the hospital. For example, an nosocomial infection is one that’s acquired during hospitalization.", "obesity: Having too much body fat. A weight more than 20% above the normal range.", "obsession: An ongoing preoccupation with an idea.", "obsessive-compulsive: Marked by a need to repeatedly perform certain behaviors or rituals.", "obstetrics: The branch of medicine that deals with the care and treatment of women during pregnancy and childbirth.", "occiput: The back of the head.", "occult: Hidden from view.", "occupational illness: Any illness caused or aggravated by a person’s job.", "occupational therapy: Teaching useful skills to sick or handicapped people to promote rehabilitation and healing.", "ocular: Having to do with the eye.", "odontalgia: Toothache.", "olecranon: The projection of the ulna (the larger of the two bones in the forearm) at the elbow.", "olfactory: Having to do with the sense of smell.", "oligomenorrhea: Light menstrual flow.", "oligospermia: A low number of sperm in the semen.", "oliguria: A condition characterized by an abnormally small output of urine.", "oncology: The study of tumors.", "oophorectomy: The surgical removal of an ovary.", "ophthalmology: The branch of medicine that pertains to the eye and its diseases.", "optic neuritis: Inflammation of the optic nerve, which connects the eye to the brain. Symptoms include pain with eye movement, blurred vision…", "optical: Having to do with vision.", "optometry: The practice of eye and vision care.", "orbit: The bony cavity containing the eyeball. Eye socket.", "orchiectomy: The surgical removal of one or both testicles. Also called castration.", "organ: A structural unit of an animal or plant that serves a specific function.", "organic: Having to do with substances derived from living organisms.", "orgasm: Sexual climax.", "orifice: The entrance or outlet of a body cavity.", "oropharynx: The part of the pharynx behind the mouth and tongue.", "orthodontics: The branch of dentistry that deals with the correction of irregularities of the teeth and related facial problems.", "orthopedics: The branch of medicine that deals with the treatment of deformities, diseases and injuries of the bones, joints and…", "orthopnea: Difficulty breathing when lying flat.", "oscillation: A back-and-forth motion; vibration.", "Osgood-Schlatter disease: Inflammation of the bone and cartilage of the shin bone, just below the knee.", "ossicle: A small bone.", "osteoarthritis: A slowly progressive form of arthritis, usually found in older people. Characterized by deterioration of bone cartilage.", "osteoma: A bony tumor.", "osteomalacia: Softening of the bones resulting from deficient bone calcium.", "osteomyelitis: Infection of a bone.", "osteopathy: A system of therapy emphasizing primary medical care and the importance of body mechanics and manipulation to correct abnormalities.", "osteoporosis: A bone disorder characterized by a reduction in bone density, chiefly found in women who have passed menopause and the…", "ostomy: A procedure done to make a passageway for waste. A colostomy is an example.", "otic: Having to do with the ear.", "otitis: Inflammation of the ear. Otitis externa (inflammation of the ear canal) is also called swimmer’s ear, while otitis media is…", "ovary: The female sex gland that contains ova, or eggs.", "ovulation: The process in which an ovum is released from the ovary.", "ovum: Egg; the female reproductive element.", "oximeter: A device for determining the oxygen saturation level of the blood.", "oxygen: A chemical element essential for sustaining life.", "oxytocin: A pituitary hormone that encourages the pregnant uterus to contract and is sometimes used to induce labor. It also encourages…", "Paget's disease: 1. A type of cancer usually involving the breast’s larger ducts, areola and nipples. 2. A disease characterized by weakened…", "palate: The roof of the mouth.", "palliative: Controlling symptoms without curing the disease.", "pallor: Pale appearance of the skin.", "palpate: To feel with the fingers.", "palpebra: The eyelid.", "palpitation: A sensation that the heart is beating too rapidly or strongly.", "palsy: Inability to move parts of the body.", "panacea: A remedy for all diseases.", "pancreas: A gland located below and behind the stomach and liver that produces insulin and glucagon, the hormones involved in carbohydrate…", "pancreatitis: Inflammation of the pancreas.", "pandemic: A widespread epidemic.", "panic: A sudden attack of anxiety.", "papilla: A small nipple-shaped projection.", "papilledema: Swelling of the optic disk. May be due to an increase of pressure in the skull.", "papilloma: A benign tumor of the skin or mucous membranes. A wart.", "papule: A solid, raised skin lesion.", "para-aminobenzoic acid: PABA, a substance used in suntan lotion and used clinically to treat rickettsial diseases.", "paracentesis: Surgical removal of fluid from a cavity.", "parainfluenza virus: One of a group of viruses that cause a variety of upper respiratory diseases.", "paralysis: Inability to move parts of the body.", "paranasal sinuses: The mucosa-lined cavities in the bones of the skull that open into the passages of the nose.", "paranoia: A mental disorder characterized by a belief that others are out to get you.", "paraplegia: Inability to feel or move the legs.", "parasite: An organism that lives on or in the tissues of another organism and draws its nourishment from the host.", "paraspadias: A developmental abnormality in which the urethra opens along one side of the penis.", "parathyroid glands: Two pair of small glands situated next to or in the thyroid gland that are involved in the metabolism of…", "parenteral: Inside the body, but outside the intestines.", "paresis: Partial or slight loss of feeling or movement.", "paresthesia: An abnormal sensation of burning or prickling on the skin, caused by a disorder of the nervous system.", "Parkinson's disease: A progressive disease of the brain. Characterized by tremors and muscle stiffness.", "parotid glands: The largest of the salivary glands, located near the ears.", "paroxysm: A sudden attack, or raised level of intensity, of symptoms.", "pasteurization: Heating milk or other substances to a temperature of 140§F for 30 minutes to kill harmful bacteria.", "patella: The kneecap.", "pathogen: Any agent that causes disease.", "pathology: The study of changes caused by disease.", "pectoral: Having to do with the chest or breast.", "pectus carinatum: An abnormally prominent sternum or breastbone. Also called pigeon breast.", "pectus excavatum: A defect of the sternum that’s present at birth.", "pedal: Having to do with the feet.", "pediatrics: The branch of medicine that deals with the development and care of infants and children.", "pediculosis: Infestation with lice.", "pelvis: The bony structure formed by the sacrum, coccyx, ilium, pubis and ischium.", "pemphigus: A skin condition characterized by large blisters.", "pepsin: A digestive enzyme found in the stomach.", "peptic: Having to do with the stomach.", "percutaneous: Introduced through the skin.", "perforation: A hole or break through a membrane or the wall of an organ.", "pericarditis: Inflammation of the sac that surrounds the heart.", "pericardium: The fibrous sac the heart.", "perineum: The pelvic floor. In females, the region from the vagina to the anus. In males, the region from the base…", "periodontitis: Inflammation of the tissues around the teeth.", "periosteum: The connective tissue covering the bones of the body.", "peripheral: At or near the surface of the body. Located away from the center structure.", "peristalsis: The waves of contraction and relaxation of the smooth muscle of the digestive tract.", "peritoneum: The membrane lining the walls of the abdominal and pelvic cavity.", "peritonitis: Inflammation of the peritoneum.", "pernicious: Fatal.", "pernicious anemia: Anemia due to vitamin B12 deficiency.", "pertussis: A serious infectious respiratory disease of children. Named for the distinctive whooping sound made by the patient after a coughing…", "petit mal: A mild seizure with a momentary loss of consciousness.", "phagocyte: Any cell that destroys invading microorganisms.", "phagomania: An obsession with eating.", "pharmacist: A person licensed to mix and dispense drugs.", "pharyngitis: Inflammation of the pharynx. Also called a sore throat.", "pharynx: The cavity of the canal leading from the mouth and nasal passages to the larynx and the esophagus.", "phenylalanine: An essential amino acid occurring in proteins. A small amount of phenylalanine is necessary in the diet to make the…",\
                     "phenylketonuria (PKU): A rare inherited disorder. Causes an inability to metabolize phenylalanine, an amino acid that’s a common part of many proteins…", "phimosis: Excessive tightness of the foreskin of the penis.", "phlebitis: Inflammation of a vein.", "phlebotomy: Withdrawal of blood from a vein.", "phlegm: Mucus, especially mucus produced by the lungs during inflammation or infection.", "phobia: Any persistent, unreasonable abnormal fear.", "phonation: Making vocal sounds.", "photophobia: Abnormal intolerance of light.", "physician: A doctor. An authorized practitioner of medicine.", "physiology: The branch of medicine that deals with the function of the various parts of the living organism.", "pigeon toe: A foot condition where the toes turn in.", "pigeon toe: A foot condition where the toes turn in.", "pilus: Hair.", "pimple: A small, elevated skin lesion", "pinguecula: A yellowish spot on the cornea of the eye that sometimes occurs in the elderly.", "pink eye: Inflammation of the conjunctiva. Also called conjunctivitis.", "pinna: The part of the ear that’s projected outside of the head.", "pinworm: A parasite, Enterobius vermicularis, that can cause intense itching around the anus.", "pituitary gland: The gland that secretes hormones that influence body growth, metabolism and the function of other endocrine glands.", "pityriasis: A skin condition in which the skin forms thin, dry scales.", "placebo: A harmless substance that resembles a medicine; often used to test the effectiveness of medicines.", "A spongy structure that grows on the uterine wall during pregnancy and provides nutrition to the fetus.", "plague: 1. Any contagious epidemic disease that is deadly. 2. An infectious disease caused by Yersinia pestis that can be spread…", "plantar: Having to do with the sole of the foot.", "plasma: The fluid portion of the blood.", "platelet: A thrombocyte, the smallest of the formed components of blood, associated with blood clotting.", "pleura: The membrane surrounding the lungs and lining the walls of the chest cavity.", "pleurisy: Inflammation of the pleura.", "plexus: A network of nerves or veins.", "plumbism: Chronic lead poisoning.", "pneumoconiosis: Any of several lung diseases caused by inhaling particles of industrial substances.", "pneumonia: Acute inflammation or infection of the lungs.", "pneumothorax: The buildup of air or gas in the chest cavity. May cause lung collapse.", "podiatry: The branch of medicine that pertains to the foot and its ailments."]
       
    science1 = ["0/00 – The symbol for parts per thousand.", "Aa – A type of lave flow that has a jagged blocky surface.", "Ablation – A general term for the loss of ice and snow from a glacier", "Abrasion – The grinding and scraping of a rock surface by the friction and impact of rock particles carried by water, wind, or ice.", "Absolute Humidity – The weight of water vapor in a given volume of air (usually expressed in grams/m3", "Absolute instability - Air that has a lapse rate greater than the dry adiabatic rate.", "Absolute magnitude - The apparent brightness of a star if it were viewed from a distance of 10 parsecs (32.6 light-years). Used to compare the true brightness of stars.", "Absolute stability - Air with a lapse rate less than the wet adiabatic rate.", "Absorption Spectrum - A continuous spectrum with dark lines superimposed.", "Abyssal plain -  Very level area of the deep-ocean floor, usually lying at the foot of the continental rise", "Abyssal zone -  A subdivision of the benthic zone characterized by extremely high pressures, low temperatures, low oxygen, few nutrients, and no sunlight", "Accretionary wedge A large wedge-shaped mass of sediment that accumulates in subduction zones. Here sediment is scraped from the subducting oceanic plate and accreted to the overriding crustal block.", "Acid precipitation - Rain or snow with a pH value that is less than the pH of unpolluted (?)  precipitation", "Active continental margin - Usually narrow and consisting of highly deformed sediments. They occur where oceanic lithosphere is being subducted beneath the margin of a continent.", "Adiabatic temperature change - Cooling or warming of air caused when air is allowed to expand or is compressed, not because heat is added or subtracted.  Dry air changes at 10°C/1,000m, and wet air (condensation has begun) changes at 5-9°C/1,000m.", "Advection - Horizontal convective motion, such as wind.", "Advection fog - A fog formed when warm, moist air is blown over a cool surface.", " Aerosols - Tiny solid and liquid particles suspended in the atmosphere.", "Aftershocks  -  Smaller earthquakes that follow the main earthquake", "Air - A mixture of many discrete gases, of which nitrogen and oxygen are most abundant, in which varying quantities of tiny solid and liquid particles are suspended.", "Air mass - A large body of air that is characterized by a sameness of temperature and humidity.", "Air-mass weather - The conditions experienced in an area as an air mass passes over it. Because air masses are large and fairly homogenous, air-mass weather will be fairly constant and may last for several days.", "Air pollutants -  Airborne particles and gases that occur in concentrations that endanger the health and well-being of organisms or disrupt the orderly functioning of the environment.", "Air pressure - The force exerted by the weight of a column of air above a given point.", "Albedo - The reflectivity of a substance, usually expressed as a percentage of the incident radiation reflected.", "Alluvial fan - A fan-shaped deposit of sediment formed when a stream's slope is abruptly reduced.", "Alluvium -  Unconsolidated sediment deposited by a stream.", "Alpine glacier - A glacier confined to a mountain valley, which in most instances had previously been a stream valley.", "Altitude (of the Sun) - The angle of the Sun above the horizon.", "Andesitic composition - See Intermediate composition.", "Anemometer - An instrument used to determine wind speed.", "Aneroid barometer - An instrument for measuring air pressure that consists of evacuated metal chambers very sensitive to variations in air pressure.", "Angle of repose - The steepest angle at which loose material remains stationary without sliding downslope.", "Angular unconformity - An unconformity in which the strata below dip at an angle different from that of the beds above.", "Annual mean temperature - An average of the 12 monthly temperature means.", "Annual temperature - The difference between the highest and lowest monthly temperature means.", "Annual temperature range - ", "Antarctic Circle – The parallel of latitude at 66½° S.  It is the furthest latitude away from (north of) the South Pole that will receive 24 hours of Sunlight on the winter solstice (December 21).", "Anthracite -  A hard, metamorphic form of coal that burns clean and hot", "Anticline  -  A fold in sedimentary strata resembling an arch", "Anticyclone - A high-pressure center characterized by a clockwise flow of air in the Northern Hemisphere.", "Aphelion - The place in the orbit of a planet where the planet is farthest from the Sun.", "Aphotic zone - That portion of the ocean where there is no sunlight.", "Apparent magnitude - The brightness of a star when viewed from Earth.", "Aquifer -   Rock or soil through which groundwater moves easily", "Aquitard - Impermeable beds that hinder or prevent groundwater movement.", "Archean eon -  The second eon of Precambrian time, following the Hadean and preceding the Proterozoic. It extends between 3.8 billion and 2.5 billion years before the present.", "Arête - A narrow knifelike ridge separating two adjacent glaciated valleys.", "Arid - See Desert.", "Arid climate - See Dry climate.", "Arkose -  A feldspar-rich sandstone.", "Artesian well  -  A well in which the water rises above the level where it was initially encountered.", "Arctic Circle -  The parallel of latitude at 66½° N.  It is the furthest latitude away from (south of) the North Pole that will receive 24 hours of Sunlight on the summer solstice (June 21).", "Asteroids - Thousands of small planet like bodies, ranging in size from a few hundred kilometers to less than a kilometer, whose orbits lie mainly between those of Mars and Jupiter.", "Asthenosphere -  A subdivision of the mantle situated below the lithosphere. This zone of weak material exists below a depth of about 100 kilometers and in some regions extends as deep as 700 kilometers. The rock within this zone is easily deformed.", "Astronomical theory - A theory of climatic change first developed by the Yugoslavian astronomer Milankovitch. It is based upon changes in the shape of Earth's orbit, variations in the obliquity of Earth's axis, and the wobbling of Earth's axis.", "Astronomical Unit (AU) - Average distance from Earth to the Sun; 1.5 X 108 km, or 93 x 106 miles.", "Astronomy - The scientific study of the universe; it includes the observation and interpretation of celestial bodies and phenomena.", "Atmosphere - The gaseous portion of a planet; the planet's envelope of air. One of the traditional subdivisions of Earth's physical environment.", "Atmospheric instability – Exists when the environmental lapse rate is greater than the dry adiabatic rate.  This can occur when the air above is very cold.", "Atoll -  A continuous or broken ring of coral reef surrounding a central lagoon.", "Atom -  The smallest particle that exists as an element", "Atomic mass unit – A proton or neutron has a mass just slightly more than one atomic mass unit, whereas an electron is only about on two-thousandth of an atomic mass unit. (pg 34 of Earth Science 11e)", "Atomic number  -  The number of protons in the nucleus of an atom", "Atomic weight -  The average of the atomic masses of isotopes for a given element", "Aurora -  A bright display of ever-changing light caused by solar radiation interacting with the upper atmosphere in the region of the poles.", "Autumnal equinox -  The equinox that occurs on September 21-23 in the Northern Hemisphere and on March 21-22 in the Southern Hemisphere.", "Backshore - The inner portion of the shore, lying landward of the high-tide shoreline. It is usually dry, being affected by waves only during storms.", "Backshore - The inner portion of the shore, lying landward of the high-tide shoreline. It is usually dry, being affected by waves only during storms.", "Backswamp - A poorly drained area on a floodplain that results when natural levees are present.", "Basalt - A fine-grained igneous rock of mafic composition.", "Basaltic composition -  A compositional group of igneous rocks indicating that the rock contains substantial dark silicate minerals and calcium-rich plagioclase feldspar.", "Base level - The level below which a stream cannot erode.", "Basalt - A fine-grained igneous rock of mafic composition.", "Basaltic composition -  A compositional group of igneous rocks indicating that the rock contains substantial dark silicate minerals and calcium-rich plagioclase feldspar.", "Base level - The level below which a stream cannot erode.", "Basin - A circular downfolded structure.", "Batholith - A large mass of igneous rock that formed when magma was emplaced at depth, crystallized, and subsequently exposed by erosion.", "Bathymetry - The measurement of ocean depths and the charting of the shape or topography of the ocean floor.", "Baymouth bar - A sandbar that completely crosses a bay, sealing it off from the open ocean.", "Beach - An accumulation of sediment found along the landward margin of the ocean or a lake.", "Beach drift -  The transport of sediment in a zigzag pattern along a beach caused by the uprush of water from obliquely breaking waves.", "Beach face - The wet, sloping surface that extends from the berm to the shoreline.", "Beach nourishment - The process by which large quantities of sand are added to the beach system to offset losses caused by wave erosion.", "Bed load - Sediment that is carried by a stream along the bottom of its channel.", "Benioff zone - Zone of inclined seismic activity that extends from a trench downward into the asthenosphere.", "Benthic zone - The marine life zone that includes any sea bottom surface regardless of its distance from shore.", "Benthos - The forms of marine life that live on or in the ocean bottom.", "Bergeron process - A theory that relates the formation of precipitation to supercooled clouds, freezing nuclei, and the different saturation levels of ice and liquid water.", "Berm - The dry, gently sloping zone on the backshore of a beach at the foot of the coastal cliffs or dunes.", "Big Bang Theory - The theory that proposes that the universe originated as a single mass, which subsequently exploded.", "Binary stars - Two stars revolving around a common center of mass under their mutual gravitational attraction.", "Biogenous sediment - Seafloor sediments consisting of material of marine-organic origin.", "Biomass -  The total mass of a defined organism or group of organisms in a particular area or ecosystem.", "Biosphere - The totality of life on Earth; the parts of the solid Earth, hydrosphere, and atmosphere in which living organisms can be found.", "Bituminous -  The most common form of coal, often called soft, black coal.", "Black dwarf -  A final state of evolution for a star, in which all of its energy sources are exhausted and it no longer emits radiation.", "Black hole -  A massive star that has collapsed to such a small volume that its gravity prevents the escape of all radiation.", "Blowout (deflation hollow) -  A depression excavated by the wind in easily eroded deposits.", "Bode's law  -  A sequence of numbers that approximates the mean distances of the planets from the Sun.", "Body waves  -  Seismic waves that travel through Earth's interior.", "Bowen's reaction series  -  A concept proposed by N. L. Bowen that illustrates the relationships between magma and the minerals crystallizing from it during the formation of igneous rocks.", "Braided stream -  A stream consisting of numerous intertwining channels", "Breakwater  -  A structure protecting a nearshore area from breaking waves.", "Breccia -  A sedimentary rock composed of angular fragments that were lithified.", "Bright-line spectrum -  The bright lines produced by an incandescent gas under low pressure.", "Bright nebula -  A cloud of glowing gas excited by ultraviolet radiation from hot stars.", "Brittle failure (deformation) -  Deformation that involves the fracturing of rock. Associated with rocks near the surface.", "Cactolith -  A quasi-horizontal chonolith composed of anastomosing ductoliths, whose distal ends curl like a harpolith, thin like a sphenolith, or bulge discordantly like an akmolith or ethmolith.", "Caldera -  A large depression typically caused by collapse or ejection of the summit area of a volcano.", "Calorie -  The amount of heat required to raise the temperature of one gram of water 1°C.", "Calving  -  Wastage of a glacier that occurs when large pieces of ice break off into water.", "Capacity  -  The total amount of sediment a stream is able to transport", "Carbonate group -  Mineral group whose members contain the carbonate ion (CO2-2) and one or more kinds of positive ions. Calcite is a common example.", "Cassini division -  A wide gap in the ring system of Saturn between the A ring and the B ring.", "Catastrophism -  The concept that Earth was shaped by catastrophic events of a short-term nature.", "Cavern -  A naturally formed underground chamber or series of chambers most commonly produced by solution activity in limestone.", "Celestial sphere  -  An imaginary hollow sphere upon which the ancients believed the stars were hung and carried around Earth.", "Cenozoic era -  A span on the geologic time scale beginning about 65 million years ago following the Mesozoic era.", "Cepheid variable  -  A star whose brightness varies periodically because it expands and contracts. A type of pulsating star.", "CFC’s – Short for chlorofluorocarbons.  These are the compounds thought to be responsible for depleting the Earth’s ozone layer.  They were used for air conditioning, cleaning solvents, propellants for aerosol sprays, etc.", "Chemical sedimentary rock -  Sedimentary rock consisting of material that was precipitated from water by either inorganic or organic means.", "Chemical weathering -  The processes by which the internal structure of a mineral is altered by the removal and/or addition of elements.", "Chinook -   -  A wind blowing down the leeward side of a mountain and warming by compression.", "Chromatic aberration -  The property of a lens whereby light of different colors is focused at different places.", "Chromosphere -  The first layer of the solar atmosphere found directly above the photosphere.", "Cinder cone -  A rather small volcano built primarily of pyroclastics ejected from a single vent.", "Circle of illumination -  The great circle that separates daylight from darkness.", "Cirque -  An amphitheater-shaped basin at the head of a glaciated valley produced by frost wedging and plucking.", "Cirrus -  One of three basic cloud forms; also one of the three high cloud types. They are thin, delicate ice-crystal clouds often appearing as veil-like patches or thin, wispy fibers.", "Clastic rock -  A sedimentary rock made of broken fragments of preexisting rock.", "Cleavage -  The tendency of a mineral to break along planes of weak bonding.", "Climate  -  A description of aggregate weather conditions; the sum of all statistical weather information that helps describe a place or region.", "Climate system -  The exchanges of energy and moisture that occur among the atmosphere, hydrosphere, solid Earth, biosphere, and cryosphere.", "Climate-feedback mechanism -  Because the atmosphere is a complex interactive physical system, several different possible outcomes may result when one of the system's elements is altered. These various possibilities are called climate feedback mechanisms", "Climatology -  The scientific study of climate.", "Closed system -  A system that is self contained with regards to matter—that is, no matter enters or leaves.", "Cloud -  A form of condensation best described as a dense concentration of suspended water droplets or tiny ice crystals.", "Clouds of vertical development -  A cloud that has its base in the low-height range but extends upward into the middle or high altitudes.", "Cluster (star) -  A large group of stars.", "Coarse-grained texture -  An igneous rock texture in which the crystals are roughly equal in size and large enougl so that individual minerals can be identified with the unaided eye", "Coast -  A strip of land that extends inland from the coastline as far as ocean-related features can be found.",\
                 "Coastline -  The coast's seaward edge. The landward limit of the effect of the highest storm waves on the shore.", "Col -  A pass between mountain valleys where the headwalls of two cirques intersect.", "Cold front -  A front along which a cold air mass thrusts beneath a warmer air mass.", "Collision-coalescence process -  A theory of raindrop formation in warm clouds (above 0°C) in which large cloud droplets (giants) collide and join together with smaller droplets to form a raindrop. Opposite electrical charges may bind the cloud droplets together.", "Column -  A feature found in caves that is formed when a stalactite and stalagmite join.", "Columnar joints -  A pattern of cracks that form during cooling of molten rock to generate columns that are generally six-sided.", "Coma -  The fuzzy, gaseous component of a comet's head.", "Comet -  A small body that generally revolves about the Sun in an elongated orbit.", "Competence -  A measure of the largest particle a stream can transport; a factor dependent on velocity.", "Composite cone -  Composite cone A volcano composed of both lava flows and pyroclastic material.", "Compound -  A substance formed by the chemical combination of two or more elements in definite proportions and usually having properties different from those of its constituent elements.", "Condensation -  The change of state from a gas to a liquid.", "Condensation nuclei -  Tiny bits of particulate matter that serve as surfaces on which water vapor condenses.", "Conditional instability -  Moist air with a lapse rate between the dry and wet adiabatic rates.", "Conduction -  The transfer of heat through matter by molecular activity. Energy is transferred through collisions from one molecule to another.", "Conduit -  A pipe-like opening through which magma moves toward Earth's surface. It terminates at a surface opening called a vent.", "Cone of depression -  A cone-shaped depression in the water table immediately surrounding a well.", "Conformable -  Layers of rock that were deposited without interruption.", "Conglomerate -  A sedimentary rock composed of rounded gravel-size particles.", "Constellation -  An apparent group of stars originally named for mythical characters. The sky is presently divided into 88 constellations.", "Contact metamorphism -  Changes in rock caused by the heat from a nearby magma body.", " Continental (c)  air mass  - An air mass that forms over land; it is normally relatively dry.", "Continental drift theory -  A theory that originally proposed that the continents are rafted about. It has essentially been replaced by the plate tectonics theory.", "Continental margin -  That portion of the seafloor adjacent to the continents. It may include the continental shelf, continental slope, and continental rise.", "Continental rise -  The gently sloping surface at the base of the continental slope.", "Continental shelf -  The gently sloping submerged portion of the continental margin, extending from the shoreline to the continental slope.", "Continental slope -  The steep gradient that leads to the deep-ocean floor and marks the seaward edge of the continental shelf.", "Continental volcanic arc -  Mountains formed in part by igneous activity associated with the subduction of oceanic lithosphere beneath a continent.", "Continuous spectrum -  An uninterrupted band of light emitted by an incandescent solid, liquid, or gas under pressure.", "Convection -  The transfer of heat by the movement of a mass or substance. It can take place only in fluids.", "Convergence -  The condition that exists when the distribution of winds within a given area results in a net horizontal inflow of air into the area. Because convergence at lower levels is associated with an upward movement of air, areas of convergent winds are regions favorable to cloud formation and precipitation.", "Convergent plate boundary -  A boundary in which two plates move together, causing one of the slabs of lithosphere to be consumed into the mantle as it descends beneath on an overriding plate.", "Coral reef -  Structure formed in a warm, shallow, sunlit ocean environment that consists primarily of the calcite-rich remains of corals as well as the limy secretions of algae and the hard parts of many other small organisms.", "Core - Located beneath the mantle, it is the innermost layer of Earth. The core is divided into an outer core and an inner core.", "Coriolis force (effect) -  The deflective force of Earth's rotation on all free-moving objects, including the atmosphere and oceans. Deflection is to the right in the Northern Hemisphere and to the left in the Southern Hemisphere.", "Corona -  The outer, tenuous layer of the solar atmosphere.", "Correlation -  Establishing the equivalence of rocks of similar age in different areas.", "Covalent bond -  A chemical bond produced by the sharing of electrons.", "Crater -  The depression at the summit of a volcano, or that which is produced by a meteorite impact.", "Creep -  The slow downhill movement of soil and regolith.", "Crevasse -  A deep crack in the brittle surface of a glacier.", "Cross-bedding -  Structure in which relatively thin layers are inclined at an angle to the main bedding. Formed by currents of wind or water.", "Cross-cutting -  A principle of relative dating. A rock or fault is younger than any rock (or fault) through which it cuts.", "Crust -  The very thin outermost layer of Earth.", "Crystal -  An orderly arrangement of atoms.", "Crystal form -  The external appearance of a mineral as determined by its internal arrangement of atoms. Crystallization", "Crystallization -  The formation and growth of a crystalline solid from a liquid or gas.", "Crystal settling -  During the crystallization of magma, the earlier-formed minerals are denser than the liquid portion and settle to the bottom of the magma chamber.", "Cumulus One of three basic cloud forms; also the name given one of the clouds of vertical development. Cumulus are billowy individual cloud masses that often have flat bases.-  ", "Cup anemometer  -  See Anemometer.", "Curie point -  The temperature above which a material loses its magnetization.", "Cutoff -  A short channel segment created when a river erodes through the narrow neck of land between meanders.", "Cyclone -  A low-pressure center characterized by a counterclockwise flow of air in the Northern Hemisphere.", "Daily mean -  The mean temperature for a day that is determined by averaging the 24 hourly readings or, more commonly, by averaging the maximum and minimum temperatures for a day.", "Daily temperature range -  The difference between the maximum and minimum temperatures for a day.", "Dark-line spectrum  -  See Absorption spectrum.", "Dark nebula -  A cloud of interstellar dust that obscures the light of more distant stars and appears as an opaque curtain.", "Daughter product -  An isotope resulting from radioactive decay.", "Debris flow -  A relatively rapid type of mass wasting that involves a flow of soil and regolith containing a large amount of water. Also called mudflows.", "Declination (stellar) -  The angular distance north or south of the celestial equator denoting the position of a celestial body.", "Decompression melting -  Melting that occurs as rock ascends due to a drop in confining pressure.", "Deep-ocean basin -  The portion of seafloor that lies between the continental margin and the oceanic ridge system. This region comprises almost 30 percent of Earth's surface.", "Deep-ocean trench  -  See Trench.", "Deep-sea fan -  A cone-shaped deposit at the base of the continental slope. The sediment is transported to the fan by turbidity currents that follow submarine canyons.", "Deflation -  The lifting and removal of loose material by wind.", "Deformation -  General term for the processes of folding, faulting, shearing, compression, or extension of rocks as the result of various natural forces.", "Delta -  An accumulation of sediment formed where a stream enters a lake or ocean.", "Dendritic pattern -  A stream system that resembles the pattern of a branching tree.", "Density -  Mass per unit volume of a substance, usually expressed as grams per cubic centimeter (g/cm3).", "Deposition -  The process by which water vapor is changed directly to a solid without passing through the liquid state.", "Desalination -  The removal of salts and other chemicals from seawater.", "Desert -  One of the two types of dry climate; the driest of the dry climates.", "Desert pavement -  A layer of coarse pebbles and gravel created when wind removed the finer material.", "Detrital sedimentary rock -  Rock formed from the accumulation of material that originated and was transported in the form of solid particles derived from both mechanical and chemical weathering.", "Dew-point temperature -  The temperature to which air has to be cooled in order to reach saturation.", "Differential weathering -  The variation in the rate and degree of weathering caused by such factors as mineral makeup, degree of jointing, and climate.", "Diffused light -  Solar energy scattered and reflected in the atmosphere that reaches Earth's surface in the form of diffuse blue light from the sky.", "Dike -  A tabular-shaped intrusive igneous feature that cuts through the surrounding rock.", "Dip-slip fault -  A fault in which the movement is parallel to the dip of the fault.", "Discharge -  The quantity of water in a stream that passes a given point in a period of time.", "Disconformity -  A type of unconformity in which the beds above and below are parallel.", "Disseminated deposit – Any economic mineral deposit in which the desired mineral occurs as scattered particles in the rock but in sufficient quantity to make the deposit an ore.", "Dissolved load -  That portion of a stream's load carried in solution.", "Distributary -  A section of a stream that leaves the main flow.", "Diurnal tidal pattern -  A tidal pattern exhibiting one high tide and one low tide during a tidal day; a daily tide.", "Divergence -  The condition that exists when the distribution of winds within a given area results in a net horizontal outflow of air from the region. In divergence at lower levels the resulting deficit is compensated for by a downward movement of air from aloft; hence, areas of divergent winds are unfavorable to cloud formation and precipitation.", "Divergent plate boundary -  A region where the rigid plates are moving apart, typified by the mid-oceanic ridges.", "Divide -  An imaginary line that separates the drainage of two streams; often found along a ridge.", "Dome -  A roughly circular upfolded structure similar to an anticline.", "Doppler effect -  The apparent change in wavelength of radiation caused by the relative motions of the source and the observer.", "Doppler radar -  In addition to the tasks performed by conventional radar, this new generation of weather radar can detect motion directly and hence greatly improve tornado and severe storm warnings.", "Drainage basin -  The land area that contributes water to a stream", "Drawdown -  The difference in height between the bottom of a cone of depression and the original height of the water table.", "Drift  -  see Glacial drift.", "Drumlin -  A streamlined asymmetrical hill composed of glacial till. The steep side of the hill faces the direction from which the ice advanced.", "Dry adiabatic rate -  The rate of adiabatic cooling or warming in unsaturated air. The rate of temperature change is 1°C per 100 meters.", "Dry climate -  A climate in which yearly precipitation is not as great as the potential loss of water by evaporation", "Dry-summer subtropical climate -  A climate located on the west sides of continents between latitudes 300 and 45°. It is the only humid climate with a strong winter precipitation maximum.", "Ductile deformation -  A type of solid state flow that produces a change in the size and shape of a rock body without fracturing. Occurs at depths where temperatures and confining pressures are high.", "Dune -  A hill or ridge of wind-deposited sand.", "Earthflow -  The downslope movement of water-saturated, clay-rich sediment. Most characteristic of humid regions.", "Earthquake -  The vibration of Earth produced by the rapid release of energy.", "Earth science -  The name for all the sciences that collectively seek to understand Earth. It includes geology, oceanography, meteorology, and astronomy.", "Earth system science -  An interdisciplinary study that seeks to examine Earth as a system composed of numerous interacting parts or subsystems.", "Ebb current -  The movement of a tidal current away from the shore.", "Eccentricity -  The variation of an ellipse from a circle.", "Echo sounder -  An instrument used to determine the depth of water by measuring the time interval between emission of a sound signal and the return of its echo from the bottom.", "Eclipse -  The cutting off of the light of one celestial body by another passing in front of it.", "Ecliptic -  The yearly path of the Sun plotted against the background of stars.", "Elastic rebound -  The sudden release of stored strain in rocks that results in movement along a fault.", "Electromagnetic radiation -  See Radiation.", "Electromagnetic spectrum -  The distribution of electromagnetic radiation by wavelength.", "Electron -  A negatively charged subatomic particle that has a negligible mass and is found outside an atom's nucleus. A proton or neutron has a mass just slightly more than one atomic mass unit, whereas an electron is only about on two-thousandth of an atomic mass unit. (pg 34, Earth Science 11e)", "Element -  A substance that cannot be decomposed into simpler substances by ordinary chemical or physical means.", "Elements of weather and climate -  Those quantities or properties of the atmosphere that are measured regularly and that are used to express the nature of weather and climate.", "Elliptical galaxy -  A galaxy that is round or elliptical in outline. It contains little gas and dust, no disk or spiral arms, and few hot, bright stars.", "El Nino -  The name given to the periodic warming of the ocean that occurs in the central and eastern Pacific. A major El Nino episode can cause extreme weather in many parts of the world.", "Eluviation -  The washing out of fine soil components from the A horizon by downward-percolating water", "Emergent coast -  A coast where land that was formerly below sea level has been exposed either because of crustal uplift or a drop in sea level or both.", "Emission nebula -  A gaseous nebula that derives its visible light from the fluorescence of ultraviolet light from a star in or near the nebula.", " End moraine -  A ridge of till marking a former position of the front of a glacier.", "Energy -  The capacity to do work.", "Energy levels -  Spherically shaped negatively charged zones that surround the nucleus of an atom.", "Environment -  Everything that surrounds and influences an organism. Environmental lapse rate The rate of temperature decrease with increasing height in the troposphere.", "Environmental lapse rate – (see also “lapse rate”) The actual (observed as opposed to calculated) decrease in temperature with an increase in altitude through the troposphere.", "Eon -  The largest time unit on the geologic time scale, next in order of magnitude above era.", "Ephemeral stream - A stream that is usually dry because it carries water only in response to specific episodes of rainfall. Most desert streams are of this type.", "Epicenter -   The location on Earth's surface that lies directly above the focus of an earthquake.", "Epoch -  A unit of the geologic calendar that is a subdivision of a period.", "Equatorial low -  A belt of low pressure lying near the equator and between the subtropical highs.", "Equatorial system -  A method of locating stellar objects much like the coordinate system used on Earth's surface.", "Equinox -  The time when the vertical rays of the Sun are striking the equator. The length of daylight and darkness is equal at all latitudes at equinox.", "Era -  A major division on the geologic calendar; eras are divided into shorter units called periods.", "Erosion -  The incorporation and transportation of material by a mobile agent, such as water, wind, or ice.", "Eruptive variable - A star that varies in brightness.",\
                  "Escape velocity - The initial velocity an object needs to escape from the surface of a celestial body.", "Esker -  Sinuous ridge composed largely of sand and gravel deposited by a stream flowing in a tunnel beneath a glacier near its terminus.", "Estuary -  A partially enclosed coastal water body that is connected to the ocean. Salinity here is measurably reduced by the freshwater flow of rivers.", "Euphotic zone -  The portion of the photic zone near the surface, where light is bright enough for photosynthesis to occur.", "Evaporation -  The process of converting a liquid to a gas.", "Evaporite -  A sedimentary rock formed of material deposited from solution by evaporation of the water.", "Evapotranspiration -  The combined effect of evaporation and transpiration.", "Evolution, (Theory of) -  A fundamental theory in biology and paleontology that sets forth the process by which members of a population of organisms come to differ from their ancestors. Organisms evolve by means of mutations, natural selection, and genetic factors. Modern species are descended from related but different species that lived in earlier times.", "Exfoliation dome -  Large, dome-shaped structure, usually composed of granite, formed by sheeting.", "Exotic stream -  A permanent stream that traverses a desert and has its source in well-watered areas outside the desert.", "External process -  Process such as weathering, mass wasting or erosion that is powered by the Sun and transforms solid rock into sediment.", "Extrusive -  Igneous activity that occurs outside the crust.", "Eye -  A zone of scattered clouds and calm averaging about 20 kilometers in diameter at the center of a hurricane.", "Eyepiece -  A short-focal-length lens used to enlarge the image in a telescope. The lens nearest the eye.", "Eye wall -  The doughnut-shaped area of intense cumulonimbus development and very strong winds that surrounds the eye of a hurricane.", "Fall -  A type of movement common to mass-wasting processes that refers to the free falling of detached individual pieces of any size.", "Fault -  A break in a rock mass along which movement has occurred.", "Fault-block mountain -  A mountain formed by the displacement of rock along a fault.", "Fault creep -  Displacement along a fault that is so slow and gradual that little seismic activity occurs.", "Fault scarp -  A cliff created by movement along a fault. It represents the exposed surface of the fault prior to modification by weathering and erosion.", "Felsic -  The group of igneous rocks composed primarily of feldspar and quartz.", "Fetch -  The distance that the wind has traveled across the open water. Filaments Dark, thin streaks that appear across the bright solar disk.", "Fine-grained texture – A texture of igneous rocks in which the crystals are too small for individual minerals to be distinguished with the unaided eye.", "Fiord -  A steep-sided inlet of the sea formed when a glacial trough was partially submerged.", "Fissure eruption -  An eruption in which lava is extruded from narrow fractures or cracks in the crust.", "Flare -  A sudden brightening of an area on the Sun.", "Flood basalts -  Flows of basaltic lava that issue from numerous cracks or fissures and commonly cover extensive areas to thicknesses of hundreds of meters.", "Flood current -  The tidal current associated with the increase in the height of the tide.", "Floodplain -  The flat, low-lying portion of a stream valley subject to periodic inundation.", "Flow -  A type of movement common to mass-wasting processes in which water-saturated material moves downslope as a viscous fluid.", "Fluorescence -  The absorption of ultraviolet light, which is reemitted as visible light.", "Focal length -  The distance from the lens to the point where it focuses parallel rays of light.", "Focus (earthquake) -  The zone within Earth where rock displacement produces an earthquake.", "Focus (light) -  The point where a lens or mirror causes light rays to converge", "Fog -  A cloud with its base at or very near Earth's surface.", "Fold -  A bent rock layer or series of layers that were originally horizontal and subsequently deformed.", "Foliated -  A texture of metamorphic rocks that gives the rock a layered appearance.", "Food chain -  A succession of organisms in an ecological community through which food energy is transferred from producers through herbivores and on to one or more carnivores.", "Food web -  A group of interrelated food chains.", "Foreshocks -  Small earthquakes that often precede a major earthquake.", "Foreshore -  That portion of the shore lying between the normal high and low water marks; the intertidal zone.", "Fossil fuel -  General term for any hydrocarbon that may be used as a fuel, including coal, oil, and natural gas.", "Fossils -  The remains or traces of organisms preserved from the geologic past.", "Fossil succession -  Fossil organisms that succeed one another in a definite and determinable order, and any time period can be recognized by its fossil content.", "Fracture -  Any break or rupture in rock along which no appreciable movement has taken place.", "Freezing -  The change of state from a liquid to a solid.", "Freezing nuclei -  Solid particles that serve as cores for the formation of ice crystals.", "Fringing reef – A coral reef formed close to the shoreline of an island or continent. Fringing reefs usually have a rough, table-like surface that is exposed during low tide and a steep edge sloping toward the open water.", "Front -  The boundary between two adjoining air masses having contrasting characteristics.", "Frontal fog -  Fog formed when rain evaporates as it falls through a layer of cool air.", "Frontal wedging -  Lifting of air resulting when cool air acts as a barrier over which warmer, lighter air will rise.", "Frost wedging -  The mechanical breakup of rock caused by the expansion of freezing water in cracks and crevices.", "Fumarole -  A vent in a volcanic area from which fumes or gases escape.", "Galactic cluster -  A system of galaxies containing from several to thousands of member galaxies.", "Geocentric -  The concept of an Earth-centered universe.", "Geologic time scale -  The division of Earth history into blocks of time—eons, eras, periods, and epochs. The time scale was created using relative dating principles.", "Geology -  The science that examines Earth, its form and composition, and the changes it has undergone and is undergoing.", "Geosphere -  The solid Earth, the largest of Earth's four major spheres.", "Geostrophic wind -  A wind, usually above a height of 600 meters (2000 feet), that blows parallel to the isobars. Geothermal energy Natural steam used for power generation.", "Geothermal gradient -  The gradual increase in temperature with depth in the crust. The average is 30°C per kilometer in the upper crust.", "Geyser -  A fountain of hot water ejected periodically.", "Giant (star) -  A luminous star of large radius.", "Glacial drift -  An all-embracing term for sediments of glacial origin, no matter how, where, or in what shape they were deposited.", "Glacial erratic -  An ice-transported boulder that was not derived from bedrock near its present site.", "Glacial striations -  Scratches and grooves on bedrock caused by glacial abrasion.", "Glacial trough -  A mountain valley that has been widened, deepened, and straightened by a glacier.", "Glacier -  A thick mass of ice originating on land from the compaction and recrystallization of snow that shows evidence of past or present flow.", "Glassy -  A term used to describe the texture of certain igneous rocks, such as obsidian, that contain no crystals.", "Glaze -  A coating of ice on objects formed when supercooled rain freezes on contact.", "Globular cluster -  A nearly spherically shaped group of densely packed stars.", "Globule - A dense, dark nebula thought to be the birthplace of stars.", "Gondwanaland -  The southern portion of Pangaea consisting of South America, Africa, Australia, India, and Antarctica", "Graben -  A valley formed by the downward displacement of a fault‑bounded block.", "Graded bed -  A sediment layer that is characterized by a decrease in sediment size from bottom to top.", "Gradient -  The slope of a stream; generally measured in feet per mile.", "Granitic composition A compositional group of igneous rocks that indicates a rock is composed almost entirely of light-colored silicates.", "Granules - The fine structure visible on the solar surface caused by convective cells below.", "Gravitational collapse - The gradual subsidence of mountains caused by lateral spreading of weak material located deep within these structures. -  ", " Greenhouse effect - The transmission of short-wave solar radiation by the atmosphere, coupled with the selective absorption of longer-wavelength terrestrial radiation, especially by water vapor and carbon dioxide.", "Groin - A short wall built at a right angle to the shore to trap moving sand.", "Ground moraine - An undulating layer of till deposited as the ice front retreats.", "Groundwater -  Water in the zone of saturation", "Guyot - A submerged flat-topped seamount.", "Gyre - The large circular surface current pattern found in each ocean.", "Habit – I think this is geology talk for the crystal shape of a mineral.", "Hadean eon - The first eon on the geologic time scale; this eon ended 3.8 billion years ago and preceded the Archean eon.", "Hail - Nearly spherical ice pellets having concentric layers and formed by the successive freezing of layers of water.", "Half-life - The time required for one half of the atoms of a radioactive substance to decay.", "Halocline - A layer of water in which there is a high rate of change in salinity in the vertical dimension.", "Hanging valley - A tributary valley that enters a glacial trough at a considerable height above its floor.", "Hardness - The resistance a mineral offers to scratching.", "Hard stabilization - Any form of artificial structure built to protect a coast or to prevent the movement of sand along a beach. Examples include groins, jetties, breakwaters, and seawalls.", "Heliocentric - The view that the Sun is at the center of the solar system.", "Heat - The kinetic energy of random molecular motion.", "Hertzsprung-Russell diagram See H-R diagram.", "High - A center of high pressure characterized by anticyclonic winds.", "High cloud - A cloud that normally has its base above 6000 meters; the base may be lower in winter and at high-latitude locations.", "Highland climate - Complex pattern of climate conditions associated with mountains. Highland climates are characterized by large differences that occur over short distances.", "Hogback - A narrow, sharp-crested ridge formed by the upturned edge of a steeply dipping bed of resistant rock.", "Horizon - A layer in a soil profile.", "Horn -  A pyramid-like peak formed by glacial action in three or more cirques surrounding a mountain summit", "Horst - An elongate, uplifted block of crust bounded by faults.", "Hot spot - A concentration of heat in the mantle capable of producing magma, which in turn extrudes onto Earth's surface. The intraplate volcanism that produced the Hawaiian Islands is one example.", "Hot spring - A spring in which the water is 6-9°C (10-15°F) warmer than the mean annual air temperature of its locality.", "H-R diagram - A plot of stars according to their absolute magnitudes and spectral types.", "Hubble's law - Relates the distance to a galaxy and its velocity.", "Humid continental climate - A relatively severe climate characteristic of broad continents in the middle latitudes between approximately 40 and 50 degrees north latitude. This climate is not found in the Southern Hemisphere, where the middle latitudes are dominated by the oceans.", "Humidity - A general term referring to water vapor in the air but not to liquid droplets of fog, cloud, or rain.", " Humid subtropical climate - A climate generally located on the eastern side of a continent and characterized by hot, sultry summers and cool winters.", "Humus - Organic matter in soil produced by the decomposition of plants and animals.", "Hurricane - A tropical cyclonic storm having winds in excess of 119 kilometers (74 miles) per hour.", "Hydrogen burning - The conversion of hydrogen through fusion to form helium.", "Hydrogenous sediment - Seafloor sediments consisting of minerals that crystallize from seawater. An important example is manganese nodules.", "Hydrosphere - The water portion of our planet; one of the traditional subdivisions of Earth's physical environment.", "Hydrothermal solution - The hot, watery solution that escapes from a mass of magma during the later stages of crystallization. Such solutions may alter the surrounding country rock and are frequently the source of significant ore deposits.", "Hygrometer - An instrument designed to measure relative humidity.", "Hygroscopic nuclei - Condensation nuclei having a high affinity for water, such as salt particles.", "Hypothesis - A tentative explanation that is tested to determine if it is valid.", "Ice cap - Amass of glacial ice covering a high upland or plateau and spreading out radially.", "Ice cap climate - A climate that has no monthly means above freezing and supports no vegetative cover except in a few scattered high mountain areas. This climate, with its perpetual ice and snow, is confined largely to the ice sheets of Greenland and Antarctica.", "Ice sheet - A very large, thick mass of glacial ice flowing outward in all directions from one or more accumulation centers.", " Igneous rock - A rock formed by the crystallization of molten magma.", "Immature soil - A soil lacking horizons.", "Incised meander - Meandering channel that flows in a steep, narrow valley. They form either when an area is uplifted or when base level drops.", "Inclination of the axis - The tilt of Earth's axis from the perpendicular to the plane of Earth's orbit.", "Inclusion - A piece of one rock unit contained within another. Inclusions are used in relative dating. The rock mass adjacent to the one containing the inclusion must have been there first in order to provide the fragment", "Index fossil - A fossil that is associated with a particular span of geologic time.", " Inertia - A property of matter that resists a change in its motion.", " Infiltration - The movement of surface water into rock or soil through cracks and pore spaces.", "Infrared - Radiation with a wavelength from 0.7 to 200 micrometers.", "Inner core - The solid innermost layer of Earth, about 1300 kilometers (800 miles) in radius.", "Inner planets See Terrestrial planets. -  ", " Inselberg - An isolated mountain remnant characteristic of the late stage of erosion in an arid region.", "Intensity (earthquake) - A measure of the degree of earthquake shaking at a given locale based on the amount of damage.", "Interface - A common boundary where different parts of a system interact (ES11e, pg 23).", " Interior drainage - A discontinuous pattern of intermittent streams that do not flow to the ocean.", "Intermediate composition - The composition of igneous rocks lying between felsic and mafic.", "Interstellar matter - Dust and gases found between stars.", "Intertidal zone - The area where land and sea meet and overlap; the zone between high and low tides.", " Intraplate volcanism - Igneous activity that occurs within a tectonic plate away from plate boundaries.", "Intrusive rock - Igneous rock that formed below Earth's surface.", "Ion -  An atom or molecule that possesses an electrical charge.", "Ionic bond - A chemical bond between two oppositely charged ions formed by the transfer of valence electrons from one atom to the other.", " Ionosphere - A complex zone of ionized gases that coincides with the lower portion of the thermosphere.", "Iron meteorite - One of the three main categories of meteorites. This group is composed largely of iron with varying amounts of nickel (5-20 percent). Most meteorite finds are irons.", "Irregular galaxy -  A galaxy that lacks symmetry", "Island arc See Volcanic island arc. -  ", " Isobar - A line drawn on a map connecting points of equal atmospheric pressure, usually corrected to sea level.", "Isostacy -  The concept that Earth's crust is floating in gravitational balance upon the material of the mantle"\
                  , "Isotherms - Lines connecting points of equal temperature.", "Isotopes - Varieties of the same element that have different mass numbers; their nuclei contain the same number of protons but different numbers of neutrons.", "Jet stream - Swift (120--240 kilometers per hour), high-altitude winds.", "Jetties - A pair of structures extending into the ocean at the entrance to a harbor or river that are built for the purpose of protecting against storm waves and sediment deposition.", "Joint - A fracture in rock along which there has been no movement.", "Jovian planet - The Jupiter-like planets: Jupiter, Saturn, Uranus, and Neptune. These planets have relatively low densities.", "Kame - A steep-sided hill composed of sand and gravel originating when sediment is collected in openings in stagnant glacial ice.", " Karst -  A topography consisting of numerous depressions called sinkholes", "Kettle holes - Depressions created when blocks of ice became lodged in glacial deposits and subsequently melted.", "Koppen classification -  A system for classifying climates devised by Wladimir Koppen that is based on mean monthly and annual values of temperature and precipitation.", "Kuiper belt - A region outside the orbit of Neptune where most short-period comets are thought to originate.", "Laccolith - A massive igneous body intruded between preexisting strata.", "lahar -  Mud flows on the slopes of volcanoes that result when unstable layers of ash and debris become saturated", "Lake-effect snow -  Snow showers associated with a cP air mass to which moisture and heat ate added from below as the air mass traverses a large and relatively warm lake (such as on of the Great Lakes), rendering the air mass humid and unstable.", "Laminar flow - The movement of water particles in straight-line paths that are parallel to the channel. The water particles move downstream without mixing.", "Land breeze - A local wind blowing from land toward the water during the night in coastal areas.", "La Niña - An episode of strong trade winds and unusually low sea-surface temperatures in the central and eastern Pacific. The opposite of El Nino.", "Lapse rate (normal - The average drop in temperature (6.5°C per kilometer; 3.5°F per 1000 feet) with increased altitude in the troposphere.", "Latent heat - The energy absorbed or released during a change in state.", "Lateral maraine - A ridge of till along the sides of an alpine glacier composed primarily of debris that fell to the glacier from the valley walls.", "Laurasia - The northern portion of Pangaea consisting of North America and Eurasia.", "Lava - Magma that reaches Earth's surface.", "Law of conservation of angular momentum -  The product of the velocity of an object around a center of rotation (axis), and the distance squared of the object from the axis is constant.", "Leaching - The depletion of soluble materials from the upper soil by downward-percolating water.", "Lightning - A sudden flash of light generated by the flow of electrons between oppositely charged parts of a cumulonimbus cloud or between the cloud and the ground.", "Light-year - The distance light travels in a year; about 6 trillion miles.", "Liquefaction - A phenomenon, sometimes associated with earthquakes, in which soils and other unconsolidated materials containing abundant water are turned into a fluid-like mass that is not capable of supporting buildings.", "Lithification - The process, generally cementation and/or compaction, of converting sediments to solid rock.", "Lithosphere - The rigid outer layer of Earth, including the crust and upper mantle.", "Local group - The cluster of 20 or so galaxies to which our galaxy belongs.", "Localized convective lifting - Unequal surface heating that causes localized pockets of air (thermals) to rise because of their buoyancy.", "Loess - Deposits of windblown silt, lacking visible layers, generally buff-colored, and capable of maintaining a nearly vertical cliff.", "Longitudinal (seif dunes) - Long ridges of sand oriented parallel to the prevailing wind; these dunes form where sand supplies are limited.", "Longshore current -  A near-shore current that flows parallel to the shore", "Low - A center of low pressure characterized by cyclonic winds.", "Low cloud - A cloud that forms below a height of 2000 meters.", "Lower mantle - The part of the mantle that extends from the core-mantle boundary to a depth of 660 kilometers.", "Low-velocity zone - See Asthenosphere.", "Luminosity - The brightness of a star. The amount of energy radiated by a star.", "Lunar breccia - A lunar rock formed when angular fragments and dust are welded together by the heat generated by the impact of a meteoroid.", "Lunar eclipse - An eclipse of the Moon.", "Lunar highlands - See Terrae.", "Lunar regolith -  A thin, gray layer on the surface of the Moon, consisting of loosely compacted, fragmented material believed to have been formed by repeated meteoritic impacts.", "Luster - The appearance or quality of light reflected from the surface of a mineral.", "Mafic - Igneous rocks with a low silica content and a high iron-magnesium content.", "Magma -  A body of molten rock found at depth, including any dissolved gases and crystals.", "Magmatic differentiation - The process of generating more than one rock type from a single magma.", " Magnitude (earthquake) - The total amount of energy released during an earthquake.", "Magnitude (stellar) - A number given to a celestial object to express its relative brightness.", "Main sequence - A sequence of stars on the Hertzsprung-Russell diagram, containing the majority of stars, that runs diagonally from the upper left to the lower right.", "Maganese nodules -  Rounded lumps of hydrogenous sediment scattered on the ocean floor, consisting mainly of manganese and iron and usually containing small amounts of copper, nickel, and cobalt.", "Mantle - The 2900-kilometer (1800mile)-thick layer of Earth located below the crust.", "Mantle convection - is the slow creeping motion of Earth's rocky mantle in response to perpetual gravitationally unstable variations in its density. This is likely caused by differential heating of mantle material by the core.", "Mantle plume - A mass of hotter-than-normal mantle material that ascends toward the surface, where it may lead to igneous activity. These plumes of solid yet mobile material may originate as deep as the core-mantle boundary.", "Maria - The Latin name for the smooth areas of the Moon formerly thought to be seas.", "Marine terrace -  A wave-cut platform that has been exposed above sea level.", "Marine west coast climate -  A climate found on windward coasts from latitudes 40 to 65 degrees and dominated by maritime air masses. Winters are mild, and summers are cool.", "Maritime (m) air mass -  An air mass that originates over the ocean. These air masses are relatively humid.", "Mass number - The number of neutrons and protons in the nucleus of an atom.", "Mass wasting - The downslope movement of rock, regolith, and soil under the direct influence of gravity.", "Meander - A loop-like bend in the course of a stream.", "Mean solar day - The average time between two passages of the Sun across the local celestial meridian.", "Mechanical weathering - The physical disintegration of rock, resulting in smaller fragments.", "Medial moraine - A ridge of till formed when lateral moraines from two coalescing alpine glaciers join.", "Melt - The liquid portion of magma, excluding the solid crystals.", "Melting - The change of state from a solid to a liquid.", "Mercalli intensity scale See Modified Mercalli intensity scale.", "Mercury barometer - A mercury-filled glass tube in which the height of the mercury column is a measure of air pressure.", "Mesocyclone - An intense, rotating wind system in the lower part of a thunderstorm that precedes tornado development.", " Mesopause - The boundary between the mesosphere and the thermosphere.", "Mesosphere - The layer of the atmosphere immediately above the stratosphere and characterized by decreasing temperatures with height.", "Mesozoic era - A span on the geologic time scale between the Paleozoic and Cenozoic eras from about 248 million to 65 million years ago.", "Metamorphic rock - Rocks formed by the alteration of preexisting rock deep within Earth (but still in the solid state) by heat, pressure, and/or chemically active fluids.", "Metamorphism - The changes in mineral composition and texture of a rock subjected to high temperature and pressure within Earth.", "Meteor - The luminous phenomenon observed when a meteoroid enters Earth's atmosphere and burns up; popularly called a 'shooting star.'", "Meteorite -  Any portion of a meteoroid that survives its traverse through Earth's atmosphere and strikes Earth's surface", " Meteoroid - Small solid particles that have orbits in the solar system.", "Meteorology - The scientific study of the atmosphere and atmospheric phenomena; the study of weather and climate.", "Meteor shower - Many meteors appearing in the sky caused when Earth intercepts a swarm of meteoritic particles.", "Middle cloud - A cloud occupying the height range from 2000 to 6000 meters.", "Middle-latitude cyclone - Large center of low pressure with an associated cold front and often a warm front. Frequently accompanied by abundant precipitation.", "Mid-ocean ridge See Oceanic ridge.", "Mineral - A naturally occurring, inorganic crystalline material with a unique chemical composition.", "Mineralogy - The study of minerals.", "Mineral resource - All discovered and undiscovered deposits of a useful mineral that can be extracted now or at some time in the future.", "Mixed tidal pattern - A tidal pattern exhibiting two high tides and two low tides per tidal day with a large inequality in high water heights, low water heights, or both. Coastal locations that experience such a tidal pattern may also show alternating periods of diurnal and semidiurnal tidal patterns. Also called mixed semidiurnal.", "Mixing depth -  The height to which convectional movements extend above Earth's surface. The greater the mixing depth, the better the air quality.", "Mixing ratio -  The mass of water vapor in a unit mass of dry air; commonly expressed as grams of water vapor per kilogram of dry air.", "Model -  A term often used synonymously with hypothesis but is less precise because it is sometimes used to describe a theory as well.", "Modified -  Mercalli intensity scale A 12-point scale developed to evaluate earthquake intensity based on the amount of damage to various structures.", "Mohorovicic discontinuity (Moho) -  The boundary separating the crust from the mantle, discernible by an increase in seismic velocity.", "Mohs scale -  A series of 10 minerals used as a standard in determining hardness.", "Moment magnitude -  A more precise measure of earthquake magnitude than the Richter scale that is derived from the amount of displacement that occurs along a fault zone.", "Monocline - A one-limbed flexure in strata. The strata are unusually flat-lying or very gently dipping on both sides of the monocline.", "Monsoon - Seasonal reversal of wind direction associated with large continents, especially Asia. In winter, the wind blows from land to sea; in summer, from sea to land.", "Monthly mean temperature - The mean temperature for a month that is calculated by averaging the daily means.", "Mountain breeze - The nightly downslope winds commonly encountered in mountain valleys.", "Natural leeves - The elevated land-forms that parallel some streams and act to confine their waters, except during floodstage.", "Neap tide - Lowest tidal range, occurring near the times of the first- and third-quarter phases of the Moon.", "Nearshore zone -  The zone of beach that extends from the low-tide shoreline seaward to where waves break at low tide.", "Nebula - A cloud of interstellar gas and/or dust.", "Nebular hypothesis -  The basic idea that the Sun and planets formed from the same cloud of gas and dust in interstellar space.", "Nekton - Pelagic organisms that can move independently of ocean currents by swimming or other means of propulsion.", "Negative feedback mechanism -  A feedback mechanism that tends to maintain a system as it is—that is, maintain the status quo.", "Neritic zone - The marine-life zone that extends from the low tideline out to the shelf break.", "Neutron - A subatomic particle found in the nucleus of an atom. The neutron is electrically neutral and has a mass approximately that of a proton.", " Neutron star - A star of extremely high density composed entirely of neutrons.", "Nonconformity - An unconformity in which older metamorphic or intrusive igneous rocks are overlain by younger sedimentary strata.", "Nonfoliated - Metamorphic rocks that do not exhibit foliation.", "Nonmetallic mineral resource -  Mineral resource that is not a fuel or processed for the metals it contains", "Nonrenewable resource - Resource that forms or accumulates over such long time spans that it must be considered as fixed in total quantity", "Normal fault -  A fault in which the rock above the fault plane has moved down relative to the rock below", "Normal polarity -  A magnetic field that is the same as that which exists at present.", "Nova -  A star that explosively increases in brightness.", "Nucleus -  The small heavy core of an atom that contains all of its positive charge and most of its mass.", "Nuee ardente -  Incandescent volcanic debris buoyed up by hot gases that moves downslope in an avalanche fashion.", "Numerical age dating - establishing the approximate age in years of a particular layer of rock by analyzing the decay of radioactive elements.", "Numerical date -  Date that specifies the actual number of years that have passed since an event occurred.", "Objective lens -  In a refracting telescope, the long-focal-length lens that forms an image of the object viewed. The lens closest to the object.", "Obliquity -  The angle between the planes of Earth's equator and orbit.", "Obsidian -  A volcanic glass of felsic composition.", "Occluded front -  A front formed when a cold front overtakes a warm front. It marks the beginning of the end of a middle-latitude cyclone.", "Occlusion -  The overtaking of one front by another.", "Occultation -  An eclipse of a star or planet by the Moon or a planet.", "Ocean basinfloor -  Area of the deep-ocean floor between the continental margin and the mid-ocean ridge.", "Oceanic plateau -  An extensive region on the ocean floor composed of thick accumulations of pillow basalts and other mafic rocks that in some cases exceed 30 kilometers in thickness.", "Oceanic ridge -  A continuous elevated zone on the floor of all the major ocean basins and varying in width from 500 to 5000 kilometers (300 to 3000 mites). The rifts at the crests of ridges represent divergent plate boundaries.", "Oceanic zone -  The marine-life zone beyond the continental shelf.", "Oceanography -  The scientific study of the oceans and oceanic phenomena.", " Offshore zone -  The relatively flat submerged zone that extends from the breaker line to the edge of the continental shelf.", "Oort cloud -  A spherical shell composed of comets that orbit the Sun at distances generally greater than 10,000 times the Earth-Sun distance.", "Open cluster -  A loosely formed group of stars of similar origin", "Open system -  One in which both matter and energy flow into and out of the system. Most natural systems are of this type.", "Orbit -  The path of a body in revolution around a center of mass.", "Ore -  Usually a useful metallic miner­al that can be mined at a profit. The term is also applied to certain nonmetallic minerals such as fluorite and sulfur.", "Original horizontality -  Layers of sediments are generally deposited in a horizontal or nearly horizontal position.", "Orogenesis - The processes that collectively result in the formation of mountains.", "Orographic lifting -  Mountains acting as barriers to the flow of air, forcing the air to ascend. The air cools adiabatically and clouds and precipitation may result.", "Outer core -  A layer beneath the mantle about 2200 kilometers (1364 miles) thick that has the properties of a liquid.",\
                   "Outer planets See Jovian planets.", "Outgassing - The escape of gases that had been dissolved in magma.", "Outwash plain -  A relatively flat, gently sloping plain consisting of materials deposited by meltwater streams in front of the margin of an ice sheet.", "Overrunning - Warm air gliding up a retreating cold air mass.", "Oxbow lake - A curved lake produced when a stream cuts off a meander.", "Oxide - an oxide is a chemical compound containing at least one oxygen atom and other elements. Most of the earth's crust consists of oxides. Oxides result when elements are oxidized by oxygen in the air.", "Ozone - A molecule of oxygen containing three oxygen atoms.", "Pahoehoe - A lava flow with a smooth-to-ropey surface.", "Paleomagnetism -  The natural remnant magnetism in rock bodies. The permanent magnetization acquired by rock that can be used to determine the location of the magnetic poles and the latitude of the rock at the time it became magnetized.", "Paleontology - The systematic study of fossils and the history of life on Earth.", "Paleozoic era - A span on the geologic time scale between the eons of the Precambrian and Mesozoic era from about 540 million to 248 million years ago.", "Pangaea - The proposed superconti­nent that 200 million years ago began to break apart and form the present landmasses.", "Parabolic dunes - The shape of these dunes resembles barchans, except their tips point into the wind; they often form along coasts that have strong on‑shore winds, abundant sand, and vegetation that partly covers the sand.", "Paradigm - A theory that is held with a very high degree of confidence and is comprehensive in scope.", "Parallax - The apparent shift of an object when viewed from two different locations.", "Parasitic cone - A volcanic cone that forms on the flank of a larger volcano.", "Parcel - An imaginary volume of air enclosed in a thin elastic cover. Typically it is considered to be a few hundred cubic meters in volume and is assumed to act independently of the surrounding air.", "Parent isotope - An element that undergoes nuclear decay.", "Parent material - The material upon which a soil develops.", "Parent rock – when discussing a rock that has undergone change, the parent rock is the rock that existed before change took place, or from where the current rock was transported.", "Parsec - The distance at which an object would have a parallax angle of 1 second of arc (3.26 light-years).", "Partial melting - The process by which most igneous rocks melt. Since individual minerals have different melting points, most igneous rocks melt over a temperature range of a few hundred degrees. If the liquid is squeezed out after some melting has occurred, a melt with a higher silica content results.", "Passive continental margin - Margins that consist of a continental shelf, continental slope, and continental rise. They are not associated with plate boundaries and therefore experience little volcanism and few earthquakes.", "Pegmatite - A very coarse-grained igneous rock (typically granite) commonly found as a dike associated with a large mass of plutonic rock that has smaller crystals. Crystallization in a water-rich environment is believed to be responsible for the very large crystals.", "Pelagic zone - Open ocean of any depth. Animals in this zone swim or float freely.", "Penumbra - The portion of a shadow from which only part of the light source is blocked by an opaque body.", "Perched water table - A localized zone of saturation above the main water table created by an impermeable layer (aquiclude).", "Peridotite - An igneous rock of ultramafic composition thought to be abundant in the upper mantle.", "Perihelion - The point in the orbit of a planet where it is closest to the Sun.", "Period - A basic unit of the geologic calendar that is a subdivision of an era. Periods may be divided into smaller units called epochs.", "Periodic table - The tabular arrangement of the elements according to atomic number.", "Permeability -  A measure of a material's ability to transmit water", "Perturbation -  The gravitational disturbance of the orbit of one celestial body by another", " Phanerozoic eon - That part of geologic time represented by rocks containing abundant fossil evidence. The eon extending from the end of the Proterozoic eon (about 540 million years ago) to the present.", "Phases of the Moon - The progression of changes in the Moon's appearance during the month.", "Pheoncryst - Conspicuously large crystals embedded in a matrix of finer-grained crystals.", "Photic zone - The upper part of the ocean into which any sunlight penetrates.", "Photochemical reaction - A chemical reaction in the atmosphere that is triggered by sunlight, often yielding a secondary pollutant.", "Photon - A discrete amount (quantum) of electromagnetic energy.", "Photosphere - The region of the Sun that radiates energy to space. The visible surface of the Sun.", "Photosynthesis - The process by which plants and algae produce carbohydrates from carbon dioxide and water in the presence of chlorophyll, using light energy and releasing oxygen.", "pH scale -  A common measure of the degree of acidity or alkalinity of a solution, it is a logarithmic scale ranging from 0 to 14. A value of 7 denotes a neutral solution, values below 7 indicate greater acidity, and numbers above 7 indicate greater alkalinity", "Physical environment -  The part of the environment that encompasses water, air, soil, and rock, as well as conditions such as temperature, humidity, and sunlight.", "Phytoplankton - Algal plankton, which are the most important community of primary producers in the ocean.", "Piedmont glacier - A glacier that forms when one or more valley glaciers emerge from the confining walls of mountain valleys and spread out to create a broad sheet in the lowlands at the base of the mountains.", "Pipe - A vertical conduit through which magmatic materials have passed.", "Placer - Deposit formed when heavy minerals are mechanically concentrated by currents, most commonly streams and waves. Placers are sources of gold, tin, platinum, diamonds, and other valuable minerals.", "Plane of the ecliptic - The imaginary plane that connects Earth's orbit with the celestial sphere.", "Planetary nebula - A shell of incandescent gas expanding from a star.", "Plankton - Passively drifting or weakly swimming organisms that cannot move independently of ocean currents. Includes microscopic algae, protozoa, jellyfish, and larval forms of many animals.", "Plate - One of numerous rigid sections of the lithosphere that moves as a unit over the material of the asthenosphere.", " Plate tectonics - The theory that proposes that Earth's outer shell consists of individual plates that interact in various ways and thereby produce earthquakes, volcanoes, mountains, and the crust itself.", "Playa - A flat area on the floor of an undrained desert basin. Following heavy rain, the playa becomes a lake.", "Playa lake - A temporary lake in a playa.", "Pleistocene epoch - An epoch of the Quaternary period beginning about 1.8 million years ago and ending about 10,000 years ago. Best known as a time of extensive continental glaciations.", "Plucking (quarrying) -  The process by which pieces of bedrock are lifted out of place by a glacier.", "Pluton - A structure that results from the emplacement and crystallization of magma beneath the surface of Earth.", "Pluvial lake -  A lake formed during a period of increased rainfall. During the Pleistocene epoch this occurred in some nonglaciated regions during periods of ice advance elsewhere.", "Polar (P) air mass -  A cold air mass that forms in a high-latitude source region.", "Polar easterlies -  In the global pattern of prevailing winds, winds that blow from the polar high toward the subpolar low. These winds, however, should not be thought of as persistent winds, such as the trade winds.", "Polar front - The stormy frontal zone separating air masses of polar origin from air masses of tropical origin.", "Polar high - Anticyclones that are assumed to occupy the inner polar regions and are believed to be thermally induced, at least in part.", "Polar wandering - As the result of paleomagnetic studies in the 1950s, researchers proposed that either the magnetic poles migrated greatly through time or the continents had gradually shifted their positions.", "Population I - Stars rich in atoms heavier than helium. Nearly always relatively young stars found in the disk of the galaxy.", "Population II - Stars poor in atoms heavier than helium. Nearly always relatively old stars found in the halo, globular clusters, or nuclear bulge.", "Porosity - The volume of open spaces in rock or soil.", "Porphyritic - An igneous texture consisting of large crystals embedded in a matrix of much smaller crystals. Positive feedback mechanism A feedback mechanism that enhances or drives change.", "Precambrian -  All geologic time prior to the Paleozoic era.", "Precession -  A slow motion of Earth's axis that traces out a cone over a period of 26,000 years.", "Precipitation fog - Fog formed when rain evaporates as it falls through a layer of cool air.", "Pressure – is the force per unit area applied on a surface in a direction perpendicular to that surface.  (from Wikipedia free encyclopedia)", "Pressure gradient - The amount of pressure change occurring over a given distance.", "Pressure tendency - The nature of the change in atmospheric pressure over the past several hours. It can be a useful aid in short-range weather prediction.", "Prevailing wind - A wind that consistently blows from one direction more than from another.", "Primary pollutants - Those pollutants emitted directly from identifiable sources.", "Primary productivity - The amount of organic matter synthesized by organisms from inorganic substances through photosynthesis or chemosynthesis within a given volume of water or habitat in a unit of time.", "Primary (P=') wave - A type of seismic wave that involves alternating compression and expansion of the material through which it passes.", "Principal shells See Energy levels. - ", "Prominence - A concentration of material above the solar surface that appears as a bright archlike structure.", "Proterozoic eon - The eon following the Archean and preceding the Phanerozoic. It extends between about 2500 million (2.5 billion) and 540 million years ago", "Proton-proton chain - A chain of thermonuclear reactions by which nuclei of hydrogen are built up into nuclei of helium.", "Protostar - A collapsing cloud of gas and dust destined to become a star.", "Psychrometer - A device consisting of two thermometers (wet bulb and dry bulb) that is rapidly whirled and, with the use of tables, yields the relative humidity and dew point.", "Ptolemaic system -  An Earth-centered system of the universe.", "Pulsar - A variable radio source of small size that emits radio pulses in very regular periods.", "Pulsating variable - A variable star that pulsates in size and luminosity.", "Pycnocline - A layer of water in which there is a rapid change of density with depth.", "Pyroclastic - An igneous rock texture resulting from the consolidation of individual rock fragments that are ejected during a violent eruption.", "Pyroclastic flow - A highly heated mixture, largely of ash and porn ice fragments, traveling down the flanks of a volcano or along the surface of the ground.", "Pyroclastic material - The volcanic rock ejected during an eruption, including ash, bombs, and blocks.", "Radial pattern - A system of streams running in all directions away from a central elevated structure, such as a volcano.", "Radiation -  The transfer of energy (heat) through space by electromagnetic waves", " Radiation fog - Fog resulting from radiation heat loss by Earth.", "Radiation pressure - The force exerted by electromagnetic radiation from an object such as the Sun.", "Radioactivity - The spontaneous decay of certain unstable atomic nuclei. Radiocarbon (carbon-14) The radioactive isotope of carbon, which is produced continuously in the atmosphere and is used in dating events from the very recent geologic past (the last few tens of thousands of years).", "Radio interferometer - Two or more radio telescopes that combine their signals to achieve the resolving power of a larger telescope.", "Radiornotric dating - The procedure of calculating the absolute ages of rocks and minerals that contain radioactive isotopes.", "Radio telescope - A telescope designed to make observations in radio wavelengths.", "Raindrop – has a volume equal to roughly 1 million cloud droplets (Earth Science 11e pg 491).", "Rainshadow desert - A dry area on the lee side of a mountain range. Many middle-latitude deserts are of this type.", "Rapids - A part of a stream channel in which the water suddenly begins flowing more swiftly and turbulently because of an abrupt steepening of the gradient.", "Ray (lunar) - Any of a system of bright elongated streaks, sometimes associated with a crater on the Moon.", "Recessional moraine - An end moraine formed as the ice front stagnated during glacial retreat.", "Recorded History – started about 5,000 years ago (pg 586 Earth Science 11e).", "Rectangular pattern - A drainage pattern characterized by numerous right-angle bends that develops on jointed or fractured bedrock.", "Red giant - A large, cool star of high luminosity; a star occupying the upper-right portion of the Hertzsprung-Russell diagram.", "Reef – A strip or ridge of rocks, sand, or coral that rises to or near the surface of a body of water", "Reflecting telescope -  A telescope that concentrates light from distant objects by using a concave mirror.", "Reflection - The process whereby light bounces hack from an object at the same angle at which it encounters a surface and with the same intensity.", "Reflection nebula - A relatively dense dust cloud in interstellar space that is illuminated by starlight.", "Refracting telescope - A telescope that employs a lens to bend and concentrate the light from distant objects.", " Refraction - The process by which the portion of a wave in shallow water slows, causing the wave to bend and tend to align itself with the underwater contours.", "Regional metamorphism - Metamorphism associated with large-scale mountain-building processes.", "Regolith - The layer of rock and mineral fragments that nearly everywhere covers Earth's surface.", "Relative dating - Rocks are placed in their proper sequence or order. Only the chronological order of events is determined.", "Relative humidity - The ratio of the air's water-vapor content to its water-vapor capacity.", "Renewable resource - A resource that is virtually inexhaustible or that can be replenished over relatively short time spans.", "Reserve - Already identified deposits from which minerals can be extracted profitably.", "Residual soil - Soil developed directly from the weathering of the bedrock below.", "Resolving power - The ability of a telescope to separate objects that would otherwise appear as one.", " Retrograde motion - The apparent westward motion of the planets with respect to the stars.", "Reverse fault - A fault in which the material above the fault plane moves up in relation to the material below.", "Reverse polarity -  A magnetic field opposite to that which exists at present.", "Revolution - The motion of one body about another, as Earth about the Sun. Richter scale A scale of earthquake magnitude based on the motion of a seismograph.", "Richter scale -  ", "Ridge push - A mechanism that may contribute to plate motion. It involves the oceanic lithosphere sliding down the oceanic ridge under the pull of gravity.", "Rift zone -  A region of Earth's crust along which divergence is taking place.", "Right ascension - An angular distance measured eastward along the celestial equator from the vernal equinox. Used with declination in a coordinate system to describe the position of celestial bodies.", "Rime - A thin coating of ice on objects produced when supercooled fog droplets freeze on contact.", "Rock -  A consolidated mixture of minerals.",\
                    "Rock cycle - A model that illustrates the origin of the three basic rock types and the interrelatedness of Earth materials and processes.", "Rock flour - Ground-up rock produced by the grinding effect of a glacier.", "Rockslide - The rapid slide of a mass of rock downslope along planes of weakness.", "Rotation - The spinning of a body, such as Earth, about its axis.", "Runoff - Water that flows over the land rather than infiltrating into the ground.", "Salinity - The proportion of dissolved salts to pure water, usually expressed in parts per thousand (%o).", "Saltation  -  Transportation of sediment through a series of leaps or bounces.", "Santa Ana - The local name given a chinook wind in southern California.", "Saturation - The maximum quantity of water vapor that the air can hold at any given temperature and pressure.", "Scattering - The redirecting (in all directions) of light by small particles and gas molecules in the atmosphere. The result is diffused light.", "Scoria - Hardened lava that has retained the vesicles produced by escaping gases. Scoria cone See Cinder cone.", "Sea – that salt waters that cover the greater part of the earth's surface, or, a division of these waters, of considerable extent, more or less definitely marked off by land boundaries: the North Sea, or, a large lake or landlocked body of water.", "Sea arch - An arch formed by wave erosion when caves on opposite sides of a headland unite.", "Sea breeze - A local wind blowing from the sea during the afternoon in coastal areas.", "Seafloor spreading - The process of producing new seafloor between two diverging plates.", "Seamount - An isolated volcanic peak that rises at least 1000 meters (3000 feet) above the deep-ocean floor.", "Sea stack - An isolated mass of rock standing just offshore, produced by wave erosion of a headland.", "Seawall - A barrier constructed to prevent waves from reaching the area behind the wall. Its purpose is to defend property from the force of breaking", "Secondary enrichment - The concentration of minor amounts of metals that are scattered through unweathered rock into economically valuable concentrations by weathering processes.", "Secondary pollutants - Pollutants that are produced in the atmosphere by chemical reactions that occur among primary pollutants.", "Secondary (S) wave -  A seismic wave that involves oscillation perpendicular to the direction of propagation.", "Sediment - Unconsolidated particles created by the weathering and erosion of rock, by chemical precipitation from solution in water, or from the secretions of organisms and transported by water, wind, or glaciers.", "Sedimentary rock -  Rock formed from the weathered products of preexisting rocks that have been transported, deposited, and lithified.", "Seismic sea wave - A rapidly moving ocean wave generated by earthquake activity capable of inflicting heavy damage in coastal regions.", "Seismogram - The record made by a seismograph.", "Seismograph - An instrument that records earthquake waves.", "Seismology - The study of earthquakes and seismic waves.", "Semiarid See Steppe.", "Semidiurnal tidal pattern - A tidal pattern exhibiting two high tides and two low tides per tidal day with small inequalities between successive highs and successive lows; a semi-daily tide.", "Sensible heat – Is potential energy in the form of thermal energy or heat. The thermal body must have a temperature higher than its surroundings, (also see: latent heat). The thermal energy can be transported via conduction, convection, radiation or by a combination thereof. The quantity or magnitude of sensible heat is the product of the body's mass, its specific heat capacity and its temperature above a reference temperature. In many cases the reference temperature is inferred from common knowledge, i.e. 'room temperature'.", "Shadow zone -  The zone between 104 and 143 degrees distance from an earthquake epicenter in which direct waves do not arrive because of refraction by Earth's core.", "Sheeting -  A mechanical weathering process characterized by the splitting off of slablike sheets of rock.", "Shelf break -  The point where a rapid steepening of the gradient occurs, marking the outer edge of the continental shelf and the beginning of the continental slope.", "Shield -  A large, relatively flat expanse of ancient metamorphic rock within the stable continental interior.", "Shield volcano -  A broad, gently sloping volcano built from fluid basaltic lavas.", "Shore -  Seaward of the coast, this zone extends from the highest level of wave action during storms to the lowest tide level.", "Shoreline -  The line that marks the contact between land and sea. It migrates up and down as the tide rises and falls.", "Sidereal day -  The period of Earth's rotation with respect to the stars.", "Sidereal month - A time period based on the revolution of the Moon around Earth with respect to the stars.", "Silicate -  Any one of numerous minerals that have the oxygen and silicon tetrahedron as their basic structure.", "Silicon-oxygen tetrahedron -  A structure composed of four oxygen atoms surrounding a silicon atom that constitutes the basic building block of silicate minerals.", "Sill -  A tabular igneous body that was intruded parallel to the layering of preexisting rock.", "Sinkhole -  A depression produced in a region where soluble rock has been removed by groundwater.", "Slab pull -  A mechanism that contributes to plate motion in which cool, dense oceanic crust sinks into the mantle and 'pulls' the trailing lithosphere along.", "Sleet -  Frozen or semifrozen rain formed when raindrops freeze as they pass through a layer of cold air.", "Slide -  A movement common to mass-wasting processes in which the material moving downslope remains fairly coherent and moves along a well-defined surface.", "Slip face -  The steep, leeward slope of a sand dune; it maintains an angle of about 34 degrees.", "Slump -  The downward slipping of a mass of rock or unconsolidated material moving as a unit along a curved surface.", "Snow -  A solid form of precipitation produced by sublimination of water vapor.", "Snowfield -  An area where snow persists year-round.", "Snowline -  Lower limit of perennial snow.", "Soil -  A combination of mineral and organic matter, water, and air; that portion of the regolith that supports plant growth.", " Soil horizon A layer of soil that has identifiable characteristics produced by chemical weathering and other soil-forming processes.", "Soil profile -  A vertical section through a soil showing its succession of horizons and the underlying parent material.", "Soil Taxonomy -  A soil classification system consisting of six hierarchical categories based on observable soil characteristics. The system recognizes 12 soil orders.", "Soil texture -  The relative proportions of clay, silt, and sand in a soil. Texture strongly influences the soil's ability to retain and transmit water and air.", "Solar constant -  The rate at which solar radiation is received outside Earth's atmosphere on a surface perpendicular to the Sun's rays when Earth is at an average distance from the Sun.", "Solar eclipse -  An eclipse of the Sun.", "Solar flare -  A sudden and tremendous eruption in the solar chromosphere.", "Solar winds -  Subatomic particles ejected at high speed from the solar corona.", "Solifluction -  Slow, downslope flow of water-saturated materials common to permafrost areas.", "Solstice -  The time when the vertical rays of the Sun are striking either the Tropic of Cancer or the Tropic of Capricorn. Solstice represents the longest or shortest day (length of daylight) of the year.", "Solum -  The O, A, and B horizons in a soil profile. Living roots and other plant and animal life are largely confined to this zone.", "Sorting -  The process by which solid particles of various sizes are separated by moving water or wind. Also, the degree of similarity in particle size in sediment or sedimentary rock.", "Source region -  The area where an air mass acquires its characteristic properties of temperature and moisture. Specific gravity The ratio of a substance's weight to the weight of an equal volume of water.", "Specific humidity – The mass of water vapor per unit mass of air, including the water vapor (usually expressed as grams of water vapor per kilogram of air).", "Spectral class -  A classification of a star according to the characteristics of its spectrum.", "Spectroscope -  An instrument for directly viewing the spectrum of a light source.", "Spectroscopy -  The study of spectra", "Spheroidal weathering -  Any weathering process that tends to produce a spherical shape from an initially blocky shape.", "Spicule -  A narrow jet of rising material in the solar chromosphere.", "Spiral galaxy -  A flattened, rotating galaxy with pinwheel-like arms of interstellar material and young stars winding out from its nucleus.", "Spit -  An elongate ridge of sand that projects from the land into the mouth of an adjacent bay.", "Spring -  A flow of groundwater that emerges naturally at the ground surface.", "Spring equinox -  The equinox that occurs on March 21-22 in the Northern Hemisphere and on September 21-23 in the Southern Hemisphere.", "Spring tide -  Highest tidal range that occurs near the times of the new and full moons.", "Stable air -  Air that resists vertical displacement. If it is lifted, adiabatic cooling will cause its temperature to be lower than the surrounding environment; if it is allowed, it will sink to its original position.", " Stable platform -  That part of the era-ton that is mantled by relatively undeformed sedimentary rocks and underlain by a basement complex of igneous and metamorphic rocks.", "Stalactite -  The icicle-like structure that hangs from the ceiling of a cavern.", "Stalagmite - The columnlike form that grows upward from the floor of a cavern.", "Star dune -  Isolated hill of sand that exhibits a complex form and develops where wind directions are variable.", "Stationary front -  A situation in which the surface position of a front does not move; the flow on either side of such a boundary is nearly parallel to the position of the front.", "Steam fog -  Fog having the appearance of steam, produced by evaporation from a warm water surface into the cool air above.", "Stellar parallax -  A measure of stellar distance.", "Steppe -  One of the two types of dry climate. A marginal and more humid variant of the desert that separates it from bordering humid climates.", "Stony-iron meteorite -  One of the three main categories of meteorites. This group, as the name implies, is a mixture of iron and silicate minerals.", "Stony meteorite -  One of the three main categories of meteorites. Such meteorites are composed largely of silicate minerals with inclusions of other minerals.", "Storm surge -  The abnormal rise of the sea along a shore as a result of strong winds.", "Strata -  Parallel layers of sedimentary rock.", "Stratified drift -  Sediments deposited by glacial meltwater.", "Stratopause -  The boundary between the stratosphere and the mesosphere.", "Stratosphere -  The layer of the atmosphere immediately above the troposphere, characterized by increasing temperatures with height, owing to the concentration of ozone.", "Stratovolcano See Composite cone.", " Stratus -  One of three basic cloud forms; also, the name given one of the flow clouds. They are sheets or layers that cover much or all of the sky. Streak The color of a mineral in powdered form.", "Stream valley -  The channel, valley floor, and sloping valley walls of a stream.", "Striations (glacial) -  Scratches or grooves in a bedrock surface caused by the grinding action of a glacier and its load of sediment.", "Strike-slip fault -  A fault along which the movement is horizontal.", "Stromatolite -  Structures that are deposited by algae and consist of layered mounds of calcium carbonate.", "Subarctic climate -  A climate found north of the humid continental climate and south of the polar climate and characterized by bitterly cold winters and short cool summers. Places within this climatic realm experience the highest annual temperature ranges on Earth.", "Subduction -  The process of thrusting oceanic lithosphere into the mantle along a convergent boundary", "Subduction zone -  A long, narrow zone where one lithospheric plate descends beneath another.", "Sublimation -  The conversion of a solid directly to a gas without passing through the liquid state.", "Submarine canyon -  A seaward extension of a valley that was cut on the continental shelf during a time when sea level was lower, or a canyon carved into the outer continental shelf, slope, and rise by turbidity currents.", "Submergent coast -  A coast with a form that is largely the result of the partial drowning of a former land surface either because of a rise of sea level or subsidence of the crust or both.", "Subpolar low -  Low pressure located at about the latitudes of the Arctic and Antarctic circles, In the Northern Hemisphere the low takes the form of individual oceanic cells; in the Southern Hemisphere there is a deep and continuous trough of low pressure.", "Subsoil -  A term applied to the B horizon of a soil profile.", "Subtropical high -  Not a continuous belt of high pressure but rather several semipermanent, anticyclonic centers characterized by subsidence and divergence located roughly between latitudes 25 and 35 degrees.", "Summer solstice -  The solstice that occurs on June 21-22 in the Northern Hemisphere and on December 21-22 in the Southern Hemisphere.", "Sunspot -  A dark spot on the Sun, which is cool by contrast to the surrounding photosphere.", "Supercooled -  The condition of water droplets that remain in the liquid state at temperatures well below 0°C.", "Supergiant -  A very large star of high luminosity.", "Supernova -  An exploding star that increases in brightness many thousands of times.", "Superposition -  In any undeformed sequence of sedimentary rocks, each bed is older than the layers above and younger than the layers below.", " Supersaturation -  The condition of being more highly concentrated than is normally possible under given temperature and pressure conditions. When describing humidity, it refers to a relative humidity that is greater than 100 percent.", "Surf -  A collective term for breakers; also, the wave activity in the area between the shoreline and the outer limit of breakers.", "Surface area - the area of a rock’s surface exposed to weathering. The more area exposed the faster chemical weathering can proceed.", "Surface soil -  The uppermost layer in a soil profile: the A horizon.", "Surface waves -  Seismic waves that travel along the outer layer of Earth.", "Suspended load -  The fine sediment carried within the body of flowing water.", " Swells -  Wind-generated waves that have moved into an area of weaker winds or calm.", "Syncline -  A linear downfold in sedimentary strata; the opposite of anticline.", "Synodic month -  The period of revolution of the Moon with respect to the Sun, or its cycle of phases.", "System -  Any size group of interacting parts that form a complex whole (ES11e, pg 21).", "Talus - An accumulation of rock debris at the base of a cliff.", "Tarn -  A small lake in a cirque", "Tectonics - The study of the large-scale processes that collectively deform Earth's crust.", "Temperate – free of extremes, mild, (from dictionary.com)", "Temperature -  A measure of the degree of hotness or coldness of a substance; a measure of the average kinetic energy of individual atoms or molecules in a substance.", "Temperature inversion -  A layer in the atmosphere of limited depth where the temperature increases rather than decreases with height.", " Temporary (local) base level -  The level of a lake, resistant rock layer, or any other base level that stands above sea level.", " Terminal moraine -  The end moraine marking the farthest advance of a glacier.", "Terrace -  A flat, benchlike structure produced by a stream, which was left elevated as the stream cut downward.", "Terrae - The extensively cratered highland areas of the Moon.",\
                     "Terrane -  A crustal block hounded by faults, whose geologic history is distinct from the histories of adjoining crustal blocks.", "Terrestrial planets -  Any of the Earth-like planets, including Mercury, Venus, Mars, and Earth.", "Terrigenous sediment -  Seafloorsediments derived from terrestrial weathering and erosion", "Texture -  The size, shape, and distribution of the particles that collectively constitute a rock.", "Theory -  A well-tested and widely accepted view that explains certain observable facts.", "Thermal gradient -  The increase in temperature with depth. It averages 1°C per 30 meters (1-2°F per 100 feet) in the crust.", "Thermal metamorphism See Contact metamorphism.", "Thermocline -  A layer of water in which there is a rapid change in temperature in the vertical dimension.", "Thermohaline circulation -  Movements of ocean water caused by density differences brought about by variations in temperature and salinity.", "Thermosphere -  The region of the atmosphere immediately above the mesosphere and characterized by increasing temperatures due to absorption of very shortwave solar energy by oxygen.", "Thrust fault -  A low-angle reverse fault.", "Thunder -  The sound emitted by rapidly expanding gases along the channel of lightning discharge.", "Thunderstorm -  A storm produced by a cumulonimbus cloud and always accompanied by lightning and thunder. It is of relatively short duration and usually accompanied by strong wind gusts, heavy rain, and sometimes hail.", "Tidal current -  The alternating horizontal movement of water associated with the rise and fall of the tide.", "Tidal delta -  A deltalike feature created when a rapidly moving tidal current emerges from a narrow inlet and slows, depositing its load of sediment.", "Tidal flat - A marshy or muddy area that is covered and uncovered by the rise and fall of the tide.", "Tide -  Periodic change in the elevation of the ocean surface.", " Till -  Unsorted sediment deposited directly by a glacier.", "Tombolo -  A ridge of sand that connects an island to the mainland or to another island.", "Tornado -  A small, very intense cyclonic storm with exceedingly high winds, most often produced along cold front, in conjunction with severe thunderstorms.", "Tornado warning -  A warning issued when a tornado has actually been sighted in an area or is indicated by radar.", "Tornado watch -  A warning issued for areas of about 65,000 square kilometers (25,000 square miles), indicating that conditions are such that tornadoes may develop; it is intended to alert people to the possibility of tornadoes.", "Trade winds -  Two belts of winds that blow almost constantly from easterly directions and are located on the equatorward sides of the subtropical highs.", "Transform fault  -  A major strike-slip fault that cuts through the lithosphere and accommodates motion between two plates.", "Transform fault boundary -  A boundary in which two plates slide past one another without creating or destroying lithosphere.", "Transpiration -  The release of water vapor to the atmosphere by plants.", "Transported soil -  Soils that form on unconsolidated deposits.", "Transverse dunes -  A series of long ridges oriented at right angles to the prevailing wind; these dunes form where vegetation is sparse and sand is very plentiful.", "Travertine -  A form of limestone (CaCO3) that is deposited by hot springs or as a cave deposit.", "Trellis pattern -  A system of streams in which nearly parallel tributaries occupy valleys cut in folded strata.", "Trench -  An elongated depression in the seafloor produced by bending of oceanic crust during subduction.", "Trophic level -  A nourishment level in a food chain. Plant and algae producers constitute the lowest level, followed by herbivores and a series of carnivores at progressively higher levels.", "Tropical depression -  By international agreement, a tropical cyclone with maximum winds that do not exceed 61 kilometers (38 miles) per hour.", "Tropical rain forest -  A luxuriant broadleaf evergreen forest; also, the name given the climate associated with this vegetation.", "Tropical storm -  By international agreement, a tropical cyclone with maximum winds between 61 and 119 kilometers (38 and 74 miles) per hour.", "Tropical wet and dry -  A climate that is transitional between the wet tropics and the subtropical steppes.", "Tropic of Cancer -  The parallel of latitude, 23 1/2 degrees north latitude, marking the northern limit of the Sun's vertical rays.", "Tropic of Capricorn -  The parallel of latitude, 23 '1 /2 degrees south latitude, marking the southern limit of the Sun's vertical rays.", "Tropopause -  The boundary between the troposphere and the stratosphere.", "Troposphere -  The lowermost layer of the atmosphere. It is generally characterized by a decrease in temperature with height.", "Tsunami -  The Japanese word for a seismic sea wave.", "Tundra climate -  Found almost exclusively in the Northern Hemisphere or at high altitudes in many mountainous regions. A treeless climatic realm of sedges, grasses, mosses, and lichens that is dominated by a long, bitterly cold winter.", "Turbidite -  Turbidity current deposit characterized by graded bedding.", "Turbidity current -  A downslope movement of dense, sediment-laden water created when sand and mud on the continental shelf and slope are dislodged and thrown into suspension.", "Turbulent flow -  The movement of water in an erratic fashion often characterized by swirling, whirlpool-like eddies. Most streamflow is of this type.", "Ultimate base level -  Sea level; the lowest level to which stream erosion could lower the land.", "Ultramafic -  Igneous rocks composed mainly of iron and magnesium-rich minerals.", "Ultraviolet -  Radiation with a wavelength from 0.2 to 0.4 micrometer.", "Umbra -  The central, completely dark part of a shadow produced during an eclipse.", "Unconformity - A surface that represents a break in the rock record, caused by erosion or nondeposition", "Uniformitarianism - The concept that the processes that have shaped Earth in the geologic past are essentially the same as those operating today.", "Unstable air - Air that does not resist vertical displacement. If it is lifted, its temperature will not cool as rapidly as the surrounding environment, so it will continue to rise on its own.", "Upslope - fog Fog created when air moves up a slope and cools adiabatically.", "Upwelling - The rising of cold water from deeper layers to replace warmer surface water that has been moved away.", "Urban heat island - The fact that temperatures within a city are generally higher than in surrounding rural areas.", "Valence electron -  The electrons involved in the bonding process; the electrons occupying the highest-principal energy level of an atom.", "Valley breeze -  The daily upslope winds commonly encountered in a mountain valley.", "Valley glacier -  See Alpine glacier.", "Valley train -  A relatively narrow body of stratified drift deposited on a valley floor by meltwater streams that issue from a valley glacier.", "Vapor pressure -  That part of the total atmospheric pressure attributable to water-vapor content.", "Vein deposit -  A mineral filling a fracture or fault in a host rock. Such deposits have a sheetlike, or tabular, form.", "Ventifact -  A cobble or pebble polished and shaped by the sandblasting effect of wind.", "Vesicular -  A term applied to igneous rocks that contain small cavities called vesicles, which are formed when gases escape from lava.", "Viscosity -  A measure of a fluid's resistance to flow.", "Visible light -  Radiation with a wavelength from 0.4 to 0.7 micrometer.", "Volatiles -  Gaseous components of magma dissolved in the melt. Volatiles will readily vaporize (form a gas) at surface pressures.", "Volcanic bomb -  A streamlined pyroclastic fragment ejected from a volcano while molten.", "Volcanic island arc -  A chain of volcanic islands generally located a few hundred kilometers from a trench where active subduction of one oceanic slab beneath another is occurring.", "Volcanic neck -  An isolated, steep-sided, erosional remnant consisting of lava that once occupied the vent of a volcano.", "Volcano -  A mountain formed of lava and/or pyroclastics", " Warm front   -  A front along which a warm air mass overrides a retreating mass of cooler air.", "Wash -  A common term for a desert stream course that is typically dry except for brief periods immediately following a rain.", "Water table   -  The upper level of the saturated zone of groundwater.", "Wave (ocean) - are surface waves that occur in the upper layer of the ocean. They usually result from wind or geologic effects and may travel thousands of miles before striking land. They range in size from small ripples to huge tsunamis. There is little actual forward motion of individual water particles in a wave, despite the large amount of energy and momentum it may carry forward.", "Wave (not liquid) - a wave is a mode of energy transfer from one place to another, often with little or no permanent displacement of the particles of the medium (i.e. little or no associated mass transport); instead there are oscillations around almost fixed positions. Thus, while mechanical waves require a medium to transverse the distance, electromagnetic waves can travel through a vacuum.", "Wave-cut cliff -  A seaward-facing cliff along a steep shoreline formed by wave erosion at its base and mass wasting.", "Wave-cut platform -  A bench or shelf in the bedrock at sea level, cut by wave erosion.", "Wave depth – for the purposes of CRC geology instructions, this is defined as ½ of the wavelength of an ocean wave. It is the depth beneath water surface at which a wave begins to 'feel' the bottom.", "Wave height   -  The vertical distance between the trough and crest of a wave.", "Wavelength -  The horizontal distance separating successive crests or troughs.", "Wave of oscillation -  A water wave in which the wave form advances as the water particles move in circular orbits.", "Wave of translation -  The turbulent advance of water created by breaking waves.", "Wave period   -  The time interval between the passage of successive crests at a stationary point.", "Wave refraction -  See Refraction.", "Weather - The state of the atmosphere at any given time.", "Weathering -  The disintegration and decomposition of rock at or near Earth's surface.", "Welded tuff -  A pyroclastic rock composed of particles that have been fused together by the combination of heat still contained in the deposit after it has come to rest and by the weight of overlying material.", "Well -  An opening bored into the zone of saturation", "Westerlies -  The dominant west-to­east motion of the atmosphere that characterizes the regions on the pole-ward side of the subtropical highs.", "Wet adiabatic rate   -  The rate of adiabatic temperature change in saturated air. The rate of temperature change is variable, but it is always less than the dry adiabatic rate.", "White dwarf -  A star that has exhausted most or all of its nuclear fuel and has collapsed to a very small size; believed to be near its final stage of evolution.", "White frost   -  Ice crystals instead of dew that form on surfaces when the dew point is below freezing.", "Wind -  Air flowing horizontally with respect to Earth's surface.", "Wind vane -  An instrument used to determine wind direction.", "Winter solstice   -  The solstice that occurs on December 21-22 in the Northern Hemisphere and on June 21-22 in the Southern Hemisphere.", "Yazoo tributary -  A tributary that flows parallel to the main stream because a natural levee is present.", "Zodiac -  A band along the ecliptic containing the 12 constellations of the zodiac.", "Zone of accumulation   -  The part of a glacier characterized by snow accumulation and ice formation. Its outer limit is the snowline.", "Zone of aeration   -  Area above the water table where openings in soil, sediment, and rock are not saturated but filled mainly with air.", "Zone of fracture   -  The upper portion of a glacier consisting of brittle ice.", "Zone of saturation -  Zone where all open spaces in sediment and rock are completely filled with water.", "Zone of wastage   -  The part of a glacier beyond the zone of accumulation where all of the snow from the previous winter melts, as does some of the glacial ice.", "Zooplankton -  Animal plankton."]
        
    psychology1 = ["Ability Model: an approach that views EI as a standard intelligence that utilizes a distinct set of mental abilities that (1) are intercorrelated, (2) relate to other extant intelligences, and (3) develop with age and experience.", "Abnormal Psychology: The application of psychological science to understanding and treating mental disorders.", "Absolute Threshold of a Sensation: the intensity of a stimulus that allows an organism to just barely detect it.", "Access: Conscious experience that recalls experiences from memory.", "Accommodation: helps determine visual depth. As the lens changes its curvature to focus on distant or close objects, information relayed from the muscles attached to the lens helps us determine an object’s distance.", "Accommodation: Learning new information and thus changing the schema.", "Action Potential: The change in electrical charge that occurs in a neuron when a nerve impulse is transmitted.", "Activation-Synthesis Theory of Dreaming: A prominent neurobiological theory of dreaming that states dreams don’t actually mean anything, and people construct dream stories after they wake up to make sense of nonsensical brain impulses.", "Active Imagination: Activating our imaginal processes in waking life in order to tap into the unconscious meanings of our symbols.", "Adaptations: Internal mechanisms that are products of natural selection and helped our ancestors get around the world, survive, and reproduce. Evolved solutions to problems that historically contributed to reproductive success.", "Addiction: When the user powerfully craves the drug and is driven to seek it out, over and over again, no matter what the physical, social, financial, and legal cost.", "Adherence: Accurately and regularly following medical orders and recommendations.", "Adolescence: The years between the onset of puberty and the beginning of adulthood.", "Adoption Study: A behavior genetic research method that involves comparison of biologically related people, including twins, who have been reared either separately or apart. Often includes a comparison of adopted children to their adoptive and biological parents.", "Adrenal Glands: Two triangular glands found atop each kidney. Responsible for the production of hormones that regulate salt and water balance in the body and secrete epinephrine and norepinephrine when a person experiences excitement, threat, or stress. The two glands are also involved in metabolism, the immune system, and sexual development and function.", "Adrenaline: A hormone that increases heart rate, elevates blood pressure, and boosts energy supplies.", "Affect: The experience of a feeling or emotion.", "Affective Forecasting: Predictions of one’s future feelings.", "Agonist: A drug that has chemical properties similar to a particular neurotransmitter and thus mimics the effects of the neurotransmitter.", "Agoraphobia: Anxiety about being in places or situations from which escape might be difficult or embarrassing, or in which help may not be available.", "Agreeableness: A core trait that includes dispositional characteristics as being sympathetic, generous, forgiving, and helpful, and behavioral tendencies toward harmonious social relations and likeability. The tendency to agree and go along with others rather than to assert one’s own opinions and choices.", "Alcohol: a colorless liquid, produced by the fermentation of sugar or starch, that is the intoxicating agent in fermented drinks.", "Altruism: Helping with the aim of improving the wellbeing of others.", "Alzheimer’s Disease: A form of dementia that, over a period of years, leads to a loss of emotions, cognitions, and physical functioning, and that is ultimately fatal.", "Ambivalent Attachment Style: When a child is wary about the situation in general, particularly the stranger, and stays close or even clings to the mother rather than exploring the toys.", "Ambivalent Sexism: Recognizes the complex nature of gender attitudes, in which women are often associated with positive and negative qualities.", "Amnesia: a memory disorder that involves the inability to remember information.", "Amniotic Sac: The fluid-filled reservoir in which the embryo will live until birth, and which acts as both a cushion against outside pressure and as a temperature regulator.", "Amphetamine: a stimulant that produces increased wakefulness and focus, along with decreased fatigue and appetite.", "Amplitude: the height of a sound wave. Determines how much energy sound contains.", "Amygdala: Located within the limbic system. This structure consists of two “almond-shaped” clusters and is primarily responsible for regulating our perceptions of, and reactions to, aggression and fear.", "Anchoring: the bias to be affected by an initial anchor, even if the anchor is arbitrary, and to insufficiently adjust our judgments away from that anchor.", "Anima: An archetype symbolizing the unconscious female component of the male psyche.", "Animus: An archetype symbolizing the unconscious male component of the female psyche.", "Anonymity: protecting a participant’s identity by not collecting or disclosing any personally identifiable information.", "Antagonist: A drug that reduces or stops the normal effects of a neurotransmitter.", "Anterograde Amnesia: the inability to transfer information from short-term into long-term memory, making it impossible to form new memories after the onset of amnesia.", "Antianxiety Medications: Drugs that help relieve fear or anxiety by increasing the action of the neurotransmitter GABA.", "Antidepressant Medications: Drugs designed to improve moods.", "Antipsychotic Drugs (Neuroleptics): Drugs that treat the symptoms of schizophrenia and related psychotic disorders.", "Antisocial Personality Disorder (APD): A pervasive pattern of violation of the rights of others that begins in childhood or early adolescence and continues into adulthood.", "Anxiety Disorders: Psychological disturbances marked by irrational fears, often of everyday objects and situations.", "Anxiety: The nervousness or agitation that we sometimes experience, often about something that is going to happen.", "APA Ethical Code: a set of 150 ethical standards that psychologists and students in psychology are expected to follow in their activities including clinical work, teaching, and research.", "Aphasia: a condition in which language functions are severely impaired.", "Applied Research: research that investigates issues that have implications for everyday life and provides solutions to everyday problems.", "Appreciation Effects: Having people around us makes us feel good about ourselves.", "Aptitude Tests: tests designed to measure one’s ability to perform a given task.", "Archetypes: Primordial images that reflect basic patterns or universal themes common to us all.", "Arithmetic Mean (M): the sum of all the scores of the variable divided by the number of participants in the distribution; Arithmetic Average.", "Arousal Cost–Reward Model: Focuses on the aversive feelings aroused by seeing another in need.", "Arousal: Our experiences of the bodily responses created by the sympathetic division of the autonomic nervous system.", "Assimilation: Using already developed schemas to understand new information.", "Association Areas: The area within the cortex where sensory and motor information is combined and associated with stored knowledge. Responsible for most of the things that make humans seem human and are involved in higher mental functions, such as learning, thinking, planning, judging, moral reflecting, figuring, and spatial reasoning.", "Associative Shifting: It is possible to shift any response from occurring with one stimulus to occurring with another stimulus.", "At-Risk Research: research that exposes participants to harm that is greater than that found in everyday circumstances (i.e., greater than minimal risk) and must be reviewed by the full Institutional Review Board committee.", "Attachment: The emotional bonds that we develop with those with whom we feel closest, and particularly the bonds that an infant develops with the mother or primary caregiver.", "Attention: A state of focused awareness on a subset of the available perceptual information.", "Attitudes: Opinions, feelings, and beliefs about a person, concept, or group. Our evaluations of things that can bias us toward having a particular response to it.", "Attraction: Being sexually interested in another person.", "Audience Design: constructing utterances to suit the audience’s knowledge.", "Auditory Cortex: Located in the temporal cortex. Responsible for hearing and language.", "Authoethnography: A narrative approach to introspective analysis.", "Authoritarian Parents: Demanding but not responsive.", "Authoritative Parents: Demanding but they also responsive to the needs and opinions of the child.", "Autobiographical Memory: memory for the events of one’s life.", "Automatic Behavior: an unconscious behavior that is not self-censored and is typically spontaneous.", "Automatic Empathy: a social perceiver unwittingly taking on the internal state of another person, usually because of mimicking the person’s expressive behavior and thereby feeling the expressed emotion.", "Automatic: A behavior or process that is unintentional, uncontrollable, occurs outside of conscious awareness, or is cognitively efficient.", "Autonomic Nervous System (ANS): A division of the peripheral nervous system (PNS) that regulates autonomic processes, or internal activities of the human body including heart rate, breathing, digestion, salivation, perspiration, urination, and sexual arousal.", "Autonomy: a fundamental right that describes a person’s ability to make his or her own decisions freely without being coerced by others.", "Availability Heuristic: the tendency to make judgments of the frequency or likelihood that an event occurs on the basis of the ease with which it can be retrieved from memory.", "Availability: The ease of getting a specific response.", "Aversion Therapy: A type of behaviour therapy in which positive punishment is used to reduce the frequency of an undesirable behaviour.", "Aversive Racism: The tendency for people to dislike admitting their own racial biases to themselves or others.", "Avoidance Learning: A learned response to avoid an unpleasant stimulus or event.", "Avoidant Attachment Style: When a child avoids or ignores his or her mother, showing little emotion when the mother departs or returns.", "Axon: A long, segmented fibre within the neuron that transmits information away from the cell body toward other neurons or to the muscles and glands.", "Babbling: the beginning stages of speech. Occurs at about seven months, babies engage in intentional vocalizations that lack specific meaning.", "Balance: Putting less effort into a focal goal by working towards other goals.", "Barbiturates: depressants that are commonly prescribed as sleeping pills and painkillers.", "Basic Research: Research that answers fundamental questions about behavior.", "Basic-Level Category: the neutral, preferred category for a given object, at an intermediate level of specificity.", "Behavioral Genetics: A variety of research techniques that scientists use to learn about the genetic and environmental influences on human behaviour by comparing the traits of biologically and nonbiologically related family members", "Behavioral Medicine: Focuses on the application of research on health predictors and risk factors, or interventions that prevent and treat illness.", "Behaviour Therapy: Psychological treatment that is based on principles of learning.", "Behaviourism: a school of psychology that is based on the premise that it is not possible to objectively study the mind, and therefore that psychologists should limit their attention to the study of behaviour itself. Focuses on observable behaviour as a means to studying the human psyche.", "Belmont Report: a set of federal guidelines created in 1978 after the Tuskegee study that articulates ethical guidelines for research.", "Beneficence: an ethical principle from the Belmont Report that emphasizes the importance of maximizing benefits and minimizing harm to research participants and society.", "Benevolent Sexism: Refers to the perception that women need to be protected, supported, and adored by men.", "Benzodiazepines: a family of depressants used to treat anxiety, insomnia, seizures, and muscle spasms.", "Beta Effect: the perception of motion that occurs when different images are presented next to each other in succession.", "Bias (i.e., test bias): a test that predicts outcomes better for one group than it does for another.", "Biases: the systematic and predictable mistakes that influence the judgment of even very talented human beings.", "Bilingualism: the ability to speak two languages.", "Binocular Depth Cues: depth cues that are created by retinal image disparity and require the coordination of both eyes.", "Bio-Psycho-Social Model of Illness: A way of understanding disorder that assumes that disorder is caused by biological, psychological, and social factors.", "Biofeedback: A stress reduction technique where the individual is shown bodily information that is not normally available to them, and then taught strategies to alter this signal.", "Biological Drive: A drive powering human behaviour including hunger, thirst, and intimacy.", "Biological Psychology: School of psychology interested in measuring biological, physiological, or genetic variables in an attempt to relate them to psychological or behavioural variables.", "Biological Rhythms: regularly occurring cycles of behaviours.", "Biomedical Approach to Reducing Disorders: An approach that is based on the use of medications to treat mental disorders as well as the employment of brain intervention techniques.", "Biomedical Model of Health: Posits that physical or pathogenic factors primarily contribute to illness.", "Biomedical Therapies: Treatments designed to reduce psychological disorder by influencing the action of the central nervous system.", "Biopsychosocial Model of Health: Posits that biology, psychology, and social factors are just as important in the development of disease as biological causes.", "Bipolar Disorder: A psychological disorder characterized by swings in mood from overly “high” to sad and hopeless, and back again, with periods of near-normal mood in between.", "Black Box Model: An interaction of stimuli, consumer characteristics, decision processes, and consumer responses.", "Blatant Biases: Conscious beliefs, feelings, and behavior that people are perfectly willing to admit, which mostly express hostility toward other groups while unduly favoring one’s own group.", "Blind Spot: a hole in one’s vision due to a lack of photoreceptor cells. Occurs the optic nerve leaves the retina.", "Blind to Condition: when the experimenter or the participants do not know which conditions the participants are assigned to.", "Blind to the Research Hypothesis: When research participants are not aware of what is being studied.", "Blindsight: a condition in which people are unable to consciously report on visual stimuli but nevertheless are able to accurately answer questions about what they are seeing.", "Blocking: in classical conditioning, the finding that no conditioning occurs to a stimulus if it is combined with a previously conditioned stimulus during conditioning trials. Suggests that information, surprise value, or prediction error is important in conditioning.", "Blood Alcohol Content (BAC): a measure of the percentage of alcohol found in a person’s blood. This measure is typically the standard used to determine the extent to which a person is intoxicated, as in the case of being too impaired to drive a vehicle.", "Borderline Personality Disorder (BPD): A psychological disorder characterized by a prolonged disturbance of personality accompanied by mood swings, unstable personal relationships, identity problems, threats of self-destructive behaviour, fears of abandonment, and impulsivity.", "Bounded Awareness: the systematic ways in which we fail to notice obvious and important information that is available to us.", "Bounded Ethicality: the systematic ways in which our ethics are limited in ways we are not even aware of ourselves.",\
                 "Bounded Rationality: model of human behavior that suggests that humans try to make rational decisions but are bounded due to cognitive limitations.", "Bounded Self-Interest: the systematic and predictable ways in which we care about the outcomes of others.", "Bounded Willpower: the tendency to place greater weight on present concerns rather than future concerns.", "Brain Lateralization: The idea that the left and the right hemispheres of the brain are specialized to perform different functions.", "Brain Stem: The oldest and innermost region of the brain that is designed to control the most basic functions of life, including breathing, attention, and motor responses.", "Broca’s Area: an area in front of the left hemisphere near the motor cortex responsible for language production.", "Bruxism: a sleep disorder in which the sufferer grinds their teeth during sleep.", "Bystander Intervention: A phenomenon in which people intervene to help others, including strangers.", "Caffeine: a bitter psychoactive drug found in the beans, leaves, and fruits of plants.", "Cannon-Bard Theory of Emotion: A theory proposed by Walter Cannon and Philip Bard that states that the experience of an emotion is accompanied by physiological arousal.", "Cartesian Catastrophe: the idea that mental processes taking place outside conscious awareness are impossible.", "Case Studies: descriptive records of one or more individual’s experience and behavior.", "Cataplexy: a symptom of narcolepsy where an individual loses muscle tone, resulting in a partial or complete collapse.", "Categories: networks of associated memories that have features in common with each other – a fundamental part of human nature.", "Categorize: to sort or arrange different items into classes or categories.", "Category Prototype: the member of the category that is most average or typical of the category.", "Category: a set of entities that are equivalent in some way. Usually the items are similar to one another.", "Central Executive: the part of working memory that directs attention and processing.", "Central Nervous System (CNS): The collection of neurons that make up the brain and the spinal cord. Is the major controller of the body’s functions, charged with interpreting sensory information and responding to it with its own directives.", "Central Tendency: the point in the distribution around which the data are centred. Typically measured using the arithmetic mean.", "Cerebellum: (i.e., little brain) Consists of two wrinkled ovals behind the brain stem. It functions to coordinate voluntary movement.", "Cerebral Cortex: The outer bark-like layer of our brain that allows us to so successfully use language, acquire complex skills, create tools, and live in social groups. The aspect of the brain that sets humans apart from other animals.", "Challenge: Seeing change and new experiences as exciting opportunities to learn and develop.", "Chameleon Effect: A phenomenon that occurs when individuals nonconsciously mimic the postures, mannerisms, facial expressions, and other behaviors of their interaction partners.", "Character Strengths: A psychological and intellectual virtue.", "Childhood: The period between infancy and the onset of puberty.", "Chromosomes: Multiple strands of DNA (deoxyribonucleic acid) that are grouped together.", "Chronic Disease: Illnesses that persist over time.", "Chunking: the process of organizing information into smaller groupings (chunks), thereby increasing the number of items that can be held in short term memory.", "Cilia: a bundle of fibres that are located on each of the hair cells found in the cochlea.", "Circadian Rhythm: the strongest and most important biorhythm. It guides the daily waking and sleeping cycle in many animals and is influenced by exposure to sunlight as well as daily schedule and activity. Biologically, it includes changes in body temperature, blood pressure and blood sugar.", "Classical Conditioning Effects: how we learn, often without effort or awareness, to associate neutral stimuli with another stimulus, which creates a naturally occurring response.", "Classical Conditioning: A type of learning in which we develop responses to certain stimuli that are not naturally occurring.", "Classical Conditioning: the procedure in which an initially neutral stimulus (the conditioned stimulus, or CS) is paired with an unconditioned stimulus (or US). The result is that the conditioned stimulus begins to elicit a conditioned response (CR). Classical conditioning is nowadays considered important as both a behavioral phenomenon and as a method to study simple associative learning. Same as Pavlovian conditioning. Describes stimulus-stimulus associative learning.", "Client- or Person-Centred Therapy: relies on clients’ capacity for self-direction, empathy, and acceptance to promote clients’ development.", "Clock Time: the hour on the timepiece that governs the beginning and ending of activities.", "Cocaine: an addictive drug obtained from the leaves of the coca plant.", "Cochlea: a snail-shaped liquid-filled tube in the inner ear that contains the cilia.", "Cochlear Implant: a device made up of a series of electrodes that are placed inside the cochlea.", "Cocktail Party Phenomenon: the ability to focus one’s auditory attention on a stimulus while filtering out other competing stimuli.", "Codeine: an analgesic that is weaker and less addictive than morphine and heroin. Also a member of the opiate family.", "Cognition: the processes of acquiring and using knowledge.", "Cognition: the processes of acquiring and using knowledge.", "Cognitive Accessibility: the extent to which knowledge is activated in memory, and thus likely to be used in cognition and behavior.", "Cognitive Appraisal: The cognitive interpretations that accompany emotions.", "Cognitive Behavioural Therapy (CBT): A structured approach to treatment that attempts to reduce psychological disorders through systematic procedures based on cognitive and behavioural principles.", "Cognitive Biases: errors in memory or judgment that are caused by the inappropriate use of cognitive processes", "Cognitive Psychology: A field of psychology that studies mental processes, including perception, thinking, memory, and judgement.", "Cognitive Therapy: A psychological treatment that helps clients identify incorrect or distorted beliefs that are contributing to disorder.", "Cognitive-Behavioural Therapy (CBT): Focuses on helping individuals challenge their patterns and beliefs and replace erroneous thinking with more realistic and effective thoughts, thus decreasing self-defeating emotions and behaviour and breaking what can otherwise become a negative cycle.", "Cohort Effects: Refer to the possibility that differences in cognition or behaviour at two points in time may be caused by differences that are unrelated to the changes in age.", "Collective Unconscious: An aspect of the unconscious that manifests in universal themes that run through all human life.", "Collectivism: Emphasizes connectedness among people and the importance of working towards common goals. A norm in East Asian cultures that are centered around interdependence, including developing harmonious social relationships with others.", "Color Blindness: the inability to detect green and/or red colors.", "Commitment: Results from the perceived value and attainability of a goal. The tendency to see the world as interesting and meaningful.", "Common Ground: information that is shared by people who engage in a conversation.", "Common-Causal Variable: a variable that is not part of the research hypothesis but that causes both the predictor and the outcome variable and thus produces the observed correlation between them.", "Community Learning: Occurs when children serve as both teachers and learners.", "Community Mental Health Services: Psychological treatments and interventions that are distributed at the community level.", "Comorbidity: Occurs when people who suffer from one disorder also suffer at the same time from other disorders.", "Competence: The recognition of one’s own abilities relative to other children.", "Complexes: Usually unconscious and repressed emotionally toned symbolic material that is incompatible with consciousness.", "Compulsions: Repetitive behaviours.", "Concept: the mental representation of a category.", "Conception: Occurs when an egg from the mother is fertilized by a sperm from the father.", "Conceptual Replication: scientific attempt to copy the scientific hypothesis used in an earlier study in an effort to determine whether the results will generalize to different samples, times, or situations. The same – or similar – results are an indication that the findings are generalizable.", "Conceptual Variables: abstract ideas that form the basis of research hypotheses.", "Concrete Operational Stage: Marked by more frequent and more accurate use of transitions, operations, and abstract concepts.", "Conditioned Compensatory Response: in classical conditioning, a conditioned response that opposes, rather than is the same as, the unconditioned response. It functions to reduce the strength of the unconditioned response. Often seen in conditioning when drugs are used as unconditioned stimuli.", "Conditioned Response (CR): the response that is elicited by the conditioned stimulus after classical conditioning has taken place.", "Conditioned Stimulus (CS): an initially neutral stimulus (like a bell, light, or tone) that elicits a conditioned response after it has been associated with an unconditioned stimulus.", "Cones: visual neurons that are specialized in detecting fine detail and colors.", "Confederate: An actor working with the researcher. Most often, this individual is used to deceive unsuspecting research participants.", "Confidentiality: refers to an agreement between researchers and participants that states that the researcher(s) will not reveal participants’ personal information without their consent or legal authorization.", "Confirmation Bias: the tendency to verify and confirm our existing memories rather than to challenge and disconfirm them. A result of our schemas influencing how we seek out and interpret new information. Confirmation bias influences memory in such a way that information that fits our schemas is better remembered than information that disconfirms our schemas.", "Conformity: a process in which people change their beliefs and behaviours to be similar to those of the people that they care about.", "Conformity: The tendency to act and think like the people around us.", "Confounding Variables: variables other than the independent on which the participants in one experimental condition differ systematically from those in the other condition.", "Conscientiousness: The tendency to be careful, on-time for appointments, to follow rules, and to be hardworking.", "Conscious: Having knowledge of something external or internal to oneself; being aware of and responding to one’s surroundings. The ability to accurately report on a stimuli’s existence (or its nonexistence) more than 50% of the time.", "Consciousness: The awareness or deliberate perception of a stimulus. OR our subjective awareness of ourselves and our environment.", "Consent Form: a written document in which informed consent is outlined and obtained from clients and participants.", "Consolidation: the process occurring after encoding that is believed to stabilize memory traces.", "Construct Validity: Tests that actually measure intelligence rather than something else; the extent to which the variables used in the research adequately assess the conceptual variables they were designed to measure.", "Context-Dependent Learning: an increase in retrieval when the external situation in which information is learned matches the situation in which it is remembered.", "Context: stimuli that are in the background whenever learning occurs. For instance, the Skinner box or room in which learning takes place is the classic example of a context. However, “context” can also be provided by internal stimuli, such as the sensory effects of drugs (e.g., being under the influence of alcohol has stimulus properties that provide a context) and mood states (e.g., being happy or sad). It can also be provided by a specific period in time—the passage of time is sometimes said to change the 'temporal context.'", "Contextual Information: the information surrounding language that help us interpret language. Examples include the knowledge that we have and that we know that other people have, and nonverbal expressions such as facial expressions, postures, gestures, and tone of voice.", "Continual-Activation Theory: Proposes that dreaming is a result of brain activation and synthesis.", "Continuous Distributions: A distribution in which most scores fall somewhere in the middle, with smaller numbers showing more extreme levels.", "Contralateral Control: How the brain is wired such that in most cases the left hemisphere receives sensations from and controls the right side of the body, and vice versa.", "Control: The belief in one’s own ability to control or influence events.", "Controlled Behavior: a conscious behavior that is self-censored.", "Convergence: the inward turning of our eyes that is required to focus on objects that are less than about 50 feet away from us.", "Convergent Thinking: thinking that is directed toward finding the correct answer to a given problem.", "Cornea: a clear covering that protects the eye and begins to focus the incoming light.", "Corpus Callosum: The region that normally connects the two halves of the brain and supports communication between the hemispheres.", "Correlational Research: research designed to discover relationships among variables and to allow the prediction of future events from present knowledge; involves the measurement of two or more relevant variables and an assessment of the relationships between or among those variables.", "Cortisol: A primary stress hormone that increases sugars (glucose) in the bloodstream, enhances the brain’s use of glucose, and increases the availability of substances that repair tissues.", "Cost–Benefit Analysis: The process that potential helpers engage in to determine the costs and benefits associated with helping. Or, when costs are compared with the benefits in a research project to determine the ethical standing of that research project.", "Counterconditioning: A second incompatible response (relaxation) is conditioned to an already conditioned response (the fear response).", "Counterfactual Thinking: the tendency to think about and experience events according to “what might have been”.", "Couples Therapy: Treatment in which two people who are cohabitating, married, or dating meet together with the practitioner to discuss their concerns and issues about their relationship.", "Critical Period: a time in which learning can easily occur.", "Cross-Cultural Psychology: Research that uses standard scales to compare cultural groups.", "Cross-Cultural Studies: Research that uses standard forms of measurement to compare people from different cultures and identify their differences.", "Cross-Sectional Research Design: Research designs in which age comparisons are made between samples of different people at different ages at one time.", "Crystallized Intelligence: General knowledge about the world, as reflected in semantic knowledge, vocabulary, and language.", "Crystallized Intelligence: the accumulated knowledge of the world we have acquired throughout our lives.", "Cue Overload Principle: the principle stating that the more memories that are associated to a particular retrieval cue, the less effective the cue will be in prompting retrieval of any one memory.", "Cues: a stimulus that has a particular significance to the perceiver (e.g., a sight or a sound that has special relevance to the person who saw or heard it).", "Cultural Differences: Refers to the differences across cultures.", "Cultural Display Rules: Rules that are learned early in life that specify the management and modification of our emotional expressions according to social circumstances.", "Cultural Intelligence: The ability to understand why members of other cultures act in the ways they do.",\
                  "Cultural Psychology: Attempts to understand and appreciate culture from the point of view of the people within it.", "Cultural Relativism: The principle of regarding and valuing the practices of a culture from the point of view of that culture.", "Cultural Scripts: How a person is taught how to behave according to regional cultural norms; people can have multiple cultural scripts.", "Cultural Similarities: Refers to the similarities across cultures.", "Culture of Honor: A cultural background that emphasizes personal or family reputation and social status.", "Culture: It is a collective understanding of the way the world works, shared by members of a group and passed down from one generation to the next. Represents the common set of social norms, including religious and family values and other moral beliefs, shared by the people who live in a geographical region.", "Curvilinear Relationship: relationships that change in direction and thus are not described by a single straight line.", "Daily Hassles: Everyday minor stressors that can raise blood pressure, alter stress hormones, and suppress the immune system function. Our everyday interactions with the environment that are essentially negative.", "Data: any information that is collected through formal observation or measurement that is used within a research study.", "Debriefing: refers to the process of informing research participants as soon as possible after the study about its purpose, disclosing any deception involved, and minimizing harm or misunderstandings that result from participating.", "Decay: the fading of memories with the passage of time.", "Deception: occurs whenever research participants are not completely and fully informed about the nature of the research project before participating in it.", "Decibel: a unit of relative loudness.", "Declaration of Helsinki: an ethics code that was created in 1964 by the World Medical Council.", "Declarative Memory: conscious memories for facts and events.", "Deep Structure of an Idea: how the idea is represented in the fundamental universal grammar that is common to all languages.", "Deficiency Needs: The bottom four levels of Maslow’s pyramid, including physiological, safety, and social needs.", "Deliberative Phase: A person must decide which of many potential goals to pursue at a given point in time.", "Delusions: False beliefs not commonly shared by others within one’s culture and maintained even though they are obviously out of touch with reality.", "Dementia: A progressive neurological disease that includes loss of cognitive abilities significant enough to interfere with everyday behaviours.", "Dendrite: A branching treelike fibre that collects information from other cells and sends the information to the soma.", "Dependence: a need to use a drug or other substance regularly.", "Dependent Variable: a measured variable that is expected to be influenced by the experimental manipulations.", "Depressants: a class of drugs (psychoactive) that slow down the body’s physiological and mental processes. Also reduces the activity of the CNS.", "Depression: a psychological disorder that affects millions of people worldwide and is known to be caused by biological, social, and cultural factors.", "Depth Cues: messages from our bodies and the external environment that supply us with information about space and distance.", "Depth Perception: the ability to perceive three-dimensional space and to accurately judge distance.", "Derailment: The shifting from one subject to another, without following any one line of thought to conclusion.", "Descriptive Norms: We act the way most people—or most people like us—act.", "Descriptive Research: designed to provide a snapshot of the current state of affairs.", "Descriptive Statistics: used to analyze descriptive research results by summarizing the distribution of scores.", "Development: The physiological, behavioural, cognitive, and social changes that occur throughout human life, which are guided by both genetic predispositions (nature) and by environmental influences (nurture).", "Developmental Intergroup Theory: Postulates that adults’ heavy focus on gender leads children to pay attention to gender as a key source of information about themselves and others, to seek out any possible gender differences, and to form rigid stereotypes based on gender that are subsequently difficult to change", "Diagnostic and Statistical Manual of Mental Disorders (DSM): A document that provides a common language and standard criteria for the classification of mental disorders.", "Dialectical Behavioral Therapy (DBT): Essentially a cognitive therapy, but it includes a particular emphasis on attempting to enlist the help of the patient in his or her own treatment.", "Dichotic Listening: an experimental task in which two messages are presented to different ears.", "Difference Threshold (or Just Noticeable Difference [JND]): the change in a stimulus that can just barely be detected by the organism.", "Diffusion of Responsibility: A phenomenon in which bystanders are relived of personal responsibility and do not intervene because they know that someone else could help.", "Direct Effects of Social Support: Having people we can trust and rely on helps us directly by allowing us to share favours when we need them.", "Directional Goals: When we want a situation to turn out a particular way or our belief to be true.", "Discrimination: When a person is biased against an individual, simply because of the individual’s membership in a social category.", "Discriminative Stimulus: in operant conditioning, a stimulus that signals whether the response will be reinforced. It is said to “set the occasion” for the operant response.", "Disorganized Attachment Style: When a child has no consistent way of coping with the stress of the strange situation.", "Dispersion: the extent to which the scores are all tightly clustered around the central tendency.", "Dissociation: the heightened focus on one stimulus or thought such that many other things around you are ignored; a disconnect between one’s awareness of their environment and the one object the person is focusing on.", "Dissociative Amnesia: A psychological disorder that involves extensive, but selective, memory loss, but in which there is no physiological explanation for the forgetting.", "Dissociative Amnesia: loss of autobiographical memories from a period in the past in the absence of brain injury or disease.", "Dissociative Disorder: A condition that involves disruptions or breakdowns of memory, awareness, and identity.", "Dissociative Fugue: A psychological disorder in which an individual loses complete memory of his or her identity and may even assume a new one, often far from home.", "Dissociative Identity Disorder: A psychological disorder in which two or more distinct and individual personalities exist in the same person, and there is an extreme memory disruption regarding personal information about the other personalities.", "Distinctiveness: the principle that unusual events (in a context of similar events) will be recalled and recognized better than uniform (nondistinctive) events.", "Distractor Task: a task that is designed to make a person think about something unrelated to an impending decision.", "Distribution: the central tendency and spread of data for a particular variable", "Divergent Thinking: the ability to generate many different ideas for or solutions to a single problem.", "Divided Attention: A person’s ability to focus on two or more things at one time; the ability to flexibly allocate attentional resources between two or more concurrent tasks.", "DNA Methylation: Covalent modifications of mammalian DNA occurring via the methylation of cytosine, typically in the context of the CpG dinucleotide.", "DNA Methyltransferases (DNMTs): Enzymes that establish and maintain DNA methylation using methyl-group donor compounds or cofactors. The main mammalian DNMTs are DNMT1, which maintains methylation state across DNA replication, and DNMT3a and DNMT3b, which perform de novo methylation.", "Double-Blind Experiment: both the researcher and the participants are blind to condition.", "Down Syndrome: a chromosomal disorder leading to intellectual disability caused by the presence of all or part of an extra 21st chromosome.", "Dream Analysis: The therapist listens while the client describes his or her dreams and then analyzes the symbolism of the dreams in an effort to probe the unconscious thoughts of the client and interpret their significance.", "Dreams: The succession of images, thoughts, sounds, and emotions that passes through our minds while sleeping; Specific expressions of the unconscious that have a definite, purposeful structure indicating an underlying idea or intention.", "Drive State: An affective experience (something you feel) that motivates organisms to fulfill goals that are generally beneficial to their survival and reproduction.", "Dualism: a term used by Descartes that states that the mind is fundamentally different from the mechanical body; the idea that the mind, a nonmaterial entity, is separate from (although connected to) the physical body.", "Durability Bias: The tendency for people to overestimate how long positive and negative events will affect them.", "Dysthymia: A condition characterized by mild, but chronic, depressive symptoms that last for at least two years.", "Early Adulthood: Roughly the ages between 25 and 45.", "Echoic Memory: auditory sensory memory. Decays slower than iconic memory (4 seconds).", "Eclectic Therapy: An approach to treatment in which the therapist uses whichever techniques seem most useful and relevant for a given patien", "EEG (Electroencephalography): the recording of the brain’s electrical activity over a period of time by placing electrodes on the scalp.", "Effect Size: A measure of the effectiveness of treatment.", "Ego-Depletion: The exhaustion of resource that occurs from resisting a temptation.", "Egocentric: The inability to readily see and understand other people’s viewpoints.", "Egoism: Being primarily concerned with one’s own cost–benefit outcomes.", "Eidetic Imagery (or Photographic Memory): a type of memory that allows people the ability to report details of an image over long periods of time.", "Elaborative Encoding: process new information in ways that make it more relevant or meaningful.", "Electroconvulsive Therapy (ECT): A medical procedure designed to alleviate psychological disorder in which electric currents are passed through the brain, deliberately triggering a brief seizure.", "Electroencephalography (EEG): A technique that records the electrical activity produced by the brain’s neurons through the use of electrodes that are placed around the research participant’s head.", "Electromagnetic Energy: pulses of energy waves that can carry information from place to place.", "Embodied: becoming so closely in touch with the environment that the person’s body and the sensed environment becomes linked with our cognition, such that the world around us becomes part of our brain.", "Embryo: A zygote that attaches to the wall of the uterus.", "Emotion Regulation: The ability to control and productively use one’s emotions.", "Emotion-Focused Coping: Regulates the emotions that come with stress.", "Emotion: A mental and physiological feeling state that directs attention and guides behavior.", "Emotional Intelligence (EI): the ability to monitor one’s own and others’ feelings and emotions, to discriminate among them, to use this information to guide one’s thinking and actions, and to effectively control one’s own emotions. EI includes four specific abilities: perceiving, using, understanding, and managing emotions.", "Empathic Concern: When potential helpers become primarily interested in increasing the well-being of the victim, even if the helper must incur some costs that might otherwise be easily avoided.", "Empathy–Altruism Model: Posits that the key for altruism is empathizing with the victim, that is, putting oneself in the shoes of the victim and imagining how the victim must feel.", "Empirical Methods: refer to a set of methods used by scientists and include the processes of collecting and organizing data and drawing conclusions about those data.", "Empirical: to be based on systematic collection and analysis of data.", "Encoding Specificity Principle: the hypothesis that a retrieval cue will be effective to the extent that information encoded from the cue overlaps or matches information in the engram or memory trace.", "Encoding: The initial experience of perceiving and learning events. It is the process by which we place the things that we experience into memory. The pact of putting information into memory.", "Enculturation: Refers to the ways people learn about and shared cultural knowledge.", "Endocrine System: The chemical regulator of the body that consists of glands that secrete hormones.", "Engrams: a term indicating the change in the nervous system representing an event; also, memory trace.", "Epigenetics: The study of heritable changes in gene expression or cellular phenotype caused by mechanisms other than changes in the underlying DNA sequence. Epigenetic marks include covalent DNA modifications and posttranslational histone modifications.", "Epigenome: The genome-wide distribution of epigenetic marks.", "Episodic Memory: Memory of autobiographical events that can be explicitly stated with a particular time and place. OR The firsthand experiences that we have had.", "Error Management Theory (EMT): A theory of selection under conditions of uncertainty in which recurrent cost asymmetries of judgment or inference favor the evolution of adaptive cognitive biases that function to minimize the more costly errors.", "Escape Learning: A learned behaviour to terminate an unpleasant stimulus.", "Estrogen: One of two female sex hormones secreted by the ovaries. Estrogen is involved in the development of female sexual features, including breast growth, the accumulation of body fat around the hips and thighs, and the growth spurt that occurs during puberty. Also involved in pregnancy and the regulation of the menstrual cycle.", "Ethical Review Board (ERB): a committee of at least five members whose goal it is to determine the cost-benefit ratio of research conducted within in institution. Also known as an Institutional Review Board (IRB).", "Ethics: a broad area within psychology that is concerned with what it means to be moral and how to act morally.", "Ethnocentric Bias: The researcher who designs the study might be influenced by personal biases that could affect research outcomes, without even being aware of it.", "Ethnographic Studies: Research in which the scientist spends time observing a culture and conducting interviews.", "Eugenics: the proposal that one could improve the human species by encouraging or permitting reproduction of only those people with genetic characteristics judged desirable.", "Euphoria: an intense feeling of pleasure, excitement or happiness.", "Eureka Experience: when a creative product enters consciousness.", "Eustress: Stress that is not necessarily debilitative and could be potentially facilitative to a person’s sense of well-being, capacity, or performance.", "Evaluative Priming Task: An implicit test that measures how quickly the participant labels the valence of the attitude object when it appears immediately after a positive or negative image.", "Event Time: scheduling is determined by the flow of the activity. Events begin and end when, by mutual consensus, participants “feel” the time is right.", "Evolution: Certain traits and behaviors developing over time because they are advantageous to our survival.", "Evolutionary Psychology: A branch of psychology that applies the Darwinian theory of natural selection to human and animal behaviour. Seeks to develop and understand ways of expanding the emotional connection between individuals and the natural world, thereby assisting individuals with developing sustainable lifestyles and remedying alienation from nature.",\
                   "Exact (or Direct) Replication: scientific attempt to exactly copy the scientific methods used in an earlier study in an effort to determine whether the results are consistent. The same – or similar – results are an indication that the findings are accurate.", "Excitation Transfer: The phenomenon that occurs when people who are already experiencing arousal from one event tend to also experience unrelated emotions more strongly.", "Excitatory: Neurotransmitters that make the cell more likely to fire.", "Exemplar: an example in memory that is labeled as being in a particular category.", "Exempt Research: research projects in which the federal regulations do not apply given its nature (e.g., using data from public sources).", "Existential Therapy: focuses on “man in the world” by emphasizing the choices to be made in the present and future and enabling a new freedom and responsibility to act.", "Expectation Fulfillment Theory: posits that dreaming serves to discharge emotional arousals that haven’t been expressed during the day.", "Experimental Research: research in which initial equivalence among research participants in more than one group is created, followed by a manipulation of a given experience for these groups and a measurement of the influence of the manipulation.", "Experimenter Bias: a situation in which the experimenter subtly treats the research participants in the various experimental conditions differently, resulting in an invalid confirmation of the research hypothesis.", "Explicit Attitude: An attitude that a person verbally or overtly expresses.", "Explicit Memory: A type of memory that is conscious. Includes memories that are intentionally recollected, typically information that are factual such as previous experiences and concepts. Knowledge or experiences that can be consciously remembered. There are two types of explicit memory – episodic and semantic.", "Exposure Therapy: A behavioural therapy based on the classical conditioning principle of extinction, in which people are confronted with a feared stimulus with the goal of decreasing their negative emotional responses to it.", "External Locus of Control: When a person believes that his or her achievements and outcomes are determined by fate, luck, or other. If the person does not succeed, he or she believes it is due to external forces outside of the person’s control.", "External Validity: the extent to which the results of a research design can be generalized beyond the specific way the original experiment was conducted.", "Extinction: decrease in the strength of a learned behavior that occurs when the conditioned stimulus is presented without the unconditioned stimulus (in classical conditioning) or when the behavior is no longer reinforced (in instrumental conditioning). The term describes both the procedure (the US or reinforcer is no longer presented) as well as the result of the procedure (the learned response declines). Behaviors that have been reduced in strength through extinction are said to be 'extinguished.'", "Extraversion: The tendency to be talkative, sociable, and to enjoy others; the tendency to have a dominant style.", "Extravert: A person who is outer-directed.", "Extrinsic Motivation: Motivation that comes from the benefits associated with achieving a goal.", "Facets: More specific, lower-level units of personality.", "Facial Feedback Hypothesis: Proposes that the movement of our facial muscles can trigger corresponding emotions.", "Factor Analysis: A statistical method that helps to determine whether a small number of dimensions underlie a larger system.", "Facts: objective statements that are determined to be accurate through empirical study.", "False Memories: memory for an event that never actually occurred, implanted by experimental manipulation or other means.", "False-Belief Test: an experimental procedure that assesses whether a perceiver recognizes that another person has a false belief—a belief that contradicts reality.", "Falsified Data (or Faked Data): data that are fabricated, or made up, by researchers intentionally trying to pass off research results that are inaccurate. This is a serious ethical breach and can even be a criminal offense", "Family Study: Starts with one person who has a trait of interest — for instance, a developmental disorder such as autism — and examines the individual’s family tree to determine the extent to which other members of the family also have the trait.", "Family Therapy: Involves families meeting together with a therapist; in some cases, the meeting is precipitated by a particular problem with one family member.", "Farsighted: an image is focused behind the retina, rather than on the retina. Occurs when the light rays bend incorrectly.", "Fear Conditioning: a type of classical or Pavlovian conditioning in which the conditioned stimulus (CS) is associated with an aversive unconditioned stimulus (US), such as a foot shock. As a consequence of learning, the CS comes to evoke fear. The phenomenon is thought to be involved in the development of anxiety disorders in humans.", "Feature Detector Neurons: Specialized neurons, located in the visual cortex, that respond to the strength, angles, shapes, edges, and movements of a visual stimulus.", "Federal Policy for the Protection of Human Subjects: a set of laws that were created from the Belmont Report that guides the conduct of research that is conducted, supported, or regulated by the federal government.", "Feeling Function: Creative, warm, intimate.", "Fetal Alcohol Syndrome (FAS): A condition caused by maternal alcohol drinking that can lead to numerous detrimental developmental effects.", "Fight-or-Flight Response: A reflex that prepares the body to respond to danger in the environment; An emotional and behavioral reaction to stress that increases the readiness for action.", "Fitness: refers to the extent to which having a given characteristic helps the individual organism survive and reproduce at a higher rate than do other members of the species who do not have the characteristic.", "Flashbulb Memory: vivid and emotional personal memories of receiving the news of some momentous (and usually emotional and unusual) event that people believe they can remember very well.", "Flexible Correction Model: the ability for people to correct or change their beliefs and evaluations if they believe these judgments have been biased (e.g., if someone realizes they only thought their day was great because it was sunny, they may revise their evaluation of the day to account for this “biasing” influence of the weather).", "Flooding: A therapeutic technique in which a client is exposed to the source of his or her fear all at once.", "Flourish: To grow and function successfully.", "Flow: A state of optimal performance.", "Fluid Intelligence: The ability to think and acquire information quickly and abstractly. The capacity to learn new ways of solving problems and performing activities.", "Flynn Effect: the observation that scores on intelligence tests worldwide have increased substantially over the past decades.", "Foils: any member of a lineup (whether live or photograph) other than the suspect.", "Forgiveness: Creates a possibility for a relationship to recover from the damage caused by the offending party’s offense.", "Formal Operational Stage: Marked by the ability to think in abstract terms and to use scientific and philosophical lines of thought.", "Four-Branch Model: an ability model developed by Drs. Peter Salovey and John Mayer that includes four main components of EI, arranged in hierarchical order, beginning with basic psychological processes and advancing to integrative psychological processes. The branches are (1) perception of emotion, (2) use of emotion to facilitate thinking, (3) understanding emotion, and (4) management of emotion.", "Fovea: the central point of the retina.", "Framing: the bias to be systematically affected by the way in which information is presented, while holding the objective information constant.", "Free Association: The therapist listens while the client talks about whatever comes to mind, without any censorship or filtering.", "Frequency Theory of Hearing: proposes that whatever the pitch of a sound wave, nerve impulses of a corresponding frequency will be sent to the auditory nerve.", "Frequency: the wavelength of the sound wave. Measured in terms of the number of waves that arrive per second.", "Frontal Lobe: A portion of the brain located behind the forehead, also known as the motor cortex, that is involved in motor skills, higher level cognition (thinking, planning, memory, and judgment), and expressive language.", "Functional Fixedness: occurs when people’s schemas prevent them from using an object in new and non-traditional ways.", "Functional Magnetic Resonance Imaging (fMRI): A type of brain scan that uses a magnetic field to create images of brain activity in each brain area. Detects the amount of blood flow in each brain region and is an indicator of neural activity.", "Functionalism (or School of Functionalism): School of psychology aimed at understanding why animals and humans have developed the particular psychological aspects that they currently possess", "Fundamental Attribution Error: The consistent way we attribute people’s actions to personality traits while overlooking situational influences.", "Gamification: A growing approach to behaviour modification today that involves applying game incentives such as prompts, competition, badges, and rewards to ordinary activities.", "Gate Control Theory of Pain: proposes that pain is determined by the operation of two types of nerve fibres in the spinal cord.", "Gender Constancy: By the third birthday, children can consistently identify their own gender and learn that gender is constant and can’t change simply by changing external attributes.", "Gender Discrimination: Differential treatment on the basis of gender.", "Gender Identity: Refers to a person’s psychological sense of being male or female.", "Gender Roles: The behaviors, attitudes, and personality traits that are designated as either masculine or feminine in a given culture.", "Gender Schema Theory: Argues that children are active learners who essentially socialize themselves.", "Gender Stereotypes: The beliefs and expectations people hold about the typical characteristics, preferences, and behaviors of men and women.", "Gender: Refers to the cultural, social, and psychological meanings that are associated with masculinity and femininity.", "Gene Selection Theory: The modern theory of evolution by selection by which differential gene replication is the defining process of evolutionary change.", "Gene: A specific deoxyribonucleic acid (DNA) sequence that codes for a specific polypeptide or protein or an observable inherited trait. This basic biological unit transmits characteristics from one generation to the next.", "General Adaptation Syndrome (GAS) Model: Describes three distinct phases of physiological change that occur in response to long-term stress: alarm, resistance, and exhaustion.", "General Intelligence Factor (g): a construct that the different abilities and skills measured on intelligence tests have in common.", "Generalization: the extent to which relationships among conceptual variables can be demonstrated in a wide variety of people and a wide variety of manipulated or measured variables.", "Generalized Anxiety Disorder (GAD): A psychological disorder diagnosed in situations in which a person has been excessively worrying about money, health, work, family life, or relationships.", "Generativity: speakers of a language can compose sentences to represent new ideas that they have never before been exposed to.", "Genotype: The DNA content of a cell’s nucleus, whether a trait is externally observable or not.", "Gestalt Therapy: Focuses on the skills and techniques that permit an individual to be more aware of his or her feelings.", "Gestalt: a meaningfully organized whole; a whole is more than the sum of its parts.", "Gland: A gland in the endocrine system that is made up of a groups of cells that function to secrete hormones.", "Glial Cells: (i.e., glia) Cells that surround and link to the neurons, protecting them, providing them with nutrients, and absorbing unused neurotransmitters.", "Glutamate: a neurotransmitter and a form of the amino acid glutamic acid, is perhaps the most important neurotransmitter in memory.", "Goal-Directed Behavior: instrumental behavior that is influenced by the animal’s knowledge of the association between the behavior and its consequence and the current value of the consequence. Sensitive to the reinforcer devaluation effect.", "Goal: The cognitive representation of a desired state or mental idea of how we would like things to turn out.", "Gratitude: A feeling of appreciation or thankfulness in response to receiving a benefit.", "Group Therapy: Psychotherapy in which clients receive psychological treatment together with others.", "Growth Need: the fifth level of Maslow’s pyramid that allows people to reach his or her fullest potential.", "Habit: instrumental behavior that occurs automatically in the presence of a stimulus and is no longer influenced by the animal’s knowledge of the value of the reinforcer. Insensitive to the reinforcer devaluation effect.", "Habituation Procedure: When a baby is placed in a high chair and presented with visual stimuli while a video camera records the infant’s eye and face movements.", "Habituation: The decreased responsiveness toward a stimulus after it has been presented numerous times in succession.", "Hallucinations: Imaginary sensations that occur in the absence of a real stimulus or which are gross distortions of a real stimulus.", "Hallucinogens: psychoactive drugs/substances that, when ingested, alter a person’s sensations and perceptions, often by creating hallucinations that are not real or distorting their perceptions of time.", "Hardiness Theoretical Model: Refers to the resilient stress response patterns in individuals and groups.", "Health Behaviors: Behaviors that can improve or harm health.", "Helpfulness: People high in helpfulness believe they can be effective with the help they give they are more likely to be helpful in the future.", "Helping: Prosocial behaviour that involves providing assistance to another person or group who is in need of help.", "Heritability Coefficient: An easily misinterpreted statistical construct that purports to measure the role of genetics in the explanation of differences among individuals. The heritability coefficient varies from 0 to 1 and is meant to provide a single measure of genetics’ influence of a trait.", "Heritability of the Characteristic: refers to the proportion of the observed differences of characteristics among people that is due to genetics.", "Heritability: (i.e., genetic influence) Is indicated when the correlation coefficient for identical twins exceeds that for fraternal twins, indicating that shared DNA is an important determinant of personality.", "Heroin: a strong addictive drug derived from opium; twice as addictive than morphine.", "Hertz: vibrations per second.", "Heuristics: Cognitive (or thinking) strategies that simplify decision making by reducing complex problem-solving to simpler, rule-based decisions. These information processing strategies are useful in many cases but may lead to errors when misapplied. Two frequently applied heuristics include the representativeness heuristic and the availability heuristic.", "HEXACO Model: Posits that one important class of individual differences was omitted from the Five-Factor Model: Honesty-Humility.", "High-Stakes Testing: Situations in which test scores are used to make important decisions about individuals.", "Highlight: Prioritizing and putting greater effort towards goals.", "Hindsight Bias: refers to the tendency to think that we could have predicted something that has already occurred that we probably would not have been able to predict.", "Hippocampus: Located within the limbic system and consists of two “horns” that curve back from the amygdala. Important for the storage of information in long-term memory.",\
                    "Histone Acetyltransferases (HATs) and Histone Deacetylases (HDACs): HATs are enzymes that transfer acetyl groups to specific positions on histone tails, promoting an “open” chromatin state and transcriptional activation. HDACs remove these acetyl groups, resulting in a 'closed' chromatin state and transcriptional repression.", "Histone Modifications: Posttranslational modifications of the N-terminal 'tails' of histone proteins that serve as a major mode of epigenetic regulation. These modifications include acetylation, phosphorylation, methylation, sumoylation, ubiquitination, and ADP-ribosylation.", "Holist: Believing the whole is more than the sum of the parts.", "Homeostasis: The natural balance in the body’s system. The tendency of an organism to maintain this stability across all the different physiological systems in the body.", "Honeymoon Effect: The tendency for newlyweds to produce unrealistically positive ratings.", "Hormone: A chemical that moves throughout the body to help regulate emotions and behaviours.", "Host Personality: The personality in control of the body most of the time.", "Hostile Sexism: Refers to the negative attitudes of women as inferior and incompetent relative to men.", "Hostility: A pattern of arousal that involves becoming easily upset, angry, and having a negative personality style.", "Hot Cognition: The mental processes that are influenced by desires and feelings.", "HPA Axis: A physiological response to stress involving interactions among the (H) hypothalamus, the (P) pituitary, and the (A) adrenal glands.", "Hue: the shade of a color.", "Human Factors: the field of psychology that uses psychological knowledge, including the principles of sensation and perception, to improve the development of technology.", "Human Intelligence: the ability to think, to learn from experience, to solve problems, and to adapt to new situations.", "Humanistic Psychology: holds a hopeful, constructive view of human beings and of their substantial capacity to be self-determining.", "Humanistic Therapy: A psychological treatment that emphasizes the person’s capacity for self-realization and fulfillment.", "Humility: A clear and accurate sense of one’s abilities and achievements; the ability to acknowledge one’s mistakes, imperfections, gaps in knowledge, and limitations.", "Hypnosis: the state of consciousness whereby a person is highly responsive to the suggestions of another; this state usually involves a dissociation with one’s environment and an intense focus on a single stimulus, which is usually accompanied by a sense of relaxation. OR a trancelike state of consciousness, usually induced by a procedure known as hypnotic induction, which consists of heightened suggestibility, deep relaxation, and intense focus", "Hypnotherapy: The use of hypnotic techniques such as relaxation and suggestion to help engineer desirable change such as lower pain or quitting smoking.", "Hypothalamus: A brain region that is located in the lower, central part of the brain that is responsible for synthesizing and secreting hormones and plays an important role in eating behavior.", "Hypothalamus: Part of the limbic system, located just under the thalamus. A brain structure that contains a number of small areas that perform a variety of functions, including the regulation of hunger and sexual behaviour, as well as linking the nervous system to the endocrine system via the pituitary gland. Helps regulate body temperature, hunger, thirst, and sex, and responds to the satisfaction of these needs by creating feelings of pleasure.", "Hypothesis: A proposed explanation for phenomenon that researchers test through research.", "Iconic Memory: visual sensory memory. Decays rapidly (250 milliseconds).", "Identical Elements Theory of Transfer: The more similar the situations are, the greater the amount of information that will transfer.", "Identical Twins: Two individual organisms that originated from the same zygote and therefore are genetically identical or very similar. The epigenetic profiling of identical twins discordant for disease is a unique experimental design as it eliminates the DNA sequence-, age-, and sex-differences from consideration.", "Identifiability: Identification or placement of a situation is a first response of the nervous system, which can recognize it.", "Illusions: occurs when the perceptual processes that normally help us correctly perceive the world around us are fooled by a particular situation so that we see something that does not exist or that is incorrect.", "Imaginary Audience: Refers to when teenagers are so highly self-conscious that they feel that everyone is constantly watching them.", "Impact Bias: The tendency for a person to overestimate the intensity of their future feelings.", "Implemental Phase: Planning specific actions related to the goal and involves having a mindset that is conducive to the effective implementation of a goal.", "Implicit Association Test (IAT): A measure that assesses how quickly the participant pairs a concept with an attribute. A computer reaction time test measures a person’s automatic associations with concepts. For instance, the IAT could be used to measure how quickly a person makes positive or negative evaluations of members of various ethnic groups.", "Implicit Attitude: An attitude that a person does not verbally or overtly express.", "Implicit Learning: occurs when we acquire information without intent that we cannot easily express.", "Implicit Measures of Attitudes: Measures that infer the participant’s attitude rather than having the participant explicitly report it.", "Implicit Memory: a type of long-term memory that does not require conscious thought to encode. It’s the type of memory one makes without intent. Or, a memory that is acquired and used unconsciously. Implicit memories can affect a person’s thoughts and behaviors. Also the influence of experience on behavior, even if the individual is not aware of those influences.", "Implicit Motives: Goals in which a person is not consciously aware of and that cannot be assessed via self-report.", "Inattentional Blindness: the failure to notice a fully visible object when attention is devoted to something else.", "Incidence: refers to the estimated frequency or occurrence (prevalence) of a psychological disorder within a population.", "Incidental Learning: any type of learning that happens without the intention to learn.", "Independent Self: Views people as unique with a stable collection of personal traits that drive behavior; people tend to express their emotions to influence others.", "Independent Variable: the causing variable that is created (manipulated) by the experimenter.", "Individual Differences: the variations among people on physical or psychological dimensions.", "Individualism: Emphasizes the uniqueness between people, personal freedom, and individual expression of opinions and decision-making. Norms in Western cultures that center on valuing the self and one’s independence from others.", "Individuation: The process of integrating the conscious with the unconscious, synergizing the many components of the psyche.", "Infancy: The developmental stage that begins at birth and continues to one year of age.", "Information Processor: A system for taking information in one form and transforming it into another.", "Informational Influence: People go along with the crowd because people are often a source of information.", "Informed Consent: information given before a participant begins a research session, designed to explain the research procedures and inform that participant of his or her rights during the investigation.", "Ingroup: group to which a person belongs.", "Inhibitory: Neurotransmitters that make the cell less likely to fire.", "Insight: An understanding by the patient of the unconscious causes of his or her symptoms.", "Insomnia: persistent difficulty falling or staying asleep.", "Instincts: Complex inborn patterns of behaviors that help ensure survival and reproduction.", "Institutional Review Board (IRB): a committee of at least five members whose goal it is to determine the cost-benefit ratio of research conducted within in institution. Also known as an Ethical Review Board (ERB).", "Instrumental Conditioning: process in which animals learn about the relationship between their behaviors and their consequences. Also known as operant conditioning.", "Integrative Psychology: Psychology that combines the nature and actions of mind, body, and spirit.", "Intellectual Disability: a generalized disorder ascribed to people who have an IQ below 70, who have experienced deficits since childhood, and who have trouble with basic life skills, such as dressing and feeding themselves and communicating with others", "Intentional Learning: any type of learning that happens when motivated by intention.", "Intentional: an agent’s mental state of committing to perform an action that the agent believes will bring about a desired outcome.", "Intentionality: the quality of an agent’s performing a behavior intentionally—that is, with skill and awareness and executing an intention (which is in turn based on a desire and relevant beliefs).", "Interdependent Self. Views people as being different in each new social context and the social context as the primary drivers of behavior; people tend to control and suppress their emotions to adjust to others.", "Interference: other memories get in the way of retrieving a desired memory", "Internal Locus of Control: When a person believes that his or her achievements and outcomes are determined by his or her own decisions and efforts. If the person does not succeed, he or she believes it is due to his or her own lack of effort.", "Internal Validity: the extent to which we can trust the conclusions that have been drawn about the causal relationship between the independent and dependent variables.", "Interneuron: The most common type of neuron and is located primarily within the CNS. Responsible for communication among neurons. Interneurons allow the brain to combine the multiple sources of available information to create a coherent picture of the sensory information being conveyed.", "Interpersonal Functions of Emotion: The role that emotions play between individuals within a group.", "Interpersonal Intelligence: the capacity to understand the emotions, intentions, motivations, and desires of other people.", "Interpretation: The therapist uses the patient’s expressed thoughts to try to understand the underlying unconscious problems.", "Intersexual Selection: A process of sexual selection by which evolution (change) occurs as a consequences of the mate preferences of one sex exerting selection pressure on members of the opposite sex.", "Intrapersonal Functions of Emotion: The role that emotions play within each of us individually.", "Intrapersonal Intelligence: the capacity to understand oneself, including one’s emotions.", "Intrasexual Competition: A process of sexual selection by which members of one sex compete with each other, and the victors gain preferential mating access to members of the opposite sex.", "Intrinsic Motivation: A drive that powers human behaviour that results from the joy of the task itself. Motivation that comes from the benefits associated with the process of pursing a goal.", "Introspection: A method used by structuralists to attempt to create a map of consciousness by asking research participants to describe exactly what they experience as they work on mental tasks. Asking research participants to describe exactly what they experience as they work on mental tasks.", "Introvert: A person who is inner-directed.", "Intuitive: Sees many possibilities in situations; goes with hunches; impatient with earthy details; impractical; sometimes not present.", "Inverted U Hypothesis: Asserts that, up to a point, stress can be growth inducing but that there is a turning or tipping point when stress just becomes too much and begins to become debilitative.", "IQ: A measure of intelligence that is adjusted for age.", "Iris: The coloured part of the eye that controls the size of the pupil by constricting or dilating in response to light intensity.", "James-Lange Theory of Emotion: A theory proposed by William James and Carl Lange that states that arousal and emotion are not independent, but rather that emotion depends on the pattern of arousal.", "Jet Lag: The state of being fatigued and/or having difficulty adjusting to a new time zone after traveling a long distance (across multiple time zones).", "Job Analysis: determining what knowledge, skills, abilities, and personal characteristics (KSAPs) are required for a given job.", "Joint Attention: two people attending to the same object and being aware that they both are attending to it.", "Joint Attention: two people attending to the same object and being aware that they both are attending to it.", "Kin Selection: The favoritism shown for helping our blood relatives.", "Knocked Out: The action that certain genes will be eliminated during the creation of DNA.", "Lack of Executive Control: Difficulty comprehending information and using it to make decisions.", "Language: a system of communication that uses symbols in a regular way to create meaning. Gives the ability communicate our intelligence to others by talking, reading, and writing.", "Late Adulthood: The final life stage, beginning in the 60s.", "Latent Content: Content within dreams that relates to deep unconscious wishes or fantasies. Or, the hidden psychological meaning of a dream.", "Laws: (in relation to psychology) principles that are so general as to apply to all situations in a given domain of inquiry.", "Law of Disuse: The longer an association is unused, the weaker it becomes.", "Law of Effect: The idea that instrumental or operant responses are influenced by their effects. Responses that are followed by a pleasant state of affairs will be strengthened and those that are followed by discomfort will be weakened. Nowadays, the term refers to the idea that operant or instrumental behaviors are lawfully controlled by their consequences.", "Law of Readiness: A quality in responses and connections that results in readiness to act.", "Law of Recency: The most recent response is most likely to reoccur.", "Law of Use: The more often an association is used, the stronger it becomes.", "Lens: a structure that focuses the incoming light on the retina.", "Lesions: Areas of the brain that are damaged by surgeries, strokes, falls, automobile accidents, gunshots, tumors, etc.", "Letter of Recommendation Effect: The tendency for informants to produce unrealistically positive ratings.", "Levels of Analysis: The different levels at which scientists might understand a single event.", "Levels of Explanation: the perspectives that are used to understand behaviour, with lower levels being tied closely to biological influences, middle levels being tied closely to the abilities and characteristics of individual people, and the highest level relating to social groups, organizations, and cultures.", "Lexical Hypothesis: States that all important personality characteristics should be reflected in the language that we use to describe other people.", "Limbic System: A brain area, located between the brain stem and the two cerebral hemispheres, that governs emotion and memory. The system includes the amygdala, the hypothalamus, and the hippocampus.", "Limited Capacity: the notion that humans have limited mental resources that can be used at a given time.", "Limiting Condition: when the results from a research study are different across cultures.", "Linear Relationship: when the association between variables on a scatter plot can be easily approximated with a straight line.", "Linguistic Intergroup Bias: a tendency for people to characterize positive things about their ingroup using more abstract expressions, but negative things about their outgroups using more abstract expressions.", "Linguistic Relativity: the idea that language and its structures influence and limit human thought.",\
                     "Long-Term Memory: memory storage that can hold information for days, months, and years. There are three processes that are central to long-term memory – encoding, storage, and retrieval.", "Long-Term Potentiation (LTP): the strengthening of the synaptic connections between neurons as result of frequent stimulation.", "Longitudinal Research Designs: Research designs in which individuals in the sample are followed and contacted over an extended period of time, often over multiple developmental stages.", "Loudness: the degree of sound volume.", "Ma: Roughly translates to the “space” between things, or the “pause” (a Japanese term).", "Maintenance Rehearsal: the process of repeating information mentally or out loud with the goal of keeping it in memory.", "Major Depressive Disorder (Clinical Depression): A mental disorder characterized by an all-encompassing low mood accompanied by low self-esteem and loss of interest or pleasure in normally enjoyable activities.", "Major Life Stressors: Large stressful events (e.g., a family death, a natural disaster) that increase the likelihood of getting sick.", "Maladaptive: The extent to which a behavior causes distress (e.g., pain and suffering) and dysfunction (impairment in one or more important areas of functioning) to the individual.", "Mandala: A symbol of wholeness, completeness, and perfection, and symbolized the self.", "Manifest Content: Superficial and meaningless content within dreams; or, the literal dream as it is remembered (i.e., literal actions that occur during dreams).", "Maximum Observed Score: the largest observed value of the variable.", "Mayer-Salovey-Caruso Emotional Intelligence Test (MSCEIT): a 141-item performance assessment of EI that measures the four emotion abilities (as defined by the four-branch model of EI) with a total of eight tasks.", "McGurk Effect: an error in perception that occurs when we misperceive sounds because the audio and visual parts of the speech are mismatched.", "Means: Activities and objects that help us attain goals.", "Measured Variables: variables consisting of numbers that represent the conceptual variables.", "Medial Temporal Lobes: inner region of the temporal lobes that includes the hippocampus.", "Median: the score in the center of the distribution, meaning that 50% of the scores are greater than the median and 50% of scores are les than the median.", "Meditation: techniques in which the individual focuses on something specific, such as an object, a word, or one’s breathing, with the goal of ignoring external distractions, focusing on one’s internal state, and achieving a state of relaxation and well-being.", "Medulla: The area of the brain stem that controls heart rate and breathing.", "Melatonin: A hormone associated with increased drowsiness and sleep.", "Memory Stages: there are three major memory stages – sensory, short-term, and long-term.", "Memory Traces: a term indicating the change in the nervous system representing an event.", "Memory: the ability to store and retrieve information over time.", "Menarche: The first menstrual period, typically experienced at around 12 or 13 years of age.", "Menopause: The cessation of the menstrual cycle, which usually occurs at around age 50.", "Mere-Exposure Effects: the result of developing a more positive attitude towards a stimulus after repeated instances of mere exposure to it.", "Meta-Analysis: A statistical technique that uses the results of existing studies to integrate and draw conclusions about those studies.", "Metacognition: Conscious thought about thought processes. Describes the knowledge and skills people have in monitoring and controlling their own learning and memory.", "Methodologies: Research study design principles.", "Middle Adulthood: Roughly the ages between 45 and 65.", "Mimicry: Copying others’ behavior, usually without awareness.", "Mind–Body Connection: The role that different feelings can have on our body’s function.", "Mindfulness: a state of heightened focus on the thoughts passing through one’s head, as well as a more controlled evaluation of those thoughts (e.g., do you reject or support the thoughts you’re having?).", "Minimal Risk Research: research that exposes participants to risks that do not exceed that found in daily life and/or routine health examinations.", "Minimum Observed Score: the smallest observed value of the variable.", "Mirror Neurons: neurons identified in monkey brains that fire both when the monkey performs a certain action and when it perceives another agent performing that action.", "Misattribution of Arousal: The tendency for people to incorrectly label the source of the arousal that they are experiencing.", "Misinformation Effect: when erroneous information occurring after an event is remembered as having been part of the original event. New information influences existing memories creating errors within our memory. Is caused by exposure to incorrect information between the original event (e.g., a crime) and later memory test (e.g., an interview, lineup, or day in court).", "Mixed and Trait Models: approaches that view EI as a combination of self-perceived emotion skills, personality traits, and attitudes.", "Mock Witnesses: a research subject who plays the part of a witness in a study.", "Mode: the value that occurs most frequently in the distribution.", "Molecular Genetics: The study of which genes are associated with which personality traits.", "Monamine Oxidase Inhibitors (MAOIs): The original antidepressants that work by increasing the amount of serotonin, norepinephrine, and dopamine at the synapses.", "Monochronic (M-time): typically used among people and organizations in clock-time cultures, where it is important to focus on one activity at a time.", "Monocular Depth Cues: depth cues that help us perceive depth using only one eye.", "Mood (or Affective) Disorders: Psychological disorders in which the person’s mood negatively influences his or her physical, perceptual, social, and cognitive processes.", "Mood-Congruent Memory: The tendency to recall memories similar in valence to our current mood.", "Mood: The positive or negative feelings that are in the background of our everyday experiences.", "Moon Illusion: the moon is perceived to be about 50% larger when it is near the horizon than when it is seen overhead, despite the fact that in both cases the moon is the same size and casts the same size retinal image.", "Morality: Standards of behaviour that are generally agreed on within a culture to be right or proper.", "Morpheme: a string of one or more phonemes that makes up the smallest units of meaning in a language.", "Morphine: a strong addictive drug derived from opium; however, less addictive than heroin.", "Motivated Skepticism: When we are skeptical of evidence that goes against what we want to believe despite the strength of the evidence.", "Motivation Theory: Posits that all work consists of simple, uninteresting tasks, and that the only viable method to get people to undertake these tasks is to provide incentives and monitor them carefully.", "Motivation: A psychological driving force that initiates and directs behavior.", "Motor Cortex: The part of the cortex that controls and executes movements of the body by sending signals to the cerebellum and the spinal cord.", "Motor Neuron (or Efferent Neuron): A type of neuron that transmits information to the muscles and glands.", "Mueller-Lyer Illusion: one line segment looks longer than another, even though they are both actually the same length. The result of the failure of monocular depth cues.", "Multiple Regression: a statistical technique, based on correlation coefficients among variables, that allows predicting a single outcome variable from more than one predictor variable.", "Multiple Response: An animal will try multiple responses (trial and error) if the first response does not lead to a specific state of affairs.", "Multiply Determined: behaviour, for example, that is produced by many factors that occur at different levels of explanation.", "Myelin Sheath: A layer of fatty tissue surrounding the axon of a neuron that both acts as an insulator and allows faster transmission of the electrical signal.", "Myers-Briggs Type Indicator: A psychometric questionnaire designed to measure psychological preferences in how people perceive the world and make decisions.", "Mystery: Life is a great mystery.", "Narcolepsy: a disorder characterized by extreme daytime sleepiness with frequent episodes of nodding off.", "Natural Improvement: The possibility that people might get better over time, even without treatment.", "Natural Selection: Differential reproductive success as a consequence of differences in heritable attributes.", "Naturalistic Observations: research based on the observation of everyday events.", "Nature Approach to Language: the belief that human brains contain a language acquisition device that includes a universal grammar that underlies all human language", "Nearsighted: an image is focused in front of the retina, rather than on the retina. Occurs when the light rays bend incorrectly.", "Need for Closure: The desire to come to a firm conclusion.", "Need to Belong: The human need to make friends, start families, and spend time together.", "Negative Linear Relationship: when above-average values for one variable tend to be associated with below-average values for the other variable.", "Negative Reinforcement: Taking something negative away in order to increase a response.", "Negative State Relief Model: People sometimes help in order to make themselves feel better.", "Nerves: Bundles of interconnected neurons that fire in synchrony to carry messages.", "Nervous System: A collection of hundreds of billions of specialized and interconnected cells through which messages are sent between the brain and the rest of the body.", "Neural Correlates of Consciousness (NCC): Seeks to link activity within the brain to subjective human experiences in the physical world.", "Neurogenesis: The generation or growth of new brain cells, specifically when neurons are created from neural stem cells.", "Neuroimaging: the use of various techniques to provide pictures of the structure and function of the living brain.", "Neuron: A cell in the nervous system that is responsible for receiving and transmitting information.", "Neurophilosophy: Views neuronal correlates of consciousness as its cause, and consciousness as a state-dependent property of some undefined complex, adaptive, and highly interconnected biological system.", "Neuroplasticity: The brain’s ability to change its structure and function in response to experience or damage. Enables our ability to remember new things and adjust to new experiences.", "Neurosis: A force that shatters the personality of the patient.", "Neuroticism: The tendency to frequently experience negative emotions such as anger, worry, and sadness, as well as being interpersonally sensitive.", "Neurotransmitter: A chemical that relays signals from terminal buttons and across the synapses between neurons to receiving dendrites using a lock and key type system.", "Nicotine: a psychoactive drug found in tobacco and other members of the nightshade family of plants, where it acts as a natural pesticide." ,"No Relationship: when there is no relationship at all between the two variables, variables are then said to be independent.", "Node of Ranvier: A series of breaks between the sausage-like segments of the myelin sheath that allow electrical charges to move down the axon.", "Non-Rapid Eye Movement (non-REM) Sleep: a deep sleep, characterized by very slow brainwaves, that is further subdivided into three stages: N1, N2, and N3. A sleep state that processes conscious-related memory (declarative memory).", "Nonassociative Learning: occurs when a single repeated exposure leads to a change in behavior.", "Nonconscious: Refers to when a person is unaware of why he or she is pursuing a goal and may not even realize that he or she is pursing it.", "Nonlinear Relationship: relationships between variables that cannot be described with a straight line.", "Nonshared Environment: Is indicated when identical twins do not have similar traits. These influences refer to experiences that are not accounted for either by heritability or by shared environmental factors. Nonshared environmental factors are the experiences that make individuals within the same family less alike.", "Nonspecific Treatment Effects: Occur when the patient gets better over time simply by coming to therapy, even though it doesn’t matter what actually happens at the therapy sessions.", "Nonverbal Communication: Communication that does not involve words.", "Normal Distribution (or Bell Curve): the pattern of scores usually observed in a variable that clusters around its average. The bulk of the scores fall toward the middle, with many fewer scores falling at the extremes.", "Normal Distribution: a data distribution in which most scores fall within the centre of the distribution and are symmetrical and bell-shaped.", "Normative Influence: People go along with the crowd because they are concerned about what others think of them.", "Nuremberg Code: a set of 10 ethics principles written in 1947 for human participants that emphasizes the importance of informed consent and weighing risks against benefits.", "Obedience: Following orders or requests from people in authority.", "Object Permanence: The child’s ability to know that an object exists even when the object cannot be perceived.", "Objective: to be free from personal bias or emotions.", "Observational Learning: learning by observing the behavior of others.", "Obsessions: Repetitive thoughts.", "Obsessive-Compulsive Disorder (OCD): A psychological disorder that is diagnosed when an individual continuously experiences distressing or frightening thoughts and engages in obsessions (repetitive thoughts) or compulsions (repetitive behaviours) in an attempt to calm these thoughts.", "Occipital Lobe: A portion of the brain, also known as the visual cortex, that is involved in interpreting visual stimuli and information.", "Olfactory Membrane: located within the upper nasal passage and embedded with 10 to 20 million receptor cells.", "Olfactory Receptor Cells: embedded within the olfactory membrane. Topped with tentacle-like protrusions that contain receptor proteins.", "Open Ended Questions: Research questions that ask participants to answer in their own words.", "Openness: The tendency to appreciate new art, ideas, values, feelings, and behaviors.", "Operant Conditioning: A type of learning that refers to how an organism operates on the environment or how it responds to what is presented to it in the environment. Describes stimulus-response associative learning. Also see instrumental conditioning.", "Operant: a behavior that is controlled by its consequences. The simplest example is the rat’s lever-pressing, which is controlled by the presentation of the reinforcer.", "Operational Definition: a precise statement of how a conceptual variable is turned into a measured variable.", "Opioids: chemicals that increase activity in opioid receptor neurons in the brain and in the digestive system, producing euphoria, analgesia, slower breathing, and constipation.", "Opium: the dried juice of the unripe seed capsule of the opium poppy", "Opponent-Process Color Theory: a theory that proposes that we analyze sensory information not in terms of three colours but rather in three sets of “opponent colours”: red-green, yellow-blue, and white-black.", "Optic Nerve: a collection of millions of ganglion neurons that sends vast amounts of visual information, via the thalamus, to the brain.", "Optimism: The general tendency to expect positive outcomes.", "Ossicles: three tiny bones located within the middle ear. Includes the hammer, the anvil, and the stirrup.", "Other-Oriented Empathy: A characteristic that involves having a strong sense of social responsibility, the ability to empathize with and feel emotionally tied to those in need, understand the problems the victim is experiencing, and have a heightened sense of moral obligation to be helpful.",\
                      "Outcome Research: Studies that assess the effectiveness of medical treatments to determine the effectiveness of different therapies.", "Outgroup: group to which a person does not belong.", "Outliers: one or more extreme scores which lay far outside the distribution.", "Oval Window: the membrane covering the opening of the cochlea.", "Ovaries: The female sex glands that are located in the pelvis. The ovaries produce eggs and secrete the female hormones estrogen and progesterone.", "Overconfidence: the tendency for people to be too certain about their ability to accurately remember events and to make judgments.", "Overconfident: the bias to have greater confidence in your judgment than is warranted based on a rational assessment.", "Overextensions: the use of a given word in a broader context than appropriate. Generally a mistake made by children.", "Overlearning: continuing to practice and study even when we think that we have mastered the material.", "Ovulation: When an ovum, or egg (the largest cell in the human body), which has been stored in one of the mother’s two ovaries, matures and is released into the fallopian tube.", "Pace of Life: the speed at which changes and events occur for individuals. Dependent on individual temperament, cultural norms, between places, at different times, during different activities.", "Pancreas: Part of the endocrine system. Secretes hormones designed to keep the body supplied with fuel to produce and maintain stores of energy.", "Panic Disorder: A psychological disorder characterized by sudden attacks of anxiety and terror that have led to significant behavioural changes in the person’s life.", "Paradigm: Prevailing model that guides an area of study.", "Parasympathetic Nervous System or Parasympathetic Division: A division of the autonomic nervous system that tends to calm the body by slowing the heart and breathing and by allowing the body to recover from the activities that are caused by the sympathetic system. Works to bring the body back to its normal state after a fight-or-flight response.", "Parathyroid Gland: The area responsible for determining how quickly the body uses energy and hormones (in conjunction with the thyroid gland), and controls the amount of calcium in the blood and bones.", "Parenting Styles: Parental behaviours that determine the nature of parent-child interactions and that guide their interaction with the child.", "Parietal Lobe: A portion of the brain that xtends from the middle to the back of the skull, also known as the somatosensory cortex, that is involved in the processing of other tactile sensory information (information about touch).", "Pavlovian Conditioning: see classical conditioning.", "Pearson Correlation Coefficient (r): the most common statistical measure of the strength of linear relationships among variables.", "People’s (Folk) Explanations of Behavior: people’s natural explanations for why somebody did something, felt something, etc. (differing substantially for unintentional and intentional behaviors).", "Perception of Social Support: The perception that a person has positive social relationships with others.", "Perception: the organization and interpretation of sensations.", "Perceptual Constancy: the ability to perceive a stimulus as constant despite changes in sensation.", "Perceptual Learning: occurs when aspects of our perception changes as a function of experience.", "Performance Assessment: a method of measurement associated with ability models of EI that evaluate the test taker’s ability to solve emotion-related problems.", "Periodic Limb Movement Disorder: a sleep disorder that involves sudden involuntary movement of limbs.", "Peripheral Nervous System (PNS): The collection of neurons that link the central nervous system (CNS) to the body’s sense receptors, muscles, and glands. Divided into the somatic and autonomous nervous systems.", "Permissive Parents: Tend to make few demands and give little punishment, but they are responsive in the sense that they generally allow their children to make their own rules.", "Person-Centred Therapy (or Client-Centred Therapy): An approach to treatment in which the client is helped to grow and develop as the therapist provides a comfortable, nonjudgmental environment.", "Person-Situation Debate: Places the power of personality against the power of situational factors as determinants of the behavior that people exhibit.", "Person’ Mental Age: age at which a person is performing intellectually.", "Persona: The mask or image a person presents to the world.", "Personal Distress: Helpers who do not empathize with a victim may experience feelings of being worried and upset and will have an egoistic motivation for helping.", "Personal Selection: the use of structured tests to select people who are likely to perform well at given jobs.", "Personal Unconscious: An aspect of the psyche does not usually enter an individual’s awareness but appears in overt behaviour or in dreams.", "Personal: The damaging impact of stress on physical and mental health.", "Personality Disorder: A disorder characterized by inflexible patterns of thinking, feeling, or relating to others that cause problems in personal, social, and work situations.", "Personality Traits: Reflect basic personality dimensions on which people differ.", "Personality: The characteristic ways that people differ from one another.", "Phenomenal: In the moment conscious experience.", "Phenotype: The pattern of expression of the genotype or the magnitude or extent to which it is observably expressed—an observable characteristic or trait of an organism, such as its morphology, development, biochemical or physiological properties, or behavior.", "Phi Phenomenon: to perceive a sensation of motion caused by the appearance and disappearance of objects that are near each other.", "Phobia: A specific fear of a certain object, situation, or activity.", "Phoneme: the smallest unit of sound that makes a meaningful difference in a language.", "Photo Spreads: a selection of normally small photographs of faces given to a witness for the purpose of identifying a perpetrator.", "Physiological Adaptations: Adaptations that occur in the body as a consequence of one’s environment.", "Pineal Gland: Located in the middle of the brain and secretes melatonin (a hormone that helps regulate the wake-sleep cycle).", "Pinna: the external and visible part of the ear. Draws in sound waves and guide them into the auditory canal.", "Pitch: the perceived frequency of a sound.", "Pituitary Gland: A pea-sized gland located near the centre of the brain that also known as the 'master gland'. The pituitary gland is responsible for controlling the body’s growth, as well as secreting hormones that signal the ovaries and testes to make sex hormones and influence our responses to pain. The gland also controls ovulation and the menstrual cycle in women and is important in regulating behaviour.", "Place Theory of Hearing: proposes that different areas of the cochlea respond to different frequencies.", "Placebo Effects: Improvements that occur as a result of the expectation that one will get better rather than from the actual effects of a treatment.", "Placenta: An organ that allows the exchange of nutrients between the embryo and the mother, while at the same time filtering out harmful material.", "Planning Fallacy: The tendency to underestimate how much time it will take to complete a task.", "Plasticity: the brain’s ability to develop new neural connections.", "Pluralistic Ignorance: Relying on others to define the situation and to then erroneously conclude that no intervention is necessary when help is actually needed.", "Polychronic (P-time): typically used among people and organizations in event-time cultures, where there is a preference for focusing on several things at once.", "Pons: A structure in the brain stem that helps control the movements of the body, playing a particularly important role in balance and walking.", "Positive Affective States: Pleasant emotional arousal or feelings.", "Positive Linear Relationship: when above-average values from one variable also tend to have above-average values for the other variable", "Positive Psychology: A branch of psychology that focuses the on the strengths, virtues, and talents that contribute to successful functioning and enable individuals and communities to flourish. Also a self-help movement that has concepts grounded in emotion and intuition.", "Positive Reinforcement: Adding something in order to increase a response.", "Post-Traumatic Stress Disorder (PTSD): A psychological disorder that is diagnosed when an individual experiences high levels of anxiety along with reexperiencing the trauma (flashbacks), and a strong desire to avoid any reminders of the event.", "Pre-Screening: identifying and excluding participants who are at high risk.", "Preconscious: Those thoughts that are unconscious at the particular moment in question, but that are not repressed and are available for recall and easily capable of becoming conscious.", "Prediction Error: when the outcome of a conditioning trial is different from that which is predicted by the conditioned stimuli that are present on the trial (i.e., when the US is surprising). Prediction error is necessary to create Pavlovian conditioning (and associative learning generally). As learning occurs over repeated conditioning trials, the conditioned stimulus increasingly predicts the unconditioned stimulus, and prediction error declines. Conditioning works to correct or reduce prediction error.", "Prejudice: Refers to how a person feels about an individual based on their group membership.", "Preoperational Stage: At about two years of age, and until about seven years of age, children begin to use language and to think more abstractly about objects, with capacity to form mental images.", "Preoptic Area: A region in the anterior hypothalamus (front of the hypothalamus) that strongly influences male sexual behavior.", "Preparedness: the idea that an organism’s evolutionary history can make it easy to learn a particular association. Because of preparedness, you are more likely to associate the taste of tequila, and not the circumstances surrounding drinking it, with getting sick. Similarly, humans are more likely to associate images of spiders and snakes than flowers and mushrooms with aversive outcomes like shocks.", "Prepotency of Elements: A subject can filter out irrelevant aspects of a problem and focus on and respond to significant elements of a problem.", "Prevalence: The frequency of occurrence of a given condition in a population at a given time.", "Prevention: Emphasizes safety, responsibility, and security needs, and views goals as 'oughts.'", "Primacy Effect: a tendency to better remember stimuli that are presented early in a list.", "Primary Appraisal: Determining whether the stressor poses a threat.", "Primary Mental Abilities: seven clusters of abilities – word fluency, verbal comprehension, spatial ability, perceptual speed, numerical ability, inductive reasoning, and memory.", "Primary Prevention: Prevention in which all members of the community receive the treatment.", "Primary Sex Characteristics: The sex organs concerned with reproduction.", "Prime: Cues in a person’s immediate environment that activate a goal", "Primed: When concepts and behaviors have been repeatedly associated with each other, one of them is made more cognitively accessible.", "Priming: Process by which exposing people to one stimulus makes certain thoughts, feelings, or behaviours more salient. The activation of certain thoughts or feelings that make them easier to think of and act upon.", "Privacy: refers to people’s right to decide what information about them is shared with others.", "Pro-Social: Benefits to promoting and maintaining human life.", "Proactive Interference: occurs when earlier learning impairs our ability to encode information that we try to learn later.", "Problem Restructuring: To restructure or reorganize the representation of the problem and capitalize on relevant information not previously noticed, switch strategies, or rearrange problem information in a manner more conducive to solution pathways.", "Problem-Focused Coping: Actively addressing the event that is causing stress in an effort to solve the issue at hand.", "Procedural Memory: Memory for the performance of particular types of action.; our often unexplainable knowledge of how to do things.", "Progesterone Female sex hormones.", "Progress: Describes the perception of a reduced discrepancy between the current state and desired end state.", "Projection: a social perceiver’s assumption that the other person wants, knows, or feels the same as the perceiver wants, know, or feels.", "Projective Hypothesis: Posits that if a person is asked to describe or interpret ambiguous stimuli—that is, things that can be understood in a number of different ways—their responses will be influenced by nonconscious needs, feelings, and experiences.", "Promotion: Emphasizes hopes, accomplishments, and advancement needs, and views goals as 'ideals.'", "Proprioception: the ability to sense the position and movement of our body parts.", "Prosocial Behavior: Behavior that benefit another person or group.", "Prosocial Personality Orientation: Personality characteristics that are highly correlated with prosocial behavior.", "Protocol: a written detailed description of a research project involving human participants that is reviewed by an independent committee for ethical approval.", "Psychiatric Service Dogs: Dogs that are trained to help people with mental disorders.", "Psychoactive Drug: a chemical that changes our states of consciousness, and particularly our perceptions and moods.", "Psychoanalysis: A process used within the psychodynamic approach that involves exploring unconscious drives by using talk therapy and dream analysis to deeply and thoroughly explore a person’s early sexual experiences and current sexual desires. A type of analysis that involves attempting to affect behavioural change through having patients talk about their difficulties.", "Psychodynamic Psychology: Approach to understanding human behaviour that focuses on the role of unconscious thoughts, feelings, and memories.", "Psychodynamic Therapy (Psychoanalysis): A psychological treatment based on Freudian and neo-Freudian personality theories in which the therapist helps the patient explore the unconscious dynamics of personality.", "Psychological Adaptations: Mechanisms of the mind that evolved to solve specific problems of survival or reproduction; conceptualized as information processing devices.", "Psychological Approach to Reducing Disorders: An approach that involves providing help to individuals or families through psychological therapy.", "Psychological Assessment: An evaluation of the patient’s psychological and mental health.", "Psychological Disorder: An ongoing dysfunctional pattern of thought, emotion, and behaviour that causes significant distress, and that is considered deviant in that person’s culture or society.", "Psychological Essentialism: the belief that members of a category have an unseen property that causes them to be in the category and to have the properties associated with it.", "Psychologist-Practitioners: psychologists who use existing research to enhance the everyday life of others, including clinical, counselling, industrial-organizational, and school psychologists.", "Psychology: the scientific study of the mind and behaviour.", "Psychoneuroimmunology: Focused on understanding how psychological factors can “get under the skin” and influence our physiology in order to better understand how factors like stress can make us sick.", "Psychophysics: the branch of psychology that studies the effects of physical stimuli on sensory perceptions and mental states.", "Psychosis: A psychological condition characterized by a loss of contact with reality.", "Psychosomatic Medicine: Focused on understanding how psychological factors can 'get under the skin' and influence our physiology in order to better understand how factors like stress can make us sick.", "Psychosurgery: Surgery that removes or destroys brain tissue in the hope of improving disorder; reserved for the most severe cases.",\
                       "Psychotherapy: The professional treatment for psychological disorder through techniques designed to encourage communication of conflicts and insight.", "Puberty: A developmental period in which hormonal changes cause rapid physical alterations in the body, culminating in sexual maturity.", "Punisher: A stimulus that decreases the strength of an operant behavior when it is made a consequence of the behavior.", "Punishment: Adding something aversive in order to decrease a behaviour.", "Pupil: a small opening in the centre of the eye.", "Quantitative Genetics: Scientific and mathematical methods for inferring genetic and environmental processes based on the degree of genetic and environmental similarity among organisms.", "Quantitative Law of Effect: a mathematical rule that states that the effectiveness of a reinforcer at strengthening an operant response depends on the amount of reinforcement earned for all alternative behaviors. A reinforcer is less effective if there is a lot of reinforcement in the environment for other behaviors.", "Radical Behaviourism: The philosophy of the science of behaviour.", "Random Assignment to Conditions: a procedure in which the condition that each participant is assigned to is determined through a random process.", "Range: a simple measure of the dispersion where you subtract the minimum from the maximum observed score.", "Rapid Eye Movement (REM) Sleep: A sleep state characterized by the presence of quick eye movements and dreaming, and that processes the unconscious-related memory (procedural memory).", "Reappraisal: Describes the process of continually reappraising both the nature of the stressor and the resources available for responding to the stressor.", "Recall Memory Test: a measure of explicit memory that involves bringing from memory information that has previously been remembered.", "Recency Effect: the tendency to better remember stimuli that are presented later in a list.", "Reciprocal Altruism: If helping someone now increases the chances that a person will be helped later, then his or her overall chances of survival are increased.", "Reciprocity: Describes how giving to others put them in the frame of mind to give back.", "Recoding: the ubiquitous process during learning of taking information in one form and converting it to another form, usually one more easily remembered.", "Recognition Memory Test: a measure of explicit memory that involves determining whether information has been seen or learned before.", "Reductionist: Believing the simple is the source of the complex.", "Reference Group Effect: People base their self-perceptions, in part, on how they compare to others in their sociocultural reference group.", "Reflex: An involuntary and nearly instantaneous movement in response to a stimulus.", "Refractory Period: A brief time after the firing of the axon in which the axon cannot fire again because the neuron has not yet returned to its resting potential.", "Reinforcement: Any stimulus which strengthens or increases the probability of a specific response.", "Reinforcer Devaluation Effect: the finding that an animal will stop performing an instrumental response that once led to a reinforcer if the reinforcer is separately made aversive or undesirable.", "Reinforcer: any consequence of a behavior that strengthens the behavior or increases the likelihood that it will be performed it again.", "Rejecting-Neglecting Parents: Undemanding and unresponsive.", "Relearning: a measure of memory that assesses how much more quickly information is processed or learned when it is studied again after it has already been learned but then forgotten.", "Reliability: The consistency of test scores across repeated assessments; the consistency of a measured variable.", "Reliable: tests that are consistent over time.", "REM Sleep Behaviour Disorder: a condition in which people (usually middle-aged or older men) engage in vigorous and bizarre physical activities during REM sleep in response to intense, violent dreams.", "Renewal Effect: recovery of an extinguished response that occurs when the context is changed after extinction. Especially strong when the change of context involves return to the context in which conditioning originally occurred. Can occur after extinction in either classical or instrumental conditioning.", "Replicate: to repeat, add to, or modify (usually in relation to previous research findings).", "Replication: the process of repeating previous research, which forms the basis of all scientific inquiry.", "Representativeness Heuristic: Basing one’s judgments on information that seems to represent, or match, what we expect will happen, while ignoring other potentially more relevant statistical information. The tendency for people to arrive at a decision quickly by simply judging the likelihood of the object belonging to a category, based on how similar it is to one’s mental representation of that category.", "Repressed: a term coined by Sigmund Freud that refers to memories that remain outside consciousness.", "Research Confederate: A person working with a researcher who acts as a research participant or bystander.", "Research Design: the specific method a researcher uses to collect, analyze, and interpret data.", "Research Hypothesis: a specific and falsifiable prediction about the relationship between or among two or more variables.", "Research Participant: A person being studied as part of a research program.", "Research Psychologists: Psychologists who use scientific methods to create new knowledge about the causes of behaviour.", "Resilience: The ability to bounce back from adversity.", "Resistance: The patient’s use of defence mechanisms to avoid the painful feelings in his or her unconscious.", "Respect for Persons: an ethical guideline from the Belmont Report that recognizes the importance using informed consent as a way to allow people to fully exercise their rights as autonomous people.", "Response Bias: a behavioural tendency to respond “yes” to the trials, which is independent of sensitivity.", "Response by Analogy: Responses from a related or similar context may be used in a new context.", "Response: Describes stress as a physiological response pattern.", "Resting Potential: A state in which the interior of the neuron contains a greater number of negatively charged ions than does the area outside the cell.", "Restless Legs Syndrome: a sleep disorder in which the sufferer reports an itching, burning, or otherwise uncomfortable feeling in his legs, usually exacerbated when resting or asleep.", "Reticular Formation: A long, narrow network of neurons that run through the medulla and the pons. Its job is to filter out some of the stimuli that are coming into the brain from the spinal cord, to relay the remainder of the signals to other areas of the brain, and to play a role in walking, eating, sexual activity, and sleeping.", "Retina: the layer of tissue at the back of the eye that contains photoreceptor cells.", "Retrieval: the process of accessing, reactivating, and utilizing information that has been stored in memory.", "Retroactive Interference: occurs when learning something new impairs our ability to retrieve information that was learned earlier. OR The phenomenon whereby events that occur after some particular event of interest will usually cause forgetting of the original event.", "Retrograde Amnesia: a memory disorder that produces an inability to retrieve memories for facts and events that occurred before the onset of amnesia.", "Reuptake: A process in which neurotransmitters that are in the synapse are reabsorbed into the transmitting terminal buttons, ready to again be released after the neuron fires.", "Reward Value: Affects an organism’s motivation to consume food and is sensitive to the level of hunger experienced.", "Reward-Punishment Drive: A drive powering human behaviour that produces the expected performance results.", "Right-Wing Authoritarianism (RWA): Describes a belief that endorses respect for obedience and authority in the service of group conformity.", "Risk Factors: The social, environmental, and economic vulnerabilities that make it more likely than average that a given individual will develop a disorder.", "Rituals: Cultural behaviors that teach people what is important.", "Rods: visual neurons that specialize in detecting black, white, and gray colours.", "Saccades: the thousands of tiny movements made by the eye every minute.", "Safety Ratio: One way to determine how dangerous a recreational drug may be. Based on the dose that is likely to be fatal divided by the normal dose needed to feel the effects of the drug.", "Sample Size: number of participants in a study. Sample size is important because it can influence the confidence scientists have in the accuracy and generalizability of their results", "Sample: the people chosen to participate in the research.", "Sapir-Whorf Hypothesis: the hypothesis that the language that people use determines their thoughts.", "Satiation: The decline of hunger and the eventual termination of eating behavior." ,"Scatter Plot: a visual image of the relationship between two variables.", "Schema: A mental model, or representation, of any of the various things we come across in our daily lives.", "Schemas (also known as Schematas): also known as a memory template, created through repeated exposure to a particular class of objects or events. Patterns of knowledge in long-term memory that help people remember, organize, and respond to information.", "Schizophrenia: A serious psychological disorder marked by delusions, hallucinations, loss of contact with reality, inappropriate affect, disorganized speech, social withdrawal, and deterioration of adaptive behaviour.", "School of Functionalism: a school in psychology that aims to understand why animals and humans have developed the particular psychological aspects that they currently possess.", "Scientific Management: Focuses on scientific study of productivity in the workplace.", "Scientific Method: the set of assumptions, rules, and procedures that scientists use to conduct empirical research.", "Seasonal Affective Disorder (SAD): depression experienced most often during the dark winter months than during the lighter summer months, which can be reduced by exposure to bright lights.", "Secondary Appraisal: The individual’s evaluation of the resources or coping strategies at his or her disposal for addressing any perceived threats.", "Secondary Sex Characteristics: Features that distinguish the two sexes from each other but are not involved in reproduction.", "Secure Attachment Style: When a child explores freely while the mother is present and engages with the stranger.", "Secure Base: Allows monkeys and human babies to feel safe.", "Selective Attention: the ability to select certain stimuli in the environment to process, while ignoring distracting information.", "Selective Forgetting: Letting go of certain ideas or concepts that may be inhibiting the problem-solving process.", "Selective Serotonin Reuptake Inhibitors (SSRIs): The antidepressants most prescribed today that are designed to selectively block the reuptake of serotonin at the synapse, thereby leaving more serotonin available in the central nervous system.", "Self-Actualize: To reach the fullest potential as a human being.", "Self-Categorization Theory: People categorize people into categories and tend to favor the groups with people like us and incidentally disfavor the others.", "Self-Concept: A knowledge representation or schema that contains knowledge about us.", "Self-Construal: The way people define the way they “fit” in relation to others.", "Self-Control: The capacity to control impulses, emotions, desires, and actions in order to resist a temptation and protect a valued goal.", "Self-Efficacy: The belief in our ability to carry out actions that produce desired outcomes.", "Self-Enhancement Bias: People are motivated to ignore (or at least downplay) some of their less desirable characteristics and to focus instead on their more positive attributes.", "Self-Help Group: A voluntary association of people who share a common desire to overcome psychological disorder or improve their well-being.", "Self-Regulation: The process through which individuals alter their perceptions, feelings, and actions in the pursuit of a goal.", "Self-Report Assessment: a method of measurement associated with mixed and trait models of emotional intelligence, which evaluates the test taker’s perceived emotion-related skills, distinct personality traits, and other characteristics.", "Self: An archetype symbolizing the totality of the personality.", "Semantic Memory: Our knowledge of facts and concepts about the world. The more or less permanent store of knowledge that people have.", "Sensation: awareness resulting from the stimulation of a sense organ.", "Sense of Coherence: A global orientation that expresses the extent to which one has a pervasive, enduring though dynamic feeling of confidence that (1) the stimuli deriving from one’s internal and external environments in the course of living are structured, predictable and explicable; (2) the resources are available to one to meet the demands posed by these stimuli; and (3) these demands are challenges, worthy of investment and engagement.", "Sensing Function: Sensory; oriented toward the body and senses; detailed, concrete, and present.", "Sensitivity: the true ability of the individual to detect the presence or absence of signals.", "Sensitization: occurs when the response to a stimulus increases with exposure.", "Sensorimotor Stage: Refers to the direct physical interactions that babies have with the objects around them, beginning at birth until around the age of two.", "Sensory Adaptation: a decreased sensitivity to a stimulus after prolonged and constant exposure.", "Sensory Deprivation: the intentional reduction of stimuli affecting one or more of the senses, with the possibility of resulting changes in consciousness.", "Sensory Interaction: the working together of different senses to create experience.", "Sensory Memory: the brief storage of sensory information.", "Sensory Neuron (or Afferent Neuron): A type of neuron that carries information from the sensory receptors.", "Serial Position Curve: people are able to retrieve more words that were presented to them at the beginning and the end of the list than they are words that were presented in the middle of the list.", "Set (or Attitude): Specific ways animals are predisposed to act in.", "Set Point: An ideal level that the state of the system being regulated is monitored and compared.", "Sex: Refers to the biological category of male or female, as defined by physical differences in genetic composition and in reproductive anatomy and function.", "Sexual Harassment Unwanted treatment related to sexual behaviors or appearance.", "Sexual Orientation: The direction of their emotional and erotic attraction toward members of the opposite sex, the same sex, or both sexes.", "Sexual Selection: The evolution of characteristics because of the mating advantage they give organisms.", "Shadow: The side of a personality that a person does not consciously display in public.", "Shadowing: a task in which the individual is asked to repeat an auditory message as it is presented.", "Shared Environment: Determinants that are indicated when the correlation coefficients for identical and fraternal twins are greater than zero and also very similar. These correlations indicate that both twins are having experiences in the family that make them alike.", "Short-term Memory (STM): the place where small amounts of information can be temporarily kept for more than a few seconds but usually for less than one minute.", "Sibling Contrast Effect: Parents often exaggerate the true magnitude of differences between their children.", "Signal Detection Analysis: a technique used to determine the ability of the perceiver to separate true signals from background noise.", "Silent Language: the notion that cultural rules of social time are seldomly made explicit, but rather just exist. Described by Edward Hall.", "Simulation: the process of representing the other person’s mental state.", "Single-Blind Experiment: the research participants are blind to condition.",\
                        "Situation Model: a mental representation of an event, object, or situation constructed at the time of comprehending a linguistic description.", "Situational Identity: Culture can change and adapt, and people can have multiple cultural identifies, dependent on their social context.", "Six Senses: seeing, hearing, smelling, touching, tasting, and monitoring the body’s positions.", "Skinner Box: Used to measure responses of organisms (most often rats and pigeons) and their orderly interactions with the environment.", "Sleep Apnea: a sleep disorder characterized by pauses in breathing that last at least 10 seconds during sleep.", "Sleep Spindles: theta waves interspersed with bursts of rapid brain activity that occurs during stage N2 sleep.", "Sleep Terrors: a disruptive sleep disorder, most frequently experienced in childhood, that may involve loud screams and intense panic.", "Sleeper Effect: attitude change that occurs over time when we forget the source of information.", "Slow Wave Sleep: also known as stage N3. The deepest level of sleep, characterized by an increased proportion of very slow delta waves.", "Social and Cultural Functions of Emotion: The role that emotions play in the maintenance of social order within a society.", "Social and Emotional Learning (SEL): the real-world application of emotional intelligence in an educational setting and/or classroom that involves curricula that teach the process of integrating thinking, feeling, and behaving in order to become aware of the self and of others, make responsible decisions, and manage one’s own behaviors and those of others." ,"Social Approach to Reducing Disorders: An approach that focuses on changing the social environment in which individuals live to reduce the underlying causes of disorder.", "Social Attribution: When we make educated guesses about the efforts or motives of others.", "Social Brain Hypothesis: the hypothesis that the human brain has evolved, so that humans can maintain larger ingroups.", "Social Clock: The culturally preferred 'right time' for major life events, such as moving out of the childhood house, getting married, and having children.", "Social Cognition: The way we think about the social world and how we perceive others.", "Social Comparison: Comparing the self to others.", "Social Component: The influences on disorder due to social and cultural factors such as socioeconomic status, homelessness, abuse, and discrimination.", "Social Constructivist: Assert that, despite a common evolutionary heritage, different groups of humans evolved to adapt to their distinctive environments.", "Social Dominance Orientation (SDO): Describes a belief that group hierarchies are inevitable in all societies and are even a good idea to maintain order and stability.", "Social Identity Theory: The tendency to favor one’s own in-group over another’s outgroup, and as a result, outgroup disliking stems from this in-group liking.", "Social Identity: The part of the self-concept that is derived from one’s group memberships.", "Social Influence: Refers to how outside influences might sway people to act or feel a certain way.", "Social Integration: The number of social roles that a person has as well as a lack of isolation.", "Social Learning Theory: The theory that people can learn new responses and behaviors by observing the behavior of others. Argues that gender roles are learned through reinforcement, punishment, and modeling.", "Social Models: authorities that are the targets for observation and who model behaviors.", "Social Networks: networks of social relationships among individuals through which information can travel.", "Social Norms: the ways of thinking, feeling, or behaving that are shared by group members and perceived by them as appropriate.", "Social Phobia: Extreme shyness around people or discomfort in social situations.", "Social Psychology: A branch of psychological science mainly concerned with understanding how the presence of others affects our thoughts, feelings, and behaviors.", "Social Referencing: The process whereby infants seek out information from others to clarify a situation and then use that information to act.", "Social Support: Receiving support from your social network that can include emotional help, tangible help, or advice.", "Social Time: cultural rules that are simply picked up in regards to being early or late, to wait or to rush, and the concept of past, present, and future.", "Social-Cultural Psychology: a school of psychology that studies how social situations and culture influence thinking and behaviour.", "Sociocultural Theory: Posits that cognitive development is not isolated entirely within the child but occurs at least in part through social interactions.", "Socioeconomic: Differential exposure to stressful experiences can produce gender, racial-ethnic, marital status, and social class inequalities in physical and mental health.", "Sociopolitical: Stressors proliferate over the life course and across generations, widening health gaps between advantaged and disadvantaged group members.", "Soma: A cell body that contains the nucleus of the cell and keeps the cell alive.", "Somatic Nervous System (SNS): The division of the peripheral nervous system that controls the external aspects of the body, including the skeletal muscles, skin, and sense organs. The somatic nervous system consists primarily of motor nerves responsible for sending brain signals for muscle contraction.", "Somatosensory Cortex: An area just behind and parallel to the motor cortex at the back of the frontal lobe, receives information from the skin’s sensory receptors and the movements of different body parts.", "Somnambulism (Sleepwalking): a sleep disorder characterized by a person leaving the bed and moving around while still asleep.", "Source Monitoring: the ability to accurately identify the source of a memory.", "Spacing Effect: the fact that learning is better when the same amount of study is spread out over periods of time than it is when it occurs closer together or at the same time.", "Specific Intelligence(s): a measure of specific skills in narrow domains.", "Spinal Cord: The long, thin, tubular bundle of nerves and supporting cells that extends down from the brain. It is the central throughway of information for the body.", "Spontaneous Recovery: recovery of an extinguished response that occurs with the passage of time after extinction. Can occur after extinction in either classical or instrumental conditioning.", "Spreading Activation: When problem solvers disengage from the problem-solving task, they expose themselves to more information that can inform the problem-solving process.", "Spurious Relationship: a relationship between two variables in which a common-causal variable produces and “explains away” the relationship.", "Stage Theory of Cognitive Development: children pass through a series of cognitive stages as they grow, each of which must be mastered in succession before movement to the next cognitive stage can occur.", "Standard Deviation (s): the most commonly used measure of dispersion. Distributions with larger standard deviations have more spread.", "Standard Scale: Surveys that ask all participants to use the same scale to respond to questions.", "Standardization: involves giving a test to a large number of people at different ages and computing the average score on the test at each age level.", "Stanford-Binet Test: a measure of general intelligence made up of a wide variety of tasks including vocabulary, memory for pictures, naming of familiar objects, repeating sentences, and following commands.", "State-Dependent Learning: superior retrieval of memories when the individual is in the same physiological or psychological state as during encoding.", "Statistical Conclusion Validity: the extent to which we can be certain that the researcher has drawn accurate conclusions about the statistical significance of the research.", "Statistical Significance: the confidence with which scientists can conclude that data are not due to chance or random error.", "Stereotype Content Model: Includes four kinds of stereotypes that form from perceptions of competence and warmth.", "Stereotype Threat: performance decrements that are caused by the knowledge of cultural stereotypes.", "Stereotypes: Our general beliefs about a group of people and, once activated, they may guide our judgments outside of conscious awareness.", "Stereotyping: A way of using information shortcuts about a group to effectively navigate social situations or make decisions.", "Stigma: A disgrace or defect that indicates that person belongs to a culturally devalued social group.", "Stigmatized Groups: A social or ethnic group that disapproved by the majority of society.", "Stimulant: a class of drugs (psychoactives) that speed up the body’s physiological and mental processes. Operates by blocking the reuptake of dopamine, norepinephrine, and serotonin in the synapses of the CNS.", "Stimulus Control: when an operant behavior is controlled by a stimulus that precedes it.", "Stimulus: Describes stress as a significant life event or change that demands response, adjustment, or adaptation.", "Storage: the stage in the learning/memory process that bridges encoding and retrieval; the persistence of memory over time.", "Story: Every person has a personal story.", "Strange Situation: A measure of attachment in young children in which the child’s behaviours are assessed in a situation in which the caregiver and a stranger move in and out of the environment.", "Stress Coping: Determining whether a person believes he or she has the resources to respond effectively to the challenges of a stressor or change.", "Stress-Related Growth: A dispositional response to stress that enables the individual to see opportunities for growth as opposed to threat or debilitation.", "Stress: The physiological responses that occur when an organism fails to respond appropriately to emotional or physical threats.", "Structuralism: A school of psychology whose goal was to identify the basic elements or structures of psychological experience.", "Subliminal Perception: the ability to process information for meaning when the individual is not consciously aware of that information.", "Subliminal Stimuli: events that occur below the absolute threshold and of which we are not conscious.", "Subtle Biases: Unexamined and sometimes unconscious biases that have real consequences.", "Suprachiasmatic Nucleus: a region in the brain above the thalamus that receives signals from ganglion cells in the retina and is the body’s primary circadian pacemaker.", "Surface Structure of the Idea: how an idea is expressed in any one language.", "Surveys: a measure administered through either an interview or a written questionnaire to get a picture of the beliefs or behaviors or a sample of people of interest", "Symbol: Implies something that is vague and partially unknown or hidden and never precisely defined.", "Sympathetic Division or Sympathetic Nervous System: A division of the autonomic nervous system that is involved in preparing the body for behavior, particularly in response to stress, by activating the organs and the glands in the endocrine system. Controls the fight-or-flight response.", "Synapses: Junction areas where the terminal buttons at the end of the axon of one neuron nearly, but do not quite, touch the dendrites of another neuron.", "Synchrony: two people displaying the same behaviors or having the same internal states (typically because of mutual mimicry).", "Synesthesia: an experience in which one sensation creates experiences in another.", "Syntax: rules by which words are strung together to form sentences.", "System 1: our intuitive decision-making system, which is typically fast, automatic, effortless, implicit, and emotional.", "System 2: our more deliberative decision-making system, which is slower, conscious, effortful, explicit, and logical.", "Systematic Desensitization: A behavioural treatment that combines imagining or experiencing the feared object or situation with relaxation exercises.", "Tardive Dyskinesia: Permanent neurological damage from taking antipsychotic drugs that causes uncontrollable muscle movements, usually in the mouth area.", "Taste Aversion Conditioning (Learning): the phenomenon in which a taste is paired with sickness, and this causes the organism to reject—and dislike—that taste in the future.", "Taste Buds: receptors covering the tongue that are designed to sense chemicals in the mouth.", "Temperament: The innate personality characteristics of an infant.", "Temporal Lobe: A portion of the brain, also known as the auditory cortex, Located in front of the occipital lobe between the ears. It is involved in the interpretation of the sounds and language we hear.", "Temporal Perspective: the perspective an individual takes about time. For example, some individuals may focus on the past, while others focus on the future.", "Temporally Graded Retrograde Amnesia: inability to retrieve memories from just prior to the onset of amnesia with intact memory for more remote events.", "Tend-and-Befriend Response: A behavioral reaction to stress that involves activities designed to create social networks that provide protection from threats.", "Teratogens: Substances that can harm the fetus.", "Tertiary Prevention: Treatment, such as psychotherapy or biomedical therapy, that focuses on people who are already diagnosed with disorder.", "Testes: Male sex glands that secrete a number of hormones, the most important of which is testosterone.", "Testosterone: Male sex hormone secreted by the testes. Regulates body changes associated with sexual development, including enlargement of the penis, deepening of the voice, growth of facial and pubic hair, and the increase in muscle growth and strength.", "Thalamus: An egg-shaped structure above the brain stem that applies more filtering to the sensory information that is coming up from the spinal cord and through the reticular formation, and relays some of these remaining signals to the higher brain levels.", "The Big Five (Five-Factor Model): The most widely accepted system that describes five major personality traits.", "Theory of Intelligence (Three Part or Triarchic): proposes that people may display more or less analytical intelligence, creative intelligence, and practical intelligence. Proposed by Robert Sternberg.", "Theory of Mind: The human capacity to understand minds, a capacity that is made up of a collection of concepts (e.g., agent, intentionality) and processes (e.g., goal detection, imitation, empathy, perspective taking). The ability to take another person’s viewpoint.", "Theory of Natural Selection: an idea coined by Charles Darwin that proposed that the physical characteristics of animals and humans evolved because they were useful or functional.", "Theory: an integrated set of principles that explains and predicts many, but not all, observed relationships within a given domain of inquiry.", "Therapeutic Alliance: A relationship between the client and the therapist that is facilitated when the therapist is genuine, when the therapist treats the client with unconditional positive regard, and when the therapist develops empathy with the client.", "Thinking Function: Logical; sees cause and effect relations; cool, distant, frank, and questioning.", "Third Force: Humanistic psychology.", "Threat-Simulation Theory: Dreams are seen as an ancient biological defense mechanism since they simulate potentially threatening events.", "Three Stages of Moral Thinking: Three stages that children pass through as they develop intellectually.", "Thriving: Growth and strength that arise in the face of adversity.", "Thyroid Gland: The area responsible for determining how quickly the body uses energy and hormones (in conjunction with the parathyroid gland), and affects metabolism, among other things.", "Tinnitus: a ringing or a buzzing sensation that typically occurs after being exposed to loud sounds that likely damaged the cilia within the cochlea.", "Tip-of-the-Tongue Phenomenon: we are certain that we know something that we are trying to recall but cannot quite come up with it.", "Tolerance: an increase in the dose of a drug that is required to produce the same effect.",\
                         "Toxic Inhalants: a substance that is easily accessible as the vapours of glue, gasoline, propane, hairspray, and spray paint, and are inhaled to create a change in consciousness. Often frequently abused as depressants.", "Traits of Good Theories: 1) General: they summarize many different outcomes. 2) Parsimonious: they provide the simplest possible account of outcomes. 3) Falsifiable: the variables of interest can be adequately measured and the relationships between the variables that are predicted by the theory can be shown, through research, to be incorrect.", "Trance States: a state of consciousness characterized by the experience of 'out-of-body possession,' or an acute dissociation between one’s self and the current, physical environment surrounding them.", "Transactional Theory of Stress and Coping (TTSC): Describes stress as a product of a transaction between a person and his or her complex environment.", "Transcranial Magnetic Stimulation (TMS): A procedure in which magnetic pulses are applied to the brain of a living person with the goal of temporarily and safely deactivating a small brain region. TMS is used to temporarily and safely deactivate a small brain region, with the goal of testing the causal effects of the deactivation on behavior.", "Transduction: the conversion of stimuli detected by receptor cells to electrical impulses that are then transported to the brain.", "Transfer-Appropriate Processing: a principle that states that memory performance is superior when a test taps the same cognitive processes as the original encoding activity.", "Transference: The unconscious redirection of the feelings experienced in an important personal relationship toward the therapist.", "Trichromatic Colour Theory: the belief that the colour we see depends on the mix of the signals from the three types of cones.", "Tricyclic Antidepressants: The original antidepressants that work by increasing the amount of serotonin, norepinephrine, and dopamine at the synapses.", "Twin Studies: A behavior genetic research method that involves comparison of the similarity of identical (monozygotic; MZ) and fraternal (dizygotic; DZ) twins.", "Two-Factor Theory of Emotion: Asserts that the experience of emotion is determined by the intensity of the arousal we are experiencing, but that the cognitive appraisal of the situation determines what the emotion will be.", "Tympanic Membrane (or Eardrum): a tightly stretched, highly sensitive membrane at the end of the auditory canal.", "Type A Behavior: A pattern of behavior that includes being competitive, impatient, hostile, and time urgent, and is associated with a greater risk of heart disease.", "Type B Behavior: A pattern of behavior that includes being easygoing, patient, and relaxed, and is associated with a lower risk of heart disease.", "Types of Memory: there are two types of memory – explicit memory and implicit memory.", "Typicality: the difference in “goodness” of category members, ranging from the most typical (the prototype) to borderline members.", "Umbilical Cord: Links the embryo directly to the placenta and transfers all material to the fetus.", "Unconditioned Response (UR): in classical conditioning, an innate response that is elicited by a stimulus before (or in the absence of) conditioning.", "Unconditioned Stimulus (US): in classical conditioning, the stimulus that elicits the response before conditioning occurs.", "Unconscious: Not conscious; the part of the mind that affects behavior though it is inaccessible to the conscious mind. Those things that are outside of conscious awareness, including many memories, thoughts, and urges of which we are not aware.", "Universalist: Assert that emotions evolved as a response to the environments of our primordial ancestors, so they are the same across all cultures.", "Valid: the conclusions drawn by the researcher are legitimate.", "Validity: Evidence related to the interpretation and use of test scores.", "Value-Free Research: When social psychologists research culture, they try to avoid making value judgments in order to approach scientific objectivity.", "Variables: any attribute that can assume different values among different people or across different times or places.", "Vestibular System: a set of liquid-filled areas in the inner ear that monitors the head’s position and movement, maintaining the body’s balance.", "Vicarious Reinforcement: learning that occurs by observing the reinforcement or punishment of another person.", "Virtual Reality CBT: The therapist uses computer-generated, three-dimensional, lifelike images of the feared stimulus in a systematic desensitization program.", "Visible Spectrum: the range of energy the eyes can detect on the electromagnetic spectrum. For humans, this range is only 400 to 700 billionths of a meter.", "Visual Accommodation: the process of changing the curvature of the lens to keep the light entering the eye focused on the retina.", "Visual Attention: The brain’s ability to selectively filter unattended or unwanted information from reaching awareness.", "Visual Cliff: a mechanism that gives the perception of a dangerous drop-off, in which infants can be safely tested for their perception of depth.", "Visual Cortex: The area located in the occipital lobe (at the very back of the brain) that processes visual information.", "Visual Perspective Taking: can refer to visual perspective taking (perceiving something from another person’s spatial vantage point) or more generally to effortful mental state inference (trying to infer the other person’s thoughts, desires, emotions).", "Wavelength: the distance between one wave peak and the next wave peak.", "Weber’s Law: the just noticeable difference of a stimulus is a constant proportion of the original intensity of the stimulus.", "Wechsler Adult intelligence Scale (WAIS): the most widely used intelligence test for adults.", "Wernicke’s Area: an area of the brain next to the auditory cortex  responsible for language comprehension.", "Wish Fulfilment: the idea that dreaming allows us to act out the desires that we must repress during the day.", "Withdrawal: negative experiences that accompany reducing or stopping drug use, including physical pain and other symptoms.", "Word Association Test: A research technique used to study the personal unconscious that involves reading 100 words to someone and having the person respond quickly with a word of his or her own.", "Working Memory: the form of memory we use to hold onto information temporarily, usually for the purposes of manipulation.", "Working Memory: the processes that we use to make sense of, modify, interpret, and store information in STM.", "Zygote: A fertilized ovum."]
        
    biology1 = ["absorption - (physiology) A process in which one substance permeates another. A fluid permeates or is dissolved by a liquid or solid. Skin absorption is a route by which substances can enter the body through the skin.", "acclimatization - (physiology) Adaptation to a new climate, as with a new temperature or altitude or environment.", "acetyl-CoA - (biochemistry) Acetyl coenzyme A is a molecule participating in many biochemical reactions in carbohydrate, protein and lipid metabolism. Its main function is to deliver the acetyl group to the citric acid cycle (Krebs cycle) to be oxidized for energy production.", "acoelomate - (zoology) A type of animal, such as a flatworm, with a body plan that lacks a fluid-filled cavity between the body wall and the digestive tract. Rather, semi-solid mesodermal tissues between the gut and body wall hold the animal's organs in place. Contrast coelomate and pseudocoelomate.", "adaptation - (evolutionary biology, population biology) Term can apply to an individual organism's adaptation to its environment, the adaptation of organisms to an environment through evolutionary processes, or the population dynamics intrisic to the evolutionary process.", "adenine - (biochemistry) A purine-derived organic compound which is one of the four canonical nucleobases used in the nucleic acids DNA and RNA. Its derivatives are involved in a wide variety of biochemical reactions, including cellular respiration.", "aerobic - Capable of surviving and growing in the presence of oxygen.", "amino acid - (biochemistry) A class of organic compounds containing an amine group and a carboxylic acid group which function as the fundamental building blocks of proteins and play important roles in many other biochemical processes.", "anaerobic - Any organism that does not require molecular oxygen for growth.", "animal - Any member of a clade of multicellular eukaryotic organisms belonging to the biological kingdom Animalia. With few exceptions, animals consume organic material, breathe oxygen, are able to move, reproduce sexually, and grow from a blastula during embryonic development. An estimated 7 million distinct animal species currently exist.", "antibiotic - Also called an antibacterial. - A type of antimicrobial drug used in the treatment and prevention of bacterial infections.", "Archaea - One of the three recognized domains of organisms, the other two being Bacteria and Eukaryota.", "artificial selection - Also called selective breeding. - The process by which humans use animal breeding and plant breeding to selectively control the development of particular phenotypic traits in organisms by choosing which individual organisms will reproduce and create offspring. While the deliberate exploitation of knowledge about genetics and reproductive biology in the hope of producing desirable characteristics is widely practiced in agriculture and experimental biology, artificial selection may also be unintentional and may produce unintended (desirable or undesirable) results.", "asexual reproduction - A type of reproduction involving a single parent that results in offspring that are genetically identical to the parent.", "astrobiology - The branch of biology concerned with the effects of outer space on living organisms and the search for extraterrestrial life.", "autoimmunity - The system of immune responses of an organism directed against its own healthy cells and tissues.", "autotroph - Sometimes used interchangeably with primary producer. - An organism capable of producing complex organic compounds from simple substances present in its surroundings, generally by using energy from sunlight (as in photosynthesis) or from inorganic chemical reactions (as in chemosynthesis). Autotrophs do not need to consume another living organism in order to obtain energy or organic carbon, as opposed to heterotrophs.", "B cell - A type of lymphocyte in the humoral immunity of the adaptive immune system.", "bacteria - An enormous and diverse clade of microscopic, prokaryotic, single-celled organisms which lack a true nucleus. They represent one of the three fundamental biological domains.", "bacteriophage - A virus that infects and multiplies within bacteria.", "Barr body - The inactive X chromosome in a female somatic cell, rendered inactive in a process called lyonization, in those species in which sex is determined by the presence of the Y chromosome (including humans) or W chromosome rather than by the presence of two X chromosomes or two Z chromosomes.", "basal body - An organelle formed from a centriole, and a short cylindrical array of microtubules. Also called a basal granule, a kinetosome, and in older cytological literature, a blepharoplast.", "behavioral ecology - The study of the evolutionary basis for animal behavior due to ecological pressures.", "bile - A dark green to yellowish-brown fluid, produced by the liver of most vertebrates, which aids the digestion of lipids in the small intestine. Also called gall.", "binary fission - The process by which one prokaryotic cell divides into two identical daughter cells.", "binomial nomenclature - A formal system of classifying species of living things by giving each a name composed of two parts, both of which use Latin grammatical forms, although they can be based on words from other languages.", "biocatalysis - The process of catalysis in biological systems. In biocatalytic processes, natural catalysts, such as protein enzymes, perform chemical transformations on organic compounds.", "biochemistry - The branch of biology that studies the chemical properties, compositions, reactions, and processes related to living organisms.", "biodiversity - A contraction of 'biological diversity' generally referring to the variety and variability of life on Earth.", "bioengineering - The application of concepts and methods of biology to solve real-world problems related to the life sciences or the application thereof.", "bioenergetics - The study of the transformation of energy within and between living organisms.", "biogeography - The study of the distribution of species and ecosystems in geographic space and through geological time. Organisms and biological communities often vary in a regular fashion along geographic gradients of latitude, elevation, isolation and habitat area.", "bioinformatics - The application of computer technology to the management of biological information.", "biological organization - The hierarchy of complex biological structures and systems, designed to define life through a reductionist approach.", "biology - The scientific study of life.", "biomass - Organic matter derived from living or recently living organisms. Biomass can be used as a source of energy and it most often refers to plants or plant-based materials which are not used for food or feed, and are specifically called lignocellulosic biomass.", "biomathematics - The theoretical use of mathematical models and abstractions of living systems to understand and predict biological problems.", "biome - Any very large ecological area on the Earth's surface containing fauna and flora (animals and plants) adapting to their environment. Biomes are often defined by abiotic factors such as climate, topographical relief, geology, soils, and water resources.", "biomechanics - The study of the structure and function of biological systems by means of the methods of 'mechanics', which is the branch of physics involving analysis of the actions of forces.", "biomedical engineering - The application of engineering principles and design concepts to medicine and biology for healthcare purposes (e.g. diagnostic or therapeutic).", "biomedical research - The pursuit of answers to medical questions. These investigations lead to discoveries, which in turn lead to the development of new preventions, therapies, and cures for problems in human and veterinary health. Biomedical research generally takes two forms: basic science and applied research.", "biomolecule - Molecules and ions that are present in organisms, essential to some typically biological process such as cell division, morphogenesis, or development.", "biophysics - The application of approaches traditionally employed in physics to study biological systems.", "biosynthesis", "biotechnology - Biotechnology is the use of living systems and organisms to develop or make products, or 'any technological application that uses biological systems, living organisms or derivatives thereof, to make or modify products or processes for specific use' (UN Convention on Biological Diversity).", "bipedal - A form of terrestrial locomotion where an organism moves by means of its two rear limbs or legs.", "birth", "blastocyst - A mammalian blastula in which some differentiation of cells has occurred." ,"blood - A body fluid that circulates in humans and other vertebrate animals and is generally responsible for delivering necessary substances such as oxygen and nutrients between the cells and tissues of the body and transporting metabolic waste products away from those same cells and tissues.", "blood–brain barrier - A semipermeable membrane separating the blood from the cerebrospinal fluid, and constituting a barrier to the passage of cells, particles, and large molecules.", "botany - The branch of biology that studies plants.", "building biology - A science that leads to natural healthy ecological homes, schools, and workplaces that exist in harmony with the environment.", "Calvin cycle - Also called the biosynthetic phase, light-independent reactions, dark reactions, or photosynthetic carbon reduction (PCR) cycle. - A series of chemical reactions which occurs as one of two primary phases of photosynthesis, specifically the phase in which carbon dioxide and other compounds are converted into simple carbohydrates such as glucose. These reactions occur in the stroma, the fluid-filled area of the chloroplast outside the thylakoid membranes. In the Calvin cycle, the products of previous light-dependent reactions (ATP and NADPH) undergo further reactions which do not require the presence of light and which can be broadly divided into three stages: carbon fixation, reduction reactions, and ribulose 1,5-bisphosphate (RuBP) regeneration.", "carbon fixation - Also called carbon assimilation. - The process by which inorganic carbon, particularly in the form of carbon dioxide, is converted to organic compounds by living organisms. Examples include photosynthesis and chemosynthesis.", "carbonate - Any member of two classes of chemical compounds derived from carbonic acid or carbon dioxide.", "carotenoid - One of a class of organic pigments produced by algae and plants, as well as certain bacteria and fungi.", "catalase - An enzyme found in nearly all living organisms exposed to oxygen, including bacteria, plants, and animals.", "cell - The basic structural and functional unit of all living organisms, and the smallest functional unit of life. A cell may exist as an independent, self-replicating unit (as in the case of unicellular organisms), or in cooperation with other cells, each of which may be specialized for carrying out particular functions within a larger multicellular organism. Cells consist of cytoplasm enclosed within a cell membrane and sometimes a cell wall, and serve the fundamental purpose of separating the controlled environment in which biochemical processes take place from the outside world. Most cells are visible only under a microscope.", "cell biology - Also called cytology. - The branch of biology that studies the structure and function of living cells, including their physiological properties, metabolic processes, chemical composition, life cycle, the organelles they contain, and their interactions with their environment. This is done at both microscopic and molecular levels.", "cell cycle - The ordered series of events which take place in a cell leading to duplication of its genetic material and ultimately the division of the cytoplasm and organelles to produce two or more daughter cells. These events can be broadly divided into phases of growth and division, each of which can vary in duration and complexity depending on the tissue or organism to which the cell belongs. Cell cycles are essential processes in all unicellular and multicellular organisms.", "cell division - Any process by which a parent cell divides into two or more daughter cells. Examples include binary fission, mitosis, and meiosis.", "cell membrane - The semipermeable membrane surrounding the cytoplasm of a cell.", "cell nucleus - The 'control room' for the cell. The nucleus gives out all the orders.", "cell plate - Grown in the cell's center, it fuses with the parental plasma membrane, creating a new cell wall that enables cell division.", "cell theory - The theory that all living things are made up of cells.", "cell wall - A tough, often rigid structural barrier surrounding certain types of cells (such as in fungi, plants, and most prokaryotes) that is immediately external to the cell membrane.", "cellular - Of or relating to a cell.", "central dogma of molecular biology - A framework for understanding the movement of genetic information between information-carrying biopolymers within biological systems. Popularly (though simplistically) stated as 'DNA makes RNA and RNA makes protein', the principle attempts to capture the notion that the transfer of genetic information only naturally occurs between certain classes of molecules and in certain directions.", "centriole - A cylindrical cell structure found in most eukaryotic cells, composed mainly of a protein called tubulin.", "centrosome - An organelle that is the primary site at which microtubules are organized. They occur only in plant and animal cells and help to regulate cell division.", "chemical compound - A chemical substance consisting of two or more different chemically bonded elements, with a fixed ratio determining the composition. The ratio of each element is usually expressed by a chemical formula.", "chemical equilibrium - The state in which both reactants and products are present in concentrations which have no further tendency to change with time in a chemical reaction.", "chemical reaction - A process that leads to the transformation of one set of chemical substances to another.", "chemistry - A branch of the physical sciences that studies the composition, structure, properties, and change of matter. Chemical interactions underlie all biological processes.", "chemosynthesis", "chlorophyll - Any of several photosynthetic pigments found in cyanobacteria, algae, or plants.", "chloroplast - A type of highly specialized organelle in the cells of plants and algae, the main role of which is to conduct photosynthesis, by which the photosynthetic pigment chlorophyll captures the energy from sunlight and converts and stores it in the molecules ATP and NADPH while freeing oxygen from water." , "cholesterol - A type of lipid molecule that is biosynthesized by all animal cells because it is an essential structural component of animal cell membranes, essential for maintaining both membrane structural integrity and fluidity.", "chromosome - A threadlike strand of DNA in the cell nucleus that carries the genes in a linear order.", "cilia", "circadian rhythm", "citric acid cycle - Also called the Krebs cycle and tricarboxylic acid cycle (TCA). - A series of chemical reactions used by all aerobic organisms to generate energy through the oxidation of acetyl-CoA derived from carbohydrates, fats, and proteins into carbon dioxide and chemical energy in the form of guanosine triphosphate (GTP). In addition, the cycle provides the chemical precursors for certain amino acids as well as the reducing agent NADH that is used in numerous other biochemical reactions. Its central importance to many biochemical pathways suggests that it was one of the earliest established components of cellular metabolism and may have originated abiogenically.", "clade", "class",\
                 "clonal selection - A scientific theory in immunology that explains the functions of cells (lymphocytes) of the immune system in response to specific antigens invading the body. The theory has become the widely accepted model for how the immune system responds to infection and how certain types of B and T lymphocytes are selected for destruction of specific antigens", "cloning - The process of producing individual organisms or molecules with identical or virtually identical DNA, either naturally or artificially. Many organisms, such as bacteria, insects, and plants, are capable of naturally producing clones through asexual reproduction. In biotechnology, cloning refers to the artificial creation of copies of cells, DNA fragments, or other biomolecules by various laboratory techniques.", "coat, coating - In the context of virus capsid, may refer colloquially to the defined geometric structure of a capsid, or the membrane of an endosome containing an intact virion. The coat of a virus is used in descriptions for the general public. Related slang: uncoating.", "colony", "comparative biology - The use of comparative methods to study the similarities and differences between two or more biological organisms (e.g. two organisms from the same time period but different taxa, or two organisms from the same taxon but different times in evolutionary history). The side-by-side comparison of morphological or molecular characteristics of different organisms is the basis from which biologists infer the organisms' genetic relatedness and their natural histories. It is a fundamental tool in many biological disciplines, including anatomy, physiology, paleontology, and phylogenetics.", "conservation biology - The scientific study of nature and of Earth's biodiversity with the aim of protecting species, their habitats, and ecosystems from excessive rates of extinction and the erosion of biotic interactions.", "convergent evolution - An evolutionary process by which species of different lineages independently develop similar characteristics, often to the point that the species appear to be more closely related than they actually are.", "countercurrent exchange - The crossover of some property, usually heat or some component, between two fluids flowing in opposite directions to each other. The phenomenon occurs naturally but is also frequently mimicked in industry and engineering.", "crista - A fold in the inner membrane of a mitochondrion.", "cryobiology - The branch of biology that studies the effects of low temperatures on living things within Earth's cryosphere or in laboratory experiments.", "cytology - See cell biology.", "cytoplasm - All of the material within a cell and enclosed by the cell membrane, except for the nucleus. The cytoplasm consists mainly of water, the gel-like cytosol, various organelles, and free-floating granules of nutrients and other biomolecules.", "cytosine - One of the four main nitrogenous bases found in both DNA and RNA, along with adenine, guanine, thymine, and uracil (in RNA); it is a pyrimidine derivative, with a heterocyclic aromatic ring and two substituents attached (an amine group at position 4 and a keto group at position 2).", "cytoskeleton - A complex, dynamic network of interlinking protein filaments that extends from the cell nucleus to the cell membrane and which is present in the cytoplasm of all cells, including bacteria and archaea. The cytoskeletal systems of different organisms are composed of similar proteins. In eukaryotes, the cytoskeletal matrix is a dynamic structure composed of three main proteins, which are capable of rapid growth or disassembly dependent on the cell's requirements.", "Darwinian fitness - The genetic contribution of an individual to the next generation's gene pool relative to the average for the population, usually measured by the number of offspring or close kin that survive to reproductive age.", "deciduous - Deciduous means 'falling off at maturity' or 'tending to fall off', and it is typically used in botany in order to refer to trees or shrubs that lose their leaves seasonally (most commonly during autumn) and to the shedding of other plant structures such as petals after flowering or fruits when ripe.", "decomposition - The process by which the organic compounds of deceased organisms are broken down into simpler organic or inorganic matter such as carbon dioxide, water, simple sugars, and mineral salts. These reactions occur naturally by both biotic means (biodegradation, such as that practiced by many bacteria and fungi) and abiotic means (basic physical and chemical processes, such as hydrolysis). Decomposition recycles matter present in the biosphere, making it an essential part of the nutrient cycle. Organisms that facilitate decomposition are known as decomposers; the scientific study of decomposition is known as taphonomy.", "decomposer - Any organism that facilitates the breakdown of dead or decaying organisms by carrying out the decomposition of complex biomolecules into simpler substances. Decomposers are heterotrophs which obtain energy and nutrition for their own growth and reproduction by recycling the chemical compounds contained in organic substrates. Microorganisms such as bacteria and fungi are the biosphere's chief decomposers, but invertebrates such as earthworms are also sometimes considered decomposers.", "dehydration reaction - A chemical reaction that involves the loss of a water molecule from the reacting molecule.", "denaturation - A process in which proteins or nucleic acids lose the quaternary, tertiary, and secondary structure which is present in their native state, when exposed to some external stress or chemical compound such as a strong acid or base, a concentrated inorganic salt, or an organic solvent.", "dendrite - A short branched extension of a nerve cell, along which impulses received from other cells at synapses are transmitted to the cell body.", "denitrification - The microbially facilitated process of nitrate reduction that ultimately produces molecular nitrogen (N2) through a series of intermediate gaseous nitrogen oxide products. It is performed by a large group of heterotrophic facultative anaerobic bacteria and is a fundamental component of the nitrogen cycle.", "deoxyribonucleic acid (DNA) - A nucleic acid polymer that serves as the fundamental hereditary material in all living organisms. Each DNA molecule is composed of long sequences of nucleotides, each of which includes one of four nitrogenous bases – adenine (abbreviated A), cytosine (C), guanine (G), and thymine (T) – attached to a sugar-phosphate complex which acts as a 'backbone' for the long-chain polymer. DNA most commonly occurs in 'double-stranded' form, i.e. as a pair of nucleotide polymers bound together by complementary base pairing.", "depolarization - The process of reversing the charge across a cell membrane (such as that of a neuron), thereby causing an action potential. In depolarization, the inside of the membrane, which is normally negatively charged, becomes positive and the outside becomes negative. This is brought about by positively charged sodium ions rapidly passing into the axon.", "desmosome - Also called the macula adhaerens. - A cell structure specialized for cell-to-cell adhesion.", "developmental biology - The branch of biology that studies the processes by which living organisms grow and develop over time. The field may also encompass the study of reproduction, regeneration, metamorphosis, and the growth and differentiation of stem cells in mature tissues.", "disease - Any particular abnormal condition that negatively affects the structure or function of all or part of a living organism and that is not the result of any immediate external injury. Diseases are medical conditions that are often identifiable by specific signs and symptoms. They may be caused by external factors such as infectious pathogens or by internal dysfunctions such as immune deficiency or senescence.", "DNA - See deoxyribonucleic acid.", "DNA replication - The chemical duplication or copying of a DNA molecule; the process of producing two identical copies from one original DNA molecule, in which the double helix is unwound and each strand acts as a template for the next strand. Complementary nucleotide bases are matched to synthesize the new partner strands.", "DNA sequencing - The process of determining the precise order of nucleotides within a DNA molecule.", "drug - Any substance that causes a change in an organism's physiology or psychology when consumed. Drugs may be naturally occurring or artificially produced, and consumption may occur in a number of different ways. Drugs are typically distinguished from substances that provide nutritional support such as food.", "dimorphism - The existence of a morphological distinction between organisms of the same species, such that individuals of that species occur in one of two distinct forms which differ in one or more characteristics, such as colour, size, shape, or any other phenotypic trait. Dimorphism based on sex – e.g. male vs. female – is common in sexually reproducing organisms such as plants and animals.", "dynein - A motor protein in cells which converts the chemical energy contained in ATP into the mechanical energy of movement.", "ecological efficiency - The efficiency with which energy is transferred from one trophic level to the next. It is determined by a combination of efficiencies relating to organismic resource acquisition and assimilation in an ecosystem.", "ecological pyramid - Also called a trophic pyramid, eltonian pyramid, energy pyramid, or sometimes food pyramid. - A graphical representation of the biomass or bio-productivity generated at each trophic level in a given ecosystem.", "ecological succession - The more or less predictable and orderly set of changes that occurs in the composition or structure of an ecological community over time.", "ecology - The scientific analysis and study of interactions between organisms and their environment. It is an interdisciplinary field that combines concepts from biology, geography, and Earth science.", "ecophysiology - A biological discipline that studies the adaptation of an organism's physiology to environmental conditions.", "ecosystem - A community of living organisms in conjunction with the non-living components of their physical environment, interacting as a system.", "ecotype - Sometimes called an ecospecies. - In evolutionary ecology, a genetically distinct geographic variety, population, or race within a species which is adapted to specific environmental conditions.", "ectoderm - The outermost layer of cells or tissue of an embryo in early development, or the parts derived from this, which include the epidermis, nerve tissue, and nephridia.", "ectotherm - An organism in which internal physiological sources of heat are of relatively small or quite negligible importance in controlling body temperature compared to ambient sources of heat. Ectotherms generally experience changes in body temperature that closely match changes in the temperature of their environment; colloquially, these organisms are often referred to as 'cold-blooded'. Contrast endotherm.", "effector - A small molecule that selectively binds to a protein and regulates its biological activity. In this manner, effector molecules act as ligands that can increase or decrease enzyme activity, gene expression, or cell signaling.", "efferent - Conducted or conducting outwards or away from something (for nerves, the central nervous system; for blood vessels, the organ supplied). Contrast afferent.", "egg - The organic vessel containing the zygote in which an animal embryo develops until it can survive on its own, at which point the developing organism emerges from the egg in a process known as hatching.", "electrochemical gradient - A gradient of electrochemical potential, usually for an ion that can move across a membrane. The gradient consists of two parts: the electrical potential and the difference in chemical concentration across the membrane.", "electron acceptor - Any chemical entity that accepts electrons transferred to it from another chemical entity. It is an oxidizing agent that, by virtue of its accepting electrons, is itself reduced in the process. Contrast electron donor.", "electron carrier - Any of various molecules that are capable of accepting one or two electrons from one molecule and donating them to another in the process of electron transport. As the electrons are transferred from one electron carrier to another, their energy level decreases, and energy is released.", "electron donor - A chemical entity that donates electrons to another chemical entity. It is a reducing agent that, by virtue of its giving up its electrons, is itself oxidized in the process. Contrast electron acceptor.", "electron microscope - A type of microscope that uses a beam of electrons to create an image of a sample or specimen. Electron microscopes are capable of much higher magnifications and have greater resolving power than conventional light microscopes, allowing them to see much smaller objects in finer detail.", "electron transport chain - The process of oxidative phosphorylation, by which the NADH and succinate generated by the citric acid cycle are oxidized and electrons are transferred sequentially down a long series of proteins, ultimately to the enzyme ATP synthase, which uses the electrical energy to catalyze the synthesis of ATP by the addition of a phosphate group to ADP. The process takes place in the cell's mitochondria and is the primary means of energy generation in most eukaryotic organisms.", "embryo - A developing stage of a multicellular organism.", "embryology - The branch of biology that studies the development of gametes (sex cells), fertilization, and development of embryos and fetuses. Additionally, embryology involves the study of congenital disorders that occur before birth.", "endangered species - Any species which is very likely to become extinct in the near future, either worldwide or in a particular area. Such species may be threatened by factors such as habitat loss, hunting, disease, and climate change, and most have a declining population or a very limited range.", "endemism - The ecological state of an organism or species being unique to a defined geographic location, such as an island, nation, country, habitat type, or other defined zone. Organisms are said to be endemic to a place if they are indigenous to it and found nowhere else.", "endergonic reaction - Also called a nonspontaneous reaction or unfavorable reaction. - A type of chemical reaction in which the standard change in free energy is positive, and energy is absorbed.", "endocrine gland - A gland of the animalian endocrine system that secretes hormones directly into the blood rather than through a duct. In humans, the major glands of the endocrine system include the pineal gland, pituitary gland, pancreas, ovaries, testes, thyroid gland, parathyroid gland, hypothalamus, and adrenal glands.", "endocrine system - The collection of glands that produce hormones which regulate metabolism, growth and development, tissue function, and a wide variety of other biological processes.", "endocytosis - A form of active transport in which a cell transports molecules such as proteins into the cell's interior by engulfing them in an energy-consuming process.", "endoderm - One of the three primary germ layers in the very early human embryo. The other two layers are the ectoderm (outside layer) and mesoderm (middle layer), with the endoderm being the innermost layer.", "endogenous - (of a substance or process) Originating from within a system (such as an organism, tissue, or cell), as with endogenous cannabinoids and circadian rhythms. Contrast exogenous.", "endoplasmic reticulum - A type of organelle found in eukaryotic cells that forms an interconnected network of flattened, membrane-enclosed sacs or tube-like structures known as cisternae.", "endosperm - The tissue produced inside the seeds of most of the flowering plants following fertilization.",\
                  "endosymbiotic theory - Also called symbiogenesis. - An evolutionary theory regarding the origin of eukaryotic cells from a hypothetical internal symbiosis between prokaryotic organisms, first articulated in 1905 and 1910 by the Russian botanist Konstantin Mereschkowski, and advanced and substantiated with microbiological evidence by Lynn Margulis in 1967.", "endotherm - An organism that is capable of maintaining a consistent, metabolically favorable body temperature, largely by the recycling of heat released by its internal physiological functions, instead of by relying on ambient sources of heat. Endotherms are generally able to maintain a stable body temperature despite changes in the temperature of their environment; colloquially, these organisms are often referred to as 'warm-blooded'. Contrast ectotherm.", "entomology - The scientific study of insects.", "environmental biology - The branch of biology concerned with the relations between organisms and their environments.", "enzyme - A protein that acts as a biological catalyst by accelerating chemical reactions. Metabolic pathways depend upon enzymes to catalyze their individual steps, and almost all metabolic processes require enzyme catalysis in order to occur at rates fast enough to sustain life.", "epidemiology - The study and analysis of the patterns, causes, and effects of health and disease conditions in defined populations. It is the cornerstone of public health, and shapes policy decisions and evidence-based practice by identifying risk factors for disease and targets for preventive healthcare.", "epigenetics - A sub-field of genetics that studies cellular and physiological phenotypic trait variations caused by external or environmental factors which affect how cells express genes, as opposed to those caused by changes in the DNA sequence.", "epiphyte - An organism that grows on the surface of a plant and derives moisture and nutrients from the air, rain, marine environments, or from debris accumulating around it.", "essential nutrient - A nutrient required for normal physiological function which cannot be synthesized by a particular organism, either at all or in sufficient quantities, and which therefore must be obtained from external sources such as food. In humans, a set of nine amino acids, two fatty acids, thirteen vitamins, and fifteen minerals are considered essential nutrients.", "estrogen - The primary female sex hormone." ,"ethology - The scientific study of non-human animal behaviour (i.e. excluding human behaviour) and usually with a focus on behaviour under natural conditions, and viewing behaviour as an evolutionarily adaptive trait.", "eukaryote - A type of organism consisting of cells which have a nucleus enclosed within a distinct nuclear membrane, unlike prokaryotes. Eukaryotes include all organisms except the bacteria and archaea (i.e. all plants, animals, fungi, and protists are eukaryotes).", "evolution - The change in the heritable characteristics of populations of biological organisms over successive generations, which may occur by mutation, gene flow, natural selection, or random chance.", "evolutionary biology - The subfield of biology that studies evolution and the evolutionary processes that produced the diversity of life on Earth from a hypothesized single common ancestor. These processes include the descent of species and the origin of new species.", "exocytosis - A form of active transport and bulk transport in which a cell transports molecules out of the cell by expelling them through an energy-dependent process.", "exogenous - (of a substance or process) Originating outside of or external to a system (such as an organism, tissue, or cell), as with drugs and many pathogens. Contrast endogenous.", "exponential growth - It is exhibited when the rate of change of the value of a mathematical function is proportional to the function's current value, resulting in its value at any time being an exponential function of time.", "external fertilization - A type of fertilization in which a sperm unites with an egg external to the body or bodies of the parent organisms. Contrast internal fertilization.", "extinction - The termination of the existence of a particular kind of organism or a particular taxon, often a species, as a result of the death of the last individual of the taxon (though the capacity to breed and recover may have been lost before this point, rendering the taxon functionally extinct).", "extracellular - Of or occurring in the space outside the plasma membrane of a cell. Contrast intracellular.", "extranuclear inheritance - A transmission of genes that takes place outside the nucleus.", "facultative anaerobe - An organism which is capable of producing energy through aerobic respiration and then switching to anaerobic respiration depending on the amounts of oxygen and fermentable material in the environment.", "family", "fermentation - A metabolic process that consumes sugar in the absence of oxygen.", "fitness", "fitness landscape", "fertilization", "fetus - Also spelled foetus. - An animal embryo after eight weeks of development.", "flagellum - (pl.) flagella - A lash-like appendage that protrudes from the cell body of certain bacterial and eukaryotic cells.", "flavin adenine dinucleotide (FAD) - A redox cofactor, more specifically a prosthetic group of a protein, involved in different important enzymatic reactions in metabolism.", "food chain - The chain of eating and getting nutrition which starts from a small herbivores animal and ends up at a big carnivorous organism.", "foramen - (pl.) foramimina - An open hole that is present in extant or extinct amniotes. Foramina inside the body of animals typically allow muscles, nerves, arteries, veins, or other structures to connect one part of the body with another.", "founder effect - A loss of genetic variation that takes places when a new population is established by a very small number of individuals from a larger population.", "fungi", "G protein - A family of proteins that act as molecular switches inside cells, and are implicated in transmitting signals from a diversity of stimuli outside a cell to its interior.", "gamete", "gene - Any segment of DNA that contains the information necessary to produce a functional RNA and/or protein product in a controlled manner. Genes are often considered the fundamental molecular units of heredity. The transmission of genes from a parent cell or organism to its offspring is the basis of the inheritance of phenotypic traits.", "gene pool - A set of all genes, or genetic information, in any population, usually of a particular species.", "generation", "genetic code - A set of rules used by living cells to translate information encoded within genetic material (DNA or mRNA sequences) into proteins.", "genetic drift - An alteration in the frequency of an existing gene variant in a population due to random sampling of organisms.", "genetic variation - Variations of genomes between members of species, or between groups of species thriving in different parts of the world as a result of genetic mutation. Genetic diversity in a population or species is a result of new gene combinations (e.g. crossing over of chromosomes), genetic mutations, genetic drift, etc.", "genetics - The study of heredity.", "genome - The entire set of genetic material contained within the chromosomes of an organism, organelle, or virus.", "genotype - Part of the genetic makeup of a cell, and therefore of an organism or individual, which determines one of its characteristics (phenotype).", "genus", "gizzard - An organ found in the digestive tract of some animals, including archosaurs (pterosaurs, crocodiles, alligators, and dinosaurs, including birds), earthworms, some gastropods, some fish, and some crustaceans.", "guanine - One of the four main nucleobases found in the nucleic acids DNA and RNA, the others being adenine, cytosine, and thymine (uracil in RNA).", "habitat - A place for animals, people, and plants and non-living things.", "habituation - A form of learning in which an organism decreases or desists its responses to a stimulus after repeated or prolonged presentations.", "heredity - The passing on of phenotypic traits from parents to their offspring, either through sexual or asexual reproduction. Offspring cells and organisms are said to inherit the genetic information of their parents.", "hermaphrodite - A sexually reproducing organism with both male and female reproductive organs.", "herpetology - The branch of zoology that studies reptiles and amphibians.", "heterosis - The improved or increased function of any biological quality in a hybrid offspring.", "heterotroph", "histology - The study of the microscopic anatomy of cells and tissues of plants and animals.", "Hodgkin–Huxley model - A mathematical model that describes how action potentials in neurons are initiated and propagated.", "hormone - Any member of a class of signaling molecules produced by glands in multicellular organisms that are transported by the circulatory system to target distant organs to regulate physiology and behaviour.", "host - Any living organism that harbors another living organism (known as a 'guest' or symbiont), whether the guest is parasitic, mutualistic, or commensalist in its interactions with the host. The guest typically receives shelter and nourishment from the host.", "hybrid", "hydrocarbon - An organic compound consisting entirely of hydrogen and carbon atoms. Hydrocarbons from which one hydrogen atom has been removed are functional groups called hydrocarbyls.", "ichthyology - The branch of biology devoted to the study of fish, including bony fishes (Osteichthyes), cartilaginous fish (Chondrichthyes), and jawless fish (Agnatha).", "immune response - The immune response is how your body recognizes and defends itself against bacteria, viruses, and substances that appear foreign and harmful.", "immunity", "immunoglobulin - Any of a class of glycoprotein molecules produced by plasma cells (white blood cells) which act as a critical part of the immune response by specifically recognizing and binding to particular antigens, such as bacteria or viruses, and aiding in their destruction. They are a major component of the group of immune defense molecules collectively called antibodies.", "infection - The invasion of an organism's cells or tissues by a disease-causing pathogen, its growth and/or multiplication, and the reaction of the host organism to the infectious agent and the toxins it produces. The variety of biological pathogens capable of causing infections includes certain bacteria, viruses, fungi, protists, parasitic worms, and arthropods.", "insulin - An anabolic peptide hormone produced in the pancreas which helps to regulate the metabolism of carbohydrates, fats, and protein by promoting the absorption of glucose from the blood into liver, fat, and skeletal muscle cells. Abnormal insulin activity is the cause of diabetes mellitus.", "integrative biology - The various forms of cross-disciplinary and multitaxon research.", "interferon - A group of signaling proteins made and released by host cells in response to the presence of several pathogens, such as viruses, bacteria, parasites, or tumor cells. In a typical scenario, a virus-infected cell will release interferons causing nearby cells to heighten their antiviral defenses.", "internal fertilization - A type of fertilization which takes place inside the egg-producing individual.", "International System of Units - (French: Système international d'unités; abbreviated SI) The modern standardized form of the metric system of units and measurements, and the system of measurement formally adopted for use in the physical and natural sciences.", "interphase", "intracellular - Of or occurring inside or within the enclosed interior of a cell. Contrast extracellular.", "introduced species - Also called an exotic species, foreign species, alien species, non-native species, or non-indigenous species. - Any species living outside its native geographic range, and which has arrived there either by accidental or deliberate human activity. Such human-caused introduction of species to foreign environments is distinguished from biological colonization, by which species spread to new areas through 'natural' means (i.e. without the involvement of humans).", "invertebrate - A group of animals that have no backbone, unlike animals such as reptiles, amphibians, fish, birds, and mammals, which all have a backbone. Among the many extant invertebrate phyla are the Cnidaria, Mollusca, Annelida, Nematoda, and Arthropoda.", "ion - An atom or molecule with a net electric charge due to the loss or gain of one or more electrons.", "ionic bond - A type of chemical bond involving the complete transfer of valence electron(s) between two atoms. Such bonds typically occur between elements characterized as metals and nonmetals, and generate two oppositely charged ions: the metal loses electrons to become a positively charged cation, and the nonmetal accepts those electrons to become a negatively charged anion.", "isomer - A molecule with the same chemical formula as another molecule, but with a different chemical structure. That is, isomers contain the same number of atoms of each element, but have different arrangements of their atoms.", "isotonic solution - Refers to two solutions having the same osmotic pressure across a semipermeable membrane. This state allows for the free movement of water across the membrane without changing the concentration of solutes on either side.", "jejunum - like gher vertebrates like mammals, birds, and reptiles. It is present between the duodenum and the ileum.", "kinase - An enzyme that catalyzes the transfer of phosphate groups from high-energy, phosphate-donating molecules to specific substrates.", "kingdom", "Krebs cycle - See citric acid cycle.", "larva - (pl.) larvae - A distinct juvenile form many animals undergo before metamorphosis into adults. Animals with indirect development, such as insects, amphibians, or cnidarians, typically have a larval phase of their life cycle.", "Law of Independent Assortment - The principle, originally formulated by Gregor Mendel, stating that when two or more characteristics are inherited, individual hereditary factors assort independently during gamete production, giving different traits an equal opportunity of occurring together.", "leukocyte - Also called a white blood cell. - A colourless cell of the immune system which circulates in the blood and body fluids and is involved in counteracting foreign substances and disease. There are several types of leukocytes, all amoeboid cells with a nucleus, including lymphocytes, granulocytes, and monocytes.", "lichen", "life - The characteristic or collection of characteristics that distinguishes physical entities that undergo biological processes (e.g. living organisms) from that those do not (e.g. non-living, inanimate matter), either because such processes have ceased or because they were not present in the first place. What constitutes 'life' is notoriously difficult to define, and there is currently no consensus definition, though some popular criteria are that living things are composed of cells, have a life cycle, undergo metabolism, maintain homeostasis, adapt to environments, respond to stimuli, reproduce, and evolve. Biology is the scientific study of life and of living organisms.", "life cycle", "ligament - The fibrous connective tissue that connects bones to other bones and is also known as articular ligament, articular larua, fibrous ligament, or true ligament.", "light-independent reactions - See Calvin cycle.", "linked genes - Any set of one or more genes which are sufficiently close together on the same chromosome that they are very unlikely to assort independently and therefore are usually inherited together.", "lipid - A substance that is insoluble in water and soluble in alcohol, ether, and chloroform. Lipids are an important component of living cells. Together with carbohydrates and proteins, lipids are the main constituents of plant and animal cells. Cholesterol and triglycerides are lipids.",\
                   "lipoprotein - A biochemical assembly that contains both proteins and lipids, bound to the proteins, which allow fats to move through the water inside and outside cells. The proteins serve to emulsify the lipid molecules.", "M phase - Mitosis and cytokinesis together define the mitotic (M) phase of an animal cell cycle – the division of the mother cell into two daughter cells, genetically identical to each other and to their parent cell.", "macroevolution - Evolution on a scale of separated gene pools. Macroevolutionary studies focus on change that occurs at or above the level of species, in contrast with microevolution, which refers to smaller evolutionary changes (typically described as changes in allele frequencies) within a species or population.", "macromolecule - A very large molecule, such as a protein, commonly created by polymerization of smaller subunits (monomers). They are typically composed of thousands or more atoms.", "macronutrient - Nutrients needed in large amounts which provide calories or energy. Nutrients are substances needed for growth, metabolism, and for other body functions. There are three basic types of macronutrients: fats, proteins, and carbohydrates.", "macrophage - A kind of swallowing cell, which means it functions by literally swallowing up other particles or smaller cells. Macrophages engulf and digest debris (such as dead cells) and foreign particles through the process of phagocytosis, so macrophages act like scavengers.", "mammalogy - The branch of biology that studies mammals, a class of vertebrates with characteristics such as homeothermic metabolism, fur, four-chambered hearts, and complex nervous systems.", "marine biology - The study of organisms in the ocean or other marine bodies of water. Given that in biology many phyla, families and genera have some species that live in the sea and others that live on land, marine biology classifies species based on the environment rather than on taxonomy.", "mast cell - A cell filled with basophil granules, found in numbers in connective tissue and releasing histamine and other substances during inflammatory and allergic reactions.", "mating", "medulla - The continuation of the spinal cord within the skull, forming the lowest part of the brainstem and containing control centres for the heart and lungs.", "meiosis - A specialized type of cell division in which a dividing parent cell proceeds through two consecutive divisions, ultimately producing four genetically unique daughter cells in each of which the chromosome number is half of that in the original parent cell. This process is exclusive to cells of the sex organs in sexually reproducing eukaryotes, where it serves the purpose of generating gametes such as eggs, sperm, or spores.", "membrane potential - When a nerve or muscle cell is at 'rest', its membrane potential is called the resting membrane potential. In a typical neuron, this is about –70 millivolts (mV). The minus sign indicates that the inside of the cell is negative with respect to the surrounding extracellular fluid.", "messenger RNA - A large family of RNA molecules that convey genetic information from DNA to the ribosome.", "metabolism", "metamorphosis", "metaphase - The third phase of mitosis, in which duplicated genetic material carried in the nucleus of a parent cell is separated into two identical daughter cells. During metaphase, the cell's chromosomes align themselves in the middle of the cell through a type of cellular 'tug of war'.", "microbiology - The study of microscopic organisms, such as bacteria, viruses, archaea, fungi and protozoa. This discipline includes fundamental research on the biochemistry, physiology, cell biology, ecology, evolution and clinical aspects of microorganisms, including the host response to these agents.", "microevolution - The alteration in allele frequencies that occurs over time within a population.", "mitochondria - (sing.) mitochondrion", "mitosis - In eukaryotic cells, the part of the cell cycle during which the division of the nucleus takes place and duplicated chromosomes are separated into two distinct nuclei. Mitosis is generally preceded by the 'S' stage of interphase, when the cell's DNA is replicated, and followed by cytokinesis, when the cytoplasm and cell membrane are divided into two new daughter cells. It is similar to but distinct from binary fission and meiosis.", "molecule - The smallest particle in a chemical element or compound that has the chemical properties of that element or compound. Molecules are made up of atoms that are held together by chemical bonds. These bonds form as a result of the sharing or exchange of electrons among atoms.", "molecular biology - The branch of biology concerning biological activity at the molecular level. The field of molecular biology overlaps with biology and chemistry and in particular with genetics and biochemistry.", "molecular switch - A molecule that can be reversibly changed between two or more stable states.", "monomer - A molecule that 'can undergo polymerization thereby contributing constitutional units to the essential structure of a macromolecule'.", "morphology", "motile", "motor neuron - A neuron whose cell body is situated in the motor cortex, brain stem, or the spinal cord, and whose axon (fiber) projects to the spinal cord or outside of the spinal cord to directly or indirectly control effector organs, mainly muscles and glands.", "mucous membrane - A membrane that lines various cavities in the body and covers the surface of internal organs.", "multicellular - Having or consisting of more than one cell, as opposed to being unicellular.", "mycology - The branch of biology concerned with the study of fungi, including their genetic and biochemical properties, their taxonomy and their use to humans as a source for tinder, medicine, food, and entheogens, as well as their dangers, such as poisoning or infection.", "myofibril - A basic rod-like unit of a muscle cell.", "myosin - A superfamily of motor proteins best known for their roles in muscle contraction and in a wide range of other motility processes in eukaryotes.", "natural selection - A process in nature in which organisms possessing certain genotypic characteristics that make them better adjusted to an environment tend to survive, reproduce, increase in number or frequency, and therefore, are able to transmit and perpetuate their essential genotypic qualities to succeeding generations.", "neurobiology - Also called neuroscience. - The scientific study of the nervous system.", "neuron - An electrically excitable cell that receives, processes, and transmits information through electrical and chemical signals.", "neurotransmitter - An endogenous compound that enable neurotransmission.", "niche - The role and position an organism or taxon fills within its environment; how it meets its needs for food and shelter, how it survives, and how it reproduces. A species' niche includes all of its interactions with the biotic and abiotic factors of its environment.", "nitrogen fixation - The chemical process by which molecular nitrogen (N2) in the air is converted into ammonia (NH3) or related nitrogenous compounds, typically by specialized microorganisms in soil and aquatic ecosystems but also by certain non-biological processes. Despite comprising nearly 80% of the gas in the Earth's atmosphere, diatomic nitrogen is metabolically useless to all but a few microorganisms, known as diazotrophs. Nitrogen fixation is essential to all life on Earth because fixed inorganic nitrogenous compounds are required for the biosynthesis of all nitrogen-containing organic compounds, including amino acids and nucleic acids.", "nucleic acid - The biopolymers, or small biomolecules, essential to all known forms of life .", "nucleic acid sequence - A succession of letters that indicate the order of nucleotides forming alleles within a DNA or RNA molecule.", "nucleobase - The nitrogen-containing biological compounds that form nucleosides, which in turn are components of nucleotides, with all of these monomers constituting the basic building blocks of nucleic acids.", "nucleoid - An irregularly shaped region within the cell of a prokaryote that contains all or most of the genetic material, called the genophore.", "nucleolus - The largest structure within the nucleus of eukaryotic cells.", "nucleotide - An organic compound which serves as the fundamental monomer used in the construction of nucleic acid polymers, such as DNA and RNA, both of which are essential biomolecules within all living organisms.", "offspring", "order", "organ - A collection of tissues joined in a structural unit to serve a common function.", "organism - A contiguous living system.", "ornithology - The branch of zoology that concerns the study of birds.", "osmosis - The spontaneous net movement of solvent molecules through a semipermeable membrane into a region of higher solute concentration, in the direction that tends to equalize the solute concentrations on the two sides.", "paleontology - The study of the history of life on Earth as reflected in the fossil record. Fossils are the remains or traces of organisms that lived in the geological past and have been preserved in the Earth's crust.", "parallel evolution - The development of a similar trait in related, but distinct, species descending from the same ancestor, but from different clades.", "parasite", "parasitology - The study of parasites, their hosts, and the relationship between them. As a biological discipline, the scope of parasitology is not determined by the organism or environment in question, but by their way of life.", "pathogen - In the broadest sense, anything that can produce disease, though the term is most commonly used to refer specifically to an infectious microscopic organism such as a virus, bacterium, protozoan, or another microbial agent which causes disease for a host organism by invading the host's tissues.", "pathology - A medical specialty that is concerned with the diagnosis of disease based on the laboratory analysis of bodily fluids such as blood and urine, as well as tissues, using the tools of chemistry, clinical microbiology, hematology, and molecular pathology.", "pH - A numeric scale used to specify the acidity or basicity (alkalinity) of an aqueous solution. It is roughly the negative of the logarithm to base 10 of the concentration, measured in units of moles per liter, of hydrogen ions.", "pharmacology - The science of drug action on biological systems. In its entirety, it embraces knowledge of the sources, chemical properties, biological effects, and therapeutic uses of drugs.", "phenotype - The composite of an organism's observable features or traits, such as its morphology, development, biochemical or physiological properties, behavior, and products of behavior.", "pheromone - A secreted or excreted chemical factor that triggers a social response in members of the same species. Pheromones are analogous to hormones acting outside the body of the secreting individual to impact the behavior of receiving individuals.", "phloem - The conducting tissue in plants responsible for the conduction of food particles.", "photosynthesis - The process by which nearly all plants and some algae and bacteria convert the energy of sunlight into chemical energy, which is used to synthesize carbohydrates such as sugars from carbon dioxide and water; these carbohydrates are stored as food, and the energy within them is later released to fuel metabolic activities. Organisms that perform photosynthesis are therefore autotrophs. Photosynthesis supplies the majority of the energy necessary for life on Earth.", "phylogeny", "phylum - A taxonomic rank or level of classification below kingdom and above class; in botany, the term division is commonly used in place of phylum.", "physiology - The branch of biology dealing with the functions and activities of living organisms and their parts, including all physical and chemical processes.", "phytochemistry - The study of phytochemicals, which are chemicals derived from plants.", "phytopathology - The science of diagnosing and managing plant diseases.", "piliferous - Bearing hair", "placebo - A substance or treatment of no intended therapeutic value.", "plant", "plasmolysis - The process in which cells lose water in a hypertonic solution.", "pollination - The transfer of pollen from a male part of a plant to a female part of a plant, enabling later fertilisation and the production of seeds. Pollen is most commonly transported by animals or by wind.", "polymer - A large macromolecule composed of many repeated subunits.", "polymerase chain reaction (PCR) - A technique used in molecular biology to amplify a single copy or a few copies of a segment of DNA across several orders of magnitude, generating thousands to millions of copies of a particular DNA sequence.", "polyploidy - Having or containing more than two complete sets of chromosomes.", "population - All the organisms of the same group or species that live in a particular geographical area and are capable of interbreeding.", "population biology - The study of populations of organisms, especially the regulation of population size, life history traits such as clutch size, and extinction.", "population ecology - Also called autoecology. - A subfield of ecology that deals with the dynamics of species populations and how these populations interact with the environment. It is the study of how the population sizes of species change over time and space.", "predation - A biological interaction in which a predator kills and eats its prey.", "predator", "prey", "primer - A short strand of RNA or DNA that serves as a starting point for DNA synthesis.", "progeny - Any genetic descendant or offspring.", "progesterone - An endogenous steroid and progestogen sex hormone which plays a critical role in the menstrual cycle, pregnancy, and embryogenesis in humans and other animal species.", "prokaryote - A type of organism which does not have a true nucleus.", "protein - A polypeptide chain of amino acids. It is a body-building nutrient.", "protist", "psychobiology - Also called behavioral neuroscience, biological psychology, and biopsychology. - The application of the principles of biology to the study of physiological, genetic, and developmental mechanisms of behavior in humans and other animals.", "regeneration - The process of renewal, restoration, and growth that makes genomes, cells, organisms, and ecosystems resilient to natural fluctuations or events that cause disturbance or damage. For example, many organisms are capable of regenerating tissues and even entire body parts if they are lost or destroyed.", "reproduction - Also called procreation or breeding. - The biological process by which one or more new individual organisms (known as offspring) is produced from an existing parent organism. Reproduction is a defining characteristic of all life, and every individual organism exists as the result of a reproductive event. There are two general methods by which reproduction takes place: sexual or asexual.", "reproductive biology - The branch of biology that studies the various types and mechanisms of reproduction used by living organisms, typically with special emphasis on cell division, fertility, endocrinology, and/or the tissues, organs, and systems involved in reproduction.", "ribonucleic acid (RNA) - A nucleic acid polymer composed of a series of ribonucleotides which incorporate a set of four nucleobases: adenine (A), guanine (G), cytosine (C), and uracil (U). Closely related to DNA, RNA molecules serve in a wide variety of essential biological roles, including coding, decoding, regulating, and expressing genes, as well as functioning as signaling molecules.", "ribosome - A complex molecular machine, found within all living cells, that serves as the site of biological protein synthesis.",\
                    "RNA - See ribonucleic acid.", "RNA polymerase - A member of a family of enzymes that are essential to life: they are found in all organisms and many viruses.", "sclerenchyma - A type of tissue in which cells have thick lignified secondary walls and often die when mature.", "seed - The embryo, enclosed in a protective outer covering, of certain types of plants.", "selective breeding - See artificial selection.", "sessile - 1.  Generally, lacking motility or means of self-locomotion; immobile or incapable of movement. Sessile organisms may move via external forces such as wind or water currents but are more often permanently fixed to a solid object such as a rock, soil, or another organism. 2.  In botany, the property of a plant or plant part that is attached directly by its base to an object or another plant part, i.e. without an intervening stem, stalk, or petiole.", "sex", "sexual reproduction - A type of reproduction in which cells from two parents unite to form the first cell of a new organism.", "sociality - The degree to which individuals in an animal population tend to associate in social groups and form cooperative societies.", "sociobiology - A branch of biology that is based on the hypothesis that social behavior has resulted from evolution and which attempts to explain and examine social behavior within that context.", "soil biology - The study of microbial and faunal activity and ecology in soil.", "species - The basic unit of biological classification and the narrowest of the canonical taxonomic ranks, as well as a unit of biodiversity. Species are traditionally distinguished on the basis of reproductive compatibility, though achieving a satisfactory definition that is universally applicable to all life has proven difficult, since many organisms classified as distinct 'species' are capable of interbreeding with different (albeit closely related) species, generating hybrids.", "speciation - The evolutionary process by which populations of organisms evolve to become distinct species, typically via reproductive isolation.", "sperm", "spore", "stem cell - A type of undifferentiated or partially undifferentiated cell that is capable of differentiating into other types of specialized cells and also capable of dividing to produce more of the same type of stem cell. Stem cells are the earliest type of cell in a cell lineage.", "steroid - A biologically active organic compound with four rings arranged in a specific molecular configuration.", "strain - A genetic variant, subtype, or culture identified as a distinct taxonomic subdivision within a species. The term is most commonly used to identify particular types of bacteria and viruses.", "structural biology - The branch of molecular biology, biochemistry, and biophysics concerned with the molecular structure of biological macromolecules, especially proteins and nucleic acids, how they acquire the structures they have, and how alterations in their structures affect their function.", "symbiogenesis - See endosymbiotic theory.", "symbiont - Any organism involved in any type of symbiosis with another organism, either of the same or a different species.", "symbiosis - Any close and long-term interaction between two different biological organisms, regardless of the nature or degree of the effect on either organism. Examples include mutualism, commensalism, and parasitism.", "synthetic biology - An interdisciplinary branch of biology and engineering combining various disciplines from within these domains, including biotechnology, evolutionary biology, molecular biology, systems biology, biophysics, computer engineering, and genetic engineering.", "systematics - The scientific study of biodiversity. It is concerned with the discovering and naming of new species of organisms (nomenclature) and arranging these taxa into classification schemes (taxonomy). A large part of modern systematics is concerned with understanding the evolutionary relationships between various taxa (phylogenetics) using methods of comparative biology (e.g. physiology, behavior, biochemistry, morphology, genetics) and statistical analysis.", "systems biology - A branch of biology concerned with the computational and mathematical analysis of complex biological systems. It is an interdisciplinary field which combines elements of systems theory and applied mathematics with theoretical biology, with a primary aim to discover and model the emergent properties of interacting biological entities.", "T cell - A type of lymphocyte that plays a central role in cell-mediated immunity.", "taxon - (pl.) taxa - A group of one or more populations of an organism or organisms used by taxonomists to classify organisms into discrete, convenient, and identifiable units.", "taxonomy", "telophase", "testosteroneThe primary male sex hormone and an anabolic steroid.", "thymine - One of the four nucleobases used in the nucleic acid DNA (but not in RNA). It is represented in DNA sequences by the letter T.", "tissue", "trait", "transcription - The first step of gene expression, in which a particular segment of DNA is copied into RNA by the enzyme RNA polymerase. Both RNA and DNA are nucleic acids, which use complementary base pairs of nucleotides as a common language.", "translation - The process by which ribosomes in the cytoplasm or endoplasmic reticulum synthesize proteins following the transcription of DNA to RNA in the cell's nucleus.", "trophic level - The position an organism occupies in a food chain.", "tumor - Also called a neoplasm.", "uncoating - The decomposition of a viral capsid. An informal and simplified description of the way a virus infectious material enters the cell, usually appearing in light science material for the general public.", "unicellular - Having or consisting of only one cell, as opposed to being multicellular.", "uracil - One of the four nucleobases in the nucleic acid of RNA that are represented by the letters A, G, C and U.", "urea - An organic compound with chemical formula CO(NH2)2.", "urine - A liquid byproduct of metabolism in humans and in many animals.", "uterus - A major female hormone-responsive secondary sex organ of the reproductive system in humans and most other mammals.", "vacuole - A membrane-bound organelle which is present in all plant and fungal cells and some protist, animal, and bacterial cells.", "vasodilation - The widening of blood vessels.", "vector", "vegetative reproduction - Any type of asexual reproduction performed by an organism which is nonetheless capable of sexual reproduction. The term is used primarily for plants.", "vertebrate", "vesicle - A small structure within or sometimes external to a cell, consisting of fluid enclosed by a lipid bilayer.", "vestigiality - The retention during the process of evolution of genetically determined structures or attributes that have lost some or all of their ancestral function in a given species.", "virology - The branch of biology that studies viruses.", "virus - A submicroscopic, infectious, parasitic particle of genetic material contained in a protein coat and which replicates only inside the living cell of a host organism.", "white blood cell - See leukocyte.", "whole genome sequencing - The process of determining the complete DNA sequence of a particular organism's entire genome at a single time.", "wood - The inner layer of the stems of woody plants such as trees and shrubs, composed of xylem.", "xanthophyll - A yellow-colored photosynthetic pigment.", "xylem - A type of plant tissue responsible for the transport of water from roots to aerial parts of the plant.", "yolk - The nutrient-bearing portion of the egg whose primary function is to supply food for the development of the embryo.", "zoology - The branch of biology that studies the animal kingdom, including the structure, embryology, evolution, classification, habits, and geographical distribution of all animals, both living and extinct, and how they interact with their ecosystems.", "zooplankton - A type of heterotrophic (sometimes detritivorous) plankton, as opposed to phytoplankton, which instead obtain energy from photosynthesis. Individual zooplankton are usually microscopic, but some (such as jellyfish) are larger and visible to the naked eye.", "zygospore - A diploid reproductive stage in the life cycle of many fungi and protists.", "zygote - A eukaryotic cell formed by a fertilization event between two gametes."]
        
    chemistry1 = ["Accuracy the closeness of a single measurement to its true value", "Acid (Arrhenius definition) a substance that produces hydrogen ions, H+ (hydronium ion, H3O+ ), when it dissolves in water", "Acid (Brønsted?Lowry definition) the species (molecule or ion) that donates a proton to another species in a proton-transfer reaction", "Acid rain rain having a pH lower than that of natural rain, which has a pH of 5.6", "Acid salt a salt that has an acidic hydrogen atom and can undergo neutralization with bases", "Acid?base indicator a dye used to distinguish between acidic and basic solutions by means of the color changes it undergoes in these solutions", "Acid?base titration curve a plot of the pH of a solution of acid (or base) against the volume of added base (or acid)", "Acidic oxide an oxide that reacts with bases", "Acid-ionization (or acid-dissociation) constant (Ka) the equilibrium constant for the ionization of a weak acid", "Actinides elements in the last of the two rows at the bottom of the periodic table; actinium plus the 14 elements following it in the periodic table, in which the 5f subshell is filling", "Activated complex (transition state) an unstable grouping of atoms that can break up to form products", "Activation energy (Ea) the minimum energy of collision required for two molecules to react", "Activity of a radioactive source the number of nuclear disintegrations per unit time occurring in a radioactive material", "Activity series a listing of the elements in order of their ease of losing electrons during reactions in aqueous solution", "Addition polymer a polymer formed by linking together many molecules by addition reactions", "Addition reaction a reaction in which parts of a reactant are added to each carbon atom of a carbon?carbon double bond, which then becomes a C?C single bond", "Adsorption the binding or attraction of molecules to a surface", "Aerosol a colloid consisting of liquid droplets or solid particles dispersed throughout a gas", "Ag+ Silver ion", "Alcohol a compound obtained by substituting a hydroxyl group (—OH) for an —H atom on a tetrahedral (sp3 hybridized) carbon atom of a hydrocarbon group", "Aldehyde a compound containing a carbonyl group with at least one H atom attached to it", "Aliphatic hydrocarbon a saturated or unsaturated hydrocarbon; a hydrocarbon that does not contain benzene rings", "Alkali metals the Group IA elements; they are reactive metals", "Alkali metals the Group IA elements; they are reactive metals", "Alkaline dry cell a voltaic cell that is similar to the Leclanché dry cell but uses potassium hydroxide in place of ammonium chloride", "Alkaline earth metals the Group IIA elements; they are reactive metals, though less reactive than the alkali metals", "Alkane an acyclic saturated hydrocarbon (one without a ring of carbon atoms); a saturated hydrocarbon with the general formula CnH2n+2", "Alkene a hydrocarbon that has the general formula CnH2n and contains a carbon–carbon double bond", "Alkyl group an alkane less one hydrogen atom", "Alkyne an unsaturated hydrocarbon containing a carbon–carbon triple bond. The general formula is CnH2n-2", "Allotrope one of two or more distinct forms of an element in the same physical state", "Alloy a material with metallic properties that is either a compound or a mixture", "Alpha emission emission of a nucleus, or alpha particle, from an unstable nucleus.", "Amide a compound derived from the reaction of ammonia, or a primary or secondary amine, with a carboxylic acid", "Amine a compound that is structurally derived by replacing one or more hydrogen atoms of ammonia with hydrocarbon groups", "Amino acid a compound containing an amino group (—NH2) and a carboxyl group (—COOH).", "Amorphous solid a solid that has a disordered structure; it lacks the well-defined arrangement of basic units (atoms, molecules, or ions) found in a crystal", "Ampere (A) the base unit of current in the International System (SI)", "Amphiprotic species a species that can act as either an acid or a base (that is, it can either lose or gain a proton)", "Amphoteric hydroxide a metal hydroxide that reacts with both bases and acids", "Amphoteric oxide an oxide that has both acidic and basic properties", "Angstrom (Å) a non-SI unit of length; 1 Å = 10-10 m", "Angular momentum quantum number (l) 'also known as the azimuthal quantum number. The quantum number that distinguishes orbitals of given n having different shapes; it can have any integer value from 0 to n - 1.'", "Anion a negatively charged ion", "Anode the electrode at which oxidation occurs", "Antibonding orbitals molecular orbitals having zero values in the region between two nuclei and therefore concentrated in other regions", "Aromatic hydrocarbon a hydrocarbon that contains a benzene ring or similar structural feature", "Arrhenius equation the mathematical equation k = Ae-Ea/RT, which expresses the dependence of the rate constant on temperature", "Association colloid a colloid in which the dispersed phase consists of micelles", "Atmosphere (atm) a unit of pressure equal to exactly 760 mmHg; 1 atm = 101.325 kPa (exact)", "Atom an extremely small particle of matter that retains its identity during chemical reactions", "Atomic mass as a general term, the mass of an individual atom; but usually we mean the average atomic mass for the naturally occurring element, expressed in atomic mass units", "Atomic mass unit (amu) a mass unit equal to exactly one-twelfth the mass of a carbon-12 atom", "Atomic number (Z) the number of protons in the nucleus of an atom", "Atomic orbital a wave function for an electron in an atom; pictured qualitatively by describing the region of space where there is a high probability of finding the electron", "Atomic symbol a one- or two-letter notation used to represent an atom corresponding to a particular element. A temporary name with a three letter notation (denoting the atomic number) is given to newly discovered elements", "Atomic theory an explanation of the structure of matter in terms of different combinations of very small particles (atoms)", "Avogadro?s law equal volumes of any two gases at the same temperature and pressure contain the same number of molecules", "Avogadro’s number (NA) the number of atoms in a 12-g sample of carbon-12, equal to 6.02 x 1023 to three significant figures", "Avogadro's law equation Vm = specific constant (depending on T, P; independent of gas)", "Axial direction one of two directions pointing from the center of a trigonal bipyramid along its axis", "Band of stability the region in which stable nuclides lie in a plot of number of protons against number of neutrons", "Band theory molecular orbital theory of metals", "Bar a unit of pressure equal to 1 x 105 Pa, slightly less than 1 atm", "Barometer a device for measuring the pressure of the atmosphere", "Base (Arrhenius definition) a substance that produces hydroxide ions, OH-, when it dissolves in water", "Base (Brønsted?Lowry definition) the species (molecule or ion) that accepts a proton in a proton-transfer reaction", "Base pairing the hydrogen bonding of complementary bases", "Base-ionization (or base-dissociation) constant (Kb) the equilibrium constant for the ionization of a weak base. Thus Kb for NH3 is 1.8 x 10-5", "Basic oxide an oxide that reacts with acids", "Bayer process a chemical procedure in which purified aluminum oxide, Al2O3, is separated from the aluminum ore bauxite", "Bent geometry (angular geometry) nonlinear molecular geometry, in the case of a molecule of three atoms", "Beta emission emission of a high-speed electron from an unstable nucleus", "Bidentate ligand a ligand that bonds to a metal atom through two atoms of the ligand", "Bimolecular reaction an elementary reaction that involves two reactant molecules", "Binary compound a compound composed of only two elements", "Binary hydride a compound that contains hydrogen and one other element", "Binding energy (of a nucleus) the energy needed to break a nucleus into its individual protons and neutrons", "Binding energy (of a nucleus) the energy needed to break a nucleus into its individual protons and neutrons", "Bohr’s formula for the energy of an electron in a hydrogen atom", "Boiling point the temperature at which the vapor pressure of a liquid equals the pressure exerted on the liquid (atmospheric pressure, unless the vessel containing the liquid is closed)", "Boiling-point elevation a colligative property of a solution equal to the boiling point of the solution minus the boiling point of the pure solvent", "Boiling-point elevation equation ΔTb = Kbcm", "Bond energy the average enthalpy change for the breaking of a bond in a molecule in the gas phase", "Bond length (bond distance) the distance between the nuclei in a bond", "Bond order in a Lewis formula, the number of pairs of electrons in a bond", "Bond order in molecular orbital theory, one-half the difference between the number of bonding electrons and the number of antibonding electrons", "Bonding orbitals molecular orbitals that are concentrated in the regions between nuclei", "Bonding pair an electron pair shared between two atoms", "Boyle?s law the volume of a sample of gas at a given temperature varies inversely with the applied pressure", "Boyle?s law equation", "Brønsted?Lowry concept a concept of acids and bases in which an acid is the species donating a proton in a proton-transfer reaction, whereas a base is the species accepting a proton in such a reaction", "Buckminsterfullerene a molecular form of carbon (C60) informally called “buckyball,” referring to its soccer-ball shape; a fullerene", "Buffer a solution characterized by the ability to resist changes in pH when limited amounts of acid or base are added to it", "Building-up principle (Aufbau principle) a scheme used to reproduce the electron configurations of the ground states of atoms by successively filling subshells with electrons in a specific order (the building-up order)", "C2H3O2- Acetate ion", "C2O42- Oxalate ion", "Calorie (cal) a non-SI unit of energy commonly used by chemists, originally defined as the amount of energy needed to raise the temperature of 1 g of water by 1oC; now defined as 1 cal = 4.184 J (exact).", "Calorimeter a device used to measure the heat absorbed or evolved during a physical or chemical change", "Carboxylic acid a compound containing the carboxyl group, ?COOH, whose H atom is acidic", "Catalysis the increase in rate of a reaction as the result of the addition of a catalyst", "Catalyst a substance that increases the rate of reaction without being consumed in the overall reaction", "Catalyst a substance that increases the rate of reaction without being consumed in the overall reaction", "Catenation the covalent bonding of two or more atoms of the same element to one another", "Cathode the electrode at which reduction occurs", "Cathode rays the rays emitted by the cathode (negative electrode) in a gas discharge tube (tube of low-pressure gas through which an electric current is discharged)", "Cation a positively charged ion", "Cation exchange resin a resin (organic polymer) that removes cations from solution and replaces them with hydrogen ions", "Cd2+ Cadmium ion", "Cell potential the maximum potential difference between the electrodes of a voltaic cell", "Cell reaction the net reaction that occurs in a voltaic cell.", "Celsius scale the temperature scale in general scientific use. There are exactly 100 units between the freezing point and the normal boiling point of water.", "Chain reaction, nuclear a self-sustaining series of nuclear fissions caused by the absorption of neutrons released from previous nuclear fissions", "Change of state (phase transition) a change of a substance from one state to another", "Charles?s law the volume occupied by any sample of gas at a constant pressure is directly proportional to the absolute temperature", "Charles's law equation", "Chelate a complex formed by polydentate ligands", "Chemical bond a strong attractive force that exists between certain atoms in a substance", "Chemical equation the symbolic representation of a chemical reaction in terms of chemical formulas", "Chemical equilibrium the state reached by a reaction mixture when the rates of forward and reverse reactions have become equal", "Chemical formula a notation that uses atomic symbols with numerical subscripts to convey the relative proportions of atoms of the different elements in a substance", "Chemical kinetics the study of how reaction rates change under varying conditions and of what molecular events occur during the overall reaction", "Chemical nomenclature the systematic naming of chemical compounds", "Chemical property a characteristic of a material involving its chemical change", "Chemical reaction (chemical change) a change in which one or more kinds of matter are transformed into a new kind of matter or several new kinds of matter", "Chemical reaction (chemical change) 'the rearrangement of the atoms present in the reacting substances to give new chemical combinations present in the substances formed by the reaction'", "Chemisorption the binding of a species to a surface by chemical bonding forces", "Chiral possessing the quality of handedness. A chiral object has a mirror image that is not identical to the object.", "Chlor?alkali membrane cell a cell for the electrolysis of aqueous sodium chloride in which the anode and cathode compartments are separated by a special plastic membrane that allows only cations to pass through it", "Chlor?alkali mercury cell a cell for the electrolysis of aqueous sodium chloride in which mercury metal is used as the cathode", "Chromatography a name given to a group of similar separation techniques that depend on how fast a substance moves, in a stream of gas or liquid, past a stationary phase to which the substance may be slightly attracted", "Claus process a method of obtaining free sulfur by the partial burning of hydrogen sulfide", "Clausius–Clapeyron equation an equation that expresses the relation between the vapor pressure P of a liquid and the absolute temperature T: ln P = -ΔHvap//RT + B, where B is a constant", "ClO- Hypochlorite ion", "ClO2- Chlorite ion", "ClO3- Chlorate ion", "ClO4- Perchlorate ion", "CN- Cyanide ion", "Co2+ Cobalt(II) ion or cobaltous ion", "CO32- Carbonate ion", "Coagulation the process by which the dispersed phase of a colloid is made to aggregate and thereby separate from the continuous phase", "Codon a sequence of three bases in a messenger RNA molecule that serves as the code for a particular amino acid", "Colligative properties properties that depend on the concentration of solute molecules or ions in a solution but not on the chemical identity of the solute", "Collision theory the theory that in order for reaction to occur, reactant molecules must collide with an energy greater than some minimum value and with proper orientation", "Colloid a dispersion of particles of one substance (the dispersed phase) throughout another substance or solution (the continuous phase)", "Combination reaction a reaction in which two substances combine to form a third substance", "Combustion reaction a reaction of a substance with oxygen, usually with the rapid release of heat to produce a flame", "Common-ion effect the shift in an ionic equilibrium caused by the addition of a solute that provides an ion that takes part in the equilibrium", "Common-ion effect the shift in an ionic equilibrium caused by the addition of a solute that provides an ion that takes part in the equilibrium", "Complementary bases nucleotide bases that form strong hydrogen bonds with one another", "Complete ionic equation a chemical equation in which strong electrolytes (such as soluble ionic compounds) are written as separate ions in the solution", "Complex (coordination compound) a compound consisting either of complex ions and other ions of opposite charge or of a neutral complex species", "Complex ion an ion formed from a metal ion with a Lewis base attached to it by a coordinate covalent bond", "Complex ion an ion formed from a metal ion with a Lewis base attached to it by a coordinate covalent bond", "Compound a substance composed of two or more elements chemically combined",\
                 "Compound a type of matter composed of atoms of two or more elements chemically combined in fixed proportions", "Concentration a general term referring to the quantity of solute in a standard quantity of solvent or solution", "Concentration a general term referring to the quantity of solute in a standard quantity of solvent or solution", "Condensation the change of a gas to either the liquid or the solid state", "Condensation polymer a polymer formed by linking many molecules together by condensation reactions", "Condensation reaction a reaction in which two molecules or ions are chemically joined by the elimination of a small molecule such as water", "Condensed (structural) formula a structural formula in which the bonds around each carbon atom are not explicitly written", "Conjugate acid in a conjugate acid?base pair, the species that can donate a proton", "Conjugate acid?base pair two species in an acid?base reaction, one acid and one base, that differ by the loss or gain of a proton", "Conjugate base in a conjugate acid?base pair, the species that can accept a proton", "Constitutional (structural) isomers isomers that differ in how the atoms are joined together", "Constitutional (structural) isomers compounds with the same molecular formula but different structural formulas", "Contact process 'an industrial method for the manufacture of sulfuric acid. It consists of the reaction of sulfur dioxide with oxygen to form sulfur trioxide using a catalyst of vanadium(V) oxide, followed by the reaction of sulfur trioxide with water.'", "Continuous spectrum a spectrum containing light of all wavelengths", "Control rods cylinders composed of substances that absorb neutrons, such as boron and cadmium, and can therefore slow a nuclear chain reaction", "Conversion factor a factor equal to 1 that converts a quantity expressed in one unit to a quantity expressed in another unit", "Coordinate covalent bond a bond formed when both electrons of the bond are donated by one atom", "Coordination compound a compound consisting either of complex ions and other ions of opposite charge or of a neutral complex species", "Coordination isomers isomers consisting of complex cations and complex anions that differ in the way the ligands are distributed between the metal atoms", "Coordination number in a crystal, the number of nearest-neighbor atoms of an atom", "Coordination number in a complex, the total number of bonds the metal atom forms with ligands", "Copolymer a polymer consisting of two or more different monomer units", "Corresponding oxoacid of ClO- HClO", "Corresponding oxoacid of ClO2- HClO2", "Corresponding oxoacid of ClO3- HClO3", "Corresponding oxoacid of ClO4- HClO4", "Corresponding oxoacid of CO32- H2CO3", "Corresponding oxoacid of NO2- HNO2", "Corresponding oxoacid of NO3- HNO3", "Corresponding oxoacid of PO43- H3PO4", "Corresponding oxoacid of SO32- H2SO3", "Corresponding oxoacid of SO42- H2SO4", "Corresponding oxoanion of H2CO3 CO32-", "Corresponding oxoanion of H2SO3 SO32-", "Corresponding oxoanion of H2SO4 SO42-", "Corresponding oxoanion of H3PO4 PO43-", "Corresponding oxoanion of HClO ClO-", "Corresponding oxoanion of HClO2 ClO2-", "Corresponding oxoanion of HClO3 ClO3-", "Corresponding oxoanion of HClO4 ClO4-", "Corresponding oxoanion of HNO2 NO2-", "Corresponding oxoanion of HNO3 NO3-", "Covalent bond a chemical bond formed by the sharing of a pair of electrons between atoms", "Covalent network solid a solid that consists of atoms held together in large networks or chains by covalent bonds", "Covalent radii values assigned to atoms in such a way that the sum of covalent radii of atoms A and B predicts an approximate A?B bond length", "Cr2O72- Dichromate ion", "Cr3+ Chromium(III) ion or chromic ion", "Critical mass the smallest mass of fissionable material in which a chain reaction can be sustained", "Critical pressure the vapor pressure at the critical temperature; it is the minimum pressure that must be applied to a gas at the critical temperature to liquefy it", "Critical temperature the temperature above which the liquid state of a substance no longer exists regardless of the pressure", "CrO42- Chromate ion", "Crystal a kind of solid having a regular three-dimensional arrangement of atoms, molecules, or ions", "Crystal field splitting (Δ) the difference in energy between the two sets of d orbitals on a central metal ion that arises from the interaction of the orbitals with the electric field of the ligands", "Crystal field theory 'a model of the electronic structure of transition-metal complexes that considers how the energies of the d orbitals of a metal ion are affected by the electric field of the ligands'", "Crystal lattice the geometric arrangement of lattice points of a crystal, in which we choose one lattice point at the same location within each of the basic units of the crystal", "Crystal systems the seven basic shapes possible for unit cells; a classification of crystals", "Crystalline solid a solid composed of one or more crystals; each crystal has a well-defined ordered structure in three dimensions", "Cu+ Copper(I) ion or cuprous ion", "Cu2+ Copper(II) ion or cupric ion", "Cubic close-packed structure (ccp) a crystal structure composed of close-packed atoms (or other units) with the stacking ABCABCABCA. . . It has a face-centered cubic unit cell.", "Curie (Ci) a unit of activity, equal to 3.700 x 1010 disintegrations per second", "Cycloalkane a cyclic saturated hydrocarbon; that is, a saturated hydrocarbon in which the carbon atoms form a ring; the general formula is CnH2n", "Cyclotron 'a type of particle accelerator consisting of two hollow, semicircular metal electrodes, called dees (because the shape resembles the letter D), in which charged particles are accelerated by stages to higher and higher kinetic energies. Ions introduced at the center of the cyclotron are accelerated in the space between the two dees'", "Dalton?s law of partial pressures the sum of the partial pressures of all the different gases in a mixture is equal to the total pressure of the mixture", "Dalton’s law of partial pressures equation P = PA + PB + PC . . .", "d-Block transition elements those transition elements with an unfilled d subshell in common oxidation states", "de Broglie relation", "deca- 10", "Decomposition reaction a reaction in which a single compound reacts to give two or more substances", "Defining equation for pH pH = -log [H3O+]", "Defining equation for the acid-ionization constant (Ka)", "Defining equation for the base-ionization constant (Kb)", "Degree of ionization the fraction of molecules that react with water to give ions", "Delocalized bonding a type of bonding in which a bonding pair of electrons is spread over a number of atoms rather than localized between two", "Denitrifying bacteria bacteria that use nitrate ion, NO3-, as a source of energy; they convert the ion to gaseous nitrogen", "Density the mass per unit volume of a substance or solution", "Deoxyribonucleic acid (DNA) the hereditary constituent of cells; it consists of two polymer strands of deoxyribonucleotide units", "Deposition the change of a vapor to a solid", "Desalinate remove ions from brackish (slightly salty) water or seawater, to make drinkable or industrially usable water", "di- 2", "Diamagnetic substance a substance that is not attracted by a magnetic field or is very slightly repelled by such a field. This property generally means that the substance has only paired electrons.", "Diffusion the process whereby a gas spreads out through another gas to occupy the space uniformly", "Dimensional analysis (factor-label method) the method of calculation in which one carries along the units for quantities", "Dipole moment a quantitative measure of the degree of charge separation in a molecule", "Dipole?dipole force an attractive intermolecular force resulting from the tendency of polar molecules to align themselves such that the positive end of one molecule is near the negative end of another", "Displacement reaction (single-replacement reaction) a reaction in which an element reacts with a compound, displacing another element from it", "Dissociation constant of a complex ion (Kd) the reciprocal, or inverse, value of the formation constant", "Distillation the process in which a liquid is vaporized then condensed; used to separate substances of different volatilities", "Disulfide linkage a covalent linkage formed between two cysteine groups within a protein molecule by oxidation of the two groups", "Double bond a covalent bond in which two pairs of electrons are shared by two atoms", "Dow process a commercial method for isolating magnesium from seawater", "Downs cell a commercial electrochemical cell used to obtain sodium metal by the electrolysis of molten sodium chloride", "Effective nuclear charge the positive charge that an electron experiences from the nucleus, equal to the nuclear charge but reduced by any shielding or screening from any intervening electron distribution", "Effusion the process in which a gas flows through a small hole in a container", "Elastomer elastic or rubbery type of polymer", "Electrochemical cell a system consisting of electrodes that dip into an electrolyte and in which a chemical reaction either uses or generates an electric current", "Electrolysis the process of producing a chemical change in an electrolytic cell", "Electrolyte a substance, such as sodium chloride, that dissolves in water to give an electrically conducting solution", "Electrolytic cell an electrochemical cell in which an electric current drives an otherwise nonspontaneous reaction", "Electromagnetic spectrum the range of frequencies or wavelengths of electromagnetic radiation", "Electron a very light, negatively charged particle that exists in the region around the atom?s positively charged nucleus", "Electron affinity the energy change for the process of adding an electron to a neutral atom in the gaseous state to form a negative ion", "Electron capture the decay of an unstable nucleus by capturing, or picking up, an electron from an inner orbital of an atom", "Electron configuration the particular distribution of electrons among available subshells", "Electron volt (eV) the quantity of energy that would have to be imparted to an electron (whose charge is 1.602 x 10-19 C) to accelerate it by one volt potential difference", "Electronegativity a measure of the ability of an atom in a molecule to draw bonding electrons to itself", "Element a substance that cannot be decomposed by any chemical reaction into simpler substances", "Element A type of matter composed of only one kind of atom, each atom of a given kind having the same properties. (2.1) A substance whose atoms all have the same atomic number. (2.3)", "Elementary reaction a single molecular event, such as a collision of molecules, resulting in a reaction", "Empirical formula (simplest formula) the formula of a substance written with the smallest integer (whole-number) subscripts", "Emulsion a colloid consisting of liquid droplets dispersed throughout another liquid", "Enantiomers (optical isomers) isomers that are nonsuperimposable mirror images of one another", "Endothermic process a chemical reaction or physical change in which heat is absorbed", "Energy the potential or capacity to move matter", "Energy levels specific energy values in an atom", "Enthalpy (H) an extensive property of a substance that can be used to obtain the heat absorbed or evolved in a chemical reaction at constant pressure", "Enthalpy (H) It equals the quantity U + PV.", "Enthalpy of reaction (ΔH) the change in enthalpy for a reaction at a given temperature and pressure; it equals the heat of reaction at constant pressure", "Entropy (S) a thermodynamic quantity that is a measure of how dispersed the energy of a system is among the different possible ways that a system can contain energy", "Enzyme a protein that catalyzes a biochemical reaction", "Equation for maximum work of a voltaic cell wmax = -nFEcell", "Equation for the first law of thermodynamics ΔU = q = w", "Equation for the ion-product constant for water (Kw) Kw = [H3O+][OH- ] = 1.0 x 10-14 at 25°C", "Equation relating entropy change to heat and temperature for an equilibrium process", "Equation relating half-life and radioactive decay constant", "Equatorial direction one of the three directions pointing from the center of a trigonal bipyramid to a vertex other than one on the axis", "Equilibrium constant Kc the value obtained for the equilibrium-constant expression when equilibrium concentrations are substituted", "Equilibrium constant Kc equation", "Equilibrium constant Kp an equilibrium constant for a gas reaction, similar to Kc, but in which concentrations of gases are replaced by partial pressures (in atm)", "Equilibrium-constant expression an expression obtained for a reaction by multiplying the concentrations of products, dividing by the concentrations of reactants, and raising each concentration term to a power equal to the coefficient in the chemical equation", "Equivalence point the point in a titration when a stoichiometric amount of reactant has been added", "Ester a compound formed from a carboxylic acid, RCOOH, and an alcohol, R'OH.", "Ether a compound formally obtained by replacing both H atoms of H2O by hydrocarbon groups R and R'", "Exact number a number that arises when you count items or sometimes when you define a unit", "Exchange (metathesis) reaction a reaction between compounds that, when written as a molecular equation, appears to involve the exchange of parts between the two reactants", "Excited state a quantum-mechanical state of an atom or molecule associated with any energy level except the lowest, which is the ground state", "Exothermic process a chemical reaction or physical change in which heat is evolved", "Experiment an observation of natural phenomena carried out in a controlled manner so that the results can be duplicated and rational conclusions obtained", "Face-centered cubic unit cell a cubic unit cell in which there are lattice points at the center of each face of the unit cell in addition to those at the corners", "Faraday constant (F) the magnitude of charge on one mole of electrons, equal to 9.6485 x 104C.", "f-Block transition elements (inner transition elements) the elements with a partially filled f subshell in common oxidation states", "Fe2+ Iron(II) ion or ferrous ion", "Fe3+ Iron(III) ion or ferric ion", "Fibrous proteins proteins that form long coils or align themselves in parallel to form long, water-insoluble fibers", "First ionization energy (first ionization potential) 'the minimum energy needed to remove the highest-energy (that is, the outermost) electron from a neutral atom in the gaseous state'", "First law of thermodynamics the change in internal energy of a system, ΔU, equals q + w", "First-order integrated rate law", "Formal charge (of an atom in a Lewis formula) the hypothetical charge you obtain by assuming that bonding electrons are equally shared between bonded atoms and that the electrons of each lone pair belong completely to one atom", "Formation constant (stability constant) of a complex ion (Kf) the equilibrium constant for the formation of a complex ion from the aqueous metal ion and the ligands", "Formula defining mass percentage", "Formula defining molality", "Formula defining molarity", "Formula defining mole fraction", "Formula defining mole fraction (in terms of moles and also in terms of gas pressures)", "Formula defining percentage yield", "Formula for free energy in a nonstandard state given the reaction quotient ΔG = ΔGo + RT ln Q", "Formula for pressure-volume work w = -PΔU", "Formula for root-mean-square (rms) speed of molecules in a gas", "Formula for the definition of density", "Formula for the definition of kinetic energy", "Formula for the energy of an emitted photon in terms of energy levels of an atom hν = -(Ef - Ei)", "Formula for the mass percentage of solute", "Formula mass (FM) the sum of the atomic masses of all atoms in a formula unit of a compound", "Formula relating cell potential and reaction quotient at 25°C (Nernst equation) ", "Formula relating emperical formula mass to molecular mass",\
                  "Formula relating enthalpy of reaction to standard enthalpies of products and reactants", "Formula relating entropy of reaction to standard entropies of products and reactants ΔS° = ΣnS° (products) - ΣmS° (reactants)", "Formula relating free energy and equilibrium constant ΔG° = -RT ln K", "Formula relating free energy of reaction to standard free energies of products and reactants", "Formula relating free-energy changes to enthalpy and entropy changes ΔH° = ΔH° - TΔS°", "Formula relating heat to heat capacity q = C Δt", "Formula relating heat to specific heat q = s x m x Δt", "Formula relating intial molaritites and volumes to final molarities and volumes", "Formula relating pH and pOH 14.00", "Formula relating speed of light, frequency, and wavelength c = νλ", "Formula relating standard cell potential and equilibrium constant at 25°C", "Formula relating standard cell potential to standard electrode potentials", "Formula relating standard free-energy change to the standard cell potential", "Formula relating the acid-ionization and base-ionization constants KaKb = Kw", "Formula to convert from degrees Celsius (tC) to degrees Fahrenheit (tF)", "Formula to convert from kelvins (TK) to degrees Celsius (tC)", "Formula unit the group of atoms or ions explicitly symbolized in the formula", "Fraction of radioactive nuclei remaining after a specified period of time equation", "Fractional (isotopic) abundance the fraction of the total number of atoms that is composed of a particular isotope", "Fractional precipitation the technique of separating two or more ions from a solution by adding a reactant that precipitates first one ion, then another, and so forth", "Frasch process a mining procedure in which underground deposits of solid sulfur are melted in place with superheated water, and the molten sulfur is forced upward as a froth using air under pressure", "Free energy (G) a thermodynamic quantity defined by the equation G = H - TS", "Freezing the change of a liquid to the solid state", "Freezing point the temperature at which a pure liquid changes to a crystalline solid, or freezes", "Freezing-point depression a colligative property of a solution equal to the freezing point of the pure solvent minus the freezing point of the solution", "Freezing-point depression equation ΔTf = Kbcm", "Frequency (ν) the number of wavelengths of a wave that pass a fixed point in one unit of time (usually one second)", "Frequency factor the symbol A in the Arrhenius equation, assumed to be a constant", "Fuel cell essentially a battery, but it differs by operating with a continuous supply of energetic reactants, or fuel", "Fuel rods the cylinders that contain fissionable material for a nuclear reactor", "Fullerene a family of molecules consisting of a closed cage of carbon atoms arranged in pentagons as well as hexagons", "Functional group a reactive portion of a molecule that undergoes predictable reactions", "Functional group a reactive portion of a molecule that undergoes predictable reactions", "Gamma emission emission from an excited nucleus of a gamma photon, corresponding to radiation with a wavelength of about 10-12 m", "Gamma photon a particle of electromagnetic radiation of short wavelength (about 1 pm, or 10-12 m) and high energy", "Gas the form of matter that is an easily compressible fluid; a given quantity of gas will fit into a container of almost any size and shape", "Gas chromatography a chromatographic separation method in which a gaseous mixture of vaporized substances is separated into its components by passing the mixture through a column of packing material. Substances in the gaseous mixture are attracted, to the packing material to different extents and thus move through the column at different rates.", "Geiger counter a kind of ionization counter used to count particles emitted by radioactive nuclei. It consists of a metal tube filled with gas, such as argon.", "Gene a sequence of nucleotides in a DNA molecule that codes for a given protein", "Geometric isomers isomers in which the atoms are joined to one another in the same way but differ because some atoms occupy different relative positions in space", "Glass electrode a compact electrode used to determine pH by cell potential measurements", "Globular proteins proteins in which long coils fold into compact, roughly spherical shapes", "Goldschmidt process a method of preparing a metal by reduction of its oxide with powdered aluminum", "Graham?s law of effusion the rate of effusion of gas molecules from a particular hole is inversely proportional to the square root of the molecular weight of the gas at constant temperature and pressure", "Graham's law of effusion equation", "Gravimetric analysis a type of quantitative analysis in which the amount of a species in a material is determined by converting the species to a product that can be isolated completely and weighed", "Ground state a quantum-mechanical state of an atom or molecule associated with the lowest energy level. States associated with higher energy levels are called excited states.", "Group (of the periodic table) the elements in any one column of the periodic table", "H2PO4- Dihydrogen phosphate ion", "Haber process an industrial process for the preparation of ammonia from nitrogen and hydrogen with a specially prepared catalyst, high temperature, and high pressure", "Haber process an industrial process for the preparation of ammonia from nitrogen and hydrogen with a specially prepared catalyst, high temperature, and high pressure", "Half-cell the portion of an electrochemical cell in which a half-reaction takes place", "Half-life (t1/2) the time it takes for one-half of the nuclei in a sample to decay", "Half-life of a first-order rate law", "Half-life of a second-order rate law", "Half-life of a zero-order reaction", "Half-reaction one of two parts of an oxidation?reduction reaction, one part of which involves a loss of electrons (or increase of oxidation number) and the other a gain of electrons (or decrease of oxidation number)", "Hall–Héroult process the commercial method for producing aluminum by the electrolysis of a molten mixture of aluminum oxide in cryolite, Na3AlF6", "Halogens the Group VIIA elements; they are reactive non-metals", "HCO3- Hydrogen carbonate ion (or bicarbonate ion)", "Heat the energy that flows into or out of a system because of a difference in temperature between the thermodynamic system and its surroundings", "Heat capacity (C) the quantity of heat needed to raise the temperature of a sample of substance one degree Celsius (or one kelvin)", "Heat of fusion (enthalpy of fusion) the heat needed for the melting of a solid", "Heat of reaction the heat absorbed (or evolved) during a chemical reaction; it equals the value of q required to return the chemical system to a given temperature at the completion of the reaction", "Heat of solution the heat absorbed (or evolved) when an ionic substance dissolves in water", "Heat of vaporization (enthalpy of vaporization) the heat needed for the vaporization of a liquid", "Henderson–Hasselbalch equation an equation relating the pH of a buffer for different concentrations of conjugate acid and base", "Henry?s law the solubility of a gas is directly proportional to the partial pressure of the gas above the solution", "Henry's law formula S = kHP", "hepta- 7", "Hess?s law of heat summation for a chemical equation that can be written as the sum of two or more steps, the enthalpy change for the overall equation equals the sum of the enthalpy changes for the individual steps", "Heterogeneous catalysis the use of a catalyst that exists in a different phase from the reacting species, usually a solid catalyst in contact with a gaseous or liquid solution of reactants", "Heterogeneous equilibrium an equilibrium that involves reactants and products in more than one phase", "Heterogeneous mixture a mixture that consists of physically distinct parts, each with different properties", "Heteronuclear diatomic molecules molecules composed of two different nuclei", "hexa- 6", "Hexagonal close-packed structure (hcp) 'a crystal structure composed of close-packed atoms (or other units) with the stacking ABABABA . . .; the structure has a hexagonal unit cell'", "Hg2+ Mercury(II) ion or mercuric ion", "Hg22+ Mercury(I) ion or mercurous ion", "High-spin complex ion a complex ion in which there is minimum pairing of electrons in the orbitals of the metal atom", "Homogeneous catalysis the use of a catalyst in the same phase as the reacting species", "Homogeneous equilibrium an equilibrium that involves reactants and products in a single phase", "Homogeneous mixture (solution) a mixture that is uniform in its properties throughout given samples", "Homologous series a series of compounds in which one compound differs from a preceding one by a fixed group of atoms, for example, a —CH2 — group", "Homonuclear diatomic molecules molecules composed of two like nuclei", "Homopolymer a polymer whose monomer units are all alike", "HPO42- Monohydrogen phosphate ion", "HSO3- Hydrogen sulfite ion (or bisulfite ion)", "HSO4- Hydrogen sulfate ion (or bisulfate ion)", "Hund?s rule the lowest-energy arrangement of electrons in a subshell is obtained by putting electrons into separate orbitals of the subshell with the same spin before pairing electrons", "Hybrid orbitals orbitals used to describe bonding that are obtained by taking combinations of atomic orbitals of the isolated atoms", "Hydrate a compound that contains water molecules weakly bound in its crystals", "Hydration the attraction of ions for water molecules", "Hydrocarbons compounds containing only carbon and hydrogen", "Hydrogen bonding a weak to moderate attractive force that exists between a hydrogen atom covalently bonded to a very electronegative atom and a lone pair of electrons on another small, electronegative atom. It is represented in formulas by a series of dots", "Hydrologic cycle the natural cycle of water from the oceans to fresh water sources and back to the oceans", "Hydrolysis the reaction of an ion with water to produce the conjugate acid and hydroxide ion or the conjugate base and hydrogen ion", "Hydronium ion the H3O+ ion; also called the hydrogen ion and written H+ (aq)", "Hydrophilic colloid a colloid in which there is a strong attraction between the dispersed phase and the continuous phase (water)", "Hypothesis a tentative explanation of some regularity of nature", "Ideal gas law the equation PV = nRT, which combines all of the gas laws", "Ideal gas law equation PV = nRT", "Ideal solution a solution of two or more substances each of which follows Raoult?s law", "Immiscible fluids fluids that do not mix but form separate layers", "Inequality relating entropy change to heat and temperature for a spontaneous process", "Initiator a compound that produces free radicals in a reaction for the preparation of an addition polymer", "Inner transition elements the two rows of elements at the bottom of the periodic table", "Inner transition elements the elements with a partially filled f subshell in common oxidation states", "Inorganic compounds compounds composed of elements other than carbon. A few simple compounds of carbon, including carbon monoxide, carbon dioxide, carbonates, and cyanides, are generally considered to be inorganic.", "Integrated rate law a mathematical relationship between concentration and time", "Intermolecular forces the forces of interaction between molecules", "Internal energy (U) the sum of the kinetic and the potential energies of the particles making up a system", "International System of Units (SI) a particular choice of metric units that was adopted by the General Conference of Weights and Measures in 1960", "Ion an electrically charged particle obtained from an atom or a chemically bonded group of atoms by adding or removing electrons", "Ion exchange a process in which a water solution is passed through a column of a material that replaces one kind of ion in solution with another kind", "Ion product (Qc) the product of ion concentrations in a solution, each concentration raised to a power equal to the number of ions in the formula of the ionic compound", "Ionic bond a chemical bond formed by the electrostatic attraction between positive and negative ions", "Ionic compound a compound composed of cations and anions", "Ionic radius a measure of the size of the spherical region around the nucleus of an ion within which the electrons are most likely to be found", "Ionic solid a solid that consists of cations and anions held together by the electrical attraction of opposite charges (ionic bonds)", "Ionization energy the energy needed to remove an electron from an atom (or molecule). Often used to mean first ionization energy.", "Ion-product constant for water (Kw) the equilibrium value of the ion product [H3O+][OH-].", "Ion-selective electrode an electrode whose cell potential depends on the concentration of a particular ion in solution", "Isoelectronic refers to different species that have the same number and configuration of electrons", "Isomers compounds of the same molecular formula but with different arrangements of the atoms", "Isotope dilution a technique to determine the quantity of a substance in a mixture or the total volume of solution by adding a known amount of an isotope to it", "Isotopes atoms whose nuclei have the same atomic number but different mass numbers; that is, the nuclei have the same number of protons but different numbers of neutrons", "Joule (J) the SI unit of energy; 1 J = 1 kg × m2/s2", "Kelvin (K) the SI base unit of temperature; a unit on the absolute temperature scale", "Ketone a compound containing a carbonyl group with two hydrocarbon groups attached to it", "Kilogram (kg) the SI base unit for mass; equal to about 2.2 pounds", "Kinetic energy the energy associated with an object by virtue of its motion", "Kinetic-molecular theory (kinetic theory) the theory that a gas consists of molecules in constant random motion", "Lanthanides the first of the two rows of elements at the bottom of the periodic table; lanthanum plus the 14 elements following it in the periodic table, in which the 4f subshell is filling", "Laser a source of intense, highly directed beam of monochromatic light; the word laser is an acronym meaning light amplification by stimulated emission of radiation", "Lattice energy the change in energy that occurs when an ionic solid is separated into isolated ions in the gas phase", "Lattice energy the change in energy that occurs when an ionic solid is separated into isolated ions in the gas phase", "Law a concise statement or mathematical equation about a fundamental relationship or regularity of nature", "Law of combining volumes a relation stating that gases at the same temperature and pressure react with one another in volume ratios of small whole numbers", "Law of conservation of energy energy may be converted from one form to another, but the total quantity of energy remains constant", "Law of conservation of mass the total mass remains constant during a chemical change (chemical reaction)", "Law of definite proportions (law of constant composition) a pure compound, whatever its source, always contains definite or constant proportions of the elements by mass", "Law of mass action the values of the equilibrium-constant expression Kc are constant for a particular reaction at a given temperature, whatever equilibrium concentrations are substituted", "Law of multiple proportions when two elements form more than one compound, the masses of one element in these compounds for a fixed mass of the other element are in ratios of small whole numbers", "Le Châtelier?s principle when a system in equilibrium is disturbed by a change of temperature, pressure, or concentration variable, the system shifts in equilibrium composition in a way that tends to counteract this change of variable", "Le Châtelier?s principle when a system in equilibrium is disturbed by a change of temperature, pressure, or concentration variable, the system shifts in equilibrium composition in a way that tends to counteract this change of variable",\
                   "Lead storage cell a voltaic cell that consists of electrodes of lead alloy grids; one electrode is packed with a spongy lead to form the anode, and the other is packed with lead dioxide to form the cathode", "Levorotatory refers to a compound whose solution rotates the plane of polarized light to the left (when looking toward the source of light)", "Lewis acid a species that can form a covalent bond by accepting an electron pair from another species", "Lewis base 'a species that can form a covalent bond by donating an electron pair to another species.'", "Lewis electron-dot formula a formula in which dots are used to represent valence electrons", "Lewis electron-dot symbol a symbol in which the electrons in the valence shell of an atom or ion are represented by dots placed around the letter symbol of the element", "Ligand a Lewis base that bonds to a metal ion to form a complex ion", "Ligand a Lewis base that bonds to a metal ion to form a complex ion", "Limiting reactant (limiting reagent) the reactant that is entirely consumed when a reaction goes to completion", "Line spectrum a spectrum showing only certain colors or specific wavelengths of light", "Linear geometry a molecular geometry in which all atoms line up along a straight line", "Linkage isomers isomers of a complex that differ in the atom of a ligand that is bonded to the metal atom", "Lipids biological substances like fats and oils that are soluble in organic solvents, such as chloroform and carbon tetrachloride", "Liquefaction the process in which a substance that is normally a gas changes to the liquid state", "Liquid the form of matter that is a relatively incompressible fluid; a liquid has a fixed volume but no fixed shape.", "Liter (L) a unit of volume equal to a cubic decimeter (equal to approximately one quart)", "Lithium?iodine battery a voltaic cell in which the anode is lithium metal and the cathode is an I2 complex.", "Logarithmic form of the Arrhenius equation expressed at two temperatures", "London forces (dispersion forces) the weak attractive forces between molecules resulting from the small, instantaneous dipoles that occur because of the varying positions of the electrons during their motion about nuclei", "Lone pair (nonbonding pair) an electron pair that remains on one atom and is not shared", "Low-spin complex ion a complex ion in which there is more pairing of electrons in the orbitals of the metal atom than in a corresponding high-spin complex ion", "Magic number the number of nuclear particles in a completed shell of protons or neutrons", "Magnetic quantum number (ml) the quantum number that distinguishes orbitals of given n and l—that is, of given energy and shape—but having a different orientation in space; the allowed values are the integers from -l to +l", "Main-group element (representative element) an element in an A column of the periodic table, in which an outer s or p subshell is filling", "Main-group element (representative element) an element in an A column of the periodic table, in which an outer s or p subshell is filling", "Manometer a device that measures the pressure of a gas or liquid in a sealed vessel", "Markownikoff?s rule a generalization stating that the major product formed by the addition of an unsymmetrical reagent such as H?Cl, H?Br, or H?OH is the one obtained when the H atom of the reagent adds to the carbon atom of the multiple bond that already has the greater number of hydrogen atoms attached to it", "Mass the quantity of matter in a material", "Mass defect the total nucleon mass minus the atomic mass of a nucleus", "Mass number (A) the total number of protons and neutrons in a nucleus", "Mass percentage parts per hundred parts of the total, by mass", "Mass percentage of solute the percentage by mass of solute contained in a solution", "Mass spectrometer an instrument, such as one based on Thomson?s principles, that measures the mass-to-charge ratios of atoms", "Mass-energy equivalence equation ΔE = (Δm)c2", "Mass-energy equivalence equation ?E = (Dm)c2", "Material any particular kind of matter", "Matter 'all of the objects around you (1.1); whatever occupies space and can be perceived by our senses. (1.3)'", "Maxwell?s distribution of molecular speeds a theoretical relationship that predicts the relative number of molecules at various speeds for a sample of gas at a particular temperature", "Melting (fusion) the change of a solid to the liquid state", "Melting point the temperature at which a crystalline solid changes to a liquid, or melts", "Messenger RNA a relatively small RNA molecule that can diffuse about the cell and attach itself to a ribosome, where it serves as a pattern for protein synthesis", "Metal a substance or mixture that has a characteristic luster, or shine, is generally a good conductor of heat and electricity and is malleable and ductile", "Metal a substance or mixture that has a characteristic luster, or shine, is generally a good conductor of heat and electricity and is malleable and ductile", "Metal refining in metallurgy, the purification of a metal", "Metallic solid a solid that consists of positive cores of atoms held together by a surrounding ?sea? of electrons (metallic bonding)", "Metalloid (semimetal) an element having both metallic and nonmetallic properties", "Metallurgy the scientific study of the production of metals from their ores and the making of alloys having various useful properties", "Metaphosphoric acids acids with the general formula (HPO3)n", "Metastable nucleus a nucleus in an excited state with a life-time of at least one nanosecond (10-9 s)", "Meter (m) the SI base unit of length", "Micelle a colloidal-sized particle formed in water by the association of molecules or ions each of which has a hydrophobic end and a hydrophilic end", "Millimeters of mercury (mmHg) a unit of pressure also known as the torr. A unit of pressure equal to that exerted by a column of mercury 1 mm high at 0.00°C.", "Mineral a naturally occurring inorganic solid substance or solid solution with definite crystalline form", "Miscible fluids fluids that mix with or dissolve in each other in all proportions", "Mixture a material that can be separated by physical means into two or more substances", "Mn2+ Manganese(II) ion or manganous ion", "MnO4- Permanganate ion", "Moderator a substance that slows down neutrons in a nuclear fission reactor", "Molality the moles of solute per kilogram of solvent", "Molar concentration (molarity), M the moles of solute dissolved in one liter (cubic decimeter) of solution", "Molar gas constant (R) the constant of proportionality relating the molar volume of a gas to T/P", "Molar gas volume (Vm) the volume of one mole of gas", "Molar mass the mass of one mole of substance. In grams, it is numerically equal to the formula mass in atomic mass units.", "Mole (mol) the quantity of a given substance that contains as many molecules or formula units as the number of atoms in exactly 12 g of carbon-12. The amount of substance containing Avogadro?s number of molecules or formula units.", "Mole fraction the fraction of moles of a component in the total moles of a mixture", "Mole fraction the moles of a component substance divided by the total moles of solution", "Mole percent percent, in terms of moles, of a component in a solution; obtained by multiplying mole fraction by 100", "Molecular equation a chemical equation in which the reactants and products are written as if they were molecular substances, even though they may actually exist in solution as ions", "Molecular formula a chemical formula that gives the exact number of different atoms of an element in a molecule", "Molecular geometry the general shape of a molecule, as determined by the relative positions of the atomic nuclei", "Molecular mass (MM) the sum of the atomic masses of all the atoms in a molecule", "Molecular orbital theory a theory of the electronic structure of molecules in terms of molecular orbitals, which may spread over several atoms or the entire molecule", "Molecular solid a solid that consists of atoms or molecules held together by intermolecular forces", "Molecular substance a substance that is composed of molecules, all of which are alike", "Molecularity the number of molecules on the reactant side of an elementary reaction", "Molecule a definite group of atoms that are chemically bonded together?that is, tightly connected by attractive forces", "Monatomic ion an ion formed from a single atom", "mono- 1", "Monodentate ligand a ligand that bonds to a metal atom through one atom of the ligand", "Monomer the small molecules that are linked together to form a polymer", "Monomer a compound used to make a polymer (and from which the polymer?s repeating unit arises)", "Monoprotic acid an acid that yields one acidic hydrogen per molecule", "Monosaccharides simple sugars, each containing three to nine carbon atoms, generally all but one of which bear a hydroxyl group, the remaining one being part of a carbonyl group", "Net ionic equation an ionic equation from which spectator ions have been canceled", "Neutralization reaction a reaction of an acid and a base that results in an ionic compound and possibly water", "Neutron a particle found in the nucleus of an atom; it has a mass almost identical to that of the proton but no electric charge", "sample based on the conversion of stable isotopes to radioactive isotopes by bombarding a sample with neutrons", "NH4+ Ammonium ion", "Ni2+ Nickel(II) ion or nickel ion", "Nickel?cadmium cell a voltaic cell consisting of an anode of cadmium and a cathode of hydrated nickel oxide (approximately NiOOH) on nickel; the electrolyte is potassium hydroxide", "Nitrogen cycle the circulation of the element nitrogen in the biosphere, from nitrogen fixation to the release of free nitrogen by denitrifying bacteria", "Nitrogen-fixing bacteria bacteria that can produce nitrogen compounds in the soil from atmospheric nitrogen", "NO2- Nitrite ion", "NO3- Nitrate ion", "Noble gases (inert gases; rare gases) the Group VIIIA elements; all are gases consisting of uncombined atoms. They are relatively unreactive elements", "Noble-gas core an inner-shell configuration corresponding to one of the noble gases", "nona- 9", "Nonelectrolyte a substance, such as sucrose, or table sugar (C12H22O11), that dissolves in water to give a nonconducting or very poorly conducting solution", "Nonmetal an element that does not exhibit the characteristics of a metal", "Nonstoichiometric compound a compound whose composition varies from its idealized formula", "Nuclear bombardment reaction a nuclear reaction in which a nucleus is bombarded, or struck, by another nucleus or by a nuclear particle", "Nuclear equation a symbolic representation of a nuclear reaction", "Nuclear fission a nuclear reaction in which a heavy nucleus splits into lighter nuclei and energy is released", "Nuclear fission reactor a device that permits a controlled chain reaction of nuclear fissions", "Nuclear force a strong force of attraction between nucleons that acts only at very short distances (about 10-15 m)", "Nuclear fusion a nuclear reaction in which light nuclei combine to give a stabler, heavier nucleus plus possibly several neutrons, and energy is released", "Nucleic acids polynucleotides folded or coiled into specific threedimensional shapes", "Nucleotides the building blocks of nucleic acids", "Nucleus the atom?s central core; it has most of the atom?s mass and one or more units of positive charge", "Nuclide a particular atom characterized by a definite atomic number and mass number", "Nuclide symbol a symbol for a nuclide, in which the atomic number is given as a left subscript and the mass number is given as a left superscript to the symbol of the element", "Number of significant figures the number of digits reported for the value of a measured or calculated quantity, indicating the precision of the value", "O22- Peroxide ion", "octa- 8", "Octahedral geometry the geometry of a molecule in which six atoms occupy the vertices of a regular octahedron (a figure with eight faces and six vertices) with the central atom at the center of the octahedron", "Octet rule the tendency of atoms in molecules to have eight electrons in their valence shells (two for hydrogen atoms)", "OH- Hydroxide ion", "Optical isomers (enantiomers) isomers that are nonsuperimposable mirror images of one another", "Optically active having the ability to rotate the plane of light waves, either as a pure substance or in solution", "Orbital diagram a diagram to show how the orbitals of a sub-shell are occupied by electrons", "Ore a rock or mineral from which a metal or nonmetal can be economically produced", "Organic compounds compounds that contain carbon combined with other elements, such as hydrogen, oxygen, and nitrogen", "Organic compounds compounds that contain carbon combined with other elements, such as hydrogen, oxygen, and nitrogen", "Osmosis the phenomenon of solvent flow through a semipermeable membrane to equalize the solute concentrations on both sides of the membrane", "Osmotic pressure a colligative property of a solution equal to the pressure that, when applied to the solution, just stops osmosis", "osmotic pressure equation π = MRT", "Ostwald process an industrial preparation of nitrogen monoxide starting from the catalytic oxidation of ammonia to nitric oxide", "Overall order of a reaction the sum of the orders of the reactant species in the rate law", "Oxidation the part of an oxidation?reduction reaction in which there is a loss of electrons by a species (or an increase in the oxidation number of an atom)", "Oxidation number (oxidation state) either the actual charge on an atom in a substance, if the atom exists as a monatomic ion, or a hypothetical charge assigned by simple rules", "Oxidation potential the negative of the standard electrode potential", "Oxidation?reduction reaction (redox reaction) 'a reaction in which electrons are transferred between species or in which atoms change oxidation number'", "Oxide a binary compound with oxygen in the -2 oxidation state", "Oxidizing agent a species that oxidizes another species; it is itself reduced", "Oxoacid an acid containing hydrogen, oxygen, and another element", "Oxoacid a substance in which O atoms (and possibly other electronegative atoms) are bonded to a central atom, with one or more H atoms usually bonded to the O atoms", "Pairing energy (P) the energy required to put two electrons into the same orbital", "Paramagnetic substance a substance that is weakly attracted by a magnetic field; this attraction generally results from unpaired electrons", "Partial pressure the pressure exerted by a particular gas in a mixture", "Particle accelerator a device used to accelerate electrons, protons, and alpha particles and other ions to very high speeds", "Pascal (Pa) the SI unit of pressure; 1 Pa = 1 kg/(m·s2)", "Pauli exclusion principle no two electrons in an atom can have the same four quantum numbers. It follows from this that an orbital can hold no more than two electrons and can hold two only if they have different spin quantum numbers.", "penta- 5", "Peptide (amide) bond the C?N bond resulting from a condensation reaction between the carboxyl group of one amino acid and the amino group of a second amino acid", "Percentage composition the mass percentages of each element in a compound", "Percentage yield the actual yield (experimentally determined) expressed as a percentage of the theoretical yield (calculated)", "Period (of the periodic table) the elements in any one horizontal row of the periodic table", "Periodic law when the elements are arranged by atomic number, their physical and chemical properties vary periodically", "Periodic table a tabular arrangement of elements in rows and columns, highlighting the regular repetition of properties of the elements", "Peroxide a compound with oxygen in the -1 oxidation state", "pH the negative of the logarithm of the molar hydrogen-ion concentration", "Phase one of several different homogeneous materials present in the portion of matter under study",\
                    "Phase diagram a graphical way to summarize the conditions under which the different states of a substance are stable", "Phospholipid a type of lipid that contains a phosphate group. These molecules have hydrophobic and hydrophilic ends, and they aggregate to give a layer structure. The process is similar to the formation of micelles.", "Phospholipid bilayer a part of a biological membrane consisting of two layers of phospholipid molecules", "Photoelectric effect the ejection of electrons from the surface of a metal or other material when light shines on it", "Photon particle of electromagnetic energy with energy E proportional to the observed frequency of light: E = hv", "Physical adsorption adsorption in which the attraction is provided by weak intermolecular forces", "Physical change a change in the form of matter but not in its chemical identity", "Physical property a characteristic that can be observed for a material without changing its chemical identity", "Pi (p) bond a bond that has an electron distribution above and below the bond axis", "Planck’s constant (h) a physical constant with the value 6.63 x 10-34 J·s. It is the proportionality constant relating the frequency of light to the energy of a photon.", "Plasma an electrically neutral gas of ions and electrons", "PO43- Phosphate ion", "Polar covalent bond a covalent bond in which the bonding electrons spend more time near one atom than near the other", "Polyamide a polymer formed by reacting a substance containing two amine groups with a substance containing two carboxylic acid groups", "Polyatomic ion an ion consisting of two or more atoms chemically bonded together and carrying a net electric charge", "Polydentate ligand a ligand that can bond with two or more atoms to a metal atom", "Polyester a polymer formed by reacting a substance containing two alcohol groups with a substance containing two carboxylic acid groups", "Polymer a very large molecule made up of a number of smaller molecules repeatedly linked together", "Polymer a chemical species of very high molecular mass that is made up from many repeating units of low molecular mass", "Polymerase chain reaction (PCR) a technique used to amplify the quantity of DNA in a sample", "Polynucleotide a linear polymer of nucleotide units", "Polypeptide a polymer formed by the linking of many amino acids by peptide bonds", "olyphosphoric acids acids with the general formula Hn+2PnO3n-1 formed from linear chains of P—O bonds", "Polyprotic acid an acid that yields two or more acidic hydrogens per molecule", "Polyprotic acid an acid that yields two or more acidic hydrogens per molecule", "Positron a particle that is similar to an electron and has the same mass but has a positive charge", "Positron emission emission of a positron from an unstable nucleus", "Potential difference the difference in electrical potential (electrical pressure) between two points", "Potential energy the energy an object has by virtue of its position in a field of force", "Precipitate an insoluble solid compound formed during a chemical reaction in solution", "Precision the closeness of the set of values obtained from identical measurements of a quantity", "Pressure the force exerted per unit area of surface", "Primary alcohol an alcohol in which the hydroxyl group is attached to a carbon atom that is itself bonded to only one other carbon atom", "Primary structure (of a protein) the order, or sequence, of the amino-acid units in the protein", "Principal quantum number (n) the quantum number on which the energy of an electron in an atom principally depends; it can have any positive integer value: 1, 2, 3, . . .", "Product a substance that results from a chemical reaction", "Protein a biological polymer of small molecules called amino acids; a polypeptide that has a biological function", "Proton a particle found in the nucleus of the atom; it has a positive charge equal in magnitude, but opposite in sign, to that of the electron and a mass 1836 times that of the electron", "Pseudo-noble-gas core the noble-gas core together with (n - 1)d10 electrons", "Qualitative analysis the determination of the identity of substances present in a mixture", "Quantitative analysis the determination of the amount of a substance or species present in a material", "Quantum (wave) mechanics the branch of physics that mathematically describes the wave properties of submicroscopic particles", "Racemic mixture a mixture of equal amounts of optical isomers", "Rad the dosage of radiation that deposits 1 x 10-2 J of energy per kilogram of tissue", "Radioactive decay the process in which a nucleus spontaneously disintegrates, giving off radiation", "Radioactive decay constant (k) rate constant for radioactive decay", "Radioactive decay series a sequence in which one radioactive nucleus decays to a second, which then decays to a third, and so on", "Radioactive tracer a very small amount of radioactive isotope added to a chemical, biological, or physical system to facilitate study of the system", "Radioactivity spontaneous radiation from unstable elements", "Raoult’s law the partial pressure of solvent, PA, over a solution equals the vapor pressure of the pure solvent, PoA, times the mole fraction of the solvent, XA, in solution: PA = P°AXA", "Raoult’s law equation", "Rate constant a proportionality constant in the relationship between rate and concentrations", "Rate law an equation that relates the rate of a reaction to the concentrations of reactants (and catalyst) raised to various powers", "Rate of radioactive decay formula Rate = kNt", "Rate-determining step the slowest step in a reaction mechanism", "Reactant a starting substance in a chemical reaction", "Reaction intermediate a species produced during a reaction that does not appear in the net equation because it reacts in a subsequent step in the mechanism", "Reaction mechanism the set of elementary reactions whose overall effect is given by the net chemical equation", "Reaction order the exponent of the concentration of a given reactant species in the rate law, as determined experimentally", "Reaction quotient (Qc) an expression that has the same form as the equilibrium-constant expression but whose concentration values are not necessarily those at equilibrium", "Reaction quotient (Qc) equation", "Reaction rate the increase in molar concentration of product of a reaction per unit time or the decrease in molar concentration of reactant per unit time", "Reducing agent a species that reduces another species; it is itself oxidized", "Reduction the part of an oxidation?reduction reaction in which there is a gain of electrons by a species (or a decrease of oxidation number of an atom)", "Reference form the stablest form (physical state and allotrope) of an element under standard thermodynamic conditions", "Relationship between enthalpy change and heat of reaction ΔH = qp", "Relationship between molecular mass and density of a gas equation PMm = dRT", "Rem a unit of radiation dosage used to relate various kinds of radiation in terms of biological destruction. It equals the rad times a factor for the type of radiation, called the relative biological effectiveness (RBE): rems = rads x RBE.", "Resonance description a representation in which you describe the electron structure of a molecule having delocalized bonding by writing all possible electron-dot formulas", "Reverse osmosis a process in which a solvent, such as water, is forced by a pressure greater than the osmotic pressure to flow through a semipermeable membrane from a concentrated solution to a more dilute one", "Ribonucleic acid (RNA) a constituent of cells that is used to manufacture proteins from genetic information. It is a polymer of ribonucleotide units.", "Ribosomal RNA the RNA in a ribosome", "Ribosomes tiny cellular particles on which protein synthesis takes place", "Roasting the process of heating a mineral in air to obtain the oxide", "Root-mean-square (rms) molecular speed a type of average molecular speed, equal to the speed of a molecule having the average molecular kinetic energy. It equals , where Mm is the molar mass.", "Rounding the procedure of dropping nonsignificant digits in a calculation result and adjusting the last digit reported", "S2O32- Thiosulfate ion", "Salt an ionic compound that is a product of a neutralization reaction", "Salt bridge a tube of an electrolyte in a gel that is connected to the two half-cells of a voltaic cell; it allows the flow of ions but prevents the mixing of the different solutions that would allow direct reaction of the cell reactants", "Saturated hydrocarbon a hydrocarbon that has only single bonds between carbon atoms; all carbon atoms are bonded to the maximum number of hydrogen atoms (that is, the hydrocarbon is saturated with hydrogen). A saturated hydrocarbon molecule can be cyclic or acyclic.", "Saturated solution a solution that is in equilibrium with respect to a given dissolved substance", "Scientific method the general process of advancing scientific knowledge through observation, the framing of laws, hypotheses, or theories, and the conducting of more experiments", "Scientific notation the representation of a number in the form A x 10n, where A is a number with a single nonzero digit to the left of the decimal point and n is an integer, or whole number", "Scintillation counter a device that detects nuclear radiations from flashes of light generated in a material by the radiation", "Second (s) the SI base unit of time", "Second law of thermodynamics the total entropy of a system and its surroundings always increases for a spontaneous process. Also, for a spontaneous process at a given temperature, the change in entropy of the system is greater than the heat divided by the absolute temperature.", "Secondary alcohol an alcohol in which the hydroxyl group is attached to a carbon atom that is itself bonded to two carbon atoms", "Secondary structure (of a protein) the relatively simple coiled or parallel arrangement of a protein molecule", "Second-order integrated rate law", "Seesaw geometry the geometry of a molecule having four atoms bonded to a central atom, in which two of these outer atoms occupy axial positions of a trigonal bipyramid and the other two occupy equatorial positions", "Self-ionization (autoionization) a reaction in which two like molecules react to give ions", "Shell model of the nucleus a nuclear model in which protons and neutrons exist in levels, or shells, analogous to the shell structure that exists for electrons in an atom", "SI base units the SI units of measurement from which all others can be derived", "SI derived unit a unit derived by combining SI base units", "SI prefix a prefix used in the International System to indicate a power of 10", "Sigma (s) bond a bond that has a cylindrical shape about the bond axis", "Significant figures those digits in a measured number (or in the result of a calculation with measured numbers) that include all certain digits plus a final digit having some uncertainty", "Silica a covalent network solid of SiO2 in which each silicon atom is covalently bonded in tetrahedral directions to four oxygen atoms; each oxygen atom is in turn bonded to another silicon atom", "Silicate a compound of silicon and oxygen (with one or more metals) that may be formally regarded as a derivative of silicic acid, H4SiO4 or Si(OH)4", "Silicone a polymer that contains chains or rings of Si?O with one or more of the bonding positions on each Si atom occupied by an organic group", "Simple cubic unit cell a cubic unit cell in which lattice points are situated only at the corners of the unit cell", "Single bond a covalent bond in which a single pair of electrons is shared by two atoms", "SO32- Sulfite ion", "SO42- Sulfate ion", "Sol a colloid that consists of solid particles dispersed in a liquid", "Solid the form of matter characterized by rigidity; a solid is relatively incompressible and has fixed shape and volume", "Solubility the amount of a substance that dissolves in a given quantity of solvent (such as water) at a given temperature to give a saturated solution", "Solubility product constant (Ksp) the equilibrium constant for the solubility equilibrium of a slightly soluble (or nearly insoluble) ionic compound", "Solute in the case of a solution of a gas or solid dissolved in a liquid, the gas or solid; in other cases, the component in smaller amount", "Solvay process an industrial method for obtaining sodium carbonate from sodium chloride and limestone", "Solvent in a solution of a gas or solid dissolved in a liquid, the liquid; in other cases, the component in greater amount", "Specific heat capacity (specific heat) the quantity of heat required to raise the temperature of one gram of a substance by one degree Celsius (or one kelvin) at constant pressure", "Spectator ion an ion in an ionic equation that does not take part in the reaction", "Spectrochemical series an arrangement of ligands according to the relative magnitudes of the crystal field splittings they induce in the d orbitals of a metal ion", "Spin quantum number (ms) the quantum number that refers to the two possible orientations of the spin axis of an electron; its possible values are +½ and -½.", "Spontaneous fission the spontaneous decay of an unstable nucleus in which a heavy nucleus of mass number greater than 89 splits into lighter nuclei and energy is released", "Spontaneous process a physical or chemical change that occurs by itself", "Square planar geometry the geometry of a molecule in which a central atom is surrounded by four other atoms arranged in a square and in a plane containing the central atom", "Square pyramidal geometry the geometry of a molecule in which a central atom is at the apex of a pyramid and four other atoms form the square base of the pyramid", "Standard (absolute) entropy (S°) the entropy value for the standard state of a species", "Standard electrode potential (Eo) the electrode potential when the concentrations of solutes are 1 M, the gas pressures are 1 atm, and the temperature has a specified value?usually 25oC", "Standard enthalpy of formation (standard heat of formation), ΔH°f the enthalpy change for the formation of one mole of a substance in its standard state from its elements in their reference forms and in their standard states", "Standard free energy of formation (ΔG°f) the free-energy change that occurs when one mole of substance is formed from its elements in their stablest states at 1 atm and at a specified temperature (usually 25°C)", "Standard potential the potential of a voltaic cell operating under standard-state conditions (solute concentrations are 1 M, gas pressures are 1 atm, and the temperature has a specified value—usually 25°C)", "Standard state the standard thermodynamic conditions (1 atm and usually 25°C) chosen for substances when listing or comparing thermochemical data", "Standard temperature and pressure (STP) the reference conditions for gases, chosen by convention to be 0°C and 1 atm", "State function a property of a system that depends only on its present state, which is determined by variables such as temperature and pressure and is independent of any previous history of the system", "State function a property of a system that depends only on its present state, which is determined by variables such as temperature and pressure and is independent of any previous history of the system", "Statement of the Nernst formula an equation relating the cell potential, Ecell, to its standard potential cell, , and the reaction quotient, Q. At 25°C, the equation is Ecell =  - (0.0592/n)log Q.", "States of matter the three forms that matter can commonly assume?solid, liquid, and gas", "Steam-reforming process an industrial preparation in which steam and hydrocarbons from natural gas or petroleum react at high temperature and pressure in the presence of a catalyst to form carbon monoxide and hydrogen", "Stereoisomers isomers in which the atoms are bonded to each other in the same order but that differ in the precise arrangement of the atoms in space", "Stock system a system of chemical nomenclature in which the charge on a metal atom or oxidation number of an atom is denoted by a Roman numeral in parentheses following the element name",\
                     "Stoichiometry the calculation of the quantities of reactants and products involved in a chemical reaction", "Stratosphere the region of the atmosphere occurring at 10 to 15 km above the ground level wherein the temperature increases with increasing altitude; it lies just above the troposphere, the lower portion of the atmosphere", "Strong acid an acid that ionizes completely in water; it is a strong electrolyte", "Strong base a base that is present in aqueous solution entirely as ions, one of which is OH-; it is a strong electrolyte", "Strong electrolyte an electrolyte that exists in solution almost entirely as ions", "Structural formula a chemical formula that shows how the atoms are bonded to one another in a molecule", "Sublimation the change of a solid directly to the vapor", "Substance a kind of matter that cannot be separated into other kinds of matter by any physical process", "Substitution reaction a reaction in which a part of the reacting molecule is substituted for an H atom on a hydrocarbon or a hydrocarbon group", "Substrate the substance whose reaction an enzyme catalyzes", "Superoxide a binary compound with oxygen in the -½ oxidation state; it contains the superoxide ion, O2-", "Supersaturated solution a solution that contains more dissolved substance than does a saturated solution; the solution is not in equilibrium with the solid substance", "Surface tension the energy required to increase the surface area of a liquid by a unit amount", "Surroundings everything in the vicinity of a thermodynamic system", "Synthesis gas reaction a chemical reaction in which a mixture of CO and H2 gases is used in the industrial preparation of a number of organic compounds, including methanol, CH3OH", "System (thermodynamic) the substance or mixture of substances under study in which a change occurs", "Termolecular reaction an elementary reaction that involves three reactant molecules", "Tertiary alcohol an alcohol in which the hydroxyl group is attached to a carbon atom that is itself bonded to three carbon atoms", "Tertiary structure (of a protein) the structure associated with the way the protein coil is folded", "tetra- 4", "Tetrahedral geometry the geometry of a molecule in which four atoms bonded to a central atom occupy the vertices of a tetrahedron with the central atom at the center of this tetrahedron", "Theoretical yield the maximum amount of product that can be obtained by a reaction from given amounts of reactants", "Theory a tested explanation of basic natural phenomena", "Thermal equilibrium a state in which heat does not flow between a system and its surroundings because they are both at the same temperature", "Thermochemical equation the chemical equation for a reaction (including phase labels) in which the equation is given a molar interpretation, and the enthalpy of reaction for these molar amounts is written directly after the equation", "Thermochemistry the study of the quantity of heat absorbed or evolved by chemical reactions", "Thermodynamic equilibrium constant (K) the equilibrium constant in which the concentrations of gases are expressed in partial pressures in atmospheres, whereas the concentrations of solutes in liquid solutions are expressed in molarities", "Thermodynamics the study of the relationship between heat and other forms of energy involved in a chemical or physical process", "Thermodynamics the study of the relationship between heat and other forms of energy involved in a chemical or physical process", "crystalline at 0 K has an entropy of zero", "Titration a procedure for determining the amount of substance A by adding a carefully measured volume of a solution with known concentration of B until the reaction of A and B is just complete", "Transfer RNA (tRNA) a small RNA molecule; it binds to a particular amino acid, carries it to a ribosome, and then attaches itself (through base pairing) to a messenger RNA codon", "Transition elements the B columns of elements in the periodic table", "Transition elements the d-block transition elements in which a d subshell is being filled", "Transition elements those metallic elements that have an incompletely filled d subshell or easily give rise to common ions that have incompletely filled d subshells", "Transition-state theory a theory that explains the reaction resulting from the collision of two molecules in terms of an activated complex (transition state)", "Transmutation the change of one element to another by bombardment of the nucleus of the element with nuclear particles or nuclei", "Transuranium elements those elements with atomic numbers greater than that of uranium (Z = 92), the naturally occurring element of greatest Z", "tri- 3", "Trigonal bipyramidal geometry the geometry of a molecule in which five atoms bonded to a central atom occupy the vertices of a trigonal bipyramid (formed by placing two trigonal pyramids base to base) with the central atom at the center of this trigonal bipyramid", "Trigonal planar geometry the geometry of a molecule in which a central atom is surrounded by three other atoms arranged in a triangle and in a plane containing the central atom", "Trigonal pyramidal geometry the geometry of a molecule in which a central atom is at the apex of a pyramid and three other atoms form the triangular base of the pyramid", "Triple bond a covalent bond in which three pairs of electrons are shared by two atoms", "Triple point the point on a phase diagram representing the temperature and pressure at which three phases of a substance coexist in equilibrium", "T-shaped geometry the geometry of a molecule in which three atoms are bonded to a central atom to form a T", "Two-point form of the Clausius–Clapeyron equation", "Tyndall effect the scattering of light by colloidal-size particles", "Uncertainty principle a relation stating that the product of the uncertainty in position and the uncertainty in momentum (mass times speed) of a particle can be no smaller than Planck?s constant divided by 4p", "Unimolecular reaction an elementary reaction that involves one reactant molecule", "Unit a fixed standard of measurement", "Unit cell the smallest boxlike unit (each box having faces that are parallelograms) from which you can imagine constructing a crystal by stacking the units in three dimensions", "Unsaturated hydrocarbon a hydrocarbon that has at least one double or triple bond between carbon atoms; not all carbon atoms are bonded to the maximum number of hydrogen atoms (that is, the hydrocarbon is unsaturated with hydrogen)", "Unsaturated solution a solution that is not in equilibrium with respect to a given dissolved substance and in which more of the substance can dissolve", "Valence bond theory an approximate theory to explain the electron pair or covalent bond in terms of quantum mechanics", "Valence electron an electron in an atom outside the noble-gas or pseudo-noble-gas core", "Valence-shell electron-pair repulsion (VSEPR) model 'predicts the shapes of molecules and ions by assuming that the valence-shell electron pairs are arranged about each atom so that electron pairs are kept as far away from one another as possible, thus minimizing electron-pair repulsions'", "van der Waals equation an equation that is similar to the ideal gas law but includes two constants, a and b, to account for deviations from ideal behavior", "van der Waals equation", "van der Waals forces a general term for those intermolecular forces that include dipole?dipole and London forces", "Vapor the gaseous state of any kind of matter that normally exists as a liquid or solid", "Vapor pressure the partial pressure of the vapor over the liquid, measured at equilibrium at a given temperature", "Vapor -pressure lowering equation", "Vaporization the change of a solid or a liquid to the vapor", "Vapor-pressure lowering a colligative property equal to the vapor pressure of the pure solvent minus the vapor pressure of the solution", "Viscosity the resistance to flow that is exhibited by all liquids and gases", "Volatile refers to a liquid or solid having a relatively high vapor pressure at normal temperatures", "Volt (V) the SI unit of potential difference", "Voltaic cell (galvanic cell) an electrochemical cell in which a spontaneous reaction generates an electric current", "Volumetric analysis a method of analysis based on titration", "Wavelength (λ) the distance between any two adjacent identical points of a wave", "Weak acid an acid that is only partly ionized in water; it is a weak electrolyte", "Weak base a base that is only partly ionized in water; it is a weak electrolyte", "Weak electrolyte an electrolyte that dissolves in water to give a relatively small percentage of ions", "Work the energy exchange that results when a force F moves an object through a distance d; it equals F x d", "Zero-order integrated rate law", "Zinc?carbon (Leclanché) dry cell a voltaic cell that has a zinc can as the anode; a graphite rod in the center, surrounded by a paste of manganese dioxide, ammonium and zinc chlorides, and carbon black, is the cathode", "Zn2+ Zinc ion", "Zwitterion an amino acid in the doubly ionized form, in which the carboxyl group has lost an H+ to give —COO- and the amino group has gained an H+ to give —NH3+"]

    legal_terms1 = ["Acquittal - A jury verdict that a criminal defendant is not guilty, or the finding of a judge that the evidence is insufficient to support a conviction.", "Active judge - A judge in the full-time service of the court. Compare to senior judge.", "Administrative Office of the United States Courts (AO) - The federal agency responsible for collecting court statistics, administering the federal courts' budget, and performing many other administrative and programmatic functions, under the direction and supervision of the Judicial Conference of the United States.", "Admissible - A term used to describe evidence that may be considered by a jury or judge in civil and criminal cases.", "Adversary proceeding - A lawsuit arising in or related to a bankruptcy case that begins by filing a complaint with the court, that is, a 'trial' that takes place within the context of a bankruptcy case.", "Affidavit - A written or printed statement made under oath.", "Affirmed - In the practice of the court of appeals, it means that the court of appeals has concluded that the lower court decision is correct and will stand as rendered by the lower court.", "Alternate juror - A juror selected in the same manner as a regular juror who hears all the evidence but does not help decide the case unless called on to replace a regular juror.", "Alternative dispute resolution (ADR) - A procedure for settling a dispute outside the courtroom. Most forms of ADR are not binding, and involve referral of the case to a neutral party such as an arbitrator or mediator.", "Amicus curiae - Latin for 'friend of the court.' It is advice formally offered to the court in a brief filed by an entity interested in, but not a party to, the case.", "Answer - The formal written statement by a defendant in a civil case that responds to a complaint, articulating the grounds for defense.", "Appeal - A request made after a trial by a party that has lost on one or more issues that a higher court review the decision to determine if it was correct. To make such a request is 'to appeal' or 'to take an appeal.' One who appeals is called the 'appellant;'' the other party is the 'appellee.'", "Appellant - The party who appeals a district court's decision, usually seeking reversal of that decision.", "Appellate - About appeals; an appellate court has the power to review the judgment of a lower court (trial court) or tribunal. For example, the U.S. circuit courts of appeals review the decisions of the U.S. district courts.", "Appellee - The party who opposes an appellant's appeal, and who seeks to persuade the appeals court to affirm the district court's decision.", "Arraignment - A proceeding in which a criminal defendant is brought into court, told of the charges in an indictment or information, and asked to plead guilty or not guilty.", "Article III judge A federal judge who is appointed for life, during 'good behavior,'' under Article III of the Constitution. Article III judges are nominated by the President and confirmed by the Senate.", "Assets - Property of all kinds, including real and personal, tangible and intangible.", "Assume - An agreement to continue performing duties under a contract or lease.", "Automatic stay - An injunction that automatically stops lawsuits, foreclosures, garnishments, and most collection activities against the debtor the moment a bankruptcy petition is filed.", "Bail - The release, prior to trial, of a person accused of a crime, under specified conditions designed to assure that person's appearance in court when required. Also, can refer to the amount of bond money posted as a financial condition of pretrial release.", "Bankruptcy - A legal procedure for dealing with debt problems of individuals and businesses; specifically, a case filed under one of the chapters of title 11 of the United States Code (the Bankruptcy Code).", "Bankruptcy administrator - An officer of the Judiciary serving in the judicial districts of Alabama and North Carolina who, like the United States trustee, is responsible for supervising the administration of bankruptcy cases, estates, and trustees; monitoring plans and disclosure statements; monitoring creditors' committees; monitoring fee applications; and performing other statutory duties.", "Bankruptcy code - The informal name for title 11 of the United States Code (11 U.S.C. §§ 101-1330), the federal bankruptcy law.", "Bankruptcy court - The bankruptcy judges in regular active service in each district; a unit of the district court.", "Bankruptcy estate - All interests of the debtor in property at the time of the bankruptcy filing. The estate technically becomes the temporary legal owner of all of the debtor's property.", "Bankruptcy judge - A judicial officer of the United States district court who is the court official with decision-making power over federal bankruptcy cases.", "Bankruptcy petition - A formal request for the protection of the federal bankruptcy laws. (There is an official form for bankruptcy petitions.)", "Bankruptcy trustee - A private individual or corporation appointed in all Chapter 7 and Chapter 13 cases to represent the interests of the bankruptcy estate and the debtor's creditors.", "Bench trial - A trial without a jury, in which the judge serves as the fact-finder.", "Brief - A written statement submitted in a trial or appellate proceeding that explains one side's legal and factual arguments.", "Burden of proof - The duty to prove disputed facts. In civil cases, a plaintiff generally has the burden of proving his or her case. In criminal cases, the government has the burden of proving the defendant's guilt. (See standard of proof.)", "Business bankruptcy - A bankruptcy case in which the debtor is a business or an individual involved in business and the debts are for business purposes.", "Capital offense - A crime punishable by death.", "Case file - A complete collection of every document filed in court in a case.", "Case law - The law as established in previous court decisions. A synonym for legal precedent. Akin to common law, which springs from tradition and judicial decisions.", "Caseload - The number of cases handled by a judge or a court.", "Cause of action - A legal claim.", "Chambers - The offices of a judge and his or her staff.", "Chapter 11 - A reorganization bankruptcy, usually involving a corporation or partnership. A Chapter 11 debtor usually proposes a plan of reorganization to keep its business alive and pay creditors over time. Individuals or people in business can also seek relief in Chapter 11.", "Chapter 12 - The chapter of the Bankruptcy Code providing for adjustment of debts of a 'family farmer' or 'family fisherman,' as the terms are defined in the Bankruptcy Code.", "Chapter 13 - The chapter of the Bankruptcy Code providing for the adjustment of debts of an individual with regular income, often referred to as a 'wage-earner' plan. Chapter 13 allows a debtor to keep property and use his or her disposable income to pay debts over time, usually three to five years.", "Chapter 13 trustee - A person appointed to administer a Chapter 13 case. A Chapter 13 trustee's responsibilities are similar to those of a Chapter 7 trustee; however, a Chapter 13 trustee has the additional responsibilities of overseeing the debtor's plan, receiving payments from debtors, and disbursing plan payments to creditors.", "Chapter 15 - The chapter of the Bankruptcy Code dealing with cases of cross-border insolvency.", "Chapter 7 - The chapter of the Bankruptcy Code providing for 'liquidation,' that is, the sale of a debtor's nonexempt property and the distribution of the proceeds to creditors. In order to be eligible for Chapter 7, the debtor must satisfy a 'means test.' The court will evaluate the debtor's income and expenses to determine if the debtor may proceed under Chapter 7.", "Chapter 7 trustee - A person appointed in a Chapter 7 case to represent the interests of the bankruptcy estate and the creditors. The trustee's responsibilities include reviewing the debtor's petition and schedules, liquidating the property of the estate, and making distributions to creditors. The trustee may also bring actions against creditors or the debtor to recover property of the bankruptcy estate.", "Chapter 9 - The chapter of the Bankruptcy Code providing for reorganization of municipalities (which includes cities and towns, as well as villages, counties, taxing districts, municipal utilities, and school districts).", "Chief judge - The judge who has primary responsibility for the administration of a court; chief judges are determined by seniority", "Claim - A creditor's assertion of a right to payment from a debtor or the debtor's property.", "Class action - A lawsuit in which one or more members of a large group, or class, of individuals or other entities sue on behalf of the entire class. The district court must find that the claims of the class members contain questions of law or fact in common before the lawsuit can proceed as a class action.", "Clerk of court - The court officer who oversees administrative functions, especially managing the flow of cases through the court. The clerk's office is often called a court's central nervous system.", "Collateral - Property that is promised as security for the satisfaction of a debt.", "Common law - The legal system that originated in England and is now in use in the United States, which relies on the articulation of legal principles in a historical succession of judicial decisions. Common law principles can be changed by legislation.", "Community service - A special condition the court imposes that requires an individual to work – without pay – for a civic or nonprofit organization.", "Complaint - A written statement that begins a civil lawsuit, in which the plaintiff details the claims against the defendant.", "Concurrent sentence - Prison terms for two or more offenses to be served at the same time, rather than one after the other. Example: Two five-year sentences and one three-year sentence, if served concurrently, result in a maximum of five years behind bars.", "Confirmation - Approval of a plan of reorganization by a bankruptcy judge.", "Consecutive sentence - Prison terms for two or more offenses to be served one after the other. Example: Two five-year sentences and one three-year sentence, if served consecutively, result in a maximum of 13 years behind bars.", "Consumer bankruptcy - A bankruptcy case filed to reduce or eliminate debts that are primarily consumer debts.", "Consumer debts - Debts incurred for personal, as opposed to business, needs.", "Contingent claim - A claim that may be owed by the debtor under certain circumstances, e.g., where the debtor is a cosigner on another person's loan and that person fails to pay.", "Contract - An agreement between two or more people that creates an obligation to do or not to do a particular thing.", "Conviction - A judgment of guilt against a criminal defendant.", "Counsel - Legal advice; a term also used to refer to the lawyers in a case.", "Count - An allegation in an indictment or information, charging a defendant with a crime. An indictment or information may contain allegations that the defendant committed more than one crime. Each allegation is referred to as a count.", "Court - Government entity authorized to resolve legal disputes. Judges sometimes use 'court' to refer to themselves in the third person, as in 'the court has read the briefs.'", "Court reporter - A person who makes a word-for-word record of what is said in court, generally by using a stenographic machine, shorthand or audio recording, and then produces a transcript of the proceedings upon request.", "Credit counseling - Generally refers to two events in individual bankruptcy cases: (1) the 'individual or group briefing' from a nonprofit budget and credit counseling agency that individual debtors must attend prior to filing under any chapter of the Bankruptcy Code; and (2) the 'instructional course in personal financial management' in chapters 7 and 13 that an individual debtor must complete before a discharge is entered. There are exceptions to both requirements for certain categories of debtors, exigent circumstances, or if the U.S. trustee or bankruptcy administrator have determined that there are insufficient approved credit counseling agencies available to provide the necessary counseling.", "Creditor - A person to whom or business to which the debtor owes money or that claims to be owed money by the debtor.", "Damages - Money that a defendant pays a plaintiff in a civil case if the plaintiff has won. Damages may be compensatory (for loss or injury) or punitive (to punish and deter future misconduct).", "De facto - Latin, meaning 'in fact' or 'actually.' Something that exists in fact but not as a matter of law.", "De jure - Latin, meaning 'in law.' Something that exists by operation of law.", "De novo - Latin, meaning 'anew.' A trial de novo is a completely new trial. Appellate review de novo implies no deference to the trial judge's ruling.", "Debtor - A person who has filed a petition for relief under the Bankruptcy Code.", "Debtor's plan - A debtor's detailed description of how the debtor proposes to pay creditors' claims over a fixed period of time.", "Declaratory judgment - A judge's statement about someone's rights. For example, a plaintiff may seek a declaratory judgment that a particular statute, as written, violates some constitutional right.", "Default judgment - A judgment awarding a plaintiff the relief sought in the complaint because the defendant has failed to appear in court or otherwise respond to the complaint.", "Defendant - An individual (or business) against whom a lawsuit is filed.", "Defendant - In a civil case, the person or organization against whom the plaintiff brings suit; in a criminal case, the person accused of the crime.", "Deposition - An oral statement made before an officer authorized by law to administer oaths. Such statements are often taken to examine potential witnesses, to obtain discovery, or to be used later in trial. See discovery.", "Discharge - A release of a debtor from personal liability for certain dischargeable debts. Notable exceptions to dischargeability are taxes and student loans. A discharge releases a debtor from personal liability for certain debts known as dischargeable debts and prevents the creditors owed those debts from taking any action against the debtor or the debtor's property to collect the debts. The discharge also prohibits creditors from communicating with the debtor regarding the debt, including through telephone calls, letters, and personal contact.", "Dischargeable debt - A debt for which the Bankruptcy Code allows the debtor's personal liability to be eliminated.", "Disclosure statement - A written document prepared by the chapter 11 debtor or other plan proponent that is designed to provide 'adequate information' to creditors to enable them to evaluate the chapter 11 plan of reorganization.", "Discovery - Procedures used to obtain disclosure of evidence before trial.", "Dismissal with prejudice - Court action that prevents an identical lawsuit from being filed later.", "Dismissal without prejudice - Court action that allows the later filing.", "Disposable income - Income not reasonably necessary for the maintenance or support of the debtor or dependents. If the debtor operates a business, disposable income is defined as those amounts over and above what is necessary for the payment of ordinary operating expenses.", "Docket - A log containing the complete history of each case in the form of brief chronological entries summarizing the court proceedings.", "Due process - In criminal law, the constitutional guarantee that a defendant will receive a fair and impartial trial. In civil law, the legal rights of someone who confronts an adverse action threatening liberty or property.", "En banc - French, meaning 'on the bench.' All judges of an appellate court sitting together to hear a case, as opposed to the routine disposition by panels of three judges. In the Ninth Circuit, an en banc panel consists of 11 randomly selected judges.",\
                 "Equitable - Pertaining to civil suits in 'equity' rather than in 'law.' In English legal history, the courts of 'law' could order the payment of damages and could afford no other remedy (see damages). A separate court of 'equity' could order someone to do something or to cease to do something (e.g., injunction). In American jurisprudence, the federal courts have both legal and equitable power, but the distinction is still an important one. For example, a trial by jury is normally available in 'law' cases but not in 'equity' cases.", "Equity - The value of a debtor's interest in property that remains after liens and other creditors' interests are considered. (Example: If a house valued at $60,000 is subject to a $30,000 mortgage, there is $30,000 of equity.)", "Evidence - Information presented in testimony or in documents that is used to persuade the fact finder (judge or jury) to decide the case in favor of one side or the other.", "Ex parte - A proceeding brought before a court by one party only, without notice to or challenge by the other side.", "Exclusionary rule - Doctrine that says evidence obtained in violation of a criminal defendant's constitutional or statutory rights is not admissible at trial.", "Exculpatory evidence - Evidence indicating that a defendant did not commit the crime.", "Executory contracts - Contracts or leases under which both parties to the agreement have duties remaining to be performed. If a contract or lease is executory, a debtor may assume it (keep the contract) or reject it (terminate the contract).", "Exempt assets - Property that a debtor is allowed to retain, free from the claims of creditors who do not have liens on the property.", "Exemptions, exempt property - Certain property owned by an individual debtor that the Bankruptcy Code or applicable state law permits the debtor to keep from unsecured creditors. For example, in some states the debtor may be able to exempt all or a portion of the equity in the debtor's primary residence (homestead exemption), or some or all 'tools of the trade' used by the debtor to make a living (i.e., auto tools for an auto mechanic or dental tools for a dentist). The availability and amount of property the debtor may exempt depends on the state the debtor lives in.", "Face sheet filing - A bankruptcy case filed either without schedules or with incomplete schedules listing few creditors and debts. (Face sheet filings are often made for the purpose of delaying an eviction or foreclosure)", "Family farmer - An individual, individual and spouse, corporation, or partnership engaged in a farming operation that meets certain debt limits and other statutory criteria for filing a petition under Chapter 12.", "Federal public defender - An attorney employed by the federal courts on a full-time basis to provide legal defense to defendants who are unable to afford counsel. The judiciary administers the federal defender program pursuant to the Criminal Justice Act.", "Federal public defender organization - As provided for in the Criminal Justice Act, an organization established within a federal judicial circuit to represent criminal defendants who cannot afford an adequate defense. Each organization is supervised by a federal public defender appointed by the court of appeals for the circuit.", "Federal question jurisdiction - Jurisdiction given to federal courts in cases involving the interpretation and application of the U.S. Constitution, acts of Congress, and treaties.", "Felony - A serious crime, usually punishable by at least one year in prison.", "File - To place a paper in the official custody of the clerk of court to enter into the files or records of a case.", "Fraudulent transfer - A transfer of a debtor's property made with intent to defraud or for which the debtor receives less than the transferred property's value.", "Fresh start - The characterization of a debtor's status after bankruptcy, i.e., free of most debts. (Giving debtors a fresh start is one purpose of the Bankruptcy Code.)", "Grand jury - A body of 16-23 citizens who listen to evidence of criminal allegations, which is presented by the prosecutors, and determine whether there is probable cause to believe an individual committed an offense. See also indictment and U.S. attorney.", "Habeas corpus - Latin, meaning 'you have the body.' A writ of habeas corpus generally is a judicial order forcing law enforcement authorities to produce a prisoner they are holding, and to justify the prisoner's continued confinement. Federal judges receive petitions for a writ of habeas corpus from state prison inmates who say their state prosecutions violated federally protected rights in some way.", "Hearsay - Evidence presented by a witness who did not see or hear the incident in question but heard about it from someone else. With some exceptions, hearsay generally is not admissible as evidence at trial", "Home confinement - A special condition the court imposes that requires an individual to remain at home except for certain approved activities such as work and medical appointments. Home confinement may include the use of electronic monitoring equipment – a transmitter attached to the wrist or the ankle – to help ensure that the person stays at home as required.", "Impeachment - 1. The process of calling a witness's testimony into doubt. For example, if the attorney can show that the witness may have fabricated portions of his testimony, the witness is said to be 'impeached;' 2. The constitutional process whereby the House of Representatives may 'impeach' (accuse of misconduct) high officers of the federal government, who are then tried by the Senate.", "In camera - Latin, meaning in a judge's chambers. Often means outside the presence of a jury and the public. In private.", "In forma pauperis - 'In the manner of a pauper.' Permission given by the court to a person to file a case without payment of the required court fees because the person cannot pay them.", "Inculpatory evidence - Evidence indicating that a defendant did commit the crime.", "Indictment - The formal charge issued by a grand jury stating that there is enough evidence that the defendant committed the crime to justify having a trial; it is used primarily for felonies. See also information.", "Information - A formal accusation by a government attorney that the defendant committed a misdemeanor. See also indictment.", "Injunction - A court order preventing one or more named parties from taking some action. A preliminary injunction often is issued to allow fact-finding, so a judge can determine whether a permanent injunction is justified.", "Insider (of corporate debtor) - A director, officer, or person in control of the debtor; a partnership in which the debtor is a general partner; a general partner of the debtor; or a relative of a general partner, director, officer, or person in control of the debtor.", "Insider (of individual debtor) - Any relative of the debtor or of a general partner of the debtor; partnership in which the debtor is a general partner; general partner of the debtor; or corporation of which the debtor is a director, officer, or person in control.", "Interrogatories - A form of discovery consisting of written questions to be answered in writing and under oath.", "Issue - 1. The disputed point between parties in a lawsuit; 2. To send out officially, as in a court issuing an order.", "Joint administration - A court-approved mechanism under which two or more cases can be administered together. (Assuming no conflicts of interest, these separate businesses or individuals can pool their resources, hire the same professionals, etc.)", "Joint petition - One bankruptcy petition filed by a husband and wife together.", "Judge - An official of the Judicial branch with authority to decide lawsuits brought before courts. Used generically, the term judge may also refer to all judicial officers, including Supreme Court justices.", "Judgeship - The position of judge. By statute, Congress authorizes the number of judgeships for each district and appellate court.", "Judgment - The official decision of a court finally resolving the dispute between the parties to the lawsuit.", "Judicial Conference of the United States - The policy-making entity for the federal court system. A 27-judge body whose presiding officer is the Chief Justice of the United States.", "Jurisdiction - The legal authority of a court to hear and decide a certain type of case. It also is used as a synonym for venue, meaning the geographic area over which the court has territorial jurisdiction to decide cases.", "Jurisprudence - The study of law and the structure of the legal system", "Jury - The group of persons selected to hear the evidence in a trial and render a verdict on matters of fact. See also grand jury.", "Jury instructions - A judge's directions to the jury before it begins deliberations regarding the factual questions it must answer and the legal rules that it must apply.", "Lawsuit - A legal action started by a plaintiff against a defendant based on a complaint that the defendant failed to perform a legal duty which resulted in harm to the plaintiff.", "Lien - A charge on specific property that is designed to secure payment of a debt or performance of an obligation. A debtor may still be responsible for a lien after a discharge.", "Liquidated claim - A creditor's claim for a fixed amount of money.", "Liquidation - The sale of a debtor's property with the proceeds to be used for the benefit of creditors.", "Litigation - A case, controversy, or lawsuit. Participants (plaintiffs and defendants) in lawsuits are called litigants.", "Magistrate judge - A judicial officer of a district court who conducts initial proceedings in criminal cases, decides criminal misdemeanor cases, conducts many pretrial civil and criminal matters on behalf of district judges, and decides civil cases with the consent of the parties.", "Means test - Section 707(b)(2) of the Bankruptcy Code applies a 'means test' to determine whether an individual debtor's chapter 7 filing is presumed to be an abuse of the Bankruptcy Code requiring dismissal or conversion of the case (generally to chapter 13). Abuse is presumed if the debtor's aggregate current monthly income (see definition above) over 5 years, net of certain statutorily allowed expenses is more than (i) $10,000, or (ii) 25% of the debtor's nonpriority unsecured debt, as long as that amount is at least $6,000. The debtor may rebut a presumption of abuse only by a showing of special circumstances that justify additional expenses or adjustments of current monthly income.", "Mental health treatment - Special condition the court imposes to require an individual to undergo evaluation and treatment for a mental disorder. Treatment may include psychiatric, psychological, and sex offense-specific evaluations, inpatient or outpatient counseling, and medication.", "Misdemeanor - An offense punishable by one year of imprisonment or less. See also felony.", "Mistrial - An invalid trial, caused by fundamental error. When a mistrial is declared, the trial must start again with the selection of a new jury.", "Moot - Not subject to a court ruling because the controversy has not actually arisen, or has ended", "Motion - A request by a litigant to a judge for a decision on an issue relating to the case.", "Motion in Limine - A pretrial motion requesting the court to prohibit the other side from presenting, or even referring to, evidence on matters said to be so highly prejudicial that no steps taken by the judge can prevent the jury from being unduly influenced.", "Motion to lift the automatic stay - A request by a creditor to allow the creditor to take action against the debtor or the debtor's property that would otherwise be prohibited by the automatic stay.", "No-asset case - A Chapter 7 case in which there are no assets available to satisfy any portion of the creditors' unsecured claims.", "Nolo contendere - No contest. A plea of nolo contendere has the same effect as a plea of guilty, as far as the criminal sentence is concerned, but may not be considered as an admission of guilt for any other purpose.", "Nondischargeable debt - A debt that cannot be eliminated in bankruptcy. Examples include a home mortgage, debts for alimony or child support, certain taxes, debts for most government funded or guaranteed educational loans or benefit overpayments, debts arising from death or personal injury caused by driving while intoxicated or under the influence of drugs, and debts for restitution or a criminal fine included in a sentence on the debtor's conviction of a crime. Some debts, such as debts for money or property obtained by false pretenses and debts for fraud or defalcation while acting in a fiduciary capacity may be declared nondischargeable only if a creditor timely files and prevails in a nondischargeability action.", "Nonexempt assets - Property of a debtor that can be liquidated to satisfy claims of creditors.", "Objection to dischargeability - A trustee's or creditor's objection to the debtor being released from personal liability for certain dischargeable debts. Common reasons include allegations that the debt to be discharged was incurred by false pretenses or that debt arose because of the debtor's fraud while acting as a fiduciary.", "Objection to exemptions - A trustee's or creditor's objection to the debtor's attempt to claim certain property as exempt from liquidation by the trustee to creditors.", "Opinion - A judge's written explanation of the decision of the court. Because a case may be heard by three or more judges in the court of appeals, the opinion in appellate decisions can take several forms. If all the judges completely agree on the result, one judge will write the opinion for all. If all the judges do not agree, the formal decision will be based upon the view of the majority, and one member of the majority will write the opinion. The judges who did not agree with the majority may write separately in dissenting or concurring opinions to present their views. A dissenting opinion disagrees with the majority opinion because of the reasoning and/or the principles of law the majority used to decide the case. A concurring opinion agrees with the decision of the majority opinion, but offers further comment or clarification or even an entirely different reason for reaching the same result. Only the majority opinion can serve as binding precedent in future cases. See also precedent.", "Oral argument - An opportunity for lawyers to summarize their position before the court and also to answer the judges' questions.", "Panel - 1. In appellate cases, a group of judges (usually three) assigned to decide the case; 2. In the jury selection process, the group of potential jurors; 3. The list of attorneys who are both available and qualified to serve as court-appointed counsel for criminal defendants who cannot afford their own counsel.", "Parole - The release of a prison inmate – granted by the U.S. Parole Commission – after the inmate has completed part of his or her sentence in a federal prison. When the parolee is released to the community, he or she is placed under the supervision of a U.S. probation officer. The Sentencing Reform Act of 1984 abolished parole in favor of a determinate sentencing system in which the sentence is set by sentencing guidelines. Now, without the option of parole, the term of imprisonment the court imposes is the actual time the person spends in prison.", "Party in interest - A party who has standing to be heard by the court in a matter to be decided in the bankruptcy case. The debtor, U.S. trustee or bankruptcy administrator, case trustee, and creditors are parties in interest for most matters.", "Per curiam - Latin, meaning 'for the court.' In appellate courts, often refers to an unsigned opinion.", "Peremptory challenge - A district court may grant each side in a civil or criminal trial the right to exclude a certain number of prospective jurors without cause or giving a reason.", "Petit jury (or trial jury) - A group of citizens who hear the evidence presented by both sides at trial and determine the facts in dispute. Federal criminal juries consist of 12 persons. Federal civil juries consist of at least six persons.",\
                  "Petition - The document that initiates the filing of a bankruptcy proceeding, setting forth basic information regarding the debtor, including name, address, chapter under which the case is filed, and estimated amount of assets and liabilities.", "Petition preparer - A business not authorized to practice law that prepares bankruptcy petitions.", "Petty offense - A federal misdemeanor punishable by six months or less in prison.", "Plaintiff - A person or business that files a formal complaint with the court.", "Plan - A debtor's detailed description of how the debtor proposes to pay creditors' claims over a fixed period of time.", "Plea - In a criminal case, the defendant's statement pleading 'guilty' or 'not guilty' in answer to the charges. See also nolo contendere.", "Pleadings - Written statements filed with the court that describe a party's legal or factual assertions about the case.", "Postpetition transfer - A transfer of the debtor's property made after the commencement of the case.", "Prebankruptcy planning - The arrangement (or rearrangement) of a debtor's property to allow the debtor to take maximum advantage of exemptions. (Prebankruptcy planning typically includes converting nonexempt assets into exempt assets.)", "Precedent - A court decision in an earlier case with facts and legal issues similar to a dispute currently before a court. Judges will generally 'follow precedent' - meaning that they use the principles established in earlier cases to decide new cases that have similar facts and raise similar legal issues. A judge will disregard precedent if a party can show that the earlier case was wrongly decided, or that it differed in some significant way from the current case.", "Preferential debt payment - A debt payment made to a creditor in the 90-day period before a debtor files bankruptcy (or within one year if the creditor was an insider) that gives the creditor more than the creditor would receive in the debtor's chapter 7 case.", "Presentence report - A report prepared by a court's probation officer, after a person has been convicted of an offense, summarizing for the court the background information needed to determine the appropriate sentence.", "Pretrial conference - A meeting of the judge and lawyers to plan the trial, to discuss which matters should be presented to the jury, to review proposed evidence and witnesses, and to set a trial schedule. Typically, the judge and the parties also discuss the possibility of settlement of the case.", "Pretrial services - A function of the federal courts that takes place at the very start of the criminal justice process – after a person has been arrested and charged with a federal crime and before he or she goes to trial. Pretrial services officers focus on investigating the backgrounds of these persons to help the court determine whether to release or detain them while they await trial. The decision is based on whether these individuals are likely to flee or pose a threat to the community. If the court orders release, a pretrial services officer supervises the person in the community until he or she returns to court.", "Priority - The Bankruptcy Code's statutory ranking of unsecured claims that determines the order in which unsecured claims will be paid if there is not enough money to pay all unsecured claims in full.", "Priority claim - An unsecured claim that is entitled to be paid ahead of other unsecured claims that are not entitled to priority status. Priority refers to the order in which these unsecured claims are to be paid.", "Pro per - A slang expression sometimes used to refer to a pro se litigant. It is a corruption of the Latin phrase 'in propria persona.'", "Pro se - Representing oneself. Serving as one's own lawyer.", "Pro tem - Temporary.", "Probation - Sentencing option in the federal courts. With probation, instead of sending an individual to prison, the court releases the person to the community and orders him or her to complete a period of supervision monitored by a U.S. probation officer and to abide by certain conditions.", "Probation officer - Officers of the probation office of a court. Probation officer duties include conducting presentence investigations, preparing presentence reports on convicted defendants, and supervising released defendants.", "Procedure - The rules for conducting a lawsuit; there are rules of civil procedure, criminal procedure, evidence, bankruptcy, and appellate procedure.", "Proof of claim - A written statement describing the reason a debtor owes a creditor money, which typically sets forth the amount of money owed. (There is an official form for this purpose.)", "Property of the estate - All legal or equitable interests of the debtor in property as of the commencement of the case.", "Prosecute - To charge someone with a crime. A prosecutor tries a criminal case on behalf of the government", "Reaffirmation agreement - An agreement by a debtor to continue paying a dischargeable debt after the bankruptcy, usually for the purpose of keeping collateral or mortgaged property that would otherwise be subject to repossession.", "Record - A written account of the proceedings in a case, including all pleadings, evidence, and exhibits submitted in the course of the case.", "Redemption - A procedure in a Chapter 7 case whereby a debtor removes a secured creditor's lien on collateral by paying the creditor the value of the property. The debtor may then retain the property.", "Remand - Send back.", "Reverse - The act of a court setting aside the decision of a lower court. A reversal is often accompanied by a remand to the lower court for further proceedings.", "Sanction - A penalty or other type of enforcement used to bring about compliance with the law or with rules and regulations.", "Schedules - Lists submitted by the debtor along with the petition (or shortly thereafter) showing the debtor's assets, liabilities, and other financial information. (There are official forms a debtor must use.)", "Secured creditor - A secured creditor is an individual or business that holds a claim against the debtor that is secured by a lien on property of the estate. The property subject to the lien is the secured creditor's collateral.", "Secured debt - Debt backed by a mortgage, pledge of collateral, or other lien; debt for which the creditor has the right to pursue specific pledged property upon default. Examples include home mortgages, auto loans and tax liens.", "Senior judge - A federal judge who, after attaining the requisite age and length of judicial experience, takes senior status, thus creating a vacancy among a court's active judges. A senior judge retains the judicial office and may cut back his or her workload by as much as 75 percent, but many opt to keep a larger caseload.", "Sentence - The punishment ordered by a court for a defendant convicted of a crime.", "Sentencing guidelines - A set of rules and principles established by the United States Sentencing Commission that trial judges use to determine the sentence for a convicted defendant.", "Sequester - To separate. Sometimes juries are sequestered from outside influences during their deliberations.", "Service of process - The delivery of writs or summonses to the appropriate party.", "Settlement - Parties to a lawsuit resolve their dispute without having a trial. Settlements often involve the payment of compensation by one party in at least partial satisfaction of the other party's claims, but usually do not include the admission of fault.", "Small business case - A special type of chapter 11 case in which there is no creditors' committee (or the creditors' committee is deemed inactive by the court) and in which the debtor is subject to more oversight by the U.S. trustee than other chapter 11 debtors. The Bankruptcy Code contains certain provisions designed to reduce the time a small business debtor is in bankruptcy.", "Standard of proof - Degree of proof required. In criminal cases, prosecutors must prove a defendant's guilt 'beyond a reasonable doubt.' The majority of civil lawsuits require proof 'by a preponderance of the evidence' (50 percent plus), but in some the standard is higher and requires 'clear and convincing' proof", "Statement of financial affairs - A series of questions the debtor must answer in writing concerning sources of income, transfers of property, lawsuits by creditors, etc. (There is an official form a debtor must use.)", "Statement of intention - A declaration made by a chapter 7 debtor concerning plans for dealing with consumer debts that are secured by property of the estate.", "Statute - A law passed by a legislature.", "Statute of limitations - The time within which a lawsuit must be filed or a criminal prosecution begun. The deadline can vary, depending on the type of civil case or the crime charged.", "Sua sponte - Latin, meaning 'of its own will.' Often refers to a court taking an action in a case without being asked to do so by either side.", "Subordination - The act or process by which a person's rights or claims are ranked below those of others.", "Subpoena - A command, issued under a court's authority, to a witness to appear and give testimony.", "Subpoena duces tecum - A command to a witness to appear and produce documents.", "Temporary restraining order - Akin to a preliminary injunction, it is a judge's short-term order forbidding certain actions until a full hearing can be conducted. Often referred to as a TRO.", "Testimony - Evidence presented orally by witnesses during trials or before grand juries.", "Toll - See statute of limitations.", "Tort - A civil, not criminal, wrong. A negligent or intentional injury against a person or property, with the exception of breach of contract.", "Transcript - A written, word-for-word record of what was said, either in a proceeding such as a trial, or during some other formal conversation, such as a hearing or oral deposition", "Transfer - Any mode or means by which a debtor disposes of or parts with his/her property.", "Trustee - The representative of the bankruptcy estate who exercises statutory powers, principally for the benefit of the unsecured creditors, under the general supervision of the court and the direct supervision of the U.S. trustee or bankruptcy administrator. The trustee is a private individual or corporation appointed in all chapter 7, chapter 12, and chapter 13 cases and some chapter 11 cases. The trustee's responsibilities include reviewing the debtor's petition and schedules and bringing actions against creditors or the debtor to recover property of the bankruptcy estate. In chapter 7, the trustee liquidates property of the estate, and makes distributions to creditors. Trustees in chapter 12 and 13 have similar duties to a chapter 7 trustee and the additional responsibilities of overseeing the debtor's plan, receiving payments from debtors, and disbursing plan payments to creditors.", "Typing service - A business not authorized to practice law that prepares bankruptcy petitions.", "U.S. attorney - A lawyer appointed by the President in each judicial district to prosecute and defend cases for the federal government. The U.S. Attorney employs a staff of Assistant U.S. Attorneys who appear as the government's attorneys in individual cases.", "U.S. trustee - An officer of the U.S. Department of Justice responsible for supervising the administration of bankruptcy cases, estates, and trustees; monitoring plans and disclosure statements; monitoring creditors' committees; monitoring fee applications; and performing other statutory duties.", "Undersecured claim - A debt secured by property that is worth less than the amount of the debt.", "Undue hardship - The most widely used test for evaluating undue hardship in the dischargeability of a student loan includes three conditions: (1) the debtor cannot maintain – based on current income and expenses – a minimal standard of living if forced to repay the loans; (2) there are indications that the state of affairs is likely to persist for a significant portion of the repayment period; and (3) the debtor made good faith efforts to repay the loans.", "Unlawful detainer action - A lawsuit brought by a landlord against a tenant to evict the tenant from rental property – usually for nonpayment of rent.", "Unliquidated claim - A claim for which a specific value has not been determined.", "Unscheduled debt - A debt that should have been listed by the debtor in the schedules filed with the court but was not. (Depending on the circumstances, an unscheduled debt may or may not be discharged.)", "Unsecured claim - A claim or debt for which a creditor holds no special assurance of payment, such as a mortgage or lien; a debt for which credit was extended based solely upon the creditor's assessment of the debtor's future ability to pay.", "Uphold - The appellate court agrees with the lower court decision and allows it to stand. See affirmed.", "Venue - The geographic area in which a court has jurisdiction. A change of venue is a change or transfer of a case from one judicial district to another.", "Verdict - The decision of a trial jury or a judge that determines the guilt or innocence of a criminal defendant, or that determines the final outcome of a civil case.", "Voir dire - Jury selection process of questioning prospective jurors, to ascertain their qualifications and determine any basis for challenge.", "Voluntary transfer - A transfer of a debtor's property with the debtor's consent.", "Wage garnishment - A nonbankruptcy legal proceeding whereby a plaintiff or creditor seeks to subject to his or her claim the future wages of a debtor. In other words, the creditor seeks to have part of the debtor's future wages paid to the creditor for a debt owed to the creditor.", "Warrant - Court authorization, most often for law enforcement officers, to conduct a search or make an arrest.", "Witness - A person called upon by either side in a lawsuit to give testimony before the court or jury.", "Writ - A written court order directing a person to take, or refrain from taking, a certain act.", "Writ of certiorari - An order issued by the U.S. Supreme Court directing the lower court to transmit records for a case which it will hear on appeal."]
        
    degrees1 = ["Acting", "Actuarial Foundations", "Actuarial Science", "Administrative Sciences", "Administrative Sciences", "Advanced Information Technology", "Advertising", "African American & Black Diaspora Studies", "African American Studies", "African Languages & Literatures", "African Studies", "American & New England Studies", "American Law", "American Studies", "Anatomy & Neurobiology", "Ancient Greek", "Ancient Greek & Latin", "Ancient Greek/Literary Translation", "Anglican & Episcopal Studies", "Anthropology", "Anthropology with a Specialization in Anthropology, Health & Medicine", "Anthropology with a Specialization in Biological Anthropology", "Anthropology with a Specialization in Sociocultural Anthropology", "Anthropology & Religion", "Applied Biomechanics", "Applied Biostatistics", "Applied Business Analytics", "Applied Data Analytics", "Applied Human Development", "Arabic", "Archaeological & Environmental Sciences", "Archaeological & Environmental Sciences/Archaeology", "Archaeology", "Architectural Studies", "Art", "Art Education", "Art Education with Initial License", "Art History", "Art & Architecture, History of", "Artificial Intelligence", "Arts Administration", "Arts Leadership", "Arts Management", "Arts Marketing", "Asian Legal Studies", "Asian Studies", "Astronomy", "Astronomy & Physics", "Astrophysics & Space Physics", "Autism Spectrum Disorders", "Autism & Emotional/Behavioral Disorders", "Banking & Financial Law", "Behavior & Health", "Behavioral Neuroscience", "Bilingual Education/Teaching English to Speakers of Other Languages", "Biochemistry", "Biochemistry & Molecular Biology; Biotechnology", "Bioimaging", "Bioinformatics", "Bioinformatics", "Biology", "Biology with a Specialization in Behavioral Biology", "Biology with a Specialization in Cell Biology, Molecular Biology & Genetics", "Biology with a Specialization in Ecology & Conservation Biology", "Biology with a Specialization in Neurobiology", "Biology Education", "Biomedical Engineering", "Biomedical Forensic Sciences", "Biomedical Research Technologies", "Biomedical Sciences", "Biostatistics", "Business Administration", "Business Administration & Law", "Business Administration & Management", "Business Administration & Medicine", "Business Administration & Public Health", "Business Analytics", "Chemistry", "Chemistry & Physics", "Chemistry: Biochemistry", "Chemistry: Chemical Biology", "Teaching of Chemistry", "Child Life & Family-Centered Care", "Chinese", "Chinese Language & Literature", "Chinese/Literary Translation", "Chronic & Non-Communicable Diseases", "Cinema & Media Production", "Cinema & Media Studies", "City Planning", "Civic Science Communication", "Classical Civilization", "Classical Studies", "Classical Studies/Philosophy", "Classics & Archaeology", "Classics & Philosophy", "Classics & Religion", "Climate Change and Health", "Clinical Research", "Cognitive & Neural Systems", "Commercial Theater Development", "Community Assessment, Program Design, Implementation & Evaluation", "Comparative Literature", "Comparative Literature/Literary Translation", "Composition", "Composition & Music Theory", "Computer Engineering", "Computer Information Systems", "Computer Networks", "Computer Science & Economics", "Computer Science", "Computing & Data Sciences", "Conducting", "Core Curriculum", "Core Independent Studies", "Corporate Finance", "Costume Design & Production", "Counseling", "Counseling Psychology & Applied Human Development", "Creative Writing", "Criminal Justice", "Curriculum & Teaching", "Cybercrime Investigation & Cybersecurity", "Dance", "Data Analytics", "Data Science", "Database Management & Business Intelligence", "Deaf Education", "Deaf Studies", "Dental Biomaterials", "Dental Medicine", "Dental Public Health", "Dermatology", "Developmental Studies", "Directing", "Early Childhood Education", "Earth & Environment", "Earth & Environmental Sciences", "Economic Policy", "Economics", "Economics, Global Development", "Economics & Mathematics", "Economics & Mathematics/Economics", "Editorial Studies", "Education", "Education for Equity & Social Justice", "Education & Human Development", "Education & Human Development/Applied Human Development", "Education & Human Development/Educational Policy Studies", "Education & Human Development/TESOL & Applied Linguistics", "Education & Human Development/TESOL Multilingual Learner Education", "Educational Leadership & Policy Studies", "Educational Studies", "Electrical Engineering", "Electrical & Computer Engineering", "Elementary Education", "Emerging Media Studies", "Emotional & Behavioral Challenges in Schools", "Endodontics", "Energy & Environment", "Engineering Science", "English", "English & American Literature", "English & Law", "English Education", "Enterprise Risk Management", "Enterprise Risk Management & Compliance", "Environmental Analysis & Policy", "Environmental Health", "Environmental Remote Sensing & GIS", "Epidemiology", "Epidemiology & Biostatistics", "Estate Planning", "Esthetic, Digital, and Operative Dentistry", "European Law", "European Studies", "Evangelism", "Event Management", "Event Management & Public Relations", "Faith & Ecological Justice", "Film", "Film & Television", "Film & Television Studies", "Finance", "Financial Management", "Financial Planning", "Financial Services Compliance", "Financial Technology", "Forensic Anthropology", "Foundations of Health Communication", "French & Linguistics", "French Language & Literature", "French Studies", "French Studies/French Language & Literature", "French Studies/Literary Translation", "Gastronomy", "Genealogical Research", "General Science Education", "Genetic Counseling", "Genetic Counseling/Master of Public Health", "Genetics & Genomics", "Geoarchaeology", "Geriatric Dental Medicine", "German", "German Language & Literature", "German/Literary Translation", "Global Education Leadership Program", "Global Health", "Global Health Program Design, Monitoring & Evaluation", "Global Marketing Management", "Global Medieval Studies", "Global Policy", "Graphic Design", "Greek—Ancient", "Greek—Modern", "Health Care Emergency Management", "Healthcare Management", "Healthcare Promotion, Media & Marketing", "Health Communication", "Health Communication & Promotion", "Health Equity", "Health Informatics", "Health Policy & Law", "Health Professions Education", "Health Science", "Health Services & Policy Research", "Hebrew", "Higher Education Leadership", "Hindi-Urdu", "Hispanic Language & Literatures", "Historical Performance", "History", "History of Art & Architecture", "History & Law", "Holocaust, Genocide & Human Rights Studies", "Hospitality", "Hospitality Administration", "Hospitality Administration & Gastronomy", "Hospitality & Communication", "Hospitality Management", "Hospitality Management (Advanced)", "Human Development & Education", "Human Physiology", "Human Resources Management", "Human Rights & Social Justice", "Immunology Training", "Independent Major", "Infectious Disease", "Information Security", "Information Technology", "Information Technology Project Management", "Innovation & Entrepreneurship", "Insurance Management", "Intellectual Property & Information Law", "Interdisciplinary Studies", "International Business Law", "International & European Business Law", "International Affairs", "International Business Management", "International Commercial & Investment Arbitration", "International Finance", "International Relations", "International Relations/International Affairs", "International Relations & Business Administration", "International Relations & Law", "Investment Analysis", "Italian", "Italian & Linguistics", "Italian Studies", "Japanese & Linguistics", "Japanese Language & Literature", "Japanese/Literary Translation", "Jewish Studies", "Journalism", "Korean Language & Literature", "Korean", "Language & Literacy Education", "Latin", "Latin American Studies", "Latin/Literary Translation", "Law", "Law—American", "Law—Asian Legal Studies", "Law—Banking & Financial", "Law—European", "Law—Intellectual Property & Information", "Law—International Business", "Law—Taxation", "Law & Business Administration", "Law & English", "Law & History", "Law & International Relations", "Law & Philosophy", "Law & Preservation Studies", "Law & Public Health", "Leadership, Policy & Advocacy for Early Childhood Well-Being", "Lighting Design", "Linguistics", "Linguistics & African Languages", "Linguistics & Computer Science", "Linguistics & Philosophy", "Linguistics and Speech, Language & Hearing Sciences", "Linguistics and Speech, Language & Hearing Sciences", "Literacy Instruction & Intervention", "Literary Translation", "Management Studies", "Management Studies", "Marine Science", "Materials Science & Engineering", "Maternal & Child Health", "Mathematical Finance", "Mathematical Finance & Financial Technology", "Mathematics (includes Statistics)", "Mathematics", "Mathematics/Biostatistics", "Mathematics & Computer Science", "Mathematics & Mathematics Education", "Mathematics & Philosophy", "Mathematics & Physics", "Mathematics Education", "Mechanical Engineering", "Media Science", "Media Ventures", "Medical Anthropology", "Medical Anthropology & Cross-Cultural Practice", "Medical Sciences", "Medical Sciences and Mental Health Counseling & Behavioral Medicine", "Medical Sciences & Public Health", "Medicine", "Medicine & Law", "Medicine/Business Administration", "Medicine & Public Health", "Early Medical School Selection Program", "Mental Health & Substance Use", "Mental Health Counseling & Behavioral Medicine", "Microbiology", "Middle East & North Africa Studies", "Middle Eastern and South Asian Languages & Literatures", "Modern Foreign Language Education", "Modern Greek", "Modular Medical/Dental Integrated Curriculum", "Molecular Biology, Cell Biology & Biochemistry", "Molecular Medicine", "Museum Education", "Museum Studies", "Music", "Musicology", "Music Education", "Music Ministry", "Music Performance", "Music Theory", "Muslim Cultures", "Muslim Societies", "Muslim Studies", "Myth Studies", "Neuroscience", "Neuroscience & Computational Neuroscience", "Nutrition", "Nutrition/Dietetics", "Nutrition & Metabolism", "Occupational Therapy", "Opera", "Oral Biology", "Oral Health Sciences", "Oral & Maxillofacial Surgery", "Orofacial & Skeletal Biology", "Orthodontics & Dentofacial Orthopedics", "Painting", "Paralegal Studies", "Path 2 Path Program", "Pathology & Laboratory Medicine", "Pediatric Dentistry", "Performance, Music", "Periodontology", "Persian Cultural Studies", "Pharmaceutical Development, Delivery & Access", "Pharmacology & Experimental Therapeutics", "Philosophy", "Philosophy & Neuroscience", "Philosophy & Physics", "Philosophy & Political Science", "Philosophy & Psychology", "Philosophy & Religion", "Physical Therapy", "Physician Assistant Program", "Physics", "Physics & Computer Science", "Physics Education", "Physiology or Biophysics", "Playwriting", "Political Science", "Population Health Research", "Portuguese & Brazilian Cultural Studies", "Premedical Studies", "Preservation Studies", "Printmaking", "Print Media & Photography", "Product Design & Manufacture", "Production Management", "Professional Fundraising", "Program Management", "Project Management", "Project, Program & Portfolio Management", "Prosthodontics", "Psychology", "Public Anthropology", "Public Health", "Public Health & Genetic Counseling", "Public Health & Law", "Public Health & Management", "Public Health & Medical Sciences", "Public Health & Medicine", "Public Health & Social Work", "Public Policy Analysis", "Public Relations", "Reading Education", "Real Estate", "Rehabilitation Sciences", "Religion", "Religion & Public Leadership", "Religion in Science & Medicine", "Religious Education", "Religious Studies", "Remote Sensing & Geospatial Sciences", "Robotics & Autonomous Systems", "Russian", "Russian Language & Literature", "Scene Design", "Scene Painting", "Science Education", "Screenwriting", "Sculpture", "Sex, Sexuality & Gender", "Social Studies Education", "Social Work, Clinical Practice", "Social Work, Macro Practice", "Social Work", "Sociology", "Sociology & Social Work", "Social Work & Education", "Social Work & Public Health", "Social Work & Theology", "Software Development", "Sound Design", "Spanish", "Spanish & Linguistics", "Spanish/Literary Translation", "Special Education", "Speech, Language & Hearing Sciences", "Speech-Language Pathology", " Spirituality Studies", "Stage Management", "Statistical Practice", "Statistics", "Statistics & Computer Science", "Strategic Management in Criminal Justice", "Supply Chain Management", "Sustainable Energy", "Systems Engineering", "Tax Law", "Teaching English to Speakers of Other Languages", "Teaching Language, Literature & Film", "Teaching Science Education", "Teaching Students with Moderate Disabilities", "Teaching Students with Severe Disabilities", "Teaching Writing", "Technical Production", "Telecommunication", "Television", "Theatre Arts", "Theatre Education", "Theatre–Stage Management", "Theatre–Technical Production", "Theology", "Theology & Latinx Studies", "Theology & Social Work", "Theology—Divinity & Sacred Music", "Theology—Sacred Music", "Theology—Sacred Theology", "Theology—Theological Studies", "Theology—Transformational Leadership", "Transactional Skills", "Turkish Cultural Studies", "Urban Affairs", "Urban Policy & Planning", "Urban Studies", "Visual Arts", "Visual & Digital Health Communication", "Visual Narrative", "Web Application Development", "Women’s, Gender & Sexuality Studies", "World Language Education"]
        
    verses1 = ["1 Blessed is the man that walketh not in the counsel of the ungodly, nor standeth in the way of sinners, nor sitteth in the seat of the scornful.", "2 But his delight is in the law of the LORD; and in his law doth he meditate day and night.", "3 And he shall be like a tree planted by the rivers of water, that bringeth forth his fruit in his season; his leaf also shall not wither; and whatsoever he doeth shall prosper.", "4 The ungodly are not so: but are like the chaff which the wind driveth away.", "5 Therefore the ungodly shall not stand in the judgment, nor sinners in the congregation of the righteous.", "6 For the LORD knoweth the way of the righteous: but the way of the ungodly shall perish.", "1 Why do the heathen rage, and the people imagine a vain thing?", "2 The kings of the earth set themselves, and the rulers take counsel together, against the LORD, and against his anointed, saying,", "3 Let us break their bands asunder, and cast away their cords from us.", "4 He that sitteth in the heavens shall laugh: the Lord shall have them in derision.", "5 Then shall he speak unto them in his wrath, and vex them in his sore displeasure.", "6 Yet have I set my king upon my holy hill of Zion.", "7 I will declare the decree: the LORD hath said unto me, Thou art my Son; this day have I begotten thee.", "8 Ask of me, and I shall give thee the heathen for thine inheritance, and the uttermost parts of the earth for thy possession.", "9 Thou shalt break them with a rod of iron; thou shalt dash them in pieces like a potter's vessel.", "10 Be wise now therefore, O ye kings: be instructed, ye judges of the earth.", "11 Serve the LORD with fear, and rejoice with trembling.", "12 Kiss the Son, lest he be angry, and ye perish from the way, when his wrath is kindled but a little. Blessed are all they that put their trust in him.", "1 LORD, how are they increased that trouble me! many are they that rise up against me.", "2 Many there be which say of my soul, There is no help for him in God. Selah.", "3 But thou, O LORD, art a shield for me; my glory, and the lifter up of mine head.", "4 I cried unto the LORD with my voice, and he heard me out of his holy hill. Selah.", "5 I laid me down and slept; I awaked; for the LORD sustained me.", "6 I will not be afraid of ten thousands of people, that have set themselves against me round about.", "7 Arise, O LORD; save me, O my God: for thou hast smitten all mine enemies upon the cheek bone; thou hast broken the teeth of the ungodly.", "8 Salvation belongeth unto the LORD: thy blessing is upon thy people. Selah.", "1 Hear me when I call, O God of my righteousness: thou hast enlarged me when I was in distress; have mercy upon me, and hear my prayer.", "2 O ye sons of men, how long will ye turn my glory into shame? how long will ye love vanity, and seek after leasing? Selah.", "3 But know that the LORD hath set apart him that is godly for himself: the LORD will hear when I call unto him.", "4 Stand in awe, and sin not: commune with your own heart upon your bed, and be still. Selah.", "5 Offer the sacrifices of righteousness, and put your trust in the LORD.", "6 There be many that say, Who will shew us any good? LORD, lift thou up the light of thy countenance upon us.", "7 Thou hast put gladness in my heart, more than in the time that their corn and their wine increased.", "8 I will both lay me down in peace, and sleep: for thou, LORD, only makest me dwell in safety.", "1 Give ear to my words, O LORD, consider my meditation.", "2 Hearken unto the voice of my cry, my King, and my God: for unto thee will I pray.", "3 My voice shalt thou hear in the morning, O LORD; in the morning will I direct my prayer unto thee, and will look up.", "4 For thou art not a God that hath pleasure in wickedness: neither shall evil dwell with thee.", "5 The foolish shall not stand in thy sight: thou hatest all workers of iniquity.", "6 Thou shalt destroy them that speak leasing: the LORD will abhor the bloody and deceitful man.", "7 But as for me, I will come into thy house in the multitude of thy mercy: and in thy fear will I worship toward thy holy temple.", "8 Lead me, O LORD, in thy righteousness because of mine enemies; make thy way straight before my face.", "9 For there is no faithfulness in their mouth; their inward part is very wickedness; their throat is an open sepulchre; they flatter with their tongue.", "10 Destroy thou them, O God; let them fall by their own counsels; cast them out in the multitude of their transgressions; for they have rebelled against thee.", "11 But let all those that put their trust in thee rejoice: let them ever shout for joy, because thou defendest them: let them also that love thy name be joyful in thee.", "12 For thou, LORD, wilt bless the righteous; with favour wilt thou compass him as with a shield.", "1 O LORD, rebuke me not in thine anger, neither chasten me in thy hot displeasure.", "2 Have mercy upon me, O LORD; for I am weak: O LORD, heal me; for my bones are vexed.", "3 My soul is also sore vexed: but thou, O LORD, how long?", "4 Return, O LORD, deliver my soul: oh save me for thy mercies' sake.", "5 For in death there is no remembrance of thee: in the grave who shall give thee thanks?", "6 I am weary with my groaning; all the night make I my bed to swim; I water my couch with my tears.", "7 Mine eye is consumed because of grief; it waxeth old because of all mine enemies.", "8 Depart from me, all ye workers of iniquity; for the LORD hath heard the voice of my weeping.", "9 The LORD hath heard my supplication; the LORD will receive my prayer.", "10 Let all mine enemies be ashamed and sore vexed: let them return and be ashamed suddenly.", "1 O LORD my God, in thee do I put my trust: save me from all them that persecute me, and deliver me:", "2 Lest he tear my soul like a lion, rending it in pieces, while there is none to deliver.", "3 O LORD my God, if I have done this; if there be iniquity in my hands;", "4 If I have rewarded evil unto him that was at peace with me; (yea, I have delivered him that without cause is mine enemy:)", "5 Let the enemy persecute my soul, and take it; yea, let him tread down my life upon the earth, and lay mine honour in the dust. Selah.", "6 Arise, O LORD, in thine anger, lift up thyself because of the rage of mine enemies: and awake for me to the judgment that thou hast commanded.", "7 So shall the congregation of the people compass thee about: for their sakes therefore return thou on high.", "8 The LORD shall judge the people: judge me, O LORD, according to my righteousness, and according to mine integrity that is in me.", "9 Oh let the wickedness of the wicked come to an end; but establish the just: for the righteous God trieth the hearts and reins.", "10 My defence is of God, which saveth the upright in heart.", "11 God judgeth the righteous, and God is angry with the wicked every day.", "12 If he turn not, he will whet his sword; he hath bent his bow, and made it ready.", "13 He hath also prepared for him the instruments of death; he ordaineth his arrows against the persecutors.", "14 Behold, he travaileth with iniquity, and hath conceived mischief, and brought forth falsehood.", "15 He made a pit, and digged it, and is fallen into the ditch which he made.", "16 His mischief shall return upon his own head, and his violent dealing shall come down upon his own pate.", "17 I will praise the LORD according to his righteousness: and will sing praise to the name of the LORD most high.", "1 O LORD our Lord, how excellent is thy name in all the earth! who hast set thy glory above the heavens.", "2 Out of the mouth of babes and sucklings hast thou ordained strength because of thine enemies, that thou mightest still the enemy and the avenger.", "3 When I consider thy heavens, the work of thy fingers, the moon and the stars, which thou hast ordained;", "4 What is man, that thou art mindful of him? and the son of man, that thou visitest him?", "5 For thou hast made him a little lower than the angels, and hast crowned him with glory and honour.", "6 Thou madest him to have dominion over the works of thy hands; thou hast put all things under his feet:", "7 All sheep and oxen, yea, and the beasts of the field;", "8 The fowl of the air, and the fish of the sea, and whatsoever passeth through the paths of the seas.", "9 O LORD our Lord, how excellent is thy name in all the earth!", "1 I will praise thee, O LORD, with my whole heart; I will shew forth all thy marvellous works.", "2 I will be glad and rejoice in thee: I will sing praise to thy name, O thou most High.", "3 When mine enemies are turned back, they shall fall and perish at thy presence.", "4 For thou hast maintained my right and my cause; thou satest in the throne judging right.", "5 Thou hast rebuked the heathen, thou hast destroyed the wicked, thou hast put out their name for ever and ever.", "6 O thou enemy, destructions are come to a perpetual end: and thou hast destroyed cities*; their memorial is perished with them.", "7 But the LORD shall endure for ever: he hath prepared his throne for judgment.", "8 And he shall judge the world in righteousness, he shall minister judgment to the people in uprightness.", "9 The LORD also will be a refuge for the oppressed, a refuge in times of trouble.", "10 And they that know thy name will put their trust in thee: for thou, LORD, hast not forsaken them that seek thee.", "11 Sing praises to the LORD, which dwelleth in Zion: declare among the people his doings.", "12 When he maketh inquisition for blood, he remembereth them: he forgetteth not the cry of the humble*.", "13 Have mercy upon me, O LORD; consider my trouble which I suffer of them that hate me, thou that liftest me up from the gates of death:", "14 That I may shew forth all thy praise in the gates of the daughter of Zion: I will rejoice in thy salvation.", "15 The heathen are sunk down in the pit that they made: in the net which they hid is their own foot taken.", "16 The LORD is known by the judgment which he executeth: the wicked is snared in the work of his own hands. Higgaion. Selah.", "17 The wicked shall be turned into hell, and all the nations that forget God.", "18 For the needy shall not alway be forgotten: the expectation of the poor* shall not perish for ever.", "19 Arise, O LORD; let not man prevail: let the heathen be judged in thy sight.", "20 Put them in fear*, O LORD: that the nations may know themselves to be but men. Selah.", "1 Why standest thou afar off, O LORD? why hidest thou thyself in times of trouble?", "2 The wicked in his pride doth persecute the poor: let them be taken in the devices that they have imagined.", "3 For the wicked boasteth of his heart's desire, and blesseth the covetous, whom the LORD abhorreth.", "4 The wicked, through the pride of his countenance, will not seek after God: God is not in all his thoughts.", "5 His ways are always grievous; thy judgments are far above out of his sight: as for all his enemies, he puffeth at them.", "6 He hath said in his heart, I shall not be moved: for I shall never be in adversity.", "7 His mouth is full of cursing and deceit and fraud: under his tongue is mischief and vanity.", "8 He sitteth in the lurking places of the villages: in the secret places doth he murder the innocent: his eyes are privily set against the poor.", "9 He lieth in wait secretly as a lion in his den: he lieth in wait to catch the poor: he doth catch the poor, when he draweth him into his net.", "10 He croucheth, and humbleth himself, that the poor* may fall by his strong ones.", "11 He hath said in his heart, God hath forgotten: he hideth his face; he will never see it.", "12 Arise, O LORD; O God, lift up thine hand: forget not the humble*.", "13 Wherefore doth the wicked contemn God? he hath said in his heart, Thou wilt not require it.", "14 Thou hast seen it; for thou beholdest mischief and spite, to requite it with thy hand: the poor committeth himself unto thee; thou art the helper of the fatherless.", "15 Break thou the arm of the wicked and the evil man: seek out his wickedness till thou find none.", "16 The LORD is King for ever and ever: the heathen are perished out of his land.", "17 LORD, thou hast heard the desire of the humble: thou wilt prepare their heart, thou wilt cause thine ear to hear:", "18 To judge the fatherless and the oppressed, that the man of the earth may no more oppress.", "1 In the LORD put I my trust: how say ye to my soul, Flee as a bird to your mountain?", "2 For, lo, the wicked bend their bow, they make ready their arrow upon the string, that they may privily* shoot at the upright in heart.", "3 If the foundations be destroyed, what can the righteous do?", "4 The LORD is in his holy temple, the LORD'S throne is in heaven: his eyes behold, his eyelids try, the children of men.", "5 The LORD trieth the righteous: but the wicked and him that loveth violence his soul hateth.", "6 Upon the wicked he shall rain snares, fire and brimstone, and an horrible tempest: this shall be the portion of their cup.", "7 For the righteous LORD loveth righteousness; his countenance doth behold the upright.", "1 Help, LORD; for the godly man ceaseth; for the faithful fail from among the children of men.", "2 They speak vanity every one with his neighbour: with flattering lips and with a double heart do they speak.", "3 The LORD shall cut off all flattering lips, and the tongue that speaketh proud things:", "4 Who have said, With our tongue will we prevail; our lips are our own: who is lord over us?", "5 For the oppression of the poor, for the sighing of the needy, now will I arise, saith the LORD; I will set him in safety from him that puffeth at him.", "6 The words of the LORD are pure words: as silver tried in a furnace of earth, purified seven times.", "7 Thou shalt keep them, O LORD, thou shalt preserve them from this generation for ever.", "8 The wicked walk on every side, when the vilest men are exalted.", "1 How long wilt thou forget me, O LORD? for ever? how long wilt thou hide thy face from me?", "2 How long shall I take counsel in my soul, having sorrow in my heart daily? how long shall mine enemy be exalted over me?", "3 Consider and hear me, O LORD my God: lighten mine eyes, lest I sleep the sleep of death;", "4 Lest mine enemy say, I have prevailed against him; and those that trouble me rejoice when I am moved.", "5 But I have trusted in thy mercy; my heart shall rejoice in thy salvation.", "6 I will sing unto the LORD, because he hath dealt bountifully with me.", "1 The fool hath said in his heart, There is no God. They are corrupt, they have done abominable works, there is none that doeth good.", "2 The LORD looked down from heaven upon the children of men, to see if there were any that did understand, and seek God.", "3 They are all gone aside, they are all together become filthy: there is none that doeth good, no, not one.", "4 Have all the workers of iniquity no knowledge? who eat up my people as they eat bread, and call not upon the LORD.", "5 There were they in great fear: for God is in the generation of the righteous.", "6 Ye have shamed the counsel of the poor, because the LORD is his refuge.", "7 Oh that the salvation of Israel were come out of Zion! when the LORD bringeth back the captivity of his people, Jacob shall rejoice, and Israel shall be glad.", "1 LORD, who shall abide in thy tabernacle? who shall dwell in thy holy hill?", "2 He that walketh uprightly, and worketh righteousness, and speaketh the truth in his heart.", "3 He that backbiteth not with his tongue, nor doeth evil to his neighbour, nor taketh up a reproach against his neighbour.", "4 In whose eyes a vile person is contemned; but he honoureth them that fear the LORD. He that sweareth to his own hurt, and changeth not.", "5 He that putteth not out his money to usury, nor taketh reward against the innocent. He that doeth these things shall never be moved.", "1 Preserve me, O God: for in thee do I put my trust.", "2 O my soul, thou hast said unto the LORD, Thou art my Lord: my goodness extendeth not to thee;", "3 But to the saints that are in the earth, and to the excellent, in whom is all my delight.", \
                "4 Their sorrows shall be multiplied that hasten after another god: their drink offerings of blood will I not offer, nor take up their names into my lips.", "5 The LORD is the portion of mine inheritance and of my cup: thou maintainest my lot.", "6 The lines are fallen unto me in pleasant places; yea, I have a goodly heritage.", "7 I will bless the LORD, who hath given me counsel: my reins also instruct me in the night seasons.", "8 I have set the LORD always before me: because he is at my right hand, I shall not be moved.", "9 Therefore my heart is glad, and my glory rejoiceth: my flesh also shall rest in hope.", "10 For thou wilt not leave my soul in hell; neither wilt thou suffer thine Holy One to see corruption.", "11 Thou wilt shew me the path of life: in thy presence is fulness of joy; at thy right hand there are pleasures for evermore.", "1 Hear the right, O LORD, attend unto my cry, give ear unto my prayer, that goeth not out of feigned lips.", "2 Let my sentence come forth from thy presence; let thine eyes behold the things that are equal.", "3 Thou hast proved mine heart; thou hast visited me in the night; thou hast tried me, and shalt find nothing; I am purposed that my mouth shall not transgress.", "4 Concerning the works of men, by the word of thy lips I have kept me from the paths of the destroyer.", "5 Hold up my goings in thy paths, that my footsteps slip not.", "6 I have called upon thee, for thou wilt hear me, O God: incline thine ear unto me, and hear my speech.", "7 Shew thy marvellous lovingkindness, O thou that savest by thy right hand them which put their trust in thee from those that rise up against them.", "8 Keep me as the apple of the eye*, hide me under the shadow of thy wings,", "9 From the wicked that oppress me, from my deadly enemies, who compass me about.", "10 They are inclosed in their own fat: with their mouth they speak proudly.", "11 They have now compassed us in our steps: they have set their eyes bowing down to the earth;", "12 Like as a lion that is greedy of his prey, and as it were a young lion lurking in secret places.", "13 Arise, O LORD, disappoint him, cast him down: deliver my soul from the wicked, which is thy sword:", "14 From men which are thy hand, O LORD, from men of the world, which have their portion in this life, and whose belly thou fillest with thy hid treasure: they are full of children, and leave the rest of their substance to their babes.", "15 As for me, I will behold thy face in righteousness: I shall be satisfied, when I awake, with thy likeness.", "1 I will love thee, O LORD, my strength.", "2 The LORD is my rock, and my fortress, and my deliverer; my God, my strength, in whom I will trust; my buckler, and the horn of my salvation, and my high tower.", "3 I will call upon the LORD, who is worthy to be praised: so shall I be saved from mine enemies.", "4 The sorrows of death compassed me, and the floods of ungodly men made me afraid.", "5 The sorrows of hell compassed me about: the snares of death prevented me.", "6 In my distress I called upon the LORD, and cried unto my God: he heard my voice out of his temple, and my cry came before him, even into his ears.", "7 Then the earth shook and trembled; the foundations also of the hills moved and were shaken, because he was wroth.", "8 There went up a smoke out of his nostrils, and fire out of his mouth devoured: coals were kindled by it.", "9 He bowed the heavens also, and came down: and darkness was under his feet.", "10 And he rode upon a cherub, and did fly: yea, he did fly upon the wings of the wind.", "11 He made darkness his secret place; his pavilion round about him were dark waters and thick clouds of the skies.", "12 At the brightness that was before him his thick clouds passed, hail stones and coals of fire.", "13 The LORD also thundered in the heavens, and the Highest gave his voice; hail stones and coals of fire.", "14 Yea, he sent out his arrows, and scattered them; and he shot out lightnings, and discomfited them.", "15 Then the channels of waters were seen, and the foundations of the world were discovered at thy rebuke, O LORD, at the blast of the breath of thy nostrils.", "16 He sent from above, he took me, he drew me out of many waters.", "17 He delivered me from my strong enemy, and from them which hated me: for they were too strong for me.", "18 They prevented me in the day of my calamity: but the LORD was my stay.", "19 He brought me forth also into a large place; he delivered me, because he delighted in me.", "20 The LORD rewarded me according to my righteousness; according to the cleanness of my hands hath he recompensed me.", "21 For I have kept the ways of the LORD, and have not wickedly departed from my God.", "22 For all his judgments were before me, and I did not put away his statutes from me.", "23 I was also upright before him, and I kept myself from mine iniquity.", "24 Therefore hath the LORD recompensed me according to my righteousness, according to the cleanness of my hands in his eyesight.", "25 With the merciful thou wilt shew thyself merciful; with an upright man thou wilt shew thyself upright;" "26 With the pure thou wilt shew thyself pure; and with the froward thou wilt shew thyself froward.", "27 For thou wilt save the afflicted people; but wilt bring down high looks.", "28 For thou wilt light my candle: the LORD my God will enlighten my darkness.", "29 For by thee I have run through a troop; and by my God have I leaped over a wall.", "30 As for God, his way is perfect: the word of the LORD is tried: he is a buckler to all those that trust in him.", "31 For who is God save the LORD? or who is a rock save our God?", "32 It is God that girdeth me with strength, and maketh my way perfect.", "33 He maketh my feet like hinds' feet, and setteth me upon my high places.", "34 He teacheth my hands to war, so that a bow of steel is broken by mine arms.", "35 Thou hast also given me the shield of thy salvation: and thy right hand hath holden me up, and thy gentleness hath made me great.", "36 Thou hast enlarged my steps under me, that my feet did not slip.", "37 I have pursued mine enemies, and overtaken them: neither did I turn again till they were consumed.", "38 I have wounded them that they were not able to rise: they are fallen under my feet.", "39 For thou hast girded me with strength unto the battle: thou hast subdued under me those that rose up against me.", "40 Thou hast also given me the necks of mine enemies; that I might destroy them that hate me.", "41 They cried, but there was none to save them: even unto the LORD, but he answered them not.", "42 Then did I beat them small as the dust before the wind: I did cast them out as the dirt in the streets.", "43 Thou hast delivered me from the strivings of the people; and thou hast made me the head of the heathen: a people whom I have not known shall serve me.", "44 As soon as they hear of me, they shall obey me: the strangers shall submit themselves unto me.", "45 The strangers shall fade away, and be afraid out of their close places.", "46 The LORD liveth; and blessed be my rock; and let the God of my salvation be exalted.", "47 It is God that avengeth* me, and subdueth the people under me.", "48 He delivereth me from mine enemies: yea, thou liftest me up above those that rise up against me: thou hast delivered me from the violent man.", "49 Therefore will I give thanks unto thee, O LORD, among the heathen, and sing praises unto thy name.", "50 Great deliverance giveth he to his king; and sheweth mercy to his anointed, to David, and to his seed for evermore.", "1 The heavens declare the glory of God; and the firmament sheweth his handywork*.", "2 Day unto day uttereth speech, and night unto night sheweth knowledge.", "3 There is no speech nor language, where their voice is not heard.", "4 Their line is gone out through all the earth, and their words to the end of the world. In them hath he set a tabernacle for the sun,", "5 Which is as a bridegroom coming out of his chamber, and rejoiceth as a strong man to run a race.", "6 His going forth is from the end of the heaven, and his circuit unto the ends of it: and there is nothing hid from the heat thereof.", "7 The law of the LORD is perfect, converting the soul: the testimony of the LORD is sure, making wise the simple.", "8 The statutes of the LORD are right, rejoicing the heart: the commandment of the LORD is pure, enlightening the eyes.", "9 The fear of the LORD is clean, enduring for ever: the judgments of the LORD are true and righteous altogether.", "10 More to be desired are they than gold, yea, than much fine gold: sweeter also than honey and the honeycomb*.", "11 Moreover by them is thy servant warned: and in keeping of them there is great reward.", "12 Who can understand his errors? cleanse thou me from secret faults.", "13 Keep back thy servant also from presumptuous sins; let them not have dominion over me: then shall I be upright, and I shall be innocent from the great transgression.", "14 Let the words of my mouth, and the meditation of my heart, be acceptable in thy sight, O LORD, my strength, and my redeemer.", "1 The LORD hear thee in the day of trouble; the name of the God of Jacob defend thee;", "2 Send thee help from the sanctuary, and strengthen thee out of Zion;", "3 Remember all thy offerings, and accept thy burnt sacrifice; Selah.", "4 Grant thee according to thine own heart, and fulfil all thy counsel.", "5 We will rejoice in thy salvation, and in the name of our God we will set up our banners: the LORD fulfil all thy petitions.", "6 Now know I that the LORD saveth his anointed; he will hear him from his holy heaven with the saving strength of his right hand.", "7 Some trust in chariots, and some in horses: but we will remember the name of the LORD our God.", "8 They are brought down and fallen: but we are risen, and stand upright.", "9 Save, LORD: let the king hear us when we call.", "1 The king shall joy in thy strength, O LORD; and in thy salvation how greatly shall he rejoice!", "2 Thou hast given him his heart's desire, and hast not withholden the request of his lips. Selah.", "3 For thou preventest him with the blessings of goodness: thou settest a crown of pure gold on his head.", "4 He asked life of thee, and thou gavest it him, even length of days for ever and ever.", "5 His glory is great in thy salvation: honour and majesty hast thou laid upon him.", "6 For thou hast made him most blessed for ever: thou hast made him exceeding glad with thy countenance.", "7 For the king trusteth in the LORD, and through the mercy of the most High he shall not be moved.", "8 Thine hand shall find out all thine enemies: thy right hand shall find out those that hate thee.", "9 Thou shalt make them as a fiery oven in the time of thine anger: the LORD shall swallow them up in his wrath, and the fire shall devour them.", "10 Their fruit shalt thou destroy from the earth, and their seed from among the children of men.", "11 For they intended evil against thee: they imagined a mischievous device, which they are not able to perform.", "12 Therefore shalt thou make them turn their back, when thou shalt make ready thine arrows upon thy strings against the face of them.", "13 Be thou exalted, LORD, in thine own strength: so will we sing and praise thy power."]
        
    deck1 = ["Ace of Hearts", "Two of Hearts", "Three of Hearts", "Four of Hearts", "Five of Hearts", "Six of Hearts", "Seven of Hearts", "Eight of Hearts", "Nine of Hearts", "Ten of Hearts", "Jack of Hearts", "Queen Of Hearts", "King of Hearts", "Ace of Clubs", "Two of Clubs", "Three of Clubs", "Four of Clubs", "Five of Clubs", "Six of Clubs", "Seven of Clubs", "Eight of Clubs", "Nine of Clubs", "Ten of Clubs", "Jack of Clubs", "Queen Of Clubs", "King of Clubs", "Ace of Diamonds", "Two of Diamonds", "Three of Diamonds", "Four of Diamonds", "Five of Diamonds", "Six of Diamonds", "Seven of Diamonds", "Eight of Diamonds", "Nine of Diamonds", "Ten of Diamonds", "Jack of Diamonds", "Queen Of Diamonds", "King of Diamonds", "Ace of Spades", "Two of Spades", "Three of Spades", "Four of Spades", "Five of Spades", "Six of Spades", "Seven of Spades", "Eight of Spades", "Nine of Spades", "Ten of Spades", "Jack of Spades", "Queen Of Spades", "King of Spades", "Joker", "Joker"]

    koran1 = ["[67.1] Blessed is He in Whose hand is the kingdom, and He has power over all things,", "[67.2] Who created death and life that He may try you-- which of you is best in deeds; and He is the Mighty, the Forgiving,", "[67.3] Who created the seven heavens one above another; you see no incongruity in the creation of the Beneficent God; then look again, can you see any disorder?", "[67.4] Then turn back the eye again and again; your look shall '~ come back to you confused while it is fatigued.", "[67.5] And certainly We have adorned this lower heaven with ( lamps and We have made these missiles for the Shaitans, and We have prepared for them the chastisement of burning.", "[67.6] And for those who disbelieve in their Lord is the punishment of hell, and evil is the resort.", "[67.7] When they shall be cast therein, they shall hear a loud moaning of it as it heaves,", "[67.8] Almost bursting for fury. Whenever a group is cast into it, its keeper shall ask them: Did there not come to you a warner?", "[67.9] They shall say: Yea! indeed there came to us a warner, but we rejected (him) and said: Allah has not revealed anything, you are only in a great error.", "[67.10] And they shall say: Had we but listened or pondered, we should not have been among the inmates of the burning fire.", "[67.11] So they shall acknowledge their sins, but far will be (forgiveness) from the inmates of the burning fire.", "[67.12] (As for) those who fear their Lord in secret, they shall surely have forgiveness and a great reward.", "[67.13] And conceal your word or manifest it; surely He is Cognizant of what is in the hearts.", "[67.14] Does He not know, Who created? And He is the Knower of the subtleties, the Aware.", "[67.15] He it is Who made the earth smooth for you, therefore go about in the spacious sides thereof, and eat of His sustenance, and to Him is the return after death.", "[67.16] Are you secure of those in the heaven that He should not make the earth to swallow you up? Then lo! it shall be in a state of commotion.", "[67.17] Or are you secure of those in the heaven that He should not send down upon you a punishment? Then shall you know how was My warning.", "[67.18] And certainly those before them rejected (the truth), then how was My disapproval.", "[67.19] Have they not seen the birds above them expanding (their wings) and contracting (them)? What is it that withholds them save the Beneficent God? Surely He sees everything.", "[67.20] Or who is it that will be a host for you to assist you besides the Beneficent God? The unbelievers are only in deception.", "[67.21] Or who is it that will give you sustenance if He should withhold His sustenance? Nay! they persist in disdain and aversion.", "[67.22] What! is he who goes prone upon his face better guided or he who walks upright upon a straight path?", "[67.23] Say: He it is Who brought you into being and made for you the ears and the eyes and the hearts: little is it that you give thanks.", "[67.24] Say: He it is Who multiplied you in the earth and to Him you shall be gathered.", "[67.25] And they say: When shall this threat be (executed) if you are truthful?", "[67.26] Say: The knowledge (thereof is only with Allah and I am only a plain warner.=", "[67.27] But when they shall see it nigh, the faces of those who disbelieve shall be sorry, and it shall be said; This is that which you used to call for.", "[67.28] Say: Have you considered if Allah should destroy me and those with me-- rather He will have mercy on us; yet who will protect the unbelievers from a painful punishment?", "[67.29] Say: He is the Beneficent God, we believe in Him and on Him do we rely, so you shall come to know who it is that is in clear error.", "[67.30] Say: Have you considered if your water should go down, who is it then that will bring you flowing water?", "[89.1] I swear by the daybreak,", "[89.2] And the ten nights,", "[89.3] And the even and the odd,", "[89.4] And the night when it departs.", "[89.5] Truly in that there is an oath for those who possess understanding.", "[89.6] Have you not considered how your Lord dealt with Ad,", "[89.7] (The people of) Aram, possessors of lofty buildings,", "[89.8] The like of which were not created in the (other) cities;", "[89.9] And (with) Samood, who hewed out the rocks in the valley,", "[89.10] And (with) Firon, the lord of hosts,", "[89.11] Who committed inordinacy in the cities,", "[89.12] So they made great mischief therein?", "[89.13] Therefore your Lord let down upon them a portion of the chastisement.", "[89.14] Most sure!y your Lord is watching.", "[89.15] And as for man, when his Lord tries him, then treats him with honor and makes him lead an easy life, he says: My Lord honors me.", "[89.16] But when He tries him (differently), then straitens to him his means of subsistence, he says: My Lord has disgraced me.", "[89.17] Nay! but you do not honor the orphan,", "[89.18] Nor do you urge one another to feed the poor,", "[89.19] And you eat away the heritage, devouring (everything) indiscriminately,", "[89.20] And you love wealth with exceeding love.", "[89.21] Nay! when the earth is made to crumble to pieces,", "[89.22] And your Lord comes and (also) the angels in ranks,", "[89.23] And hell is made to appear on that day. On that day shall man be mindful, and what shall being mindful (then) avail him?", "[89.24] He shall say: O! would that I had sent before for (this) my life!", "[89.25] But on that day shall no one chastise with (anything like) His chastisement,", "[89.26] And no one shall bind with (anything like) His binding.", "[89.27] O soul that art at rest!", "[89.28] Return to your Lord, well-pleased (with him), well-pleasing (Him),", "[89.29] So enter among My servants,", "[89.30] And enter into My garden.", "[87.1] Glorify the name of your Lord, the Most High,", "[87.2] Who creates, then makes complete,", "[87.3] And Who makes (things) according to a measure, then guides (them to their goal),", "[87.4] And Who brings forth herbage,", "[87.5] Then makes it dried up, dust-colored.", "[87.6] We will make you recite so you shall not forget,", "[87.7] Except what Allah pleases, surely He knows the manifest, and what is hidden.", "[87.8] And We will make your way smooth to a state of ease.", "[87.9] Therefore do remind, surely reminding does profit.", "[87.10] He who fears will mind,", "[87.11] And the most unfortunate one will avoid it,", "[87.12] Who shall enter the great fire;", "[87.13] Then therein he shall neither live nor die.", "[87.14] He indeed shall be successful who purifies himself,", "[87.15] And magnifies the name of his Lord and prays.", "[87.16] Nay! you prefer the life of this world,", "[87.17] While the hereafter is better and more lasting.", "[87.18] Most surely this is in the earlier scriptures,", "[87.19] The scriptures of Ibrahim and Musa.", "[24.1] (This is) a chapter which We have revealed and made obligatory and in which We have revealed clear communications that you may be mindful.", "[24.2] (As for) the fornicatress and the fornicator, flog each of them, (giving) a hundred stripes, and let not pity for them detain you in the matter of obedience to Allah, if you believe in Allah and the last day, and let a party of believers witness their chastisement.", "[24.3] The fornicator shall not marry any but a fornicatress or idolatress, and (as for) the fornicatress, none shall marry her but a fornicator or an idolater; and it is forbidden to the believers.", "[24.4] And those who accuse free women then do not bring four witnesses, flog them, (giving) eighty stripes, and do not admit any evidence from them ever; and these it is that are the transgressors,", "[24.5] Except those who repent after this and act aright, for surely Allah is Forgiving, Merciful.", "[24.6] And (as for) those who accuse their wives and have no witnesses except themselves, the evidence of one of these (should be taken) four times, bearing Allah to witness that he is most surely of the truthful ones.", "[24.7] And the fifth (time) that the curse of Allah be on him if he is one of the liars.", "[24.8] And it shall avert the chastisement from her if she testify four times, bearing Allah to witness that he is most surely one of the liars;", "[24.9] And the fifth (time) that the wrath of Allah be on her if he is one of the truthful.", "[24.10] And were it not for Allah's grace upon you and His mercy-- and that Allah is Oft-returning (to mercy), Wise!", "[24.11] Surely they who concocted the lie are a party from among you. Do not regard it an evil to you; nay, it is good for you. Every man of them shall have what he has earned of sin; and (as for) him who took upon himself the main part thereof, he shall have a grievous chastisement.", "[24.12] Why did not the believing men and the believing women, when you heard it, think well of their own people, and say: This is an evident falsehood?", "[24.13] Why did they not bring four witnesses of it? But as they have not brought witnesses they are liars before Allah.", "[24.14] And were it not for Allah's grace upon you and His mercy in this world and the hereafter, a grievous chastisement would certainly have touched you on account of the discourse which you entered into.", "[24.15] When you received it with your tongues and spoke with your mouths what you had no knowledge of, and you deemed it an easy matter while with Allah it was grievous.", "[24.16] And why did you not, when you heard it, say: It does not beseem us that we should talk of it; glory be to Thee! this is a great calumny?", "[24.17] Allah admonishes you that you should not return to the like of it ever again if you are believers.", "[24.18] And Allah makes clear to you the communications; and Allah is Knowing, Wise.", "[24.19] Surely (as for) those who love that scandal should circulate respecting those who believe, they shall have a grievous chastisement in this world and the hereafter; and Allah knows, while you do not know.", "[24.20] And were it not for Allah's grace on you and His mercy, and that Allah is Compassionate, Merciful.", "[24.21] O you who believe! do not follow the footsteps of the Shaitan, and whoever follows the footsteps of the Shaitan, then surely he bids the doing of indecency and evil; and were it not for Allah's grace upon you and His mercy, not one of you would have ever been pure, but Allah purifies whom He pleases; and Allah is Hearing, Knowing.", "[24.22] And let not those of you who possess grace and abundance swear against giving to the near of kin and the poor and those who have fled in Allah's way, and they should pardon and turn away. Do you not love that Allah should forgive you? And Allah is Forgiving, Merciful.", "[24.23] Surely those who accuse chaste believing women, unaware (of the evil), are cursed in this world and the hereafter, and they shall have a grievous chastisement.", "[24.24] On the day when their tongues and their hands and their feet shall bear witness against them as to what they did.", "[24.25] On that day Allah will pay back to them in full their just reward, and they shall know that Allah is the evident Truth.", "[24.26] Bad women .are for bad men and bad men are for bad women. Good women are for good men and good men are for good women", "[24.27] O you who believe! Do not enter houses other than your own houses until you have asked permission and saluted their inmates; this is better for you, that you may be mindful.", "[24.28] But if you do not find any one therein, then do not enter them until permission is given to you; and if it is said to you: Go back, then go back; this is purer for you; and Allah is Cognizant of what you do.", "[24.29] It is no sin in you that you enter uninhabited houses wherein you have your necessaries; and Allah knows what you do openly and what you hide.", "[24.30] Say to the believing men that they cast down their looks and guard their private parts; that is purer for them; surely Allah is Aware of what they do.", "[24.31] And say to the believing women that they cast down their looks and guard their private parts and do not display their ornaments except what appears thereof, and let them wear their head-coverings over their bosoms, and not display their ornaments except to their husbands or their fathers, or the fathers of their husbands, or their sons, or the sons of their husbands, or their brothers, or their brothers' sons, or their sisters' sons, or their women, or those whom their right hands possess, or the male servants not having need (of women), or the children who have not attained knowledge of what is hidden of women; and let them not strike their feet so that what they hide of their ornaments may be known; and turn to Allah all of you, O believers! so that you may be successful.", "[24.32] And marry those among you who are single and those who are fit among your male slaves and your female slaves; if they are needy, Allah will make them free from want out of His grace; and Allah is Ample-giving, Knowing.", "[24.33] And let those who do not find the means to marry keep chaste until Allah makes them free from want out of His grace. And (as for) those who ask for a writing from among those whom your right hands possess, give them the writing if you know any good in them, and give them of the wealth of Allah which He has given you; and do not compel your slave girls to prostitution, when they desire to keep chaste, in order to seek the frail good of this world's life; and whoever compels them, then surely after their compulsion Allah is Forgiving, Merciful.", "[24.34] And certainly We have sent to you clear communications and a description of those who have passed away before you, and an admonition to those who guard (against evil).", "[24.35] Allah is the light of the heavens and the earth; a likeness of His light is as a niche in which is a lamp, the lamp is in a glass, (and) the glass is as it were a brightly shining star, lit from a blessed olive-tree, neither eastern nor western, the oil whereof almost gives light though fire touch it not-- light upon light-- Allah guides to His light whom He pleases, and Allah sets forth parables for men, and Allah is Cognizant of all things.", "[24.36] In houses which Allah has permitted to be exalted and that His name may be remembered in them; there glorify Him therein in the mornings and the evenings,", "[24.37] Men whom neither merchandise nor selling diverts from the remembrance of Allah and the keeping up of prayer and the giving of poor-rate; they fear a day in which the hearts and eyes shall turn about;", "[24.38] That Allah may give them the best reward of what they have done, and give them more out of His grace; and Allah gives sustenance to whom He pleases without measure.", "[24.39] And (as for) those who disbelieve, their deeds are like the mirage in a desert, which the thirsty man deems to be water; until when he comes to it he finds it to be naught, and there he finds Allah, so He pays back to him his reckoning in full; and Allah is quick in reckoning;", "[24.40] Or like utter darkness in the deep sea: there covers it a wave above which is another wave, above which is a cloud, (layers of) utter darkness one above another; when he holds out his hand, he is almost unable to see it; and to whomsoever Allah does not give light, he has no light.", "[24.41] Do you not see that Allah is He Whom do glorify all those who are in the heavens and the earth, and the (very) birds with expanded wings? He knows the prayer of each one and its glorification, and Allah is Cognizant of what they do.", "[24.42] And Allah's is the kingdom of the heavens and the earth, and to Allah is the eventual coming.", "[24.43] Do you not see that Allah drives along the clouds, then gathers them together, then piles them up, so that you see the rain coming forth from their midst? And He sends down of the clouds that are (like) mountains wherein is hail, afflicting therewith whom He pleases and turning it away from whom He pleases; the flash of His lightning almost takes away the sight.", "[24.44] Allah turns over the night and the day; most surely there is a lesson in this for those who have sight.", \
        "[24.45] And Allah has created from water every living creature: so of them is that which walks upon its belly, and of them is that which walks upon two feet, and of them is that which walks upon four; Allah creates what He pleases; surely Allah has power over all things.", "[24.46] Certainly We have revealed clear communications, and Allah guides whom He pleases to the right way.", "[24.47] And they say: We believe in Allah and in the apostle and we obey; then a party of them turn back after this, and these are not believers.", "[24.48] And when they are called to Allah and His Apostle that he may judge between them, lo! a party of them turn aside.", "[24.49] And if the truth be on their side, they come to him quickly, obedient.", "[24.50] Is there in their hearts a disease, or are they in doubt, or do they fear that Allah and His Apostle will act wrongfully towards them? Nay! they themselves are the unjust.", "[24.51] The response of the believers, when they are invited to Allah and His Apostle that he may judge between them, is only to say: We hear and we obey; and these it is that are the successful.", "[24.52] And he who obeys Allah and His Apostle, and fears Allah, and is careful of (his duty to) Him, these it is that are the achievers.", "[24.53] And they swear by Allah with the most energetic of their oaths that if you command them they would certainly go forth. Say: Swear not; reasonable obedience (is desired); surely Allah is aware of what you do.", "[24.54] Say: Obey Allah and obey the Apostle; but if you turn back, then on him rests that which is imposed on him and on you rests that which is imposed on you; and if you obey him, you are on the right way; and nothing rests on the Apostle but clear delivering (of the message).", "[24.55] Allah has promised to those of you who believe and do good that He will most certainly make them rulers in the earth as He made rulers those before them, and that He will most certainly establish for them their religion which He has chosen for them, and that He will most certainly, after their fear, give them security in exchange; they shall serve Me, not associating aught with Me; and whoever is ungrateful after this, these it is who are the. transgressors.", "[24.56] And keep up prayer and pay the poor-rate and obey the Apostle, so that mercy may be shown to you.", "[24.57] Think not that those who disbelieve shall escape in the earth, and their abode is the fire; and certainly evil is the resort!", "[24.58] O you who believe! let those whom your right hands possess and those of you who have not attained to puberty ask permission of you three times; before the morning prayer, and when you put off your clothes at midday in summer, and after the prayer of the nightfall; these are three times of privacy for you; neither is it a sin for you nor for them besides these, some of you must go round about (waiting) upon others; thus does Allah make clear to you the communications, and Allah is Knowing, Wise.", "[24.59] And when the children among you have attained to puberty, let them seek permission as those before them sought permission; thus does Allah make clear to you His communications, and Allah is knowing, Wise.", "[24.60] And (as for) women advanced in years who do not hope for a marriage, it is no sin for them if they put off their clothes without displaying their ornaments; and if they restrain themselves it is better for them; and Allah is Hearing, Knowing.", "[24.61] There is no blame on the blind man, nor is there blame on the lame, nor is there blame on the sick, nor on yourselves that you eat from your houses, or your fathers' houses or your mothers' houses, or your brothers' houses, or your sisters' houses, or your paternal uncles' houses, or your paternal aunts' houses, or your maternal uncles' houses, or your maternal aunts' houses, or what you possess the keys of, or your friends' (houses). It is no sin in you that you eat together or separately. So when you enter houses, greet your people with a salutation from Allah, blessed (and) goodly; thus does Allah make clear to you the communications that you may understand.", "[24.62] Only those are believers who believe in Allah and His Apostle, and when they are with him on a momentous affair they go not away until they have asked his permission; surely they who ask your permission are they who believe in Allah and His Apostle; so when they ask your permission for some affair of theirs, give permission to whom you please of them and ask forgiveness for them from Allah; surely Allah is Forgiving, Merciful.", "[24.63] Do not hold the Apostle's calling (you) among you to be like your calling one to the other; Allah indeed knows those who steal away from among you, concealing themselves; therefore let those beware who go against his order lest a trial afflict them or there befall them a painful chastisement.", "[24.64] Now surely Allah's is whatever is in the heavens and the earth; He knows indeed that to which you are conforming yourselves; and on the day on which they are returned to Him He will inform them of what they did; and Allah is Cognizant of all things.", "[85.1] I swear by the mansions of the stars,", "[85.2] And the promised day,", "[85.3] And the bearer of witness and those against whom the witness is borne.", "[85.4] Cursed be the makers of the pit,", "[85.5] Of the fire (kept burning) with fuel,", "[85.6] When they sat by it,", "[85.7] And they were witnesses of what they did with the believers.", "[85.8] And they did not take vengeance on them for aught except that they believed in Allah, the Mighty, the Praised,", "[85.9] Whose is the kingdom of the heavens and the earth; and Allah is a Witness of all things.", "[85.10] Surely (as for) those who persecute the believing men and the believing women, then do not repent, they shall have the chastisement of hell, and they shall have the chastisement of burning.", "[85.11] Surely (as for) those who believe and do good, they shall have gardens beneath which rivers flow, that is the great achievement.", "[85.12] Surely the might of your Lord is great.", "[85.13] Surely He it is Who originates and reproduces,", "[85.14] And He is the Forgiving, the Loving,", "[85.15] Lord of the Arsh, the Glorious,", "[85.16] The great doer of what He will.", "[85.17] Has not there come to you the story of the hosts,", "[85.18] Of Firon and Samood?", "[85.19] Nay! those who disbelieve are in (the act of) giving the lie to the truth.", "[85.20] And Allah encompasses them on every side.", "[85.21] Nay! it is a glorious Quran,", "[85.22] In a guarded tablet.", "[113.1] Say: I seek refuge in the Lord of the dawn,", "[113.2] From the evil of what He has created,", "[113.3] And from the evil of the utterly dark night when it comes,", "[113.4] And from the evil of those who blow on knots,", "[113.5] And from the evil of the envious when he envies", "[52.1] I swear by the Mountain,", "[52.2] And the Book written", "[52.3] In an outstretched fine parchment,", "[52.4] And the House (Kaaba) that is visited,", "[52.5] And the elevated canopy", "[52.6] And the swollen sea", "[52.7] Most surely the punishment of your Lord will come to pass;", "[52.8] There shall be none to avert it;", "[52.9] On the day when the heaven shall move from side to side", "[52.10] And the mountains shall pass away passing away (altogether).", "[52.11] So woe on that day to those who reject (the truth),", "[52.12] Those who sport entering into vain discourses.", "[52.13] The day on which they shall be driven away to the fire of hell with violence.", "[52.14] This is the fire which you used to give the lie to.", "[52.15] Is it magic then or do you not see?", "[52.16] Enter into it, then bear (it) patiently, or do not bear (it) patiently, it is the same to you; you shall be requited only (for) what you did.", "[52.17] Surely those who guard (against evil) shall be in gardens and bliss", "[52.18] Rejoicing because of what their Lord gave them, and their Lord saved them from the punishment of the burning fire.", "[52.19] Eat and drink pleasantly for what you did,", "[52.20] Reclining on thrones set in lines, and We will unite them to large-eyed beautiful ones.", "[52.21] And (as for) those who believe and their offspring follow them in faith, We will unite with them their offspring and We will not diminish to them aught of their work; every man is responsible for what he shall have wrought.", "[52.22] And We will aid them with fruit and flesh such as they desire.", "[52.23] They shall pass therein from one to another a cup wherein there shall be nothing vain nor any sin.", "[52.24] And round them shall go boys of theirs as if they were hidden pearls.", "[52.25] And some of them shall advance towards others questioning each other.", "[52.26] Saying: Surely we feared before on account of our families:", "[52.27] But Allah has been gracious to us and He has saved us from the punishment of the hot wind:", "[52.28] Surely we called upon Him before: Surely He is the Benign, the Merciful.", "[52.29] Therefore continue to remind, for by the grace of your Lord, you are not a soothsayer, or a madman.", "[52.30] Or do they say: A poet, we wait for him the evil accidents of time.", "[52.31] Say: Wait, for surely I too with you am of those who wait.", "[52.32] Nay! do their understandings bid them this? Or are they an inordinate people?", "[52.33] Or do they say: He has forged it. Nay! they do not believe.", "[52.34] Then let them bring an announcement like it if they are truthful.", "[52.35] Or were they created without there being anything, or are they the creators?", "[52.36] Or did they create the heavens and the earth? Nay! they have no certainty.", "[52.37] Or have they the treasures of your Lord with them? Or have they been set in absolute authority?", "[52.38] Or have they the means by which they listen? Then let their listener bring a clear authority.", "[52.39] Or has He daughters while you have sons?", "[52.40] Or do you ask them for a reward, so that they are overburdened by a debt?", "[52.41] Or have they the unseen so that they write (it) down?", "[52.42] Or do they desire a war? But those who disbelieve shall be the vanquished ones in war.", "[52.43] Or have they a god other than Allah? Glory be to Allah from what they set up (with Him).", "[52.44] And if they should see a portion of the heaven coming down, they would say: Piled up clouds.", "[52.45] Leave them then till they meet that day of theirs wherein they shall be made to swoon (with terror):", "[52.46] The day on which their struggle shall not avail them aught, nor shall they be helped.", "[52.47] And surely those who are unjust shall have a punishment besides that (in the world), but most of them do not know.", "[52.48] And wait patiently for the judgment of your Lord, for surely you are before Our eyes, and sing the praise of your Lord when you rise;", "[52.49] And in the night, give Him glory too, and at the setting of the stars."]

    fcci = ['a', 'ai', 'an', 'ang', 'ao', 'ba', 'bai', 'ban', 'bang', 'bao', 'bei', 'ben', 'beng', 'bi', 'bian', 'biao', 'bie', 'bin', 'bing', 'bo', 'bu', 'ca', 'cai', 'can', 'cang', 'cao', 'ce', 'cei', 'cen', 'ceng', 'cha', 'chai', 'chan', 'chang', 'chao', 'che', 'chen', 'cheng', 'chi', 'chong', 'chou', 'chu', 'chua', 'chuai', 'chuan', 'chuang', 'chui', 'chun', 'chuo', 'ci', 'cong', 'cou', 'cu', 'cuan', 'cui', 'cun', 'cuo', 'da', 'dai', 'dan', 'dang', 'dao', 'de', 'dei', 'den', 'deng', 'di', 'dia', 'dian', 'diao', 'die', 'ding', 'diu', 'dong', 'dou', 'du', 'duan', 'dui', 'dun', 'duo', 'e', 'ei', 'en', 'eng', 'er', 'fa', 'fan', 'fang', 'fei', 'fen', 'feng', 'fo', 'fou', 'fu', 'ga', 'gai', 'gan', 'gang', 'gao', 'ge', 'gei', 'gen', 'geng', 'gong', 'gou', 'gu', 'gua', 'guai', 'guan', 'guang', 'gui', 'gun', 'guo', 'ha', 'hai', 'han', 'hang', 'hao', 'he', 'hei', 'hen', 'heng', 'hong', 'hou', 'hu', 'hua', 'huai', 'huan', 'huang', 'hui', 'hun', 'huo', 'ji', 'jia', 'jian', 'jiang', 'jiao', 'jie', 'jin', 'jing', 'jiong', 'jiu', 'ju', 'juan', 'jue', 'jun', 'ka', 'kai', 'kan', 'kang', 'kao', 'ke', 'kei', 'ken', 'keng', 'kong', 'kou', 'ku', 'kua', 'kuai', 'kuan', 'kuang', 'kui', 'kun', 'kuo', 'la', 'lai', 'lan', 'lang', 'lao', 'le', 'lei', 'leng', 'li', 'lia', 'lian', 'liang', 'liao', 'lie', 'lin', 'ling', 'liu', 'long', 'lou', 'lu', 'luan', 'lun', 'luo', 'lü', 'lüe', 'ma', 'mai', 'man', 'mang', 'mao', 'me', 'mei', 'men', 'meng', 'mi', 'mian', 'miao', 'mie', 'min', 'ming', 'miu', 'mo', 'mou', 'mu', 'na', 'nai', 'nan', 'nang', 'nao', 'ne', 'nei', 'nen', 'neng', 'ni', 'nian', 'niang', 'niao', 'nie', 'nin', 'ning', 'niu', 'nong', 'nou', 'nu', 'nuan', 'nuo', 'nü', 'nüe', 'o', 'ou', 'pa', 'pai', 'pan', 'pang', 'pao', 'pei', 'pen', 'peng', 'pi', 'pian', 'piao', 'pie', 'pin', 'ping', 'po', 'pou', 'pu', 'qi', 'qia', 'qian', 'qiang', 'qiao', 'qie', 'qin', 'qing', 'qiong', 'qiu', 'qu', 'quan', 'que', 'qun', 'ran', 'rang', 'rao', 're', 'ren', 'reng', 'ri', 'rong', 'rou', 'ru', 'ruan', 'rui', 'run', 'ruo', 'sa', 'sai', 'san', 'sang', 'sao', 'se', 'sen', 'seng', 'sha', 'shai', 'shan', 'shang', 'shao', 'she', 'shei', 'shen', 'sheng', 'shi', 'shou', 'shu', 'shua', 'shuai', 'shuan', 'shuang', 'shui', 'shun', 'shuo', 'si', 'song', 'sou', 'su', 'suan', 'sui', 'sun', 'suo', 'ta', 'tai', 'tan', 'tang', 'tao', 'te', 'tei', 'teng', 'ti', 'tian', 'tiao', 'tie', 'ting', 'tong', 'tou', 'tu', 'tuan', 'tui', 'tun', 'tuo', 'wa', 'wai', 'wan', 'wang', 'wei', 'wen', 'weng', 'wo', 'wu', 'xi', 'xia', 'xian', 'xiang', 'xiao', 'xie', 'xin', 'xing', 'xiong', 'xiu', 'xu', 'xuan', 'xue', 'xun', 'ya', 'yan', 'yang', 'yao', 'ye', 'yi', 'yin', 'ying', 'yo', 'yong', 'you', 'yu', 'yuan', 'yue', 'yun', 'za', 'zai', 'zan', 'zang', 'zao', 'ze', 'zei', 'zen', 'zeng', 'zha', 'zhai', 'zhan', 'zhang', 'zhao', 'zhe', 'zhei', 'zhen', 'zheng', 'zhi', 'zhong', 'zhou', 'zhu', 'zhua', 'zhuai', 'zhuan', 'zhuang', 'zhui', 'zhun', 'zhuo', 'zi', 'zong', 'zou', 'zu', 'zuan', 'zui', 'zun', 'zuo', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ']

    def nano():
        dd = (diction)
        ct = datetime.datetime.now()
        nano = (random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd))
        result = random.sample(nano, random.randint(1, 6))
        star = "***"
        print(star, result, ct)

    def tinie_N():
        an = (fcci)
        acad = (acadlist)
        ct = datetime.datetime.now()
        cci = random.sample(an, random.randint(1,10))
        acadl = random.sample(acad, random.randint(1,5))
        wonyao_str = ''.join(cci)
        ha_sh = "#"
        print(ha_sh, wonyao_str, acadl, ct)

    def commands():
        print()
        print(" version | [blank input] for nano | profile | pwd / ls / cd / clear [cl] / mkdir / rm | type-text | fsearch ")
        print()
        print(" FNTCCI: tinien [single space/**], ntag, fcci-monitor [fstart/fcci] | synthesis: xcbmp, xhbmp, xjbmp, xfbmp")
        print()
        print(" | zuz [pp], call, message [lh], [echo], [fuzz], alerts, light incense, prayer, dhammapada, message-scan [scan], ascii, archery, value, tag / atag, map, monitor-start [mstart], acad-monitor (astart), weapon start [wstart], oscillator/time-oscillator [oscill/toscill], MedProc AI [MAI], MedProcCont [MAIc/MPC], burner-start/time-burner [burn/tburn], burner-search [b-search], Medicals (M), Earth Science (SCI), psychology (psyc), Patient Simu, biology (B), chemistry (ch), legal terms (Law), change username [username/user], print time, (ai) auto-mat [AAM], [ID / IDC], the heart sutra, herbs/herbals, degree/major, frames [fps], police (prad), CAI Environments (CAI/GES), time-monitor [tmonitor], speech-time-monitor [stmonitor], guard, Programs [PROGR]")
        print()
        print(" | pray, sleep, eat, meditate, draw card, slot, find coins, search for items, fly, drink coffee, drink tea, surf, skate, art, give alms, radio, hack, brawl, souls, hipster tarot, mp3, spar, train, rest, psalms, haiku, karate, koans, equips, rpg, color key, doodling, BUMP, MA, Magic, zen melody, monopoly, stats, progress, collections, football, c, entry, posting, koran, heBrews, Clearance, MiCasa, stuff, worship, License, climb, teletubby, {[muslim prayer] fajr (before dawn) / dhuhr (noon) / asr (late afternoon) / maghrib (at sunset) / isha (nighttime)}")

    def ls():
        try:
            result = subprocess.run(['ls'], capture_output=True, text=True, check=True)
            print(result.stdout)
        except subprocess.CalledProcessError as e:
            print(f"Error executing command: {e}")
            print(f"Stderr: {e.stderr}")

    def pwd():
        print(f"Current directory: {os.getcwd()}")

    def cd():
        path = input("$ ")
        try:
            os.chdir(path)
        except FileNotFoundError:
            print(f"Error: Folder '{path}' does not exist.")
        except NotADirectoryError:
            print(f"Error: '{path}' is not a directory.")
        except PermissionError:
            print(f"Error: Permission denied to access '{path}'.")
        except Exception as e:
            print(f"An unexpected error occurred: {e}")

    def mkdir():
        path = input("$ ")
        try:
            os.mkdir(path)
        except FileExistsError:
            print(f"Directory already exists at: {path}")

    def clear():
        try:
            result = subprocess.run(['clear'], capture_output=True, text=True, check=True)
            print(result.stdout)
        except subprocess.CalledProcessError as e:
            print(f"Error executing command: {e}")
            print(f"Stderr: {e.stderr}")

    def rm():
        path = input("$ ")
        try:
            os.remove(path)
        except FileNotFoundError:
            print(f"Error: Folder '{path}' does not exist.")
        except NotADirectoryError:
            print(f"Error: '{path}' is not a directory.")
        except PermissionError:
            print(f"Error: Permission denied to access '{path}'.")
        except Exception as e:
            print(f"An unexpected error occurred: {e}")        

    def clear():
        if os.name == 'posix':
            _ = os.system('clear')
        else:
            _ = os.system('cls')

    def text():
        title = input("Title: ")
        j = open("MProcs-text.txt", "a", buffering=1)
        ct = datetime.datetime.now()
        monitor = "text-type:"
        print(usr, monitor, title, ct)
        print(usr, monitor, title, ct, file=j)
        print()
        print("*this saves to MProcs-text.txt*")
        print()
        print(file=j)
        type_text = input("# ")
        print(type_text, file=j)
        print(file=j)

    def GES():
        print()
        print("Crown | ART | Birth Snapshot | YzB | Thailand Hospital | egg | Zen Meditation (USVU) | Shinobi Primer | Hacking 101 @m0nkrpg | Saler | 445 | First Office Salute | Poker Table | chi_a | med_apteu #proc #music")

    def print_time():
        t_time = datetime.datetime.now()
        l_time = "Time: "
        print(l_time, t_time)

    def change_username():
        def set_usr(newUsr):
            global usr
            usr = newUsr
        new = input("Session username: ")
        user = f"{GREEN}{new}{RESET}"
        maroon = "^m^"
        medicci = f"{RED}{maroon}{RESET}"
        dollar = "$"
        sign = f"{BLUE}{dollar}{RESET}"
        set_usr(medicci + "" + " " + "" + "[" + "" + user + "" + "]" + "" + " " + "" + sign + "" + " ")
        ct = datetime.datetime.now()

    def search():
        zen = input("Search: ")
        print()
        with open(r"MProcs-logs.txt", 'r') as fp:
            for l_no, line in enumerate(fp):
                # search string
                if zen in line:
                    print(zen + "" + ' found')
                    print('Line Number:', l_no)
                    print('Line:', line)

    def busearch(file_path="burner-log.txt"):
        zen = input("(burner) search: ")
        if not zen:
            print("Search cancelled.")
            return

        while True:
            try:
                fps = float(input("Indicate speed in seconds: "))
                if fps < 0:
                    print("Speed must be non-negative.")
                    continue
                break
            except ValueError:
                print("Invalid value. Please enter a number.")
            except KeyboardInterrupt:
                print("\nInput cancelled.")
                return

        print()
        print("Ctrl-C to stop")
        print()
        try:
            with open(file_path, 'r') as fp:
                for line in fp:  # Process line by line to save memory
                    if zen in line:  # Case-sensitive search
                        try:
                            time.sleep(fps)  # Can be interrupted by Ctrl+C
                            print(line.strip())
                        except KeyboardInterrupt:
                            print("\nSearch interrupted by user.")
                            return
        except FileNotFoundError:
            print(f"Error: File '{file_path}' not found.")
        except Exception as e:
            print(f"An error occurred: {e}")

    def profile():
        print()
        ID()
        print()
        value()
        print()
        atag()
        print()
        earth_science()
        print()
        draw_card()
        print()
        stats()
        print()
        hack()
        print()
        progress()
        print()
        haiku()
        print()
        rpg()
        print()
        equips()
        print()
        legal_terms()
        print()
        dhammapada()

    def echo():
        echo = input("$ ")
        ct = datetime.datetime.now()
        print()
        ech = "echo:"
        print(ech, usr, echo, ct)

    def pray():
        ct = datetime.datetime.now()
        print("You start praying to a God...")
        time.sleep(7)
        print("You finished praying", ct)
        time.sleep(3)

    def climb():
        time.sleep(1)
        climbing = ["you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you climb", "you hold unto a groove", "you hold unto a groove", "you hold unto a groove", "you hold unto a groove", "you hold unto a groove", "you hold unto a groove", "you reached a level", "you reached a level", "you reached a level", "you reached a level", "you reached a level", "you balance along a plank", "you balance along a plank", "you balance along a plank", "you balance along a plank", "you balance along a plank", "you balance along a plank", "you reach the top", "you reach the top", "you reach the top", "you reach the top", "you reach the top", "you reach the top", "you reach the top", "you fall",  "you fall",  "you fall",  "you fall", "you slide down", "you slide down", "you slide down", "you slide down", "you slide down", "you slide down", "you slide down", "you slip", "you slip", "you slip", "you slip", "you slip", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you walk along a ledge", "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto",  "you find something to hold unto", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you hold for your life", "you got sighted", "you got sighted", "you got sighted", "you got sighted", "you got sighted", "you got sighted", "you got sighted", "you got sighted", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", "you balance", ]
        climb = random.sample(climbing, 1)
        ct = datetime.datetime.now()
        clim = "climb:"
        print(clim, climb, ct)

    def prayer():
        ct = datetime.datetime.now()
        print("OM MANI PADME HUM", ct)

    def stats():
        stat = "stats:"
        hea = "Health:"
        health = (round(random.random()*120))
        conf = "Confidence:"
        confidence = (round(random.random()*120))
        oxyg = "Oxygen:"
        oxygen  = (round(random.random()*120))
        happ = "Happiness:"
        happiness = (round(random.random()*120))
        luc = "Luck:"
        luck = (round(random.random()*120))
        rele = "Release:"
        release = (round(random.random()*120))
        ener = "Energy:"
        energy = (round(random.random()*120))
        oppo = "Opportunity:"
        opportunity = (round(random.random()*120))
        chem = "Chemicals:"
        chemicals = (round(random.random()*120))
        ct = datetime.datetime.now()
        print(stat, hea, health, conf, confidence, oxyg, oxygen, happ, happiness, luc, luck, rele, release, ener, energy, oppo, opportunity, chem, chemicals, ct)

    def progress():
        ct = datetime.datetime.now()
        time.sleep(2)
        percentage = (round(random.random()*300))
        progress = "progress: "
        print(percentage)
        print("% done with")
        probability = (round(random.random()*4))
        print(probability)
        print("quads", ct)

    def light_incense():
        while True:
            try:
                number = int(input("Enter incense number: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        numberstr = str(number)
        print()
        ct = datetime.datetime.now()
        print("You light" + "" + " " + "" + numberstr + "" + " " + "" + "incense...", ct)
        time.sleep(3)

    def heart_sutra():
        time.sleep(2)
        print()
        print("The Bodhisattva of Compassion, / When he meditated deeply, / Saw the emptiness of all five skandhas / And sundered the bonds that caused him suffering.")
        time.sleep(8)
        print()
        print("Here then, / Form is no other than emptiness, / Emptiness no other than form. / Form is only emptiness, / Emptiness only form.")
        time.sleep(8)
        print()
        print("Feeling, thought, and choice, / Consciousness itself, / Are the same as this.")
        time.sleep(8)
        print()
        print("All things are by nature void / They are not born or destroyed / Nor are they stained or pure / Nor do they wax or wane")
        time.sleep(8)
        print()
        print("So, in emptiness, no form, / No feeling, thought, or choice, / Nor is there consciousness. / No eye, ear, nose, tongue, body, mind; / No colour, sound, smell, taste, touch, / Or what the mind takes hold of, / Nor even act of sensing.")
        time.sleep(10)
        print()
        print("No ignorance or end of it, / Nor all that comes of ignorance; / No withering, no death, / No end of them.")
        time.sleep(7)
        print()
        print("Nor is there pain, or cause of pain, / Or cease in pain, or noble path / To lead from pain; / Not even wisdom to attain! / Attainment too is emptiness.")
        time.sleep(8)
        print()
        print("So know that the Bodhisattva / Holding to nothing whatever, / But dwelling in Prajna wisdom, / Is freed of delusive hindrance, / Rid of the fear bred by it, / And reaches clearest Nirvana.")
        time.sleep(9)
        print()
        print("All Buddhas of past and present, / Buddhas of future time, / Using this Prajna wisdom, / Come to full and perfect vision.")
        time.sleep(8)
        print()
        print("Hear then the great dharani, / The radiant peerless mantra, / The Prajnaparamita / Whose words allay all pain; Hear and believe its truth!")
        time.sleep(8)
        print()
        print("Gate Gate Paragate Parasamgate / Bodhi Svaha / Gate Gate Paragate Parasamgate / Bodhi Svaha / Gate Gate Paragate Parasamgate / Bodhi Svaha")
        time.sleep(10)

    def hebrews():
        time.sleep(2)
        heBrews1 = ['Scroll 1.1 "The Meadows" There isnt compliance, there is only substance.', 'Scroll 1.2 "The Meadows" Nothing is really certain, but we are certain.', 'Scroll 1.3 "The Meadows" Is there a multiverse? Because if there is then the jobs are really done.', 'Scroll 1.4 "The Meadows" I think that there is no certainty to anything, only probability.', 'Scroll 1.5 "The Meadows" Tobacco got me, just a little, right now, what is this chemical?', 'Scroll 1.6 "The Meadows" Extreme climate is too extreme.', 'Scroll 1.7 "The Meadows" High up high, low as lows.', 'Scroll 1.8 "The Meadows" Music playing nothing really matters anymore, is that not the matter?', 'Scroll 1.9 "The Meadows" I come black and blue.', 'Scroll 1.10 "The Meadows" Dont come to me when youre lonely.', 'Scroll 1.11 "The Meadows" Hit it high up, lock to the target and glide it.', 'Scroll 1.12 "The Meadows" Busy as a bee, tranquil as an ox.', 'Scroll 1.13 "The Meadows" Dry it up, then soak it again.', 'Scroll 1.14 "The Meadows" Stop the press, stop the press, stop it.', 'Scroll 1.15 "The Meadows" Extremate again.', 'Scroll 1.16 "The Meadows" Youre just an NPC (Non-Playable Character)', 'Scroll 2.1 "Ecstacy" Happiness is a must.', 'Scroll 2.2 "Ecstacy" Company is equitable.', 'Scroll 2.3 "Ecstacy" Nano-particles', 'Scroll 2.4 "Ecstacy" Kill me softly, softly.', 'Scroll 2.5 "Ecstacy" Stop and just look and just listen.', 'Scroll 2.6 "Ecstacy" Indicate the trajectory, to come up with a map.', 'Scroll 2.7 "Ecstacy" Go far, go longing, go straight ahead!', 'Scroll 2.8 "Ecstacy" Hit me up on my phone.', 'Scroll 2.9 "Ecstacy" Projectile vomit sometimes.', 'Scroll 2.10 "Ecstacy" Build me up, continue.', 'Scroll 2.11 "Ecstacy" Build me a temple too.', 'Scroll 2.12 "Ecstacy" Supper is served.', 'Scroll 3.1 "The End" This poison, it got me.', 'Scroll 3.2 "The End" Never minding anything, I take flight.', 'Scroll 3.3 "The End" Its not even this, but you get my point.', 'Scroll 3.4 "The End" Quite experimental, yet successful in personal terms.', 'Scroll 3.5 "The End" This scroll means something to us.', 'Scroll 3.6 "The End" Indica or Sativa? or not at all, never?', 'Scroll 3.7 "The End" Pump it up.', 'Scroll 3.8 "The End" Run on your free time.']
        heBrews = (random.choice(heBrews1), random.choice(heBrews1), random.choice(heBrews1), random.choice(heBrews1))
        verse = random.sample(heBrews, 4)
        ct = datetime.datetime.now()
        brews = "heBrews:"
        print(brews, verse, ct)

    def teletubby():
        ct = datetime.datetime.now()
        print("You think of a command", ct)
        time.sleep(2)

    def herbs():
        while True:
            try:
                number = int(input("Indicate number of (herbals) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print()
        herbs = ["Acacia senegal - Gum arabic - A natural gum sourced from hardened sap of various species of acacia tree used in ancient birth control as well as a binder and emulsifier for medicinal compounds.", "Achillea millefolium - Common yarrow - Purported to be a diaphoretic, astringent, tonic, stimulant and mild aromatic.", "Actaea racemosa - Black cohosh - Historically used for arthritis and muscle pain, used more recently for conditions related to menopause and menstruation.", "Aesculus hippocastanum - Horse chestnut - Its seeds, leaves, bark, and flowers have been used medicinally for many centuries for treating joint pain, bladder and gastrointestinal problems, fever, leg cramps, and other conditions. It may be useful for treating chronic venous insufficiency. The raw plant materials are toxic unless processed.", "Ageratina altissima - White snakeroot - White snakeroot    Root tea has been used to treat diarrhea, kidney stones, and fever. A root poultice can be used on snakebites. The smoke from burning leaves is used to revive unconscious people. The plant contains the toxin tremetol which causes milk sickness, a sometimes fatal condition.", "Alcea rosea - Common hollyhock - Believed to be an emollient and laxative. It is used to control inflammation, to stop bedwetting and as a mouthwash in cases of bleeding gums.", "Alisma plantago-aquatica - Water-plantain - Used for the urinary tract.", "Allium sativum - Garlic - Purported use to lower blood cholesterol and high blood pressure.", "Aloe vera - Aloe vera - Leaves are widely used to heal burns, wounds and other skin ailments.", "Althaea officinalis - Marsh-mallow - Used historically as both a food and a medicine.", "Amorphophallus konjac - Konjac - Significant dietary source of glucomannan,[14] which is purported for use in treating obesity, constipation,[15] and reducing cholesterol.", "Anemone hepatica - Common hepatica - Historically used to treat liver diseases, it is still used in alternative medicine today. Other modern applications by herbalists include treatments for pimples, bronchitis and gout.", "Angelica archangelica - Garden angelica  - Roots have been used in the traditional Austrian medicine internally as tea or tincture for treatment of disorders of the gastrointestinal tract, respiratory tract, nervous system, and also against fever, infections, and flu.", "Angelica sinensis - Dong quai - Used for thousands of years in Asia, primarily in women's health.", "Apium graveolens - Celery - Seed is used only occasionally in tradition medicine. Modern usage is primarily as a diuretic.", "Arctium lappa - Burdock - Used traditionally as a diuretic and to lower blood sugar and, in traditional Chinese medicine as a treatment for sore throat and symptoms of the common cold.", "Arnica montana - Arnica - Used as an anti-inflammatory and for osteoarthritis. The US Food and Drug Administration has classified Arnica montana as an unsafe herb because of its toxicity. It should not be taken orally or applied to broken skin where absorption can occur.", "Astragalus propinquus - Astragalus - Long used in traditional Chinese medicine.", "Atropa belladonna - Belladonna - Although toxic, was used historically in Italy by women to enlarge their pupils, as well as a sedative, among other uses. The name itself means 'beautiful woman' in Italian.", "Azadirachta indica - Neem", "Used in India to treat worms, malaria, rheumatism and skin infections among many other things. Its many uses have led to neem being called 'the village dispensary' in India.", "Bellis perennis - Daisy - Flowers have been used in the traditional Austrian medicine internally as tea (or the leaves as a salad) for treatment of disorders of the gastrointestinal and respiratory tract.", "Berberis vulgaris - Barberry - Long history of medicinal use, dating back to the Middle Ages particularly among Native Americans. Uses have included skin ailments, scurvy and gastro-intestinal ailments.", "Borago officinalis - Borage - Used in hyperactive gastrointestinal, respiratory and cardiovascular disorders, such as gastrointestinal (colic, cramps, diarrhea), airways (asthma, bronchitis), cardiovascular, (cardiotonic, antihypertensive and blood purifier), urinary (diuretic and kidney/bladder disorders).", "Broussonetia kurzii - Salae - Known as Salae in Thailand where this species is valued as a medicinal plant.", "Calendula officinalis - Marigold - Also named calendula, has a long history of use in treating wounds and soothing skin.", "Cannabis - Hemp, Cannabis, Marijuana, Indian hemp, Ganja  - Used worldwide since ancient times as treatment for various conditions and ailments including pain, inflammation, gastrointestinal issues such as IBS, muscle relaxation, anxiety, Alzheimer's and dementia, ADHD, autism, cancer, cerebral palsy, recurring headaches, Crohn's disease, depression, epilepsy, glaucoma, insomnia, and neuropathy among others.", "Capsicum annuum - Cayenne - Type of chili that has been used as both food and medicine for thousands of years. Uses have included reducing pain and swelling, lowering triglyceride and cholesterol levels and fighting viruses and harmful bacteria, due to high levels of Vitamin C.", "Capsicum frutescens - Chili - Its active ingredient, capsaicine, is the basic of commercial pain-relief ointments in Western medicine. The low incidence of heart attack in Thais may be related to capsaicine's fibronolytic action (dissolving blood clots).", "Carica papaya - Papaya - Used for treating wounds and stomach troubles.", "Cassia occidentalis - Coffee senna - Used in a wide variety of roles in traditional medicine, including in particular as a broad-spectrum internal and external antimicrobial, for liver disorders, for intestinal worms and other parasites and as an immune-system stimulant.", "Catha edulis - Khat - Mild stimulant used for thousands of years in Yemen, and is banned today in many countries. Contains the amphetamine-like substance cathinone.", "Cayaponia espelina - São Caetano melon  - It is a diuretic and aid in the treatment of diarrhea and syphilis.", "Centaurea cyanus - Cornflower  - In herbalism, a decoction of cornflower is effective in treating conjunctivitis and as a wash for tired eyes.", "Chrysopogon zizanioides - Vetiver - Used for skin care.", "Cinchona spec. - Cinchona - Genus of about 38 species of trees whose bark is a source of alkaloids, including quinine. Its use as a febrifuge was first popularized in the 17th century by Peruvian Jesuits.", "Citrus × aurantium - Bitter orange - Used in traditional Chinese medicine and by indigenous peoples of the Amazon for nausea, indigestion and constipation.", "Citrus limon - Lemon - Along with other citruses, it has a long history of use in Chinese and Indian traditional medicine. In contemporary use, honey and lemon is common for treating coughs and sore throat.", "Citrus trifoliata - Trifoliate orange, bitter orange - Fruits of Citrus trifoliata are widely used in Oriental medicine as a treatment for allergic inflammation.", "Cissampelos pareira - Velvetleaf - Used for a wide variety of conditions.", "Cnicus benedictus - Blessed thistle - Used during the Middle Ages to treat bubonic plague. In modern times, herbal teas made from blessed thistle are used for loss of appetite, indigestion and other purposes.", "Crataegus monogyna and Crataegus laevigata - Hawthorn - Fruit has been used for centuries purportedly for heart disease, digestive and kidney related problems.", "Curcuma longa - Turmeric - Spice that lends its distinctive yellow color to Indian curries, has long been used in Ayurvedic and traditional Chinese medicine to aid digestion and liver function, relieve arthritis pain, and regulate menstruation.", "Cypripedium parviflorum - Yellow lady's slipper - The Cypripedium species have been used in native remedies for dermatitis, tooth aches, anxiety, headaches, as an antispasmodic, stimulant and sedative. However, the preferred species for use are Cyp. parviflorum and Cyp.acaule, used as topical applications or tea.", "Digitalis lanata - Digitalis or foxglove - It came into use in treating cardiac disease in late 18th century England in spite of its high toxicity.a Its use has been almost entirely replaced by the pharmaceutical derivative Digoxin, which has a shorter half-life in the body, and whose toxicity is therefore more easily managed. Digoxin is used as an antiarrhythmic agent and inotrope.[", "Echinacea purpurea - Purple coneflower - This plant and other species of Echinacea have been used for at least 400 years by Native Americans to treat infections and wounds, and as a general 'cure-all' (panacea). It is currently used for symptoms associated with cold and flu.", "Echinopsis pachanoi - San Pedro cactus - The San Pedro cactus contains the entheogen mescaline and has a long history of being used in Andean traditional medicine.", "Ephedra sinica - Ephedra - It has been used in traditional Chinese medicine for more than 2,000 years.[58][59] Native Americans and Mormon pioneers drank a tea brewed from other Ephedra species, called 'Mormon tea' and 'Indian tea'. It contains the alkaloids ephedrine and pseudoephedrine, which are used as breathing aids (bronchodilators and decongestants).", "Equisetum arvense - Horsetail - Dates back to ancient Roman and Greek medicine, when it was used to stop bleeding, heal ulcers and wounds, and treat tuberculosis and kidney problems.", "Eriodictyon crassifolium - Yerba Santa - Used by the Chumash people to keep airways open for proper breathing. The US Forest Service profile for Eriodictyon crassifolium provides information on species distribution; taxonomic relationships; ecological and evolutionary considerations for restoration; growth form and distinguishing traits; habitat characteristics; projected future suitable habitat; growth, reproduction and dispersal; biological interactions; ecological genetics; seed characteristics, germination requirements and processing; and plant uses including agriculture, restoration, and traditional products, plus an extensive bibliography. It is part of Riverside-Corona Resource Conservation District's resource materials collection on native plant recommendations for southern California ecoregions.", "Erythroxylum coca - Coca - Used as coca tea or chewed, traditionally as a stimulant to overcome fatigue, hunger, thirst, and altitude sickness.[64] Also used as an anesthetic and analgesic.", "Eschscholzia californica - Californian poppy - Used as a herbal remedy: an aqueous extract of the plant has sedative and anxiolytic actions.", "Eucalyptus globulus - Eucalyptus - Leaves were widely used in traditional medicine as a febrifuge.[67] Eucalyptus oil is commonly used in over-the-counter cough and cold medications, as well as for an analgesic.", "Euonymus atropurpureus - Wahoo - Plant is a purgative and might affect the heart.", "Euphorbia hirta - Asthma-plant - Used traditionally in Asia to treat bronchitic asthma and laryngeal spasm. It is used in the Philippines for dengue fever.", "Euphrasia - Eyebright - Used for eye problems, mental depression, oxygenation and radiation poisoning.", "Euterpe oleracea - Açai - Although açai berries are a longstanding food source for indigenous people of the Amazon, there is no evidence that they have effectiveness for any health-related purpose.", "Ferula assa-foetida - Asafoetida - Might be useful for IBS, high cholesterol, and breathing problems.", "Frangula alnus - Alder buckthorn - Bark (and to a lesser extent the fruit) has been used as a laxative, due to its 3 – 7% anthraquinone content. Bark for medicinal use is dried and stored for a year before use, as fresh bark is violently purgative; even dried bark can be dangerous if taken in excess.", "Fumaria officinalis - Fumitory - Traditionally thought to be good for the eyes and to remove skin blemishes. In modern times herbalists use it to treat skin diseases and conjunctivitis, as well as to cleanse the kidneys. However, Howard (1987) warns that fumitory is poisonous and should only be used under the direction of a medical herbalist.", "Galanthus - Snowdrop - It contains an active substance called galantamine, which is an acetylcholinesterase inhibitor. Galantamine (or galanthamine) can be helpful in the treatment of Alzheimer's disease, though it is not a cure.", "Geranium robertianum - Robert geranium  - In traditional herbalism, it was used as a remedy for toothache and nosebleeds[79] and as a vulnerary (used for or useful in healing wounds).", "Ginkgo biloba - Ginkgo - The leaf extract has been used to treat asthma, bronchitis, fatigue, Alzheimer's and tinnitus.", "Glechoma hederacea - Ground-ivy - It has been used as a 'lung herb'. Other traditional uses include as an expectorant, astringent, and to treat bronchitis. The essential oil of the plant has been used for centuries as a general tonic for colds and coughs, and to relieve congestion of the mucous membranes.", "Glycyrrhiza glabra - Licorice root - Purported uses include stomach ulcers, bronchitis, and sore throat.", "Hamamelis virginiana - Common witch-hazel - It produces a specific kind of tannins called hamamelitannins. One of those substances displays a specific cytotoxic activity against colon cancer cells.", "Hippophae rhamnoides - Sea buckthorn - The leaves are used as herbal medicine to alleviate cough and fever, pain, and general gastrointestinal disorders as well as to cure dermatologic disorders. Similarly, the fruit juice and oils can be used in the treatment of liver disease, gastrointestinal disorders, chronic wounds or other dermatological disorders.", "Hoodia gordonii - Hoodia - The plant is traditionally used by Kalahari San (Bushmen) to reduce hunger and thirst. It is marketed as an appetite suppressant.", "Hydrastis canadensis - Goldenseal - Although used traditionally by Native Americans to treat skin diseases and ulcers, there is no scientific evidence to support the use of goldenseal for treating any disease.", "Hypericum perforatum - St. John's wort - Widely used within herbalism for depression. Evaluated for use as an antidepressant, but with ambiguous results.", "Hyssopus officinalis - Hyssop - It is purported for digestive and intestinal problems, and for respiratory problems.", "Ilex paraguariensis - Yerba mate - Mate contains compounds that may improve mood.", "Illicium verum - Star anise - It is the major source of the chemical compound shikimic acid, a primary precursor in the pharmaceutical synthesis of anti-influenza drug oseltamivir (Tamiflu).", "Inula helenium - Elecampane - It is used in herbal medicine as an expectorant and for water retention.", "Jasminum officinale - Jasmine - It is purported as either an antiseptic or anti-inflammatory agent.", "Knautia arvensis - Field scabious - The whole plant is astringent and mildly diuretic.", "Larrea tridentata - Chaparral - The leaves and twigs are used by Native Americans to make a herbal tea used for a variety of conditions. Chaparral has also been shown to have high liver toxicity, and has led to kidney failure, and is not recommended for any use by the U.S. Food and Drug Administration or American Cancer Society.", "Laurus nobilis - Bay laurel - Aqueous extracts of bay laurel can be used as astringents and even as a reasonable salve for open wounds.", "Lavandula angustifolia - Lavender - It was traditionally used as an antiseptic and for mental health purposes. It was also used in ancient Egypt in mummifying bodies. There is little scientific evidence that use of lavender affects health.", "Lawsonia inermis - Henna", "Leucojum aestivum - Summer snowflake", "Linum usitatissimum - Flaxseed - The plant is most commonly used as a laxative. Flaxseed oil is used for different conditions, including arthritis.", "Magnolia officinalis - Magnolia-bark - The bark contains magnolol and honokiol, two polyphenolic compounds.", "Malva sylvestris - Mallow - The seeds are used internally in a decoction or herbal tea as a demulcent and diuretic, and the leaves made into poultices as an emollient for external applications. ",\
         "Matricaria recutita and Anthemis nobilis - Chamomile - It has been used over history for a variety of conditions, including sleeplessness and anxiety.", "Medicago sativa - Alfalfa - The leaves are purported to lower cholesterol, and treat kidney and urinary tract ailments, although there is insufficient scientific evidence for its efficacy.", "Melaleuca alternifolia - Tea tree oil - It has been used over history by Australian aboriginal people. Modern usage is primarily as an antibacterial or antifungal agent, but there is insufficient scientific evidence for such effects.", "Melissa officinalis - Lemon balm - Lemon balm  It is purported as a sleep aid and digestive aid.", "Mentha x piperita - Peppermint - Its oil, from a cross between water mint and spearmint, has a history of purported use for various conditions, including nausea, indigestion, and symptoms of the common cold.", "Mitragyna speciosa - Kratom - Kratom leaves are chewed to relieve musculoskeletal pain and increase energy, appetite, and sexual desire in ways similar to khat and coca.", "Momordica charantia - Bitter melon", "Morinda citrifolia - Noni - It is purported for joint pain and skin conditions.", "Moringa oleifera - Drumstick tree  - It is used for food and traditional medicine.", "Nasturtium officinale - Watercress", "Nelumbo nucifera - Lotus - Insufficient evidence for any biological effect.", "Nigella sativa - Nigella, black-caraway, black-cumin, and kalonji - One meta-analysis of clinical trials concluded that N. sativa has a short-term benefit on lowering systolic and diastolic blood pressure.", "Ocimum tenuiflorum - Tulsi or holy basil - It is used for a variety of purposes in traditional medicine; tulsi is taken in many forms: as herbal tea, dried powder, fresh leaf or mixed with ghee. Essential oil extracted from Karpoora tulasi is mostly used for medicinal purposes and in herbal cosmetics.", "Oenothera - Evening primrose - Its oil has been used since the 1930s for eczema, and more recently as an anti-inflammatory, but there is insufficient evidence for it having any effect.", "Origanum vulgare - Oregano", "Panax spec. - Ginseng - Asian ginseng may affect glucose metabolism and lower blood sugar levels, but the poor quality of research prevents conclusions about such effects.", "Papaver somniferum - Opium poppy - The plant is the plant source of morphine, used for pain relief. Morphine made from the refined and modified sap is used for pain control in people with severe cancer.", "Passiflora - Passion flower", "Peganum harmala - Syrian Rue (common name Harmal)", "Pelargonium sidoides - Umckaloabo, or South African Geranium - Possibly useful for treating respiratory infections.", "Piper methysticum - Kava - The plant has been used for centuries in the South Pacific to make a ceremonial drink with sedative and anesthetic properties, with potential for causing liver injury.", "Piscidia erythrina / Piscidia piscipula - Jamaica dogwood - The plant is used in traditional medicine for the treatment of insomnia and anxiety, despite serious safety concerns. A 2006 study suggested medicinal potential.", "Plantago lanceolata - Plantain - It is used frequently in herbal teas and other herbal remedies. A tea from the leaves is used as a highly effective cough medicine. In the traditional Austrian medicine Plantago lanceolata leaves have been used internally (as syrup or tea) or externally (fresh leaves) for treatment of disorders of the respiratory tract, skin, insect bites, and infections.", "Platycodon grandiflorus - Platycodon, balloon flower - The extracts and purified platycoside compounds (saponins) from the roots may exhibit neuroprotective, antimicrobial, anti-inflammatory, anti-cancer, anti-allergy, improved insulin resistance, and cholesterol-lowering properties.", "Polemonium reptans - Abscess root - It is used to reduce fever, inflammation, and cough.", "Psidium guajava - Guava - It has a rich history of use in traditional medicine. It is traditionally used to treat diarrhea; however, evidence of its effectiveness is very limited.", "Ptelea trifoliata - Wafer Ash - The root bark is used for the digestive system. Also known as hoptree.", "Pulmonaria officinalis - Lungwort - Used since the Middle Ages to treat and/or heal various ailments of the lungs and chest", "Quassia amara - Amargo, bitter-wood - A 2012 study found a topical gel with 4% Quassia extract to be a safe and effective cure of rosacea.", "Reichardia tingitana - False sowthistle - Uses in folk medicine have been recorded in the Middle East, its leaves being used to treat ailments such as constipation, colic and inflamed eyes.", "Rosa majalis - Cinnamon rose - It yields edible hip fruits rich in vitamin C, which are used in medicine and to produce rose hip syrup.", "Rosmarinus officinalis - Rosemary - It has been used medicinally from ancient times.", "Ruellia tuberosa - Minnieroot, fever root, snapdragon root - In folk medicine and Ayurvedic medicine it has been used as a diuretic, anti-diabetic, antipyretic, analgesic, antihypertensive, gastroprotective, and to treat gonorrhea.", "Rumex crispus - Curly dock or yellow dock  - In Western herbalism the root is often used for treating anemia, due to its high level of iron. The plant will help with skin conditions if taken internally or applied externally to things like itching, scrofula, and sores. It is also used for respiratory conditions, specifically those with a tickling cough that is worse when exposed to cold air. It mentions also passing pains, excessive itching, and that it helps enlarged lymphs.", "Salix alba - White willow - Plant source of salicylic acid, white willow is like the chemical known as aspirin, although more likely to cause stomach upset as a side effect than aspirin itself which can cause the lining of the stomach to be destroyed. Used from ancient times for the same uses as aspirin.", "Salvia officinalis - Sage - Shown to improve cognitive function in patients with mild to moderate Alzheimer's disease.", "Sambucus nigra - Elderberry - The berries and leaves have traditionally been used to treat pain, swelling, infections, coughs, and skin conditions and, more recently, flu, common cold, fevers, constipation, and sinus infections.", "Santalum album - Indian sandalwood - Sandalwood oil has been widely used in folk medicine for treatment of common colds, bronchitis, skin disorders, heart ailments, general weakness, fever, infection of the urinary tract, inflammation of the mouth and pharynx, liver and gallbladder complaints and other maladies.", "Santolina chamaecyparissus - Cotton lavender - Most commonly, the flowers and leaves are made into a decoction used to expel intestinal parasites.", "Saraca indica - Ashoka tree - The plant is used in Ayurvedic traditions to treat gynecological disorders. The bark is also used to combat oedema or swelling.", "Satureja hortensis - Summer savory - Its extracts show antibacterial and antifungal effects on several species including some of the antibiotic resistant strains.", "Sceletium tortuosum - Kanna - African treatment for depression. Suggested to be an SSRI or have similar effects, but unknown mechanism of activity.", "Senna auriculata - Avaram senna - The root is used in decoctions against fevers, diabetes, diseases of urinary system and constipation. The leaves have laxative properties. The dried flowers and flower buds are used as a substitute for tea in case of diabetes patients. The powdered seed is also applied to the eye, in case of chronic purulent conjunctivitis.", "Sesuvium portulacastrum - Shoreline purslane - The plant extract showed antibacterial and anticandidal activities and moderate antifungal activity.", "Silybum marianum - Milk thistle - It has been used for thousands of years for a variety of medicinal purposes, in particular liver problems.", "Stachytarpheta cayennensis - Blue snakeweed - Extracts of the plant are used to ease the symptoms of malaria. The boiled juice or a tea made from the leaves or the whole plant is taken to relieve fever and other symptoms. It is also used for dysentery, pain, and liver disorders. A tea of the leaves is taken to help control diabetes in Peru and other areas. Laboratory tests indicate that the plant has anti-inflammatory properties.", "Stellaria media - Common chickweed - It has been used as a remedy to treat itchy skin conditions and pulmonary diseases. 17th century herbalist John Gerard recommended it as a remedy for mange. Modern herbalists prescribe it for iron-deficiency anemia (for its high iron content), as well as for skin diseases, bronchitis, rheumatic pains, arthritis and period pain.", "Strobilanthes callosus - Karvy - The plant is anti-inflammatory, antimicrobial, and anti-rheumatic.", "Symphytum officinale - Comfrey - It has been used as a vulnerary and to reduce inflammation. It was also used internally in the past, for stomach and other ailments, but its toxicity has led a number of other countries, including Canada, Brazil, Australia, and the United Kingdom, to severely restrict or ban the use of comfrey.", "Syzygium aromaticum - Clove - The plant is used for upset stomach and as an expectorant, among other purposes. The oil is used topically to treat toothache.", "Tanacetum parthenium - Feverfew - The plant has been used for centuries for fevers, headaches, stomach aches, toothaches, insect bites and other conditions.", "Taraxacum officinale - Dandelion - It was most commonly used historically to treat liver diseases, kidney diseases, and spleen problems.", "Teucrium scordium - Water germander - It has been used for asthma, diarrhea, fever, intestinal parasites, hemorrhoids, and wounds.", "Thymus vulgaris - Thyme - The plant is used to treat bronchitis and cough. It serves as an antispasmodic and expectorant in this role. It has also been used in many other medicinal roles in Asian and Ayurvedic medicine, although it has not been shown to be effective in non-respiratory medicinal roles.", "Tilia cordata - Small-leaved linden - In the countries of Central, Southern and Western Europe, linden flowers are a traditional herbal remedy made into a herbal tea called tisane.", "Tradescantia zebrina - Inchplant - It is used in southeast Mexico in the region of Tabasco as a cold herbal tea, which is named Matali. Skin irritation may result from repeated contact with or prolonged handling of the plant, particularly from the clear, watery sap (a characteristic unique to T. zebrina as compared with other types).", "Trema orientalis - Charcoal-tree - The leaves and the bark are used to treat coughs, sore throats, asthma, bronchitis, gonorrhea, yellow fever, toothache, and as an antidote to general poisoning.", "Trifolium pratense - Red clover - The plant is an ingredient in some recipes for essiac tea. Research has found no benefit for any human health conditions.", "Trigonella foenum-graecum - Fenugreek - It has long been used to treat symptoms of menopause, and digestive ailments. More recently, it has been used to treat diabetes, loss of appetite and other conditions.", "Triticum aestivum - Wheatgrass - It may contain antioxidant and anti-inflammatory compounds.", "Turnera subulata - White buttercup - It is used for skin, gastrointestinal, and respiratory ailments.", "Uncaria tomentosa - Cat's claw - It has a long history of use in South America to prevent and treat disease.", "Urtica dioica - Common nettle, stinging nettle - It has been used in the traditional Austrian medicine internally (as tea or fresh leaves) to treat disorders of the kidneys and urinary tract, gastrointestinal tract, locomotor system, skin, cardiovascular system, hemorrhage, influenza, rheumatism, and gout.", "Vaccinium spec. - Blueberries - They are of current medical interest as an antioxidant and for urinary tract ailments.", "Vaccinium macrocarpon - Cranberry - It was used historically as a vulnerary and for urinary disorders, diarrhea, diabetes, stomach ailments, and liver problems. Modern usage has concentrated on urinary tract related problems.", "Vaccinium myrtillus - Bilberry - It is used to treat diarrhea, scurvy, and other conditions.", "Valeriana officinalis - Valerian - It has been used since at least ancient Greece and Rome for sleep disorders and anxiety.", "Verbascum thapsus - Common mullein  - It contains glycyrrhizin compounds with bactericide and potential anti-tumoral action. These compounds are concentrated in the flowers.", "Verbena officinalis - Verbena - It is used for sore throats and respiratory tract diseases.", "Vernonia amygdalina - Bitter leaf - The plant is used by both primates and indigenous peoples in Africa to treat intestinal ailments such as dysentery.", "Veronica officinalis - Veronica - The plant is used for sinus and ear infections.", "Viburnum tinus - Laurustinus - V. tinus has medicinal properties. The active ingredients are viburnin (a substance or more probably a mixture of compounds) and tannins. Tannins can cause stomach upset. The leaves when infused have antipyretic properties. The fruits have been used as purgatives against constipation. The tincture has been used lately in herbal medicine as a remedy for depression. The plant also contains iridoid glucosides.", "Viola tricolor - Wild pansy - It is one of many viola plant species containing cyclotides. These small peptides have proven to be useful in drug development due to their size and structure giving rise to high stability. Many cyclotides, found in Viola tricolor are cytotoxic. This feature means that it could be used to treat cancers.", "Viscum album - European mistletoe - It has been used to treat seizures, headaches, and other conditions.", "Vitex agnus-castus - Chasteberry - It has been used for over thousands of years for menstrual problems, and to stimulate lactation.", "Vitis vinifera - Grape - The leaves and fruit have been used medicinally since the ancient Greeks.", "Withania somnifera -   Ashwagandha - The plant's long, brown, tuberous roots are used in traditional medicine. In Ayurveda, the berries and leaves are applied externally to tumors, tubercular glands, carbuncles, and ulcers.", "Xanthoparmelia scabrosa - Sexy footpath lichen - It is a lichen used for sexual dysfunction.", "Youngia japonica -      Japanese hawkweed - The plant is antitussive and febrifuge. It is also used in the treatment of boils and snakebites.", "Zingiber officinale - Ginger - Ginger is effective for the relief of nausea."]
        herbal = random.sample(herbs, number)
        h = "herbals:"
        letters1 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters2 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters3 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters4 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters5 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letter1 = random.sample(letters1, 1)
        letter2 = random.sample(letters2, 1)
        letter3 = random.sample(letters3, 1)
        letter4 = random.sample(letters4, 1)
        letter5 = random.sample(letters5, 1)
        value = (round(random.random()*9999999999,10))
        ct = datetime.datetime.now()
        print(h, letter1, letter2, letter3, letter4, letter5, value, herbal, ct)

    def legal_terms():
        dd = list(legal_terms1)
        while True:
            try:
                number = int(input("Indicate number of (legal_terms) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print()
        law = random.sample(dd, number)
        ct = datetime.datetime.now()
        l = "law:"
        print(l, law, ct)

    def degree():
        dd = list(degrees1)
        while True:
            try:
                number = int(input("Indicate number of (degree/major) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print()
        degree = random.sample(dd, number)
        value = (round(random.random()*9999,4))
        d = "degree/major:"
        bu = "-from Boston University website (bu.edu)"
        ct = datetime.datetime.now()
        print(d, value, degree, ct)
        print()
        print(bu)

    def biology():
        dd = list(biology1)
        while True:
            try:
                number = int(input("Indicate number of (biology) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(0)
        print()
        b = random.sample(dd, number)
        ct = datetime.datetime.now()
        bio = "biology:"
        print(bio, b, ct)

    def chemistry():
        dd = list(chemistry1)
        while True:
            try:
                number = int(input("Indicate number of (chemistry) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        print()
        time.sleep(.4)
        ch = random.sample(dd, number)
        ct = datetime.datetime.now()
        chem = "chemistry:"
        print(chem, ch, ct)

    def patient_simu():
        time.sleep(0)
        print()
        t_time = datetime.datetime.now()
        patient = "PATIENT:"
        initials = ["A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z"]
        name = random.sample(initials, 1)
        surname = random.sample(initials, 1)
        n = "name:"
        ages = (round(random.random()*100))
        age = "age:"
        genders = ["male", "female"]
        gender = random.sample(genders, 1)
        g = "gender:"
        localities = ["local", "global"]
        locality = random.sample(localities, 1)
        l = "locality:"
        temperature = random.randrange(25, 45)
        temp = "body temperature:"
        pulse = random.randrange(30, 200)
        pu = "pulse rate:"
        respiration = random.randrange(5, 45)
        rr = "respiration rate:"
        bloodp = ["normal", "normal", "normal", "elevated", "elevated", "stage 1", "stage 2"]
        pressure = random.sample(bloodp, 1)
        bp = "blood pressure:"
        symptoms1 = ["chills", "fever", "numbness and/or tingling and/or electric tweaks", "light-headed", "dizzy", "mouth is dry", "nauseated", "sick (flu, need to vomit etc.)", "short of breath", "sleepy", "sweaty", "thirsty", "tired", "weak",  "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a"]
        symptoms = (random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1), random.choice(symptoms1))
        symptom = random.sample(symptoms, random.randint(1,12))
        s = "symptoms:"
        others1 = ["can't breathe normally", "losing hearing", "sounds are too loud", "ringing or hissing in my ears", "can't move one side", "can't defecate normally", "can't urinate normally", "can't remember normally", "blindness", "double vision", "blurred vision", "can't sleep normally", "can't smell things normally", "can't speak normally", "can't excrete solid feces", "can't stop scratching", "can't stop sweating", "can't swallow normally", "can't taste properly", "can't walk normally", "can't write normally", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", ]
        others = (random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), random.choice(others1), )
        osymptoms = random.sample(others, random.randint(1,12))
        othersy = "other symptoms:"
        msymptoms1 = ["anxiety", "social phobias", "panic disorders", "obsessive compulsive disorder", "post-traumatic stress disorder", "opossitional defiant disorder", "conduct disorder", "attention deficit hyperactivity disorder", "bipolar disorder", "depression", "amnesia", "depersonalisation disorder" ,"dissociative identity disorder", "anorexia", "bulimia nervosa", "binge eating disorder", "paranoid personality disorder", "delusional (paranoid) disorder" ,"schizophrenia", "post-traumatic stress disorder", "psychosis", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a", "n/a"]
        msymptoms = (random.choice(msymptoms1), random.choice(msymptoms1))
        missue = random.sample(msymptoms, 2)
        m = "mental issue:"
        print(t_time, patient, n, name, surname, age, ages, g, gender, l, locality, temp, temperature, pu, pulse, rr, respiration, bp, pressure, s, symptom, othersy, osymptoms, m, missue)

    def earth_science():
        dd = list(science1)
        while True:
            try:
                number = int(input("Indicate number of (earth_science) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print
        earth = random.sample(dd, number)
        ct = datetime.datetime.now()
        sci = "earth science:"
        print(sci, earth, ct)

    def psychology():
        dd = list(psychology1)
        while True:
            try:
                number = int(input("Indicate number of (psychology) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(0)
        print()
        psych = random.sample(dd, number)
        ct = datetime.datetime.now()
        p = "psychology:"
        print(p, psych, ct)

    def medicals():
        dd = list(medicals1)
        while True:
            try:
                number = int(input("Indicate number of (medical) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(0)
        print()
        medical = random.sample(dd, number)
        ct = datetime.datetime.now()
        med = "Medicals:"
        print(med, medical, ct)

    def license():
        license = ["You have no license", "You have no license", "You have a license"]
        lice = random.sample(license, 1)
        ct = datetime.datetime.now()
        lic = "License:"
        print(lic, lice, ct)

    def police():
        time.sleep(0)
        code = ["Code Red", "Code Blue", "Code Green", "Code Orange", "Code Yellow", "Code Black", "Code White", "Code Purple", "Code Pink"]
        cod = random.sample(code, 1)
        urgency = ["Critical", "High", "Medium", "Low", "Lowest"]
        urge = random.sample(urgency, 1)
        polis = ["3511 A vehicle that has been impounded for a mandatory 30 days", "A.P.S. Arizona Public Service", "A.S.A.P. As soon as possible", "A.T.F. Bureau of Alcohol, Tobacco, and Firearms", "BAILED OUT Subject jumped out of car and ran", "BYFRND Boyfriend", "BEER RUN Shoplifting beer", "BONDOUT Prisoner who is going to post bail and be released", "BEEN MADE/BURNED Undercover officer's ID is known", "BHND Behind", "BIKE Motorcycle", "BIKERS Motorcycle riders", "BOOKING Booking prisoner into jail", "BREAKING UP Radio transmissions are not being received clearly", "BUSTED Arrested", "C.C.W. Carrying concealed weapon", "C.O. Civilian observer", "COMP Complainant", "C.L.D. Citation in lieu of detention", "CRACK, ROCK Smokeable form of cocaine", "D.E.B. Drug Enforcement Bureau", "DIX Detectives", "D.O.A. Dead on arrival", "D.O.B. Date of birth", "D.O.C. Department of Corrections", "D.P.S. Department of Public Safety", "DRIVE BY Shots fired from a moving vehicle", "E.O.C. Emergency Operations Center", "EQUIPMENT Police vehicle", "E.R. Emergency Room", "E.T.A. Estimated time of arrival", "F.A.A. Federal Aviation Administration", "B.I. Federal Bureau of Investigation", "F.I. Field Interrogation (Form 36 card)", "FILE STOP Notation put in police record; File Stops are confirmed by R&I Bureau", "FLIR Device used by aircraft to check for heat sources", "F.O.J. From other jurisdiction", "FRONT DESK Information Desk at main station", "FUGITIVE A wanted person", "GAS WASH/WASHDOWN Fire Department needed to wash gas down", "G.C.I. /B.A. Test used to determine blood alcohol content", "G.I.B. General Investigations Bureau", "GOT THE EYE In view (on a code 5)", "GRN Green", "HOND Honda", "HIT Subject or item wanted", "H.G.N. Horizontal Gaze Nystagmus (a test for detecting drug / alcohol use)", "HOBBLES Nylon rope used for legs and hand restraint", "HOOK Wrecker", "HSE House", "ICE, CRYSTAL Smokeable methamphetamine", "J.C.C. Juvenile Corrections Center", "J.P. Justice of the Peace", "JUMPED ON Assaulted", "JUMPER Person attempting suicide by jumping", "LADDER Fire Department ladder truck", "MARQUIS Test for narcotics", "M.D.C. Mobile Digital Computer (Police car computer)", "MEDICS Paramedics", "MERZ Mercedes Benz", "MHP Mobile Home Park", "MOTOR Solo motor unit", "NUMBER 1 SITUATION Probable cause for arrest", "NUMBER 9's Citations", "OD Overdose", "ONE FROM LIST Contract wrecker (926)", "ONE ON ONE Suspect / witness I.D.", "ONE ROLL Fingerprints", "O.V. On view, officer just witnessed an incident", "PAGE 2 Additional charges filed on a subject already in custody", "P.C. Probable cause", "PLE Purple", "P.O. Probation officer", "RESTRAINTS Leather straps used to restrain prisoners", "RINGER Audible alarm", "ROLLOVER Accident involving overturned vehicle", "R.P. Responsible party", "S/E/C Southeast corner", "SEIZURE Impound a vehicle; subject having convulsions", "SGT Sergeant", "SILENT Silent alarm", "SLIM JIM Device used to open locked vehicle", "SMASH & GRAB Broke out window, grabbed items and ran", "S.O./M.C.S.O. Maricopa County Sheriff's Office", "S.R.P. Salt River Project", "STRIPPED Vehicle stripped", "TECH Radio or computer technician", "THIRTY-SIX Field interrogation (or form 36)", "THREE WHEELER Police 3-wheeled motorcycle", "TILL TAP Grab money from register", "DISPATCH AN ANIMAL To shoot an animal", "TRAFFIC BOX KEY Key used to open traffic signal control box", "XHUSB Ex-husband", "WAGON/WAGON Police paddy wagon"]
        pol = random.sample(polis, random.randint(1, 8))
        locate = ["Local", "Local", "Foreign"]
        loc = random.sample(locate, 1)
        direction = ["South", "North", "West", "East", "Southwest", "Southeast", "Northwest", "Northeast"]
        dire = random.sample(direction, 1)
        suspectcode = (round(random.random()*26))
        sus = "Suspect Code:"
        location = (round(random.random()*99999999,10))
        ct = datetime.datetime.now()
        po = "police:"
        print(po, cod, urge, sus, suspectcode, pol, loc, dire, location, ct)

    def clearance():
        time.sleep(0)
        clearance = ["You are not cleared", "You are cleared"]
        clear = random.sample(clearance, 1)
        ct = datetime.datetime.now()
        med = "Clearance:"
        print(med, clear, ct)

    def entry():
        _entry = "Entry: "
        gates = ["Gate 1", "Gate 2", "Gate 3", "Gate 4", "Gate 5", "Gate 6", "Gate 7", "Gate 8", "Gate 9"]
        phases = ["Phase 1", "Phase 2", "Phase 3", "Phase 4", "Phase 5", "Phase 6", "Phase 7", "Phase 8", "Phase 9", "Phase 10"]
        floors = (round(random.random()*102))
        _floor = "Floor"
        gate = random.sample(gates, 1)
        phase = random.sample(phases, 1)
        rooms = (round(random.random()*102))
        ct = datetime.datetime.now()
        _room = "Room"
        print(_entry, gate, phase, _floor, floors, _room, rooms, ct)

    def zuz():
        dd = (diction)
        ct = datetime.datetime.now()
        nano = (random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd))
        result = random.sample(nano, random.randint(1, 6))
        sitar = ">"
        random_result = [random.choice(dd)]
        result_text = ", ".join(random_result)
        speak(result_text)
        print(sitar, result_text, result, ct)

    def micasa():
        time.sleep(1)
        mic = "home:"
        rooms = ["living room", "kitchen", "bedroom", "garden", "patio", "guest room", "garage", "work room", "library", "art room", "meditation room", "bath room", "temple"]
        micasa = random.sample(rooms, 1)
        ct = datetime.datetime.now()
        print(mic, micasa, ct)

    def stuff():
        stu = "stuff:"
        stuffd = ["sofa", "tv", "radio", "computer", "tablet", "phone", "refrigerator", "bed", "sink", "oven", "stove", "clock", "refreshments", "snacks", "cookies", "easel", "sketchpad", "laptop", "postcard", "table", "study table", "desk", "kitchen counter", "bible", "dining table", "chair", "gaming chair", "lamp", "light", "fruit", "speaker", "guitar", "piano", "synthesizer", "photo", "painting", "cdj", "vinyl", "electric guitar", "bass guitar", "monitor", "camera", "vinyl player", "gun", "iPod", "cctv", "bike", "car", "window", "door", "sweater", "ps5", "pillow", "blanket", "clothes", "dresser", "safe", "dhammapada", "keyboard", "koran", "paint", "paper", "brush", "tree", "pencil", "spraypaint", "drawing tablet", "drawing", "buddha", "air conditioner", "duster", "walkie", "grass", "mirror", "tools", "pen", "magazine", "book", "carpet", "mat", "zafu", "weed", "kush"]
        stuff = (random.choice(stuffd), random.choice(stuffd), random.choice(stuffd), random.choice(stuffd), random.choice(stuffd), random.choice(stuffd), random.choice(stuffd), random.choice(stuffd))
        stuffs = random.sample(stuff, random.randint(1, 8))
        ct = datetime.datetime.now()
        print(stu, stuffs, ct)

    def worship():
        ct = datetime.datetime.now()
        time.sleep(1)
        wor = "worship:"
        worship = "You worship in silence.."
        print(wor, worship, ct)
        time.sleep(3)

    def posting():
        ct = datetime.datetime.now()
        _have = "You have"
        _posting = "job postings with"
        _default = "defaults"
        _post = "Posting:"
        postings = (round(random.random()*5))
        defaults = (round(random.random()*15))
        print(_post, _have, postings, _posting, defaults, _default, ct)

    def speech(text):
        if platform.system() == "Linux" and shutil.which("termux-tts-speak"):
            try:
                subprocess.run(["termux-tts-speak", text], check=True)
                return
            except subprocess.CalledProcessError as e:
                print(f"Termux-TTS error: {e}")
            except FileNotFoundError:
                pass

        if shutil.which("espeak"):
            try:
                if platform.system() == "Windows":
                    subprocess.run(["espeak", text], check=True)
                else:
                    subprocess.run(["espeak", text], check=True)
                return
            except subprocess.CalledProcessError as e:
                print(f"eSpeak error: {e}")
                return
            except Exception as e:
                print(f"An unexpected error occurred with eSpeak: {e}")
                return d
               
    def muslim_prayer():
        def prayer():
            time.sleep(3)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            speech("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            time.sleep(8)
            print()
            print("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            speech("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            time.sleep(8)
            print()
            print("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")
            speech("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")        
            time.sleep(9)
            print()
            print("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            speech("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            time.sleep(9)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)

        def main_loop():
            prayer()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def muslim_prayer2():
        def prayer():
            time.sleep(3)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")        
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            speech("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            time.sleep(8)
            print()
            print("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            speech("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            time.sleep(8)
            print()
            print("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")
            speech("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")
            time.sleep(9)
            print()
            print("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            speech("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            time.sleep(9)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)

        def main_loop():
            prayer()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def muslim_prayer3():
        def prayer():
            time.sleep(3)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")        
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            speech("All compliments, prayers, and pure words are due to Allah, Peace be upon you oh Prophet and the mercy of Allah and his blessings")
            time.sleep(8)
            print()
            print("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            speech("Peace be upon us and upon the righteous slaves of Allah, I bear witness that there is no God except Allah and I bear witness that Muhammad is his slave and messenger")
            time.sleep(8)
            print()
            print("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")
            speech("Oh Allah, bless Muhammad and the family of Muhammad as you blessed Ibrahim and the family of Ibrahim.. You are indeed worthy of praise, full of glory")
            time.sleep(9)
            print()
            print("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            speech("Oh Allah, send prayers upon Muhammad and the family of Muhammad as you sent prayers upon Ibrahim and the family of Ibrahim.. you are indeed worthy of praise, full of glory")
            time.sleep(9)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            speech("Allah hears those who praise him, our Lord all praise is for you, praise which is abundant, excellent, and blessed")
            time.sleep(6)
            print()
            print("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            speech("Glorious is my Lord the most Great, Glorious is my Lord the most great, Glorious is my Lord the most great")
            time.sleep(4)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(2)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            speech("Oh Allah, forgive me, have mercy on me, strengthen me, raise me in status, pardon me and grant me provision")
            time.sleep(8)
            print()
            print("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            speech("Glorious is my Lord the most high, Glorious is my Lord the most high, Glorious is my Lord the most high")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            speech("Assalamu Alaikum Wa Rammatullahi Wa Barakatuhu")
            time.sleep(5)
            print()
            print("Allah Hu Akbar")
            speech("Allah Hu Akbar")
            time.sleep(5)

        def main_loop():
            prayer()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def meditate():
        while True:
            try:
                number = int(input("Enter meditation time in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        ct = datetime.datetime.now()
        print()
        print("You sit and start to meditate...", ct)
        time.sleep(number)
        print("You finished meditating", ct)
        time.sleep(3)

    def sleep():
        ct = datetime.datetime.now()
        print("You lay down and doze off...", ct)
        time.sleep(29)
        print("You wake up", ct)
        time.sleep(3)

    def eat():
        ct = datetime.datetime.now()
        print("You prepare food and start to consume a meal...")
        time.sleep(5)
        print("You have eaten", ct)
        time.sleep(3)

    def find_coins():
        ct = datetime.datetime.now()
        print("You start to search around for coins...")
        time.sleep(10)
        print("You found:")
        tin = (random.randint(0,100))
        coins = "coins: "
        print(coins, tin, ct)
        time.sleep(3)

    def slot():
        ct = datetime.datetime.now()
        print("You pull on the slot lever...")
        time.sleep(5)
        slot = random.choices(range(10), k=3)
        slots = "slot: "
        print(slots, slot, ct)
        time.sleep(3)

    def draw_card():
        dd = list(deck1)
        while True:
            try:
                number = int(input("Enter number of cards: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        ct = datetime.datetime.now()
        print()
        print("You draw a card from a deck...")
        time.sleep(2)
        card = random.sample(dd, number)
        print("You drew:")
        cards = "card: "
        print(cards, card, ct)
        time.sleep(3)

    def search_for_items():
        print("You search around...")
        time.sleep(2)
        itemd = ["empty bottle", "bottle of wine", "wine glass", "bottle of iced tea", "energy drink", "lemon juice", "pack of green peas", "shirt", "bed", "headphones", "earphones", "blanket", "tablet", "kindle", "pills", "pack of coffee beans", "cup of coffee", "junkfood", "medicine", "spoon", "fork", "Nintendo Switch", "laptop", "mobile phone", "electric fan", "chair", "guitar", "keyboard", "piano", "tv", "monitor", "oil", "hashish", "marijuana", "cigarette", "vape", "pillow", "dog food", "bike", "car", "scooter", "skateboard", "printer", "shards of glass", "garbage", "strips of sleather", "food", "bottle of water", "bible", "Dhammapada", "yoga mat", "helmet", "chewing gum", "vitamins", "shirt", "sweater", "pants", "working pants", "skirt", "underwear", "parachute", "gun", "knife", "sword", "katana", "oatmeal", "chain", "slippers", "shoes", "book", "wires", "credit card", "stove", "oven", "hat", "bucket hat", "baseball cap", "beanie", "hoodie", "necklace", "ring", "gold ring", "diamond ring", "diamond", "diamonds", "painting", "pencil", "ballpoint pen", "sketchpad", "crayon", "box of crayons", "paint", "spray paint", "fruit", "lettuce", "carrot", "watermelon", "orange", "apple", "banana", "pear", "gold", "gold bar", "pistol", "lantern", "lamp", "umbrella", "newspaper", "Sega", "ecstasy", "Nintendo 64", "calculator", "brownies", "pie", "loaf bread", "aviator shades", "shutter shades", "CD", "floppy disk", "mp3 player", "walkman", "cassette", "ticket", "food stub", "ski mask", "spear", "nunchucks", "frying pan", "beans", "charger", "guitar pick", "mic", "digicam", "GoPro", "night vision goggles", "sniper rifle", "DS4 Playstation controller", "CDJ", "Raybans", "smartwatch", "modem", "axe"]
        items = (random.choice(itemd), random.choice(itemd))
        item = random.sample(items, 2)
        ct = datetime.datetime.now()
        print("You found:")
        items = "items: "
        print(items, item, ct)
        time.sleep(3)

    def fly():
        print("You go to the airport and board a plane...")
        time.sleep(2)
        print("You arrived in:")
        countries = ["Canada", "Sweden", "China", "Beijing", "New York", "California", "L.A.", "San Francisco", "Detroit", "Colorado", "Newark", "New Jersey", "Australia", "Gold Coast", "Thailand", "North Korea", "Pyongyang", "Seoul", "Tokyo", "Osaka", "Japan", "Fujian", "Kyoto", "Manila", "Palawan", "Siargao", "Sultan Kudarat", "Davao", "Sydney", "Poland", "Uzbekistan", "Kyrgystan", "Turkey", "Iraq", "Iran", "Bolivia", "Iceland", "Lithuania", "Greenland", "UK", "France", "Spain", "Rome", "Greece", "Amsterdam", "Netherlands", "Boracay", "Indonesia", "Russia", "Ukraine", "Africa", "Antarctica", "Alaska", "South Carolina", "North Carolina", "Philadelphia", "Brooklyn", "Mexico", "Brazil", "Taiwan", "Burma", "Cambodia", "Vietnam", "India", "Bangladesh", "New Delhi", "Bombay", "Philippines"]
        country = random.sample(countries, 1)
        ct = datetime.datetime.now()
        fly = "fly: "
        print(fly, country, ct)
        time.sleep(3)

    def drink_coffee():
        print("You have coffee and feel the effect of caffeine...")
        time.sleep(7)
        ct = datetime.datetime.now()
        print("You finished drinking your coffee", ct)
        time.sleep(3)

    def drink_tea():
        print("You have tea...")
        time.sleep(7)
        ct = datetime.datetime.now()
        print("You finish your tea", ct)
        time.sleep(3)

    def surf():
        print("You enter the water and wait for a wave...")
        time.sleep(random.randint(1,8))
        print("You surfed:")
        time.sleep(3)
        modnar = (round(random.random()*60,2))
        ct = datetime.datetime.now()
        surf = "surfed: "
        print(surf, modnar, ct)
        print("..meters before you wiped-out")
        time.sleep(3)

    def collections():
        print("You recall")
        time.sleep(3)
        semit = (round(random.random()*666))
        collections = "collections: "
        print(semit)
        print("items out of 666 with")
        time.sleep(1)
        sitch  = (round(random.random()*100,3))
        print(sitch)
        ct = datetime.datetime.now()
        print("in your Satchel")

    def doodling():
        print("You pick up a calculator...")
        time.sleep(5)
        print()
        print("You draw:")
        time.sleep(1)
        print()
        print()
        mondar = (round(random.random()*999,8))
        ct = datetime.datetime.now()
        doodling = "doodling: "
        print(doodling, mondar, ct)
        print()

    def zen_melody():
        keys = ["C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B"]
        key = random.sample(keys, 1)
        raondam = (round(random.random()*9999,9))
        ct = datetime.datetime.now()
        zenmelody = "zen melody: "
        print(zenmelody, key, raondam, ct)

    def value():
        letters1 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters2 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters3 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters4 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letters5 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
        letter1 = random.sample(letters1, 1)
        letter2 = random.sample(letters2, 1)
        letter3 = random.sample(letters3, 1)
        letter4 = random.sample(letters4, 1)
        letter5 = random.sample(letters5, 1)
        value = (round(random.random()*9999999999,10))
        ct = datetime.datetime.now()
        values = "value:"
        print(values, letter1, letter2, letter3, letter4, letter5, value, ct)

    def bump():
        ct = datetime.datetime.now()
        time.sleep(1.5)
        print("You can do it!", ct)
        time.sleep(3)

    def ma():
        time.sleep(2)
        mstyles = ["Africa and African America", "Aikido", "Animal and Imitative Systems in Chinese Martial Arts", "Archery, Japanese", "Baguazhang (Pa Kua Ch' uan)", "Boxing, Chinese", "Boxing, Chinese Shaolin Styles", "Boxing, European", "Brazilian Jiu Jitsu", "Budo, Bujutsu, and Bugei", "Capoeira", "China", "Chivalry", "Combatives: Military and Police Martial Art Training", "Dueling", "Europe", "External vs. Internal Chinese Martial Arts", "Folklore in the Martial Arts", "Form/Xing/Kata/Pattern Practice", "Gladiators", "Gunfighters","Hapkido", "Heralds", "Iaido", "India", "Japan", "Japanese Martial Arts, Chinese Influences on", "Jeet Kune Do", "Judo", "Kajukenbo", "Kalarippayattu", "Karate, Japanese", "Karate, Okinawan", "Kendo", "Kenpo", "Ki/Qi", "Knights", "Kobudo, Okinawan", "Korea", "Korean Martial Arts, Chinese Influences On", "Koryu Bugei, Japanese", "Krav Maga", "Kung Fu/Gungfu/Gongfu", "Masters of Defense", "Medicine, Traditional Chinese", "Meditation", "Middle East", "Mongolia", "Muay Thai", "Ninjutsu", "Okinawa", "Orders of Knighthood, Secular", "Pacific Islands", "Pankration", "Performing Arts", "Philippines", "Political Conflict and the Martial Arts", "Rank", "Religion and Spiritual Development: Ancient Mediterranean and Medieval West", "Religion and Spiritual Development: China", "Religion and Spiritual Development: India", "Religion and Spiritual Development: Japan", "Sambo", "Samurai", "Savate", "Silat", "Social Uses of the Martial Arts", "Southeast Asia", "Stage Combat", "Stickfighting, Non-Asian", "Sword, Japanese", "Swordsmanship, European Medieval", "Swordsmanship, European Renaissance", "Swordsmanship, Japanese", "Swordsmanship, Korean/Hankuk Haedong Kumdo", "T'aek'kyon", "Taekwondo", "Taijiquan (Tai Chi Ch'uan)", "Thaing", "Thang-Ta", "Training Area", "Varma Ati", "Vovinam/Viet Vo Dao", "Warrior Monks, Japanese/Sohei", "Women in the Martial Arts", "Women in the Martial Arts: Britain and North America", "Women in the Martial Arts: China", "Women in the Martial Arts: Japan", "Wrestling and Grappling: China", "Wrestling and Grappling: Europe", "Wrestling and Grappling: India", "Wrestling and Grappling: Japan", "Wrestling, Professional", "Written Texts: China", "Written Texts: India", "Written Texts: Japan", "Xingyiquan (Hsing I Ch'uan)", "Yongchun/Wing Chun"]
        mart = random.sample(mstyles, random.randint(1, 6))
        ct = datetime.datetime.now()
        MA = "MA: "
        print(MA, mart, ct)
        print()
        print("-from the contents of Martial Arts of the World: An Encyclopedia")
        time.sleep(6)

    def skate():
        time.sleep(5)
        print("You ride your trickboard and did a")
        tricks = ["Backside 180", "Backside 360", "Backside Caballerial", "Backside Half Cab", "Fakie Ollie", "Frontside 180", "Frontside 360", "Frontside Caballerial", "Frontside Half Cab", "Kickturn", "Nollie", "Nollie Backside 180", "Nollie Backside 360", "Nollie Frontside 180", "Nollie Frontside 360", "Ollie", "Ollie North", "Ollie South", "Switch Backside 180", "Switch Backside 360", "Switch Frontside 180", "Switch Frontside 360", "Switch Ollie", "Tic-Tac", "360 Flip", "360 Hardflip", "360 Ollie Heelflip", "360 Ollie Kickflip", "360 Pop Shove-it", "360 Shuvit", "540 Flip", "720 Flip", "Alpha Flip", "Anti Casper Flip", "Backside Bigspin", "Backside Flip", "Backside Half Cab Heelflip", "Backside Half Cab Kickflip", "Backside Heelflip", "Backside Kickflip", "Big Heelflip", "Bigflip", "Biggerflip", "Biggerspin", "Bigspin", "Bubble Flip", "Bullflip", "Caballerial Flip", "Camel Flip", "Casper Flip", "Daydream Flip", "De Comply", "Disco Flip", "Double Heelflip", "Double Kickflip", "Dragon Flip", "Fakie 360 Flip", "Fakie 360 Hardflip", "Fakie Backside Bigspin", "Fakie Backside Pop Shove-it", "Fakie Frontside Bigspin", "Fakie Frontside Pop Shove-it", "Fakie Hardflip", "Fakie Heelflip", "Fakie Inward Heelflip", "Fakie Kickflip", "Fakie Varial Heelflip", "Fakie Varial Kickflip", "Feather Flip", "Fingerflip", "Forward Flip", "Front Foot Impossible", "Frontside 360 Pop Shove it", "Frontside Bigspin", "Frontside Flip", "Frontside Half Cab Heelflip", "Frontside Half Cab Kickflip", "Frontside Heelflip", "Frontside Kickflip", "Frontside Pop Shove-it", "Gazelle Flip", "Gazelle Spin", "Ghetto Bird", "Gingersnap", "Grape Flip", "Half Cab", "Handstand Flip", "Hardflip", "Haslam Flip", "Heelflip", "Hospital Flip", "Illusion Flip", "Impossible", "Inward Heelflip", "Jesus Flip", "Kickback Flip", "Kickflip", "Kiwi Flip", "Laser Flip", "Late Kickflip", "Nerd Flip", "Nightmare Flip", "No Comply", "540", "720", "900", "Airwalk", "Benihana", "Cannonball", "Christ Air", "Crossbone", "Delmar Indy", "Indy", "Indy Grab", "Invert", "Japan Air", "Judo Air", "Madonna", "McTwist", "Melancholy Grab", "Melon", "Method Air", "Mute Air", "Nose Grab", "Rocket Air", "Sal Flip", "Seatbelt Grab", "Stiffy", "Superman Grab", "Varial", "Egg Plant", "Manual", "Nose Manual", "Varial Heelflip", "Varial Kickflip",\
                     "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", "bail", ]
        trick = random.sample(tricks, 1)
        ct = datetime.datetime.now()
        skate = "skate: "
        print(skate, trick, ct)
        time.sleep(3)

    def art():
        time.sleep(4)
        print("You make a piece in the style of")
        styles = ["Abstract Art", "Abstract Expressionism", "Academicism", "Analytical Cubism", "Art Deco", "Art Nouveau", "Ashcan School", "Banksy", "Baroque", "Byzantine Art", "Classicism", "Cloisonnism", "Color Field", "Conceptual Art", "Constructivism", "Cubism", "Cubo-Futurism", "Dadaism", "Dutch Golden Age", "Early Netherlandish", "Early Renaissance", "Expressionism", "Fauvism", "Futurism", "Geometric Abstract Art", "Gothic Art", "High Renaissance", "Hudson River School", "Impressionism", "Italian Renaissance", "Kitsch", "Luminism", "Mannerism", "Metaphysical Art", "Minimalism", "Modernism", "Naive Art/ Primitivism", "Neo-Baroque", "Neo-Classicism", "Neo-Dada", "Neo Expressionism", "Neoplasticism", "New Realism", "Northern Renaissance", "Op-Art", "Orientalism", "Orphism", "Pointilism", "Pop Art", "Pop Surrealism", "Post-Impressionism", "Pre-Raphaelites", "Precisionism", "Proto Renaissance", "Purism", "Realism", "Regionalism", "Renaissance", "Rococo", "Romanticism", "Social Realism", "Socialist Realism", "Suprematism", "Surrealism", "Symbolism", "Synthetic Cubism", "Synthetism", "Tenebrism", "Tonalism", "Tubism", "Ukiyo-E", "Verism"]
        art = random.sample(styles, 1)
        ct = datetime.datetime.now()
        arts = "art: "
        print(arts, art, ct)
        time.sleep(3)

    def radio():
        time.sleep(2)
        print("You tune in to the radio and listen to:")
        time.sleep(1)
        genres = ["Alternative", "Anime", "Blues", "Classical", "Comedy", "Commercials", "Country", "Dance", "Easy Listening", "Electronic", "Enka", "French Pop", "Folk Music", "German Folk", "German Pop", "Fitness and Workout", "Hip-Hop/Rap", "Holiday Music", "Indie Pop", "Industrial", "Inspirational", "Instrumental", "Jazz", "K-Pop", "Karaoke", "Latin", "Metal", "New Age", "Opera", "Pop", "R&B/Soul", "Reggae", "Rock", "Soundtracks", "Spoken Word", "Tex-Mex/Tejano", "Vocal", "World"]
        music = random.sample(genres, 1)
        ct = datetime.datetime.now()
        radio = "radio: "
        print(radio, music, ct)
        time.sleep(3)

    def give_alms():
        ct = datetime.datetime.now()
        time.sleep(3)
        print("You gave alms to the needy", ct)
        time.sleep(3)

    def brawl():
        time.sleep(1)
        actions = ["You met", "You fought with", "You fought with", "You defeated", "You defeated","You defeated", "You were sent to the hospital by", "You were defeated by", "You healed", "You were healed by", "You jailed", "You pranked", "You were pranked by", "You were jailed by", "you were beat by", "you were K.Ode by"]
        action = random.sample(actions, 1)
        people = ["a stranger", "a child", "an emo", "a doctor", "a soldier", "a police", "a homeless person", "a mom", "a gamer", "a dancer", "an artist", "a peasant", "a prince", "a princess", "a King", "a Queen", "a lawyer", "a vendor", "an alien", "a Mexican", "a nurse", "a lizard", "a woman", "a girl", "a boy", "an optometrist", "a physician", "a psychologist", "a psychiatrist", "a teacher", "White Tara", "Green Tara", "a ninja", "a gangster"]
        person = random.sample(people, 1)
        ct = datetime.datetime.now()
        brawl = "brawl: "
        brawls = brawl, action, person
        print(brawls, ct)
        time.sleep(3)
        print()
        print("With A Score Of:")
        time.sleep(2)
        randit = (random.randint(50,100))
        ct = datetime.datetime.now()
        print(randit)
        time.sleep(3)

    def karate():
        time.sleep(1)
        print("Movement:")
        time.sleep(3)
        print()
        radnti = (random.randint(0,999))
        opponents = ["You", "Sensei", "Opponent", "Opponent"]
        opponent = random.sample(opponents, 1)
        ct = datetime.datetime.now()
        karate = "karate: "
        print(karate, radnti, opponent, ct)
        time.sleep(3)

    def koans():
        time.sleep(2)
        print()
        koans = ['One day, the World-Honored One ascended to the rostrum. Manjusri struck the table with the gavel and said, “Contemplate clearly the Dharma of the Dharma-King! The Dharma of the Dharma-King is like this.” Thereupon, the World-Honored One descended from the rostrum.', 'Emperor Bu of Ryo asked Great Master Bodhidharma, “What is the highest meaning of the holy reality?” Bodhidharma replied, “Vast and void, no holiness.” The emperor said, “Who are you in front of me?” Bodhidharma said, “I don’t know.” The emperor did not match him. Finally, Bodhidharma crossed the Yangtse River and came to the Shorin Temple. There he sat for nine years, facing the wall.', 'A king of Eastern India invited the twenty-seventh patriarch, Prajna Tara, for a meal. The king asked, “Why don’t you recite sutras?” The patriarch said, “The poor way [1] does not stay in the world of subject when breathing in, and has nothing to do with the world of objects when breathing out. I am always reciting the suchness-sutra in millions and millions of volumes.” [1]: i.e., “I.”', 'When the World-Honored One was walking with his assembly, he pointed to the ground with his hand and said, “This place is good for building a temple.” Indra [1] took a stalk of grass and stuck it in the ground and said, “The temple has been built.” The World-Honored One smiled. [1]: Exactly: Sakra Devendra. The lord god of the Trayastrimasa Heaven.', 'A monk asked Seigen, “What is the essence of Buddhism?” Seigen said, “What is the price of rice in Roryo?”', 'A monk asked Great Master Ba, “Apart from the Four Phrases, beyond one hundred Negations, please tell me directly, Master, the meaning of Bodhidharma’s coming from the West.” Master Ba said, “I am tired today, I can’t explain it to you. Go and ask Chizo.” The monk asked Chizo about it. Chizo said, “Why don’t you ask our master?” The monk said, “He told me to ask you.” Chizo said, “I have a headache today, I can’t explain it to you. Go and ask Brother Kai.” The monk asked Brother Kai about it. Kai said, “I don’t understand nothing about that question.” The monk told Great Master Ba about it. Great Master said, “Chizo’s head is white, Kai’s head is black.”', 'Yakusan had not ascended the rostrum for a long time. The temple steward said, “All the assembly has been wishing for instruction for a long time. Please, Master, give your assembly a sermon.” Yakusan had the bell rung. The assembly gathered. Yakusan ascended the rostrum and sat there for a while. Then he descended and returned to his room. The temple steward followed him and asked, “You said a while ago that you would give the assembly a sermon. Why didn’t you speak even a word?” Yakusan said, “For sutras, there are sutra specialists; for sastras [1], there are sastra specialists. Why do you have doubts about this old monk [2] ?” [1]: Books on Buddhist doctrines, written by ancient Buddhist philosophers. [2]: i.e. Yakusan.', 'Whenever Master Hyakujo delivered a sermon, an old man was always there listening with the monks. When they left, he left too. One day, however, he remained behind. Hyakujo asked him, “What man are you, standing there?” The old man replied, “In the past, in the time of Kashyapa Buddha, I lived on this mountain as a Zen priest. Once a monk came and asked me, ‘Does a perfectly enlightened person fall under the law of cause and effect or not?’ I said to him, He does not.’ Because of this answer, I fell into the state of a fox for 500 lives. Now, I beg you, Master, please say a turning word.” Hyakujo said, “The law of cause and effect cannot be obscured.” Upon hearing this, the old man became greatly enlightened.', 'Once the monks of the eastern and western Zen halls in Nansen’s temple were quarrelling about a cat. As he saw this, Nansen held up the cat and said, “You monks! If one of you can say a word, I will not slay the cat.” No one could answer. Nansen cut the cat in two. Nansen told Joshu what had happened, and asked him for his view. Joshu thereupon took his sandals, put them upon his head and went away. Nansen said, “If you had been there, I could have spared the cat.”', 'There was an old woman on the way to Taizan. Whenever a monk asked her how to get to Taizan, she would answer, “Go straight on.” After the monk had gone a few steps, she would say, “This good and naïve fellow goes off that way, too.” Later a monk told Joshu about this. Joshu said, “Wait a bit. I will go and see through her for you.” He went and asked the same question. The next day, Joshu ascended the rostrum and said, “I have seen through the old woman for you.”', 'Great Master Unmon said, “When the light does not penetrate, there are two diseases. Everything is unclear and things hang before you: this is one disease. Even after you have realized the emptiness of all things, somehow you feel as if there were still something there. This shows that the light has not yet penetrated thoroughly. Also there are two diseases concerning the Dharma-body. You have reached the Dharma-body, but you remain attached to the Dharma and cannot extinguish your own view; therefore you lead a corrupt life around the Dharma-body: this is one disease. Suppose you have truly penetrated to the end, if you give up further efforts, it will not do. You examine yourself minutely and say you have no flaw: this is nothing but a disease.”', 'Jizo asked Shuzanshu, “Where have you come from?” Shuzanshu said, “I have come from the South.” Jizo said, “How is Buddhism in the South these days?” Shuzanshu said, “There is much lively discussion.” Jizo said, “How could that match with our planting the rice field here and making rice-balls to eat?” Shuzanshu said, “How could you then save the beings of the Three Worlds?” Jizo said, “What do you call ‘the Three Worlds’?”', 'When Rinzai was about to die, he entrusted Sansho with his Dharma and said, “After my passing, do not destroy my treasury of the Eye of the true Dharma [1].” Sansho said, “How would I dare destroy your treasury of the Eye of the true Dharma?” Rinzai said, “If someone asks you about it, how will you answer?” Sansho instantly shouted his Kaatz. Rinzai said, “Who knows that my treasury of the Eye of the true Dharma has been destroyed by this blind donkey?” [1]: Originally: shobogenzo.', 'Attendant Kaku asked Tokusan, “Where have all the past saints gone?” Tokusan said, “What? What?” Kaku said, “I gave the command for an excellent horse like a flying dragon to spring forth, but there came out only a lame tortoise.” Tokusan was silent. The next day, when Tokusan came out of the bath, Kaku served him tea. Tokusan passed his hand gently over Kaku’s back. Kaku said, “This old fellow has gotten a glimpse for the first time.” Again, Tokusan was silent.', 'Isan asked Kyozan, “Where have you come from?” Kyozan said, “From the rice field.” Isan said, “How many people are there in the rice field?” Kyozan thrust his hoe into the ground and stood with his hands folded on his chest. Isan said, “There are a great number of people cutting thatch on the South Mountain.” Kyozan took up his hoe and left immediately.', 'Mayoku, with his ring-staff in hand, came to Shokei. He circled Shokei’s dais three times, shook the ring-staff and stood there bolt upright. Shokei said, “Right, right!” Mayoku then came to Nansen. He circled Nansen’s dais three times, shook the ring-staff and stood there bolt upright. Nansen said, “Not right, not right!” Then, Mayoku said, “Master Shokei said, ‘Right, right!’ Why, Master, do you say, ‘Not right, not right!’?” Nansen said, “With Shokei it is right, but with you it is not right. This is nothing but a whirling of the wind. In the end, it will perish.”', 'Hogen asked Shuzanshu, “"If there is only a hairsbreadth of difference, it is the distance between heaven and earth."[1] How do you understand that?” Shuzanshu said, “If there is only a hairsbreadth of difference, it is the distance between heaven and earth.” Hogen said, “If that’s your understanding, how could you ever attain IT?” Shuzanshu said, “My view is just that. How about you, Master?” Hogen said, “If there only is a hairsbreadth of difference, it is the distance between heaven and earth.” Shuzanshu made a deep bow. [1]: Cited from the Shinjinmei (A Hymn of Sincere Mind), a work by the Third Patriarch Sosan.', 'A monk asked Joshu, “Does the dog have buddha-nature, or not?” Joshu said, “It has” [U]. The monk said, “If it has it, why did it creep into that skin bag?” Joshu said, “Because it does so knowingly.” Another monk asked, “Does the dog have buddha-nature, or not?” Joshu said, “It has not” [Mu]. The monk said, “All living beings have buddha-nature [2]. Why doesn’t the dog have any?” Joshu said, “Because it is in its karma-consciousness.” [1]: see case 1 of Mumonkan: the Shoyoroku case presents a fuller text of the dialogue. [2]: Quotation from the Nirvana Sutra 7, 25.', 'A monk asked Unmon, “Not a single thought arises: is there any fault or not?” Unmon said, “Mt. Sumeru. [1]” [1]: The highest and most massive mountain in the world according to the Indian cosmology.', 'Jizo asked Hogen, “Where are you going, senior monk? [1]” Hogen said, “I am on pilgrimage [2], following the wind.” Jizo said, “What are you on pilgrimage for?” Hogen said, “I don’t know.” Jizo said, “Non knowing is most intimate.” Hogen suddenly attained great enlightenment. [1]: “Senior monk” (joza) is an honorific for a monk who has practiced more than 10 years. [2]: Originally: angya.', 'When Ungan was sweeping the ground, Dogo said, “You are having a hard time!” Ungan said, “You should know there is one who doesn’t have a hard time.” Dogo said, “If that’s true, you mean there is a second moon?” Ungan held up his broom and said, “What number of moon is this?” Dogo was silent. Gensha said, “That is precisely the second moon.” Unmon said, “The servant greets the maid politely.”', 'Ganto came to Tokusan. He straddled the threshold of the gate and asked, “Is this ordinary or is this holy?” Tokusan shouted, “Kaatz!” Ganto made a deep bow. Hearing of this, Tozan said, “Hardly anyone but Ganto could have accepted it that way.” Ganto said, “Old Tozan can’t tell between good and bad. At that time, I raised up with one hand and suppressed with the other.”', 'Whenever Roso saw a monk coming, he immediately sat facing the wall. Hearing of this, Nansen said, “I usually tell my people to realize what has existed before the kalpa of emptiness [1], or to understand what has been before Buddhas appeared in the world. Still, I haven’t acknowledged one disciple or even a half. If he continues that way, he will go on even until the year of the donkey [2].” [1]: One of the “four kalpas” or periods of cosmic changes: the kalpa of creation, the kalpa of existence, the kalpa of destruction, and the kalpa of emptiness. [2]: Since there is no “year of the donkey” in the Chinese zodiac, the expression “until the year of donkey” means endlessly.', 'Seppo, instructing the assembly, said, “There’s a poisonous snake on the southern side of the mountain. All of you should look at it carefully!” Chokei said, “Today in the Zen hall there are many people. They have lost their body and life.” A monk told this to Gensha, who said, “Only Elder Brother Ryo [2] could say something like that. However, I wouldn’t talk like that.” The monk asked, “What then would you say, Master”? Gensha replied, “Why does it have to be ‘the southern side of the mountain’?” Unmon threw his staff in front of Seppo and acted frightened. [1]: see case 22 of Hekiganroku. [2]: i.e. Chokei.', 'One day, Enkan called to his attendant, “Bring me the rhinoceros fan.” The attendant said, “It is broken.” Enkan said, “If the fan is already broken, bring me the rhinoceros himself.” The attendant gave no answer. Shifuku drew a circle and wrote the ideograph “ox [2]” in it. [1]: see case 91 of Hekiganroku. [2]: The Chinese character for “ox” (gyu) is one of the two characters for “rhinoceros” (saigyu = sai + gyu).', 'Kyozan pointed to the snow lion [1] and said, “Is there any [2] that goes beyond this color?” Unmon said [3], “I would have pushed it over for him at once.” Setcho said [4], “He only knows how to push it over, but he doesn’t know how to help it up.” [1]: Probably a lion made of snow or a stone lion covered with snow. [2]: I.e., “anyone” or “anything.” [3]: I.e., later. [4]: I.e., hearing of this.', 'Hogen pointed to the bamboo blinds with his hand. At that moment, two monks who were there went over to the blinds together and rolled them up. Hogen said, “One has gained, one has lost.”', 'A monk asked Gokoku, “How about when a crane perches on a withered pine tree?” Gokoku said, “It is a disgrace when seen from the ground.” The monk asked, “What about when every drop of water is frozen at once?” Gokoku said, “It’s a disgrace after the sun has risen.” The monk asked, “At the time of the Esho Persecution [1], where did the good Guardian Deities [2] of the Dharma go?” Gokoku said, “It is a disgrace for the two of them on both sides of the temple gate.” [1]: Buddhism was suppressed by order of Emperor Bu (about 840). [2]: Nio-figures representing the two Deva kings on each side of the main gate of a Buddhist temple. They are considered to be protectors of the Dharma.', 'When he was staying at the government office of the Province Ei, Fuketsu entered the hall [to preach] and said, “The heart seal [stamp] of the patriarch resembles the activity of the iron ox. When it goes away, the [impression of the] seal remains; when it stays there, the [impression of the] seal is brought to naught. If it neither goes away nor stays, would it be right to give a seal [of approval] or not?” Then Elder Rohi came up and said, “I have the activities of the iron ox. [However,] I ask you, Master, not to give me the seal.” Fuketsu said, “I am accustomed to leveling the great ocean through fishing whales. But, alas, now I find instead a frog wriggling about in the mud.” Rohi stood there considering. Fuketsu shouted “Kaatz!” and said, “Why don’t you say anything else, Elder?” Rohi was perplexed. Fuketsu hit him with his whisk and said, “Do you remember what you said? Say something, I’ll check it for you.” Rohi tried to say something. Fuketsu hit him again with his whisk. The Magistrate said, “Buddha’s law and the King’s law are of the same nature.” Fuketsu said, “What principle do you see in them?” The Magistrate said, “If you do not make a decision where a decision should be made, you are inviting disorder.” Fuketsu descended from the rostrum.', 'A monk asked Daizui, “When the great kalpa fire bursts out, the whole universe [2] will be destroyed. I wonder if IT will also be destroyed or not.” Daizui said, “Destroyed.” The monk said, “If so, will IT be gone with the other [3]?” Daizui said, “Gone with the other.” A monk asked Ryusai, “When the great kalpa fire bursts out, the whole universe will be destroyed. I wonder if IT will also be destroyed or not.” Ryusai said, “Not destroyed.” The monk said, “Why is it not destroyed?” Ryusai said, “Because it is the same as the whole universe.” [1]: see case 29 of Hekiganroku: The Shoyoroku case has an additional part with Ryusai. [2]: Literally: “a billion worlds.” [3]: The word “the other” means “the universe.”', 'Unmon, instructing the assembly, said, “The old buddha and a pillar intersect each other. What number of activity is that?” The assembly was silent. He said on their behalf, “Clouds gather over the South Mountain; rain falls on the North Mountain.”', 'Kyozan asked a monk, “Where do you come from?” The monk said, “I am from Yu Province” Kyozan said, “Do you think of that place?” The monk said, “I always do.” Kyozan said, “That which thinks is the mind [1]. That which is thought about is the objective world. Within that are mountains, rivers and the great earth, towers, palaces, people, animals, and other things. Reflect upon the mind that thinks. Are there a lot of things there?” The monk said, “I don’t see anything at all there.” Kyozan said, “That’s right for the stage of understanding, but not yet for the stage of personalization.” The monk said, “Do you have any special advice, Master?”\
                 Kyozan said, “It is not right to say that there is or there is not. Your insight shows that you have obtained only one side of the mystery. Sitting down, putting on clothes, from now on you see by yourself.” [1]: Originally: kokoro.', 'Sansho asked Seppo, “When a fish with golden scales has passed through the net, what should it get for food?” Seppo said, “I will tell you when you have passed through the net.” Sansho said, “A great Zen master with 1500 disciples doesn’t know how to speak.” Seppo said, “The old monk is just too busy with temple affairs.”', 'Fuketsu, giving instruction, said, “If one raises a speck of dust, the house and the nation prosper. If one does not raise a speck of dust, they perish.” Setcho held up his staff and said, “Is there anyone who lives and dies with this?”', 'Rakuho came to Kassan and without bowing stood facing him. Kassan said, “A chicken dwells in the phoenix nest. It’s not of the same class. Go away.” Rakuho said, “I have come from far away, hearing much about you. Please, Master, I beg you to guide me.” Kassan said, “Before my eyes there is no you, and here there is no old monk [1].” Rakuho shouted, “Kaatz!” Kassan said, “Stop it, stop it. Don’t be so careless and hasty. Clouds and the moon are the same; valleys and mountains are different from each other. It is not difficult to cut off the tongues of the people under heaven. But how can you make a tongueless person speak?” Rakuho said nothing. Kassan hit him. With this, Rakuho started to obey Kassan. [1]: I.e., “I.”', 'Great Master Ba was seriously ill. The temple steward asked him, “Master, how are you feeling these days?” Great Master said, “Sun-faced Buddha, Moon-faced Buddha.”', 'Isan asked Kyozan, “Suppose a man asks you, saying, ‘All living beings are tossed in a vast karma-consciousness, and have no foundation to rely upon.’ How would you check him?” Kyozan said, “If such a monk appears, I call out to him, ‘Mr. So-and-so!’ When he turns his head, instantly I say, ‘What is this?’ If he hesitates, then I say to him, "Not only is there a vast karma-consciousness, but also there is no foundation to rely upon."” Isan said, “Good.”', 'Rinzai instructed his assembly and said, “There is one true person of no rank, always coming out and going in through the gates of your face [1]. Beginners who have not yet witnessed that, look! look!” Then a monk came out and asked, “What is the one true person of no rank?” Rinzai descended from the rostrum and grabbed him. The monk hesitated. Rinzai pushed him away and said, “The true person of no rank — what a shit-stick you are!” [1]: I.e., sense organs such as eyes, nose, ears, tongue, etc.', 'A monk asked Joshu, “I have just entered this monastery. I beg you, Master, please give me instructions.” Joshu asked, “Have you eaten your rice gruel yet?” The monk answered, “Yes, I have.” Joshu said, “Then wash your bowls.”', 'Unmon asked Kempo, “May I ask for your answer [1]?” Kempo said, “Have you ever reached this old monk or not?” Unmon said, “If so, I must say I was too late.” Kempo said, “Is that so? Is that so?” Unmon said, “I thought I was Marquis White, but I find that here is Marquise Black [2].” [1]: A literal translation. It is possible to understand the word simply as “instruction.” [2]: Marquis White and Marquise Black are noted thieves in Chinese folklore. Marquise Black, a female thief, seems to have been the cleverer of the two.', 'When he was about to die, Rakuho addressed his assembly and said, “I have one matter to ask you about. If you say ‘yes’ to this, you are putting another head on your own. If you say ‘no,’ you are looking for life by cutting off your head.” The head monk said, “The green mountain always lifts up its legs; you don’t need to carry a lantern in the daylight.” [1] Rakuho said, “What time is this to utter such a saying?” A senior monk named Genjo stepped forward and said, “Apart from these two ways, I beg you, Master, not to ask.” Rakuho said, “That’s not enough. Say some more.” Genjo said, “I cannot say it fully.” Rakuho said, “I don’t care whether or not you can say it fully.” Genjo said, “I feel just like an attendant who has nothing to respond to his master.” [2] That evening, Rakuho called Genjo to him and said, “Your response today had something quite reasonable. You have to realize what our late master [3] said, "There are no dharmas before the eyes, Yet consciousness is before the eyes. IT is not the Dharma before the eyes, IT cannot be reached by eyes and ears."" Which phrase is the guest? Which phrase is the host? If you can sort them out, I will transmit the bowl and robe to you.” Genjo said, “I don’t understand.” Rakuho said, “You must understand.” Genjo said, “I really don’t understand.” Rakuho uttered a kaatz and said, “Miserable, miserable!” [Another] monk asked, “What would you like to say, Master?” Rakuho said, “The boat of compassion is not rowed over pure waves. It’s been wasted labor releasing wooden geese down the precipitous strait [4].” [1]: Most probably a saying formed by Rakuho himself. [2]: Apparently an idiomatic expression meaning, “I can’t describe it in words.” [3]: Rinzai or Kassan. [4]: It was a custom that the boat rushing down the stream through a gorge released pieces of wood ahead as a warning so that a possible crash with the boat coming upstream could be avoided. These wooden chips were called “wooden geese.”', 'A monk asked National Teacher Chu of Nanyo, “What is the essential body [1] of Vairocana Buddha [2]?” National Teacher said, “Pass me that water jug.” The monk passed him the water jug. National Teacher said, “Put it back where it was.” The monk asked again, “What is the essential body of Vairocana Buddha?” National Teacher said, “The old Buddha is long gone.” [1]: The so-called “Dharma-body” or dharmakaya. [2]: The principal Buddha.', 'Razan asked Ganto, “What if things appear and disappear without ceasing?” Ganto scolded him saying, “Who appears and disappears?”', 'A monk asked Master Ho of Koyo, “The great dragon has emerged from the ocean, calming heaven and earth. How will you treat him when he suddenly appears before you?” Master Ho said, “Suparnin [1], the king of birds, absorbs the entire universe. Who can stick his head within him?” The monk said, “But how about when he does appear?” Ho said, “It is like a falcon catching a pigeon. If you don’t realize it, you will learn the truth through the ‘inspection before the balcony.’ [2]” The monk said, “If so, then I’ll fold my hands on my chest and retreat three steps.” Ho said, “You black tortoise under the Sumeru altar. [3] Don’t wait to be struck on the forehead again and get hurt.” [1]: A giant bird that eats even dragons. [2]: A reference to a story in which Heigenkun Chosho, the brother of the king of Cho and a wealthy landlord with 3,000 dependents, built a grand palace with a balcony that overlooked the main road. One day a crippled person was passing by and one of the concubines saw him and laughed. The crippled person was angered and demanded Heigenkun her head. Heigenkun presented the head of an executed convict as the head of the concubine. His dependents knew of his deception, lost faith in their master and gradually all left him. His fortunes declined, so at last he cut off the head of the concubine and presented it for the crippled person to inspect. After that the dependents returned and his fortunes were restored. The story is an allusion to the fact that you can never hide away the real truth. [3]: A reference to one of the four carved figures, representing black tortoises, underneath the Sumeru altar (with the Buddha statue). It is used here as a symbol of someone who has lost the freedom of movement.', 'The Engaku [1] Sutra says: “At all times, you do not raise the delusive mind. When there are all kinds of illusory thoughts, you do not extinguish them. Dwelling in the delusory state of mind, you do not add understanding. Where there is no understanding, you do not distinguish the truth.” [1]: “Engaku” means the perfect awakening of Buddha.', 'Great Master Tokusan Emmyo instructed his assembly and said, “If you have exhausted to the end, you will realize right away that all buddhas in the three worlds have stuck their mouths to the wall [1]. Yet there is still one person ¡© he is giving a great laugh. If you can recognize that person, you have accomplished your study.” [1]: I.e., they are unable to open their mouths.', 'A monk asked Joshu, “What is the meaning of the patriarch’s coming from the West?” Joshu said, “The oak tree there in the garden.”', 'Vimalakirti asked Manjusri, “What does it mean that the Bodhisattva enters the Dharma-gate of Not-Two?” Manjusri said, “I see it like this: in all phenomena, there are neither words nor explanations, neither presentations nor knowledge; it is beyond all questions and answers. That is what I understand with /to enter the Dharma-gate of Not-Two/.” Then Manjusri asked Vimalakirti, “All of us have finished giving our explanations. Now you should give your explanation. What does it mean that the Bodhisattva enters the Dharma-gate of Not-Two?” Vimalakirti remained silent.', 'When Tozan held a memorial service for Ungan before his portrait, he mentioned the episode with the portrait [1]. A monk came forward and asked, “When Ungan said, ‘Just this!’ what did that mean?” Tozan said, “At that time, I almost misunderstood my master’s meaning.” The monk said, “I wonder whether or not Ungan really knew that IT is.” Tozan said, “If he did not know that it is, how could he say like that? If he knew that it is, how did he dare say like that?” [1]: Tozan was still a young monk under Ungan. One day, when he was leaving his master, he asked Ungan, “After your passing, if I am asked by someone whether I have your portrait, what should I answer?” Ungan was silent for a while and then said, “Just this.”', 'When Seppo was living in a hermitage, two monks came to pay their respects. When he saw them coming, Seppo thrust open the gate of his hermitage with his hands, jumped out, and said, “What is this?” The monks also said, “What is this?” Seppo hung his head and retired into his hermitage. Later, the monks came to Ganto. He asked them, “Where have you come from?” The monks said, “From Reinan.” Ganto said, “Did you ever visit Seppo?” The monks said, “Yes, we visited him.” Ganto said, “What did he say?” The monks related what had happened. Ganto said, “What else did he say?” The monks said, “Not a word; he hung his head and retired into his hermitage.” Ganto said, “Oh, how I regret now that in those days I did not tell him the last word! If I had told it to him, no one under heaven could do anything against him.” At the end of the summer practice period the monks came back to this conversation and asked him about its meaning. Ganto said, “Why didn’t you ask me about it sooner?” The monks said, “We could not dare to ask you about it.” Ganto said, “Seppo was born on the same stem as I, but he will not die on the same stem. If you want to know the last word, it is just this.”']
        koan = random.sample(koans, 1)
        ct = datetime.datetime.now()
        koans = "koans: "
        print(koans, koan, ct)
        print()
        print("-Shoyoroku (E. Book of Serenity, C. Ts’ung-jung lu) A collection of 100 koans (50 are in LIFE), originally compiled in the 12th century by Wanshi Shogaku (C. Hung-chih Cheng-chüeh)")

    def hipster_tarot():
        while True:
            try:
                number = int(input("Indicate number of (tarot) cards: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        numberstr = str(number)
        print()
        print("You draw" + "" + " " + "" + numberstr + "" + " " + "" + "cards from a deck...")
        time.sleep(4)
        deck = ["The Fool | Upright | Beginnings, innocence, spontaneity, a free spirit", "The Fool | Reversed | Holding back, recklessness, risk-taking", "The Fool | Upright | Manifestation, resourcfulness, power, inspired action", "The Fool | Reversed | Manipulation, poor planning, untapped talents", "The High Priestess | Upright | Intuition, sacred knowledge, the subconscious mind", "The High Priestess | Reversed | Secrets, disconnected from intuition, withdrawal and silence", "The Empress | Upright | Femininity, beauty, nature, nurturing, abundance", "The Empress | Reversed | Creative block, dependence on others", "The Emperor | Upright | Authority, establishment, structure, a father figure", "The Emperor | Reversed | Domination, excessive control, lack of discipline, inflexibility", "The Hierophant | Upright | Spiritual wisdom, religious beliefs, conformity, tradition,institutions", "The Hierophant | Reversed | Personal beliefs, freedom, challenging the status quo", "The Lovers | Upright | Love, harmony, relationships, values alignment, choices", "The Lovers | Reversed | Self-love, disharmony, imbalance, misalignment of values", "The Chariot | Upright | Control, willpower, success, action, determination", "The Chariot | Reversed | Self-discipline, opposition, lack of direction", "Strength | Upright | Strength, courage, persuasion, influence, compassion", "Strength | Reversed | Inner strength, self-doubt, low energy, raw emotion", "The Hermit | Upright | Soul-searching, introspection, being alone, inner guidance", "The Hermit | Reversed | Isolation, loneliness, withdrawal", "Wheel Of Fortune | Upright | Good luck, karma, life cycles, destiny, a turning point", "Wheel Of Fortune | Reversed | Bad luck, resistance to change, breaking cycles", "Justice | Upright | Justice, fairness, truth, cause and effect, law", "Justice | Reversed | Unfairness, lack of accountability, dishonesty", "The Hanged Man | Upright | Pause, surrender, letting go, new perspectives", "The Hanged Man | Reversed | Delays, resistance, stalling, indecision", "Death | Upright | Endings, change, transformation, transition", "Death | Reversed | Resistance to change, personal transformation, inner purging", "Temperance | Upright | Balance, moderation, patience, purpose", "Temperance | Reversed | Imbalance, excess, self-healing, re-alignment", "The Devil | Upright | Shadow self, attachment, addiction, restriction, sexuality", "The Devil | Reversed | Releasing limiting beliefs, exploring dark thoughts, detachment", "The Tower | Upright | Sudden change, upheaval, chaos, revelation, awakening", "The Tower | Reversed | Personal transformation, fear of change, averting disaster", "The Star | Upright | Hope, faith, purpose, renewal, spirituality", "The Star | Reversed | Lack of faith, despair, self-trust, disconnection", "The Moon | Upright | Lack of faith, despair, self-trust, disconnection", "The Moon | Reversed | Release of fear, repressed emotion, inner confusion", "The Sun | Upright | Positivity, fun, warmth, success, vitality", "The Sun | Reversed | Inner child, feeling down, overly optimistic", "Judgement | Upright | Judgement, rebirth, inner calling, absolution", "Judgement | Reversed | Self-doubt, inner critic, ignoring the call", "The World | Upright | Completion, integration, accomplishment, travel", "The World | Reversed | Seeking personal closure, short-cuts, delays", "Ace Of Cups | Upright | Love, new relationships, compassion, creativity.", "Ace Of Cups | Reversed | Self-love, intuition, repressed emotions." "Two Of Cups | Upright | Unified love, partnership, mutual attraction", "Two Of Cups | Reversed | Self-love, break-ups, disharmony, distrust.", "Three Of Cups | Upright | Celebration, friendship, creativity, collaborations.", "Three Of Cups | Reversed | Independence, alone time, hardcore partying, ‘three’s a crowd’.", "Four Of Cups | Upright | Meditation, contemplation, apathy, reevaluation.", "Four Of Cups | Reversed | Retreat, withdrawal, checking in for alignment.", "Five Of Cups | Upright | Retreat, withdrawal, checking in for alignment.", "Five Of Cups | Reversed | Personal setbacks, self-forgiveness, moving on.", "Six Of Cups | Upright | Revisiting the past, childhood memories, innocence, joy.", "Six Of Cups | Reversed | Living in the past, forgiveness, lacking playfulness.", "Seven Of Cups | Upright | Opportunities, choices, wishful thinking, illusion.", "Seven Of Cups | Reversed | Alignment, personal values, overwhelmed by choices.", "Eight Of Cups | Upright | Disappointment, abandonment, withdrawal, escapism.", "Eight Of Cups | Reversed | Trying one more time, indecision, aimless drifting, walking away.", "Nine Of Cups | Upright | Contentment, satisfaction, gratitude, wish come true.", "Nine Of Cups | Reversed | Inner happiness, materialism, dissatisfaction, indulgence.", "Ten Of Cups | Upright | Divine love, blissful relationships, harmony, alignment.", "Ten Of Cups | Reversed | Disconnection, misaligned values, struggling relationships.", "Page Of Cups | Upright | Creative opportunities, intuitive messages, curiosity, possibility.", "Page Of Cups | Reversed | New ideas, doubting intuition, creative blocks, emotional immaturity.", "Knight Of  Cups | Upright | Creativity, romance, charm, imagination, beauty.", "Knight Of Cups | Reversed | Overactive imagination, unrealistic, jealous, moody.", "Queen Of Cups | Upright | Compassionate, caring, emotionally stable, intuitive, in flow.", "Queen Of Cups | Reversed | Inner feelings, self-care, self-love, co-dependency.", "King Of Cups | Upright | Emotionally balanced, compassionate, diplomatic.", "King Of Cups | Reversed | Self-compassion, inner feelings, moodiness, emotionally manipulative.", "Ace Of Swords | Upright | Breakthroughs, new ideas, mental clarity, success", "Ace of Swords | Reversed | Inner clarity, re-thinking an idea, clouded judgement", "Two Of Swords | Upright | Difficult decisions, weighing up options, an impasse, avoidance", "Two Of Swords | Reversed | Indecision, confusion, information overload, stalemate", "Three Of Swords | Upright | Heartbreak, emotional pain, sorrow, grief, hurt", "Three Of Swords | Reversed | Negative self-talk, releasing pain, optimism, forgiveness", "Four Of Swords | Upright | Rest, relaxation, meditation, contemplation, recuperation", "Four Of Swords | Reversed | Exhaustion, burn-out, deep contemplation, stagnation", "Five Of Swords | Upright | Conflict, disagreements, competition, defeat, winning at all costs", "Five Of Swords | Reversed | Reconciliation, making amends, past resentment", "Six Of Swords | Upright | Transition, change, rite of passage, releasing baggage.", "Six Of Swords | Reversed | Personal transition, resistance to change, unfinished business", "Seven Of Swords | Upright | Betrayal, deception, getting away with something, acting strategically", "Seven Of Swords | Reversed | Imposter syndrome, self-deceit, keeping secrets", "Eight Of Swords | Upright | Negative thoughts, self-imposed restriction, imprisonment, victim mentality", "Eight Of Swords | Reversed | Self-limiting beliefs, inner critic, releasing negative thoughts, open to new perspectives", "Nine Of Swords | Upright | Anxiety, worry, fear, depression, nightmares", "Nine Of Swords | Reversed | Inner turmoil, deep-seated fears, secrets, releasing worry", "Ten Of Swords | Upright | Painful endings, deep wounds, betrayal, loss, crisis", "Ten Of Swords | Reversed | Recovery, regeneration, resisting an inevitable end", "Page Of Swords | Upright | New ideas, curiosity, thirst for knowledge, new ways of communicating", "Page Of Swords | Reversed | Self-expression, all talk and no action, haphazard action, haste", "Knight Of Swords | Upright | Ambitious, action-oriented, driven to succeed, fast-thinking", "Knight Of Swords | Reversed | Restless, unfocused, impulsive, burn-out", "Queen Of Swords | Upright | Independent, unbiased judgement, clear boundaries, direct communication", "Queen Of Swords | Reversed | Overly-emotional, easily influenced, bitchy, cold-hearted", "King Of Swords | Upright | Mental clarity, intellectual power, authority, truth", "King Of Swords | Reversed | Quiet power, inner truth, misuse of power, manipulation", "Ace Of Pentacles | Upright | A new financial or career opportunity, manifestation, abundance", "Ace Of Pentacles | Reversed | Lost opportunity, lack of planning and foresight", "Two Of Pentacles | Upright | Multiple priorities, time management, prioritisation, adaptability.", "Two Of Pentacles | Reversed | Over-committed, disorganisation, reprioritisation.", "Three Of Pentacles | Upright | Teamwork, collaboration, learning, implementation.", "Three Of Pentacles | Reversed | Disharmony, misalignment, working alone.", "Four Of Pentacles | Upright | Saving money, security, conservatism, scarcity, control.", "Four Of Pentacles | Reversed | Over-spending, greed, self-protection.", "Five Of Pentacles | Upright | Financial loss, poverty, lack mindset, isolation, worry.", "Five Of Pentacles | Reversed | Recovery from financial loss, spiritual poverty.", "Six Of Pentacles | Upright | Giving, receiving, sharing wealth, generosity, charity.", "Six Of Pentacles | Reversed | Self-care, unpaid debts, one-sided charity.", "Seven Of Pentacles | Upright | Long-term view, sustainable results, perseverance, investment.", "Seven Of Pentacles | Reversed | Lack of long-term vision, limited success or reward.", "Eight Of Pentacles | Upright | Apprenticeship, repetitive tasks, mastery, skill development.", "Eight Of Pentacles | Reversed | Self-development, perfectionism, misdirected activity.", "Nine Of Pentacles | Upright | Abundance, luxury, self-sufficiency, financial independence.", "Nine Of Pentacles | Reversed | Self-worth, over-investment in work, hustling.", "Ten Of Pentacles | Upright | Wealth, financial security, family, long-term success, contribution.", "Ten Of Pentacles | Reversed | The dark side of wealth, financial failure or loss.", "Page Of Pentacles | Upright | Manifestation, financial opportunity, skill development.", "Page Of Pentacles | Reversed | Lack of progress, procrastination, learn from failure.", "Knight Of Pentacles | Upright | Hard work, productivity, routine, conservatism.", "Knight Of Pentacles | Reversed | Self-discipline, boredom, feeling ‘stuck’, perfectionism.", "Queen Of Pentacles | Upright | Nurturing, practical, providing financially, a working parent.", "Queen Of Pentacles | Reversed | Financial independence, self-care, work-home conflict", "King Of Pentacles | Upright | Wealth, business, leadership, security, discipline, abundance.", "King Of Pentacles | Reversed | Financially inept, obsessed with wealth and status, stubborn.", "Ace Of Wands | Upright | Inspiration, new opportunities, growth, potential", "Ace Of Wands | Reversed | An emerging idea, lack of direction, distractions, delays", "Two Of Wands | Upright | Future planning, progress, decisions, discovery", "Two Of Wands | Reversed | Personal goals, inner alignment, fear of unknown, lack of planning", "Three Of Wands | Upright | Progress, expansion, foresight, overseas opportunities", "Three Of Wands | Reversed | Playing small, lack of foresight, unexpected delays", "Four Of Wands | Upright | Celebration, joy, harmony, relaxation, homecoming", "Four Of Wands | Reversed | Personal celebration, inner harmony, conflict with others, transition.", "Five Of Wands | Upright | Conflict, disagreements, competition, tension, diversity", "Five Of Wands | Reversed | Inner conflict, conflict avoidance, tension release", "Six Of Wands | Upright | Success, public recognition, progress, self-confidence", "Six Of Wands | Reversed | Private achievement, personal definition of success, fall from grace, egotism", "Seven Of Wands | Upright | Challenge, competition, protection, perseverance", "Seven Of Wands | Reversed | Exhaustion, giving up, overwhelmed", "Eight Of Wands | Upright | Movement, fast paced change, action, alignment, air travel", "Eight Of Wands | Reversed | Delays, frustration, resisting change, internal alignment", "Nine Of Wands | Upright | Resilience, courage, persistence, test of faith, boundaries", "Nine Of Wands | Reversed | Inner resources, struggle, overwhelm, defensive, paranoia", "Ten Of Wands | Upright | Burden, extra responsibility, hard work, completion", "Ten Of Wands | Reversed | Doing it all, carrying the burden, delegation, release", "Page Of Wands | Upright | Inspiration, ideas, discovery, limitless potential, free spirit", "Page Of Wands | Reversed | Newly-formed ideas, redirecting energy, self-limiting beliefs, a spiritual path", "Knight Of Wands | Upright | Energy, passion, inspired action, adventure, impulsiveness", "Knight Of Wands | Reversed | Passion project, haste, scattered energy, delays, frustration", "Queen Of Wands | Upright | Courage, confidence, independence, social butterfly, determination", "Queen Of Wands | Reversed | Self-respect, self-confidence, introverted, re-establish sense of self", "King Of Wands | Upright | Natural-born leader, vision, entrepreneur, honour", "King Of Wands | Reversed |  Impulsiveness, haste, ruthless, high expectations"]
        card = random.sample(deck, number)
        print("You drew:")
        print()
        ct = datetime.datetime.now()
        tarot = "tarot: "
        print(tarot, card, ct)

    def hack():
        time.sleep(5)
        youm = "You manage to connect to..."
        print(youm)
        time.sleep(2)
        countries = ["Canada", "Sweden", "China", "Beijing", "New York", "California", "L.A.", "San Francisco", "Detroit", "Colorado", "Newark", "New Jersey", "Australia", "Gold Coast", "Thailand", "North Korea", "Pyongyang", "Seoul", "Tokyo", "Osaka", "Japan", "Fujian", "Kyoto", "Manila", "Palawan", "Siargao", "Sultan Kudarat", "Davao", "Sydney", "Poland", "Uzbekistan", "Kyrgystan", "Turkey", "Iraq", "Iran", "Bolivia", "Iceland", "Lithuania", "Greenland", "UK", "France", "Spain", "Rome", "Greece", "Amsterdam", "Netherlands", "Boracay", "Indonesia", "Russia", "Ukraine", "Africa", "Antarctica", "Alaska", "South Carolina", "North Carolina", "Philadelphia", "Brooklyn", "Mexico", "Brazil", "Taiwan", "Burma", "Cambodia", "Vietnam", "India", "Bangladesh", "New Delhi", "Bombay", "Philippines", "Italy", "Belgium", "Denmark", "Colombia", "Argentina", "Albania", "Algeria", "Andora", "Angola", "Antigua and Barbuda", "Armenia", "Austria", "Azerbaijan", "Bahamas", "Bahrain", "Belarus", "Belize", "Benin", "Bhutan", "Bosnia", "Botswana", "Brunei", "Bulgaria", "Burkina Faso", "Burundi", "Cabo Verde", "Cameroon", "Chad", "Chile", "Costa Rica", "Croatia", "Cuba", "Cyprus", "Czechia", "Congo", "Djibouti", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador", "Guinea", "Estonia", "Swaziland", "Ethiopia", "Fiji", "Gabon", "Gambia", "Ghana", "Guatemala", "Guyana", "Haiti", "Honduras", "Hungary", "Israel", "Italy", "Jamaica", "Kenya", "Jordan", "Laos", "Latvia", "Lebanon", "Liberia", "Liechtenstein", "Luxembourg", "Madagascar", "Malawi", "Malaysia", "Maldives", "Mali", "Malta", "Mauritiana", "Mauritius", "Micronesia", "Moldova", "Monaco", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nauru", "Nepal", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "Oman", "Pakistan", "Palau", "Palestine State", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Portugal", "Qatar", "Romania", "Rwanda", "Saint Kitts and Nevis", "Saint Lucia", "Saint Vincent and the Grenadines", "Samoa", "San Marino", "Sao Tome and Principe", "Senegal", "Serbia", "Seychelles", "Sierra Leone", "Slovakia", "Slovenia", "Solomon Islands", "South Africa", "South Korea", "South Sudan", "Sri Lanka", "Sudan", "Suriname", "Syria", "Tajikistan", "Tanzania", "Togo", "Tonga", "Trinidad and Tobago", "Tunisia", "Turkmenistan", "Tuvalu", "Uganda", "Ukraine", "Uruguay", "Uzbekistan", "Vanuatu", "Venezuela", "Yemen", "Zambia", "Zimbabwe"]
        country = random.sample(countries, 1)
        print(country)
        serv = "Server at:"
        print(serv)
        time.sleep(1)
        negat = ["-", "+"]
        nega = random.sample(negat, 1)
        print(nega) 
        amdorn = (round(random.random()*90,4))
        print(amdorn)
        nega = random.sample(negat, 1)
        print(nega)
        andorm = (round(random.random()*180,4))
        print(andorm)
        time.sleep(2)
        andg = "and got away with:"
        print(andg)
        time.sleep(3)
        tidnar = (random.randint(0,999999999))
        print(tidnar)
        monies = ["Dollars", "Rupies", "Yen", "Pesos", "Pounds", "Coins", "Arcade Coins", "Mickey Mouse Money", "Francs", "Shekels", "Tugriks", "Indian Rupees", "Singapore Dollars", "Rubles", "Dinars", "Yuans", "Bahts", "Afghanis", "Riyals", "Kronas", "Riels", "DDOS attacks", "Botnets", "Credit Card Numbers", "E-mail addresses", "Business Addresses", "Home Addresses", "Passwords", "Mobile Numbers", "Telephone Numbers", "STD", "spits", "garbage", "sickness", "nudes", "hate", "likes"]
        money = random.sample(monies, 1)
        ct = datetime.datetime.now()
        print(money, ct)
        hack = "hack:"
        time.sleep(3)

    def spar():
        time.sleep(4)
        actions = ["You connected with a", "You connected a", "You anticipate to give a", "You hit your opponent with a", "You give a", "You waited and gave a", "You missed with a", "You missed with a", "You attempted a", "You recieved a", "Your opponent connected with a", "Your opponent missed with a", "Your opponent waited and gave a", "Your opponent anticipated to give a", "You blocked a", "You blocked a", "You blocked a", "You blocked a", "You blocked a", "Your opponent blocked a", "Your opponent blocked a", "Your opponent blocked a", "Your opponent blocked a"]
        action = random.sample(actions, 1)
        kicks = ["45 kick", "45 kick", "45 kick", "45 kick", "45 kick", "front kick", "stretching kick", "turning-side kick", "turning-side kick", "side kick", "side kick", "punching kick", "axe kick", "axe kick", "full moon kick","full moon kick", "turning-long", "turning-long", "turning-jumping 45 kick", "out-in kick", "in-out kick", "turning-jumping out-in", "roundhouse kick", "roundhouse kick", "roundhouse kick", "turning-jumping roundhouse kick", "punch", "punch", "punch", "punch", "bullet 45 kick", "double 45 kick", "triple 45 kick", "jumping 45 kick", "jumping roundhouse kick", "jumping axe kick", "jumping front kick", "jumping out-in kick", "jumping in-out kick", "jumping side kick", "jumping turning-side kick", "jumping full moon kick"]
        kick = random.sample(kicks, 1)
        ct = datetime.datetime.now()
        spar = "spar: "
        print(spar, action, kick, ct)
        time.sleep(3)

    def train():
        time.sleep(2)
        print("You did:")
        time.sleep(5)
        nums = [10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 20, 20, 20, 20, 30, 30, 40, 40, 50, 50, 60, 70, 80, 90, 100]
        num = random.sample(nums, 1)
        ct = datetime.datetime.now()
        train = "train: "
        print(train, num, ct)
        print("push-ups")
        time.sleep(3)

    def rest():
        ct = datetime.datetime.now()
        print("You start to rest...", ct)
        time.sleep(8)
        print("You rested", ct)
        time.sleep(3)

    def haiku():
        time.sleep(4)
        starting = ["in the depths of soul", "in as much as I want", "nevertheless", "coming up with it", "i don't know this", "thinking of it", "thinking of you", "thinking of us", "i never want to but", "carry me all the way", "i am happy", "starting", "i never know how", "as much as i would", "killing me softly", "killing us", "the quietest weather", "gray clouds above", "i see the clear sky", "while the sky is bluest", "i've never been apart", "how would i know", "will i see you again", "it came up to me", "i was surprised", "surprising", "i would", "come to me", "start with this", "a few words", "lenten season is upon us", "i love", "thinking", "stop"]
        start = random.sample(starting, 1)
        middle = ["i wish i would have", "consider me", "i am looking for food", "while i am clothed", "walking the distance", "i still end up with you", "consider my wish", "halfed tree", "searching", "unsure", "not minding everyone", "listening to music", "on my computer", "typing", "eating", "sleeping", "thinking", "never missing", "stopping", "staring", "resting", "excruciating pain", "this sadness", "while im without", "collecting", "listening", "happiness", "the surf", "inspired", "rocking the music", "travelling", "playing", "while music plays", "stirring things up", "taking a bath", "walking on the shore", "grinding"]
        mid = random.sample(middle, 1)
        ending = ["i never knew how", "i be at it", "considered everything", "i died", "i slept", "its wrapped", "made a union", "the sky bleeds", "music is spoken", "chilled", "i am spoiled", "this bringeth happiness", "its up to me", "the weather is", "i stay awake", "pillows", "grains", "half of the time", "it ends here", "i take flight", "distance is", "i like this", "forever", "lets meet", "gathered my wits"]
        end = random.sample(ending, 1)
        ct = datetime.datetime.now()
        haiku = "haiku: "
        print(haiku, start, mid, end, ct)

    def psalms():
        dd = list(verses1)
        time.sleep(5)
        print("From the Bible (King James Version), The Book of Psalms 1-21,")
        print()
        time.sleep(2)
        verse = random.sample(dd, 1)
        ct = datetime.datetime.now()
        psalms = "psalms: "
        print(psalms, verse, ct)

    def dhammapada():
        dd = list(dhammapada1)
        while True:
            try:
                number = int(input("Indicate number of verses (1 or 2 is a good starting point): "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print()
        print()
        print("Here are verses from Buddha's text, The Dhammapada")
        print()
        time.sleep(1)
        verse = random.sample(dd, number)
        ct = datetime.datetime.now()
        dhammapad = "dhammapada: "
        print(dhammapad, verse, ct)
        print()

    def koran():
        koran = list(koran1)
        while True:
            try:
                number = int(input("Indicate number of (koran) verses "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(1)
        print()
        print("Here are five verses from The Koran, from chapters 24. The Light, 52. The Mountain, 67. The Kingdom, 85. The Celestial Stations, 87. The Most High, 89. The Daybreak, 113. The Dawn")
        print()
        time.sleep(2)
        koran = ["[67.1] Blessed is He in Whose hand is the kingdom, and He has power over all things,", "[67.2] Who created death and life that He may try you-- which of you is best in deeds; and He is the Mighty, the Forgiving,", "[67.3] Who created the seven heavens one above another; you see no incongruity in the creation of the Beneficent God; then look again, can you see any disorder?", "[67.4] Then turn back the eye again and again; your look shall '~ come back to you confused while it is fatigued.", "[67.5] And certainly We have adorned this lower heaven with ( lamps and We have made these missiles for the Shaitans, and We have prepared for them the chastisement of burning.", "[67.6] And for those who disbelieve in their Lord is the punishment of hell, and evil is the resort.", "[67.7] When they shall be cast therein, they shall hear a loud moaning of it as it heaves,", "[67.8] Almost bursting for fury. Whenever a group is cast into it, its keeper shall ask them: Did there not come to you a warner?", "[67.9] They shall say: Yea! indeed there came to us a warner, but we rejected (him) and said: Allah has not revealed anything, you are only in a great error.", "[67.10] And they shall say: Had we but listened or pondered, we should not have been among the inmates of the burning fire.", "[67.11] So they shall acknowledge their sins, but far will be (forgiveness) from the inmates of the burning fire.", "[67.12] (As for) those who fear their Lord in secret, they shall surely have forgiveness and a great reward.", "[67.13] And conceal your word or manifest it; surely He is Cognizant of what is in the hearts.", "[67.14] Does He not know, Who created? And He is the Knower of the subtleties, the Aware.", "[67.15] He it is Who made the earth smooth for you, therefore go about in the spacious sides thereof, and eat of His sustenance, and to Him is the return after death.", "[67.16] Are you secure of those in the heaven that He should not make the earth to swallow you up? Then lo! it shall be in a state of commotion.", "[67.17] Or are you secure of those in the heaven that He should not send down upon you a punishment? Then shall you know how was My warning.", "[67.18] And certainly those before them rejected (the truth), then how was My disapproval.", "[67.19] Have they not seen the birds above them expanding (their wings) and contracting (them)? What is it that withholds them save the Beneficent God? Surely He sees everything.", "[67.20] Or who is it that will be a host for you to assist you besides the Beneficent God? The unbelievers are only in deception.", "[67.21] Or who is it that will give you sustenance if He should withhold His sustenance? Nay! they persist in disdain and aversion.", "[67.22] What! is he who goes prone upon his face better guided or he who walks upright upon a straight path?", "[67.23] Say: He it is Who brought you into being and made for you the ears and the eyes and the hearts: little is it that you give thanks.", "[67.24] Say: He it is Who multiplied you in the earth and to Him you shall be gathered.", "[67.25] And they say: When shall this threat be (executed) if you are truthful?", "[67.26] Say: The knowledge (thereof is only with Allah and I am only a plain warner.=", "[67.27] But when they shall see it nigh, the faces of those who disbelieve shall be sorry, and it shall be said; This is that which you used to call for.", "[67.28] Say: Have you considered if Allah should destroy me and those with me-- rather He will have mercy on us; yet who will protect the unbelievers from a painful punishment?", "[67.29] Say: He is the Beneficent God, we believe in Him and on Him do we rely, so you shall come to know who it is that is in clear error.", "[67.30] Say: Have you considered if your water should go down, who is it then that will bring you flowing water?", "[89.1] I swear by the daybreak,", "[89.2] And the ten nights,", "[89.3] And the even and the odd,", "[89.4] And the night when it departs.", "[89.5] Truly in that there is an oath for those who possess understanding.", "[89.6] Have you not considered how your Lord dealt with Ad,", "[89.7] (The people of) Aram, possessors of lofty buildings,", "[89.8] The like of which were not created in the (other) cities;", "[89.9] And (with) Samood, who hewed out the rocks in the valley,", "[89.10] And (with) Firon, the lord of hosts,", "[89.11] Who committed inordinacy in the cities,", "[89.12] So they made great mischief therein?", "[89.13] Therefore your Lord let down upon them a portion of the chastisement.", "[89.14] Most sure!y your Lord is watching.", "[89.15] And as for man, when his Lord tries him, then treats him with honor and makes him lead an easy life, he says: My Lord honors me.", "[89.16] But when He tries him (differently), then straitens to him his means of subsistence, he says: My Lord has disgraced me.", "[89.17] Nay! but you do not honor the orphan,", "[89.18] Nor do you urge one another to feed the poor,", "[89.19] And you eat away the heritage, devouring (everything) indiscriminately,", "[89.20] And you love wealth with exceeding love.", "[89.21] Nay! when the earth is made to crumble to pieces,", "[89.22] And your Lord comes and (also) the angels in ranks,", "[89.23] And hell is made to appear on that day. On that day shall man be mindful, and what shall being mindful (then) avail him?", "[89.24] He shall say: O! would that I had sent before for (this) my life!", "[89.25] But on that day shall no one chastise with (anything like) His chastisement,", "[89.26] And no one shall bind with (anything like) His binding.", "[89.27] O soul that art at rest!", "[89.28] Return to your Lord, well-pleased (with him), well-pleasing (Him),", "[89.29] So enter among My servants,", "[89.30] And enter into My garden.", "[87.1] Glorify the name of your Lord, the Most High,", "[87.2] Who creates, then makes complete,", "[87.3] And Who makes (things) according to a measure, then guides (them to their goal),", "[87.4] And Who brings forth herbage,", "[87.5] Then makes it dried up, dust-colored.", "[87.6] We will make you recite so you shall not forget,", "[87.7] Except what Allah pleases, surely He knows the manifest, and what is hidden.", "[87.8] And We will make your way smooth to a state of ease.", "[87.9] Therefore do remind, surely reminding does profit.", "[87.10] He who fears will mind,", "[87.11] And the most unfortunate one will avoid it,", "[87.12] Who shall enter the great fire;", "[87.13] Then therein he shall neither live nor die.", "[87.14] He indeed shall be successful who purifies himself,", "[87.15] And magnifies the name of his Lord and prays.", "[87.16] Nay! you prefer the life of this world,", "[87.17] While the hereafter is better and more lasting.", "[87.18] Most surely this is in the earlier scriptures,", "[87.19] The scriptures of Ibrahim and Musa.", "[24.1] (This is) a chapter which We have revealed and made obligatory and in which We have revealed clear communications that you may be mindful.", "[24.2] (As for) the fornicatress and the fornicator, flog each of them, (giving) a hundred stripes, and let not pity for them detain you in the matter of obedience to Allah, if you believe in Allah and the last day, and let a party of believers witness their chastisement.", "[24.3] The fornicator shall not marry any but a fornicatress or idolatress, and (as for) the fornicatress, none shall marry her but a fornicator or an idolater; and it is forbidden to the believers.", "[24.4] And those who accuse free women then do not bring four witnesses, flog them, (giving) eighty stripes, and do not admit any evidence from them ever; and these it is that are the transgressors,", "[24.5] Except those who repent after this and act aright, for surely Allah is Forgiving, Merciful.", "[24.6] And (as for) those who accuse their wives and have no witnesses except themselves, the evidence of one of these (should be taken) four times, bearing Allah to witness that he is most surely of the truthful ones.", "[24.7] And the fifth (time) that the curse of Allah be on him if he is one of the liars.", "[24.8] And it shall avert the chastisement from her if she testify four times, bearing Allah to witness that he is most surely one of the liars;", "[24.9] And the fifth (time) that the wrath of Allah be on her if he is one of the truthful.", "[24.10] And were it not for Allah's grace upon you and His mercy-- and that Allah is Oft-returning (to mercy), Wise!", "[24.11] Surely they who concocted the lie are a party from among you. Do not regard it an evil to you; nay, it is good for you. Every man of them shall have what he has earned of sin; and (as for) him who took upon himself the main part thereof, he shall have a grievous chastisement.", "[24.12] Why did not the believing men and the believing women, when you heard it, think well of their own people, and say: This is an evident falsehood?", "[24.13] Why did they not bring four witnesses of it? But as they have not brought witnesses they are liars before Allah.", "[24.14] And were it not for Allah's grace upon you and His mercy in this world and the hereafter, a grievous chastisement would certainly have touched you on account of the discourse which you entered into.", "[24.15] When you received it with your tongues and spoke with your mouths what you had no knowledge of, and you deemed it an easy matter while with Allah it was grievous.", "[24.16] And why did you not, when you heard it, say: It does not beseem us that we should talk of it; glory be to Thee! this is a great calumny?", "[24.17] Allah admonishes you that you should not return to the like of it ever again if you are believers.", "[24.18] And Allah makes clear to you the communications; and Allah is Knowing, Wise.", "[24.19] Surely (as for) those who love that scandal should circulate respecting those who believe, they shall have a grievous chastisement in this world and the hereafter; and Allah knows, while you do not know.", "[24.20] And were it not for Allah's grace on you and His mercy, and that Allah is Compassionate, Merciful.", "[24.21] O you who believe! do not follow the footsteps of the Shaitan, and whoever follows the footsteps of the Shaitan, then surely he bids the doing of indecency and evil; and were it not for Allah's grace upon you and His mercy, not one of you would have ever been pure, but Allah purifies whom He pleases; and Allah is Hearing, Knowing.", "[24.22] And let not those of you who possess grace and abundance swear against giving to the near of kin and the poor and those who have fled in Allah's way, and they should pardon and turn away. Do you not love that Allah should forgive you? And Allah is Forgiving, Merciful.", "[24.23] Surely those who accuse chaste believing women, unaware (of the evil), are cursed in this world and the hereafter, and they shall have a grievous chastisement.", "[24.24] On the day when their tongues and their hands and their feet shall bear witness against them as to what they did.", "[24.25] On that day Allah will pay back to them in full their just reward, and they shall know that Allah is the evident Truth.", "[24.26] Bad women .are for bad men and bad men are for bad women. Good women are for good men and good men are for good women", "[24.27] O you who believe! Do not enter houses other than your own houses until you have asked permission and saluted their inmates; this is better for you, that you may be mindful.", "[24.28] But if you do not find any one therein, then do not enter them until permission is given to you; and if it is said to you: Go back, then go back; this is purer for you; and Allah is Cognizant of what you do.", "[24.29] It is no sin in you that you enter uninhabited houses wherein you have your necessaries; and Allah knows what you do openly and what you hide.", "[24.30] Say to the believing men that they cast down their looks and guard their private parts; that is purer for them; surely Allah is Aware of what they do.", "[24.31] And say to the believing women that they cast down their looks and guard their private parts and do not display their ornaments except what appears thereof, and let them wear their head-coverings over their bosoms, and not display their ornaments except to their husbands or their fathers, or the fathers of their husbands, or their sons, or the sons of their husbands, or their brothers, or their brothers' sons, or their sisters' sons, or their women, or those whom their right hands possess, or the male servants not having need (of women), or the children who have not attained knowledge of what is hidden of women; and let them not strike their feet so that what they hide of their ornaments may be known; and turn to Allah all of you, O believers! so that you may be successful.", "[24.32] And marry those among you who are single and those who are fit among your male slaves and your female slaves; if they are needy, Allah will make them free from want out of His grace; and Allah is Ample-giving, Knowing.", "[24.33] And let those who do not find the means to marry keep chaste until Allah makes them free from want out of His grace. And (as for) those who ask for a writing from among those whom your right hands possess, give them the writing if you know any good in them, and give them of the wealth of Allah which He has given you; and do not compel your slave girls to prostitution, when they desire to keep chaste, in order to seek the frail good of this world's life; and whoever compels them, then surely after their compulsion Allah is Forgiving, Merciful.", "[24.34] And certainly We have sent to you clear communications and a description of those who have passed away before you, and an admonition to those who guard (against evil).", "[24.35] Allah is the light of the heavens and the earth; a likeness of His light is as a niche in which is a lamp, the lamp is in a glass, (and) the glass is as it were a brightly shining star, lit from a blessed olive-tree, neither eastern nor western, the oil whereof almost gives light though fire touch it not-- light upon light-- Allah guides to His light whom He pleases, and Allah sets forth parables for men, and Allah is Cognizant of all things.", "[24.36] In houses which Allah has permitted to be exalted and that His name may be remembered in them; there glorify Him therein in the mornings and the evenings,", "[24.37] Men whom neither merchandise nor selling diverts from the remembrance of Allah and the keeping up of prayer and the giving of poor-rate; they fear a day in which the hearts and eyes shall turn about;", "[24.38] That Allah may give them the best reward of what they have done, and give them more out of His grace; and Allah gives sustenance to whom He pleases without measure.", "[24.39] And (as for) those who disbelieve, their deeds are like the mirage in a desert, which the thirsty man deems to be water; until when he comes to it he finds it to be naught, and there he finds Allah, so He pays back to him his reckoning in full; and Allah is quick in reckoning;", "[24.40] Or like utter darkness in the deep sea: there covers it a wave above which is another wave, above which is a cloud, (layers of) utter darkness one above another; when he holds out his hand, he is almost unable to see it; and to whomsoever Allah does not give light, he has no light.", "[24.41] Do you not see that Allah is He Whom do glorify all those who are in the heavens and the earth, and the (very) birds with expanded wings? He knows the prayer of each one and its glorification, and Allah is Cognizant of what they do.", "[24.42] And Allah's is the kingdom of the heavens and the earth, and to Allah is the eventual coming.", "[24.43] Do you not see that Allah drives along the clouds, then gathers them together, then piles them up, so that you see the rain coming forth from their midst? And He sends down of the clouds that are (like) mountains wherein is hail, afflicting therewith whom He pleases and turning it away from whom He pleases; the flash of His lightning almost takes away the sight.", "[24.44] Allah turns over the night and the day; most surely there is a lesson in this for those who have sight.", \
        "[24.45] And Allah has created from water every living creature: so of them is that which walks upon its belly, and of them is that which walks upon two feet, and of them is that which walks upon four; Allah creates what He pleases; surely Allah has power over all things.", "[24.46] Certainly We have revealed clear communications, and Allah guides whom He pleases to the right way.", "[24.47] And they say: We believe in Allah and in the apostle and we obey; then a party of them turn back after this, and these are not believers.", "[24.48] And when they are called to Allah and His Apostle that he may judge between them, lo! a party of them turn aside.", "[24.49] And if the truth be on their side, they come to him quickly, obedient.", "[24.50] Is there in their hearts a disease, or are they in doubt, or do they fear that Allah and His Apostle will act wrongfully towards them? Nay! they themselves are the unjust.", "[24.51] The response of the believers, when they are invited to Allah and His Apostle that he may judge between them, is only to say: We hear and we obey; and these it is that are the successful.", "[24.52] And he who obeys Allah and His Apostle, and fears Allah, and is careful of (his duty to) Him, these it is that are the achievers.", "[24.53] And they swear by Allah with the most energetic of their oaths that if you command them they would certainly go forth. Say: Swear not; reasonable obedience (is desired); surely Allah is aware of what you do.", "[24.54] Say: Obey Allah and obey the Apostle; but if you turn back, then on him rests that which is imposed on him and on you rests that which is imposed on you; and if you obey him, you are on the right way; and nothing rests on the Apostle but clear delivering (of the message).", "[24.55] Allah has promised to those of you who believe and do good that He will most certainly make them rulers in the earth as He made rulers those before them, and that He will most certainly establish for them their religion which He has chosen for them, and that He will most certainly, after their fear, give them security in exchange; they shall serve Me, not associating aught with Me; and whoever is ungrateful after this, these it is who are the. transgressors.", "[24.56] And keep up prayer and pay the poor-rate and obey the Apostle, so that mercy may be shown to you.", "[24.57] Think not that those who disbelieve shall escape in the earth, and their abode is the fire; and certainly evil is the resort!", "[24.58] O you who believe! let those whom your right hands possess and those of you who have not attained to puberty ask permission of you three times; before the morning prayer, and when you put off your clothes at midday in summer, and after the prayer of the nightfall; these are three times of privacy for you; neither is it a sin for you nor for them besides these, some of you must go round about (waiting) upon others; thus does Allah make clear to you the communications, and Allah is Knowing, Wise.", "[24.59] And when the children among you have attained to puberty, let them seek permission as those before them sought permission; thus does Allah make clear to you His communications, and Allah is knowing, Wise.", "[24.60] And (as for) women advanced in years who do not hope for a marriage, it is no sin for them if they put off their clothes without displaying their ornaments; and if they restrain themselves it is better for them; and Allah is Hearing, Knowing.", "[24.61] There is no blame on the blind man, nor is there blame on the lame, nor is there blame on the sick, nor on yourselves that you eat from your houses, or your fathers' houses or your mothers' houses, or your brothers' houses, or your sisters' houses, or your paternal uncles' houses, or your paternal aunts' houses, or your maternal uncles' houses, or your maternal aunts' houses, or what you possess the keys of, or your friends' (houses). It is no sin in you that you eat together or separately. So when you enter houses, greet your people with a salutation from Allah, blessed (and) goodly; thus does Allah make clear to you the communications that you may understand.", "[24.62] Only those are believers who believe in Allah and His Apostle, and when they are with him on a momentous affair they go not away until they have asked his permission; surely they who ask your permission are they who believe in Allah and His Apostle; so when they ask your permission for some affair of theirs, give permission to whom you please of them and ask forgiveness for them from Allah; surely Allah is Forgiving, Merciful.", "[24.63] Do not hold the Apostle's calling (you) among you to be like your calling one to the other; Allah indeed knows those who steal away from among you, concealing themselves; therefore let those beware who go against his order lest a trial afflict them or there befall them a painful chastisement.", "[24.64] Now surely Allah's is whatever is in the heavens and the earth; He knows indeed that to which you are conforming yourselves; and on the day on which they are returned to Him He will inform them of what they did; and Allah is Cognizant of all things.", "[85.1] I swear by the mansions of the stars,", "[85.2] And the promised day,", "[85.3] And the bearer of witness and those against whom the witness is borne.", "[85.4] Cursed be the makers of the pit,", "[85.5] Of the fire (kept burning) with fuel,", "[85.6] When they sat by it,", "[85.7] And they were witnesses of what they did with the believers.", "[85.8] And they did not take vengeance on them for aught except that they believed in Allah, the Mighty, the Praised,", "[85.9] Whose is the kingdom of the heavens and the earth; and Allah is a Witness of all things.", "[85.10] Surely (as for) those who persecute the believing men and the believing women, then do not repent, they shall have the chastisement of hell, and they shall have the chastisement of burning.", "[85.11] Surely (as for) those who believe and do good, they shall have gardens beneath which rivers flow, that is the great achievement.", "[85.12] Surely the might of your Lord is great.", "[85.13] Surely He it is Who originates and reproduces,", "[85.14] And He is the Forgiving, the Loving,", "[85.15] Lord of the Arsh, the Glorious,", "[85.16] The great doer of what He will.", "[85.17] Has not there come to you the story of the hosts,", "[85.18] Of Firon and Samood?", "[85.19] Nay! those who disbelieve are in (the act of) giving the lie to the truth.", "[85.20] And Allah encompasses them on every side.", "[85.21] Nay! it is a glorious Quran,", "[85.22] In a guarded tablet.", "[113.1] Say: I seek refuge in the Lord of the dawn,", "[113.2] From the evil of what He has created,", "[113.3] And from the evil of the utterly dark night when it comes,", "[113.4] And from the evil of those who blow on knots,", "[113.5] And from the evil of the envious when he envies", "[52.1] I swear by the Mountain,", "[52.2] And the Book written", "[52.3] In an outstretched fine parchment,", "[52.4] And the House (Kaaba) that is visited,", "[52.5] And the elevated canopy", "[52.6] And the swollen sea", "[52.7] Most surely the punishment of your Lord will come to pass;", "[52.8] There shall be none to avert it;", "[52.9] On the day when the heaven shall move from side to side", "[52.10] And the mountains shall pass away passing away (altogether).", "[52.11] So woe on that day to those who reject (the truth),", "[52.12] Those who sport entering into vain discourses.", "[52.13] The day on which they shall be driven away to the fire of hell with violence.", "[52.14] This is the fire which you used to give the lie to.", "[52.15] Is it magic then or do you not see?", "[52.16] Enter into it, then bear (it) patiently, or do not bear (it) patiently, it is the same to you; you shall be requited only (for) what you did.", "[52.17] Surely those who guard (against evil) shall be in gardens and bliss", "[52.18] Rejoicing because of what their Lord gave them, and their Lord saved them from the punishment of the burning fire.", "[52.19] Eat and drink pleasantly for what you did,", "[52.20] Reclining on thrones set in lines, and We will unite them to large-eyed beautiful ones.", "[52.21] And (as for) those who believe and their offspring follow them in faith, We will unite with them their offspring and We will not diminish to them aught of their work; every man is responsible for what he shall have wrought.", "[52.22] And We will aid them with fruit and flesh such as they desire.", "[52.23] They shall pass therein from one to another a cup wherein there shall be nothing vain nor any sin.", "[52.24] And round them shall go boys of theirs as if they were hidden pearls.", "[52.25] And some of them shall advance towards others questioning each other.", "[52.26] Saying: Surely we feared before on account of our families:", "[52.27] But Allah has been gracious to us and He has saved us from the punishment of the hot wind:", "[52.28] Surely we called upon Him before: Surely He is the Benign, the Merciful.", "[52.29] Therefore continue to remind, for by the grace of your Lord, you are not a soothsayer, or a madman.", "[52.30] Or do they say: A poet, we wait for him the evil accidents of time.", "[52.31] Say: Wait, for surely I too with you am of those who wait.", "[52.32] Nay! do their understandings bid them this? Or are they an inordinate people?", "[52.33] Or do they say: He has forged it. Nay! they do not believe.", "[52.34] Then let them bring an announcement like it if they are truthful.", "[52.35] Or were they created without there being anything, or are they the creators?", "[52.36] Or did they create the heavens and the earth? Nay! they have no certainty.", "[52.37] Or have they the treasures of your Lord with them? Or have they been set in absolute authority?", "[52.38] Or have they the means by which they listen? Then let their listener bring a clear authority.", "[52.39] Or has He daughters while you have sons?", "[52.40] Or do you ask them for a reward, so that they are overburdened by a debt?", "[52.41] Or have they the unseen so that they write (it) down?", "[52.42] Or do they desire a war? But those who disbelieve shall be the vanquished ones in war.", "[52.43] Or have they a god other than Allah? Glory be to Allah from what they set up (with Him).", "[52.44] And if they should see a portion of the heaven coming down, they would say: Piled up clouds.", "[52.45] Leave them then till they meet that day of theirs wherein they shall be made to swoon (with terror):", "[52.46] The day on which their struggle shall not avail them aught, nor shall they be helped.", "[52.47] And surely those who are unjust shall have a punishment besides that (in the world), but most of them do not know.", "[52.48] And wait patiently for the judgment of your Lord, for surely you are before Our eyes, and sing the praise of your Lord when you rise;", "[52.49] And in the night, give Him glory too, and at the setting of the stars."]
        verse = random.sample(koran, number)
        ct = datetime.datetime.now()
        kor = "koran: "
        print(kor, verse, ct)
        print()

    def message():
        chat = input("$ ")
        while True:
            try:
                number = int(input("Indicate number of (lh) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        ctd = datetime.datetime.now()
        lh = "lh: "
        print(lh + "" + "$" + "" + " " + "" + usr, chat)
        for _ in range(number):
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            time.sleep(random.randint(0,4))
            print()
            nano = (diction)
            sitch  = (round(random.random()*9999,4))
            lokalhost = "LOKALHOST: "
            chat = random.sample(nano, random.randint(0,5))
            ct = datetime.datetime.now()
            print(lokalhost, random_letters, sitch, chat, ct)

    def souls():
        nano = (diction)
        while True:
            try:
                number = int(input("Indicate number of (souls) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(4)
        print()
        for _ in range(number):
            time.sleep(1)
            print()
            anrdom = (round(random.random()*999,8))
            soulchat = random.sample(nano, 1)
            ct = datetime.datetime.now()
            souls = "souls: "
            print(souls, anrdom, soulchat, ct)

    def c():
        chat2 = input("chat: ")
        print()
        print(usr + "" + " " + "" + "You: " + "" + chat2)
        for _ in range(6):
            print()
            time.sleep(random.randint(1,4))
            kpop = ["AK", "Joji", "Kiera", "Ape"]
            kchatz = random.sample(kpop, 1)
            chatso = ["how are you", "i am fine", "youre welcome", "i dont know", "maybe", "hi", "hello", "whats up", "im thinking of you", "i miss you", "i love you", "i love you deeply", "i love you so much", "i love you always", "i love you much", "where are you", "ill come over", "come over here", "lets meet", "playing", "just joking", "youre in my mind", "whenever", "i saw you", "we were together", "we met", "we met a while ago", "we just met", "you saw me", "im studying", "im in school", "im travelling", "im in transit", "im at work", "im playing", "im shopping", "im at the grocery", "im at the parlor", "im at home", "where you are", "i adore you", "you are adored", "you are special", "am i special", "do you love me?", "yes", "no", "maybe", "lets meet again", "i hope to see you again", "what are you thinking", "youre always in my mind", "in the depths of soul", "in as much as I want", "nevertheless", "coming up with it", "i don't know this", "thinking of it", "thinking of you", "thinking of us", "i never want to but", "carry me all the way", "i am happy", "starting", "i never know how", "as much as i would", "killing me softly", "killing us", "the quietest weather", "gray clouds above", "i see the clear sky", "while the sky is bluest", "i've never been apart", "how would i know", "will i see you again", "it came up to me", "i was surprised", "surprising", "i would", "come to me", "start with this", "a few words", "lenten season is upon us", "i love", "thinking", "stop", "i wish i would have", "consider me", "i am looking for food", "while i am clothed", "walking the distance", "i still end up with you", "consider my wish", "halfed tree", "searching", "unsure", "not minding everyone", "listening to music", "on my computer", "typing", "eating", "sleeping", "thinking", "never missing", "stopping", "staring", "resting", "excruciating pain", "this sadness", "while im without", "collecting", "listening", "happiness", "the surf", "inspired", "rocking the music", "travelling", "playing", "while music plays", "stirring things up", "taking a bath", "walking on the shore", "grinding", "i never knew how", "i be at it", "considered everything", "i died", "i slept", "its wrapped", "made a union", "the sky bleeds", "music is spoken", "chilled", "i am spoiled", "this bringeth happiness", "its up to me", "the weather is", "i stay awake", "pillows", "grains", "half of the time", "it ends here", "i take flight", "distance is", "i like this", "forever", "lets meet", "gathered my wits", "what is?", "what is ?", "ouch!", "**", "that?", "ok", "ok bye", "really?", "why not..", "aww why?", "tell me!", "what s it?", "don't do that to me", "hi sir", "oh uhm..", "I honestly don't know", "I know", "this", "did you see", "good boy", "good pinsan", "do you have a gf?", "*kisses*", "feel good!", "like this", "like thus", "what are you doing to me?", "shall we talk about something else?", "oh yes..", "because", "I might consider it", "yes you :)", "you and me", "I like that more", "me?", "I agree", "I love you more", "I will", "IDK", "stuff", "sorry you cant do this here", "I love it", "oh no", ""]
            kchat = random.sample(chatso, 1)
            c = "c: "
            print(c, kchatz, kchat)

    def asciii():
        print()
        ctm = datetime.datetime.now()
        def generate_random_letters():
            random1 = random.choice(string.ascii_letters)
            random2 = random.choice(string.ascii_letters)
            random3 = random.choice(string.ascii_letters)
            letters = [random1, random2, random3]
            random.shuffle(letters)
            return letters
        random_letters = generate_random_letters()
        sitch  = (round(random.random()*9999,4))
        asc = "ascii:"
        print(asc, usr, random_letters, sitch, ctm)
        pr1 = (round(random.random()*99999999999999999999999999999999999999999))
        pr2 = (round(random.random()*99999999999999999999999999999999999999999))
        pr3 = (round(random.random()*99999999999999999999999999999999999999999))
        pr4 = (round(random.random()*99999999999999999999999999999999999999999))
        pr5 = (round(random.random()*99999999999999999999999999999999999999999))
        pr6 = (round(random.random()*99999999999999999999999999999999999999999))
        pr7 = (round(random.random()*99999999999999999999999999999999999999999))
        pr8 = (round(random.random()*99999999999999999999999999999999999999999))
        pr9 = (round(random.random()*99999999999999999999999999999999999999999))
        pr10 = (round(random.random()*99999999999999999999999999999999999999999))
        pr11 = (round(random.random()*99999999999999999999999999999999999999999))
        pr12 = (round(random.random()*99999999999999999999999999999999999999999))
        print()
        print(pr1)
        print(pr2)
        print(pr3)
        print(pr4)
        print(pr5)
        print(pr6)
        print(pr7)
        print(pr8)
        print(pr9)
        print(pr10)
        print(pr11)
        print(pr12)

    def mp3():
        print("You queue five tracks from an mp3 player that you found on the train...")
        time.sleep(4)
        tracks = ["NO RULES by Mija, bloody white", "How Low by Ludacris", "BURN IT DOWN by Kayzo", "COUNT DANKULA by GENGHAR, GHASTLY", "Chum by Earl Sweatshirt", "O.P.U.S. by Subtronics", "Cyclops Rocks by Subtronics", "Wyclef Jean by Young Thug", "Wild for the Night by A$AP Rocky, Skrillex", "Hercules by Young Thug", "Angels by A$AP Rocky", "F**kin' Problems by A$AP Rocky, Drake, 2 Chainz, Kendrick Lamar", "Goldie by A$AP Rocky", "Don't Think It Over by Her's", "In My Mind - Deathpact Reprise by ILLENIUM, Excision, HALIENE, Deathpact", "Morning Star's Fall by Caster, Mantis", "Worldwide Suicide by In Hearts Wake, PhaseOne", "Never Let Go by Dion Timmer, Haley Maze", "Dont Wake Me Up by Oliverse", "Someone Else by Bear Grillz, Elle Vee", "Bottle Of Rain by Kayzo, POORSTACY", "GIGACHAD by Kai Wachi", "You're Gonna Love Me by Eliminate, Leah Culver", "Love, Love, Love by As Tall As Lions", "MakeDamnSure by Taking Back Sunday", "Kings And Queens by Thirty Seconds To Mars", "Maps by Yeah Yeah Yeahs", "Poetically Pathetic by Amber Pacific", "Tonight by FM Static", "Anthem Of Our Dying Day by Story Of The Year", "MAKE U MISS ME by Kayzo, Seon", "NEWS FLASH by Kayzo, Kamiyada+", "Fight or Flight by Alison Wonderland, MEMBA", "YUKON (INTERLUDE) by Joji", "My Hero by Foo Fighters", "Called Out In The Dark by Snow Patrol", "my god by Trevor Hall", "Real Love by Jess Glynne, Clean Bandit", "MIND YOUR BUSINESS by will.i.am, Britney Spears", "Obstacle 1 by Interpol", "Full Circle by HAELOS", "Hold On by HAELOS", "Fire Ina Hole by Method Man, Redman", "Rockit by Herbie Hancock", "Hymn For The Weekend by Coldplay", "Agent Orange by Slapshock", "I'm Gonna Be by Post Malone", "I'm Not Okay by My Chemical Romance", "Rude Boy by Rihanna", "D.O.A. (Death Of Auto-Tune) by JAY-Z", "Roses by The Chainsmokers, ROZES", "Stick Stickly by Attack Attack!", "Jail pt 2 by Kanye West", "Risk by Deftones", "This Is What You Came For by Calvin Harris, Rihanna", "Hot-n-Fun by N.E.R.D, Nelly Furtado", "Work by Rihanna, Drake", "777 by Kid Trunks, XXXTENTACION", "Music by Madonna", "What's My Name by Rihanna, Drake", "Love Never Felt So Good by Michael Jackson, Justin Timberlake", "Sweet Disposition by The Temper Trap", "Forrest Gump by Frank Ocean", "Purification by Purification", "Total Liberation by Gather", "Soaked In Torment by All Out War", "Scream & Shout by will.i.am, Britney Spears", "Decode by Paramore", "Miracle by Paramore", "Messiah by Alison Wonderland, M-Phazes", "Heart Skipped A Beat by The xx", "Basic Space by The xx", "Intro by The xx", "Islands by The xx", "Crystalized by The xx", "VCR by The xx", "Mood Ring by Lorde", "Sudden Desire by Hayley Williams", "August 10 by Khruangbin", "The Pioneers by Bloc Party", "Chasing Cars by Snow Patrol", "RUNNING by The Kid LAROI", "Shake It by Metro Station", "The Less I Know The Better by Tame Impala", "Miss The Rage by Trippie Red, Playboi Carti", "This Is America by Childish Gambino", "Consistency by Megan Thee Stallion, Jhene Aiko", "Flexing So Hard by Higher Brothers", "Laundry by QUIX", "Cologne by Clean Bandit, Nikki Cislyn, Javeon", "Pachuca Sunrise by Minus The Bear", "Feeling Like The End by Joji", "Nomadic by Higher Brothers, Joji", "Upper Echelon by Travis Scott, T.I., 2 Chainz", "Same Ol' Mistakes by Rihanna", "Power Trip by J. Cole, Miguel", "Hits From The Bong by Cypress Hill", "Y.O.U. by Method Man, Redman"]
        music = random.sample(tracks, 5)
        ct = datetime.datetime.now()
        mp3 = "mp3: "
        print(mp3, music, ct)
        time.sleep(3)

    def monopoly():
        print("You rolled:")
        time.sleep(2)
        dice1 = ["1", "2", "3", "4", "5", "6", "7", "8"]
        dice2 = ["1", "2", "3", "4", "5", "6", "7", "8"]
        roll1 = random.sample(dice1, 1)
        roll2 = random.sample(dice2, 1)
        print(roll1)
        print(roll2)
        time.sleep(2)
        boxes = ["Mediterranean Avenue", "Community Chest", "Baltic Avenue", "INCOME TAX", "Reading Railroad", "Oriental Avenue", "Chance", "Vermont Avenue", "Connecticut Avenue", "Jail", "St. Charles Palace", "Electric Company", "States Avenue", "Virginia Avenue", "Pennsylvania Railroad", "St. James Place", "Community Chest", "Free Parking", "Kentucky Avenue", "Chance", "Indiana Avenue", "Illinois Avenue", "B&O Railroad", "Atlantic Avenue", "Ventnor Avenue", "Water Works", "Marvin Gardens", "GO TO JAIL", "Pacific Avenue", "North Carolina Avenue", "Community Chest", "Pennsylvania Avenue", "Short Line", "Chance", "Park Place", "LUXURY TAX", "Boardwalk"]
        box = random.sample(boxes, 1)
        print("And landed in =")
        ct = datetime.datetime.now()
        monopoly = "monopoly: "
        print(monopoly, box, ct)
        time.sleep(3)

    def equips():
        time.sleep(2)
        print("head:")
        headgear = ["samurai helmet", "bike helmet", "motorcycle helmet", "astronaut helmet", "pilot helmet", "aviator hat", "baseball cap", "backwards baseball cap", "trucker cap", "backwards trucker cap", "construction helmet", "miner helmet", "skate helmet", "ski mask", "facemask", "beanie", "birthday party hat", "pantyhose", "f13th mask", "jabbawockee mask", "none", "poring hat", "beehive", "idea bubble", "speech bubble", "bucket hat", "black bucket hat", "beige bucket hat", "orange bucket hat", "blue bucket hat", "american football helmet", "rugby helmet", "emo hair", "mohawk", "blonded semi-balded", "skinhead", "tropika", "glasses", "raybans", "shades", "spectacles", "night-vision goggles", "pilot goggles", "black-rimmed glasses", "nostril piercing", "tibetan headgear", "sikh headgear", "muslim hat", "skullcap", "muslim skullhat", "long hair", "salt and pepper", "blonde", "headphones", "earphones", "visor hat", "headband", "cat headband", "rabbit headband", "afro", "curly curls", "facial mask", "face paint", "warpaint", "unipaint", "maked-up", "bush headgear", "soldier helmet", "buddhahead", "game-night drink", "cig", "tobacco", "spliff", "straw", "british army guard headgear", "police helmet", "police mask", "hanja mask", "java mask", "african continent mask", "feather", "chef hat", "indian chief headgear", "black paint", "hijab"]
        head= random.sample(headgear, 1)
        print(head)
        print("torso:")
        torsogear = ["knight armor", "police armor", "samurai armor", "karate uniform", "police uniform", "soldier uniform", "korean robe", "japanese robe", "barong", "polo", "shirt", "black shirt", "sweater", "tanktop", "backpack", "slingbag", "none", "chest hair", "kevlar", "press vest", "bush gear", "hoodie", "white hoodie", "blue hoodie", "tight shirt", "nikes", "puma", "adidas", "coca-cola retro shirt", "rasta shirt", "sash", "soccer uniform", "american football armor", "football shirt", "soccer shirt", "referee shirt", "pacemaker", "bra", "bikini", "chest bag", "tuxedo", "suit", "bowtie", "tie", "apron", "chef uniform", "red paint", "black paint", "astronaut suit", "diving suit", "rashguard", "jersey", "bathrobe", "farmer gear", "lanyard", "muslim clothing", "sikh clothing", "tourguide uniform", "boyscout uniform", "girlscout uniform", "black sweater", "scarf", "shawl", "green hoodie", "pink hoodie", "jacket", "windbreaker", "varsity jacket", "jock jacket", "vest", "coat"]
        torso= random.sample(torsogear, 1)
        print(torso)
        print("hand:")
        handgear = ["sword", "samurai", "club", "knife", "machete", "ice cream", "food", "coffee", "pizza", "camera", "gun", "staff", "ruler", "katana", "arnis", "nunchucks", "cat", "tablet", "phone", "iphone", "android", "fruitshake", "vape", "bong", "spliff", "joint", "beer", "champagne", "chainsaw", "folder", "testpaper", "pen", "macbook", "laptop", "linux computer", "pencil", "paintbrush", "tire pump", "fire extinguisher", "measuring device", "scalpel", "diamond cutter", "diamond", "diamonds", "trash", "water", "none", "empty-hand", "spraypaint", "smartwatch", "dynamite", "c4", "whisker", "whiskey", "liquor", "flask", "leaf", "feather", "book", "novel", "junkfood", "rifle", "sniper", "handgun", "laser", "keys", "guitar", "electric guitar", "classical guitar", "ukulele", "keyboard", "burger", "twig", "plank", "paddel", "coins", "money", "dollar bills", "fruit", "vegetable", "ps4 controller", "xbox controller", "ipod", "yarn", "spear", "bow"]
        hand= random.sample(handgear, 1)
        print(hand)
        print("legs:")
        leggear = ["tights", "shorts", "cycling shorts", "skirt", "bushwear", "pants", "leggings", "elephant pants", "skinny jeans", "jeans", "none", "trunks", "pants", "pants", "pants", "holster", "bruise", "slacks", "hiking pants", "karate pants", "taekwondo pants", "mma shorts", "briefs", "sleather pants"]
        legs= random.sample(leggear, 1)
        print(legs)
        print("feet:")
        feetgear = ["slippers", "hotel slippers", "shoes", "shoes", "shoes", "shoes", "boots", "beige boots", "black army boots", "nikes", "adidas", "puma", "converse", "chucks", "none", "socks", "clogs", "leather shoes", "white shoes", "skateboard", "longboard", "sneakers", "new balance", "world balance", "fluffy shoes", "fluffy slippers", "sandals"]
        feet= random.sample(feetgear, 1)
        print(feet)
        print()
        ct = datetime.datetime.now()
        equips = "equips: "
        print(equips, head, torso, hand, legs, feet, ct)

    def rpg():
        time.sleep(2)
        paths = ["You level up", "You level up", "You level up", "You walk in a field", "You encounter an animal", "You encounter a monster", "You encounter an enemy", "You encounter a friend", "You encounter an ally", "You enter an alley", "It is night time", "The sun just rised", "It is dawn", "It is dusk", "You enter the university", "You sit down on your computer", "You just chill", "You chill in a cafe", "You feel sleepy", "You are hungry", "You walk on", "You run straight", "You run in loops", "You are tired", "You are bullied", "You are sent to the hospital", "You go on a roadtrip", "You hike", "You mine", "You are out of money", "You just earned your salary", "You spend your time waiting", "You just nearly died", "You do your assignment", "You paint", "You hum", "You rap", "You sing", "You hear someone singing", "You compose rap", "You compose a classical track", "You feel lonely", "You feel happy", "You feel ecstatic", "You yearn for something", "You feel you should meditate", "You feel you should pray", "You walk in a church", "You walk in a temple", "You walk in a mosque", "You walk in a forest", "You walk in a jungle", "You walk along the road", "You're in the city", "You ride a bus", "You ride a cab", "You take out the trash", "You find a job", "Someone gave you work", "You worship", "You're in transit", "You surf the internet", "You got hacked", "You got scammed", "You exercise", "You were commissioned in the army", "You were commisioned in the police force", "You were commissioned in the airforce", "You were commissioned in the marines", "You have a mission", "You feel inspired", "You feel uninspired", "You feel creative block", "You feel like dancing", "You hear music", "You watch TV", "You hear the radio", "You are fatigued", "You enter war", "You meet someone", "You view film showing schedules", "You browse through courses", "You walk into a market", "You think of getting souvenirs", "You explore the place"]
        path = random.sample(paths, 1)
        ct = datetime.datetime.now()
        rpg = "rpg: "
        print(rpg, path, ct)
        time.sleep(3)

    def archery():
        time.sleep(2)
        print()
        print("You aim your bow..")
        time.sleep(2)
        print("You hit:")
        num = (round(random.random()*30,3))
        print(num)
        print("centimeters from the bullseye with")
        raditn = (random.randint(50,100))
        print(raditn)
        ct = datetime.datetime.now()
        print("percent accuracy", ct)
        archery = "archery: "
        time.sleep(3)

    def color_key():
        time.sleep(1)
        color = ["red", "crimson", "maroon", "scarlet", "orange", "amber", "rust", "salmon", "green", "emerald", "lime", "olive", "yellow", "gold", "lemon", "mustard", "blue", "azure", "indigo", "teal", "purple", "lavender", "magenta", "violet", "brown", "beige", "chocolate", "sienna", "gray", "charcoal", "silver", "slate", "black", "ebony", "jet", "onyx", "white", "alabaster", "ivory", "pearl", "pink", "sky blue", "neon green", "neon yellow", "neon orange", "neon blue"]
        colors = random.sample(color, 5)
        ct = datetime.datetime.now()
        colorkey = "color key: "
        print(colorkey, colors, ct)

    def magic():
        opp = "OPPONENT"
        print(opp)
        print()
        deck1 = ["Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Island", "Joint Assault (Spell, 1 Forest)", "Joint Assault (Spell, 1 Forest)", "Ice Cage (Spell, 1 Land and 1 Island)", "Lair Delve (Spell, 2 Land and 1 Forest)", "Lair Delve (Spell, 2 Land and 1 Forest)", "Overrun (Spell, 2 Land and 3 Forest)", "Llanowar Elves (Creature, 1 Forest)", "Llanowar Elves (Creature, 1 Forest)", "Nephalia Smuggler (Creature, 1 Island)", "Wingcrafter (Creature, 1 Island)", "Wingcrafter (Creature, 1 Island)", "Runeclaw Bear (Creature, 1 Land and 1 Forest)", "Nightshade Peddler (Creature, 1 Land and 1 Forest)", "Nightshade Peddler (Creature, 1 Land and 1 Forest)", "Tandem Lookout (Creature, 2 Land and 1 Island)", "Tandem Lookout (Creature, 2 Land and 1 Island)", "Trusted Forcemage (2 Land and 1 Forest)", "Trusted Forcemage (Creature, 2 Land and 1 Forest)", "Trusted Forcemage (Creature, 2 Land and 1 Forest)", "Latch Seeker (Creature, 1 Land and 2 Island)", "Latch Seeker (Creature, 1 Land and 2 Island)", "Wolfir Avenger (Creature, 1 Land and 2 Forest", "Druid's Familiar (Creature, 3 Land and 1 Forest)", "Druid's Familiar (Creature, 3 Land and 1 Forest)", "Elgaud Shieldmate (Creature, 3 Land and 1 Island)", "Elgaud Shieldmate (Creature, 3 Land and 1 Island)", "Flowering Lumberknot (Creature, 3 Land and 1 Forest)", "Flowering Lumberknot (Creature, 3 Land and 1 Forest)", "Geist Trapper (Creature, 4 Land and 1 Forest)", "Acidic Slime (Creature, 3 Land and 2 Forest)", "Wolfir Silverheart (Creature, 3 Land and 2 Forest)", "Vorstclaw (Creature, 4 Land and 2 Forest)", "Vorstclaw (Creature, 4 Land and 2 Forest)", "Deadeye Navigator (Creature, 4 Land and 2 Island)", "Pathbreaker Wurm (Creature, 4 Land and 2 Forest)"]
        hand1 = random.sample(deck1, 1)
        hand2 = random.sample(deck1, 1)
        hand3 = random.sample(deck1, 1)
        hand4 = random.sample(deck1, 1)
        hand5 = random.sample(deck1, 1)
        hand6 = random.sample(deck1, 1)
        hand7 = random.sample(deck1, 1)
        next1 = random.sample(deck1, 10)
        hand = "Hand:"
        print(hand)
        print(hand1)
        print(hand2)
        print(hand3)
        print(hand4)
        print(hand5)
        print(hand6)
        print(hand7)
        print()
        nexto = "Next on deck:"
        print(nexto)
        print(next1)
        print()
        fromb = "-from Bound by Strength deck"
        print(fromb)
        print()
        you = "YOU"
        print(you)
        print()
        deck2 = ["Evolving Wilds", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Forest", "Plains", "Plains", "Plains", "Plains", "Plains", "Plains", "Plains", "Plains","Plains", "Plains", "Plains", "Plains", "Plains", "Plains", "Plains", "Tranquil Expanse", "Immolating Glare (Spell, 1 Land and 1 Plain)", "Lead by Example (Spell, 1 Land and 1 Forest)", "Lead by Example (Spell, 1 Land and 1 Forest)", "Mighty Leap (Spell, 1 Land and 1 Plain)", "Shoulder to Shoulder (Spell, 2 Land and 1 Plain)", "Shoulder to Shoulder (Spell, 2 Land and 1 Plain)", "Isolation Zone (Spell, 2 Land and 2 Plain)", "Isolation Zone (Spell, 2 Land and 2 Plain)", "Iona's Blessing (Spell, 3 Land and 3 Plain)", "Allied Reinforcements (Spell, 3 Land and 3 Plain)", "Expedition Envoy (Creature, 1 Plain)", "Expedition Envoy (Creature, 1 Plain)", "Kitesail Scout (Creature, 1 Plain)", "Kitesail Scout (Creature, 1 Plain)", "Cliffside Lookout (Creature, 1 Plain)","Cliffside Lookout (Creature, 1 Plain)", "Oran-Rief Invoker (Creature, 1 Land and 1 Forest)", "Makindi Aeronaut (Creature, 1 Land and 1 Plain)", "Makindi Aeronaut (Creature, 1 Land and 1 Plain)", "Kor Castigator (Creature, 1 Land and 1 Plain)", "Kor Castigator (Creature, 1 Land and 1 Plain)", "Joraga Auxiliary (Creature, 1 Land and 1 Forest and 1 Plain)", "Joraga Auxiliary (Creature, 1 Land and 1 Forest and 1 Plain)", "Veteran Warleader (Creature, 1 Land and 1 Forest and 1 Plain)", "Shadow Glider (Creature, 2 Land and 1 Plain)", "Shadow Glider (Creature, 2 Land and 1 Plain)", "Kor Sky Climber (Creature, 2 Land and 1 Plain)", "Kor Sky Climber (Creature, 2 Land and 1 Plain)", "Relief Captain (Creature, 2 Land and 2 Plain)", "Relief Captain (Creature, 2 Land and 2 Plain)", "Saddleback Lagac (Creature, 3 Land and 1 Forest)", "Expedition Raptor (Creature, 3 Land and 2 Plain)", "Expedition Raptor (Creature, 3 Land and 2 Plain)", "Steppe Glider (Creature, 4 Land and 1 Plain)", "Angel of Renewal (Creature, 5 Land and 1 Plain)", "Gladeheart Cavalry (Creature, 5 Land and 2 Forest)"]
        hand21 = random.sample(deck2, 1)
        hand22 = random.sample(deck2, 1)
        hand23 = random.sample(deck2, 1)
        hand24 = random.sample(deck2, 1)
        hand25 = random.sample(deck2, 1)
        hand26 = random.sample(deck2, 1)
        hand27 = random.sample(deck2, 1)
        next2 = random.sample(deck2, 10)
        print(hand)
        print(hand21)
        print(hand22)
        print(hand23)
        print(hand24)
        print(hand25)
        print(hand26)
        print(hand27)
        print()
        print(nexto)
        print(next2)
        print()
        fromc = "-from Concerted Effort deck"
        print(fromc)
        print()
        turn = ["First turn is yours", "Opponent is first turn"]
        turnt = random.sample(turn, 1)
        ct = datetime.datetime.now()
        print(turnt, ct)
        magic = "magic:"

    def football():
        football = ["touchdown", "touchdown", "touchdown", "first down", "first down", "first down", "first down", "second down", "second down", "second down", "third down", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "the path is clear", "there are 3 guards ahead of you", "there are 3 guards ahead of you", "there are 3 guards ahead of you", "there are 4 guards ahead of you", "there are 2 guards ahead of you", "there are 2 guards ahead of you", "there are 2 guards ahead of you", "there is 1 guard ahead of you", "there is 1 guard ahead of you"]
        fball= random.sample(football, 1)
        ct = datetime.datetime.now()
        footballs = "football: "
        print(footballs, fball, ct)

    def mapp():
        print()
        time.sleep(1.1)
        dd = (diction)
        nano = (random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd), random.choice(dd))
        mape = random.sample(nano, 100)
        ct = datetime.datetime.now()
        mapd = "map: "
        print(mapd, mape, ct)

    def auto_mat():
        while True:
            try:
                number = int(input("Indicate number of processes: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        numberstr = str(number)
        time.sleep(1)
        print()
        print(numberstr + "" + " " + "" + "processes will be queued...")
        time.sleep(3)
        for _ in range(number):
            print()
            time.sleep(2)
            function_list = [version, print_time, pray, climb, prayer, stats, progress, light_incense, hebrews, teletubby, legal_terms, biology, chemistry, patient_simu, earth_science, psychology, medicals, license, police, clearance, nano, entry, micasa, stuff, worship, posting, meditate, sleep, eat, find_coins, slot, draw_card, search_for_items, fly, drink_coffee, drink_tea, surf, collections, doodling, zen_melody, value, bump, ma, skate, art, radio, give_alms, brawl, karate, koans, hipster_tarot, hack, spar, train, rest, haiku, psalms, dhammapada, koran, message, souls, c, asciii, mp3, monopoly, equips, rpg, archery, color_key, magic, football, mapp, ID, IDC, fuzz, msgs, tag, atag, frames]
            random.choice(function_list)()
        print()
        ct = datetime.datetime.now()
        print("/processes finished!", ct)
        print()

    def ID():
        ct = datetime.datetime.now()
        ID = "ID:"
        log = "[Logged-in]"
        print(usr, ID, log, ct)

    def IDC():
        ct = datetime.datetime.now()
        IDC = "IDC:"
        log = "[Logged-out]"
        print(usr, IDC, log, ct)

    def weapon_start():
        print("Ctrl+C to stop")
        print()
        def generate_random_result():
            nano = (diction)
            letters1 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters2 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters3 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters4 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters5 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters6 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters7 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters8 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters9 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letters10 = ["A", "a", "B", "b", "C", "c", "D", "d", "E", "e", "F", "f", "G", "g", "H", "h", "I", "i", "J", "j", "K", "k", "L", "l", "M", "m", "N", "n", "O", "o", "P", "p", "Q", "q", "R", "r", "S", "s", "T", "t", "U", "u", "V", "v", "W", "w", "X", "x", "Y", "y", "Z", "z"]
            letter1 = random.sample(letters1, 1)
            letter2 = random.sample(letters2, 1)
            letter3 = random.sample(letters3, 1)
            letter4 = random.sample(letters4, 1)
            letter5 = random.sample(letters5, 1)
            letter6 = random.sample(letters1, 1)
            letter7 = random.sample(letters2, 1)
            letter8 = random.sample(letters3, 1)
            letter9 = random.sample(letters4, 1)
            letter10 = random.sample(letters5, 1)
            value = (round(random.random()*9999999999,10))
            value2 = (round(random.random()*9999999999,10))
            hlevel = (round(random.random()*100,6))
            mthreshold = (round(random.random()*100,6))
            cpercentage = (round(random.random()*100,6))
            values = "value:"
            hlev = "H-level:"
            mthresh = "M-threshold:"
            cpercent = "C-percentage:"
            print()
            print(hlev, hlevel)
            print(mthresh, mthreshold)
            print(cpercent, cpercentage)
            print()
            time.sleep(5.5)
            print(values, letter1, letter2, letter3, letter4, letter5, value)
            print(values, letter6, letter7, letter8, letter9, letter10, value2)
            print()
            time.sleep(.2)
            print("%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%")
            print()
            time.sleep(.3)
            print("OM MANI PADME HUM")
            print()
            time.sleep(.3)
            print("You light an incense")
            print()
            time.sleep(.5)
            result = random.sample(nano, 1)
            result2 = random.sample(nano, 1)
            result3 = random.sample(nano, 1)
            print(result)
            print(result2)
            print(result3)
            time.sleep(.5)
            print()
            print("--------------------------------------------")

        def main_loop():
            while True:
                time.sleep(.3)
                generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def speak(text):
        if platform.system() == "Linux" and shutil.which("termux-tts-speak"):
            try:
                subprocess.run(["termux-tts-speak", text], check=True)
                return
            except subprocess.CalledProcessError as e:
                print(f"Termux-TTS error: {e}")
            except FileNotFoundError:
                pass

        if shutil.which("espeak"):
            try:
                if platform.system() == "Windows":
                    subprocess.run(["espeak", text], check=True)
                else:
                    subprocess.run(["espeak", text], check=True)
                return
            except subprocess.CalledProcessError as e:
                print(f"eSpeak error: {e}")
                return
            except Exception as e:
                print(f"An unexpected error occurred with eSpeak: {e}")
                return d
        else:
            print()
            print("ERROR: Neither 'termux-tts-speak' nor 'espeak' was found.")
            print("Install 'termux-api' (and the Android Termux:API app) or 'sudo apt install espeak / pkg install espeak'.")

    def call():
        maroon = "^m^"
        nano = (diction)
        title = input("call name: ")
        print()
        def generate_random_result():
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            random_result = random.sample(nano, random.randint(1,7))
            result_text = ", ".join(random_result)
            print(maroon, random_letters, sitch, result_text, ctm)
            speak(result_text)
            print()
        
        def main_loop():
            while True:
                time.sleep(random.randint(0,5))
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def monitor_start():
        maroon = "^m^"
        nano = (diction)
        title = input("monitor name: ")
        print()
        def generate_random_result():
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            print(maroon, random_letters, sitch, kchat, ctm)
            print()

        def main_loop():
            while True:
                time.sleep(random.randint(0,5))
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def acad_monitor():
        maroon = "^m^"
        nano = (diction)
        acad = (acadlist)
        title = input("a-monitor name: ")
        print()
        def generate_random_result():
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            kchat2 = random.sample(acad, random.randint(1,7))
            print(maroon, random_letters, sitch, kchat, kchat2, ctm)
            print("_______________________________________")
            print()

        def main_loop():
            while True:
                time.sleep(random.randint(0,14))
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        generate_random_result()
        
        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def fntcci_monitor():
        maroon = "^m^"
        aono = (fcci)
        acad = (acadlist)
        title = input("FNTCCI-monitor name: ")
        ct = datetime.datetime.now()
        monitor = "FNTCCI-monitor-start:"
        print()
        print(usr, monitor, title, ct)
        print()
        def Wonraoyerjishibli():
            cci = random.sample(aono, random.randint(1,10))
            acadl = random.sample(acad, random.randint(1,7))
            wonyao_str = ''.join(cci)
            ctm = datetime.datetime.now()
            print(maroon, wonyao_str, acadl, ctm)
            print("_______________________________________")
            print()

        def main_loop():
            while True:
                time.sleep(random.randint(0,12))
                integer = (round(random.random()*35))
                if integer > 17:
                    if random.choice([True, False]):
                        Wonraoyerjishibli()
        
        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def time_monitor():
        maroon = "^m^"
        nano = (diction)
        acad = (acadlist)
        title = input("t-monitor name: ")
        while True:
            try:
                buffer = float(input("time-buffer in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        buffer
        print()
        def generate_random_result():
            time.sleep(buffer)
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            kchat2 = random.sample(acad, random.randint(1,7))
            print(maroon, random_letters, sitch, kchat, kchat2, ctm)
            print("_______________________________________")
            print()

        def main_loop():
            while True:
                generate_random_result()
        
        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def s_time_monitor():
        maroon = "^m^"
        nano = (diction)
        acad = (acadlist)
        title = input("t-monitor name: ")
        while True:
            try:
                buffer = float(input("time-buffer in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        buffer
        print()
        def generate_random_result():
            time.sleep(buffer)
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            kchat2 = random.sample(acad, random.randint(1,7))
            print(maroon, random_letters, sitch, kchat, kchat2, ctm)
            print("_______________________________________")
            random_result = [random.choice(nano)]
            result_text = ", ".join(random_result)
            speak(result_text)
            print()

        def main_loop():
            while True:
                generate_random_result()
        
        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def programs():
        maroon = "^m^"
        nano = list(diction)
        acad = list(acadlist)
        medica = list(medicals1)
        scienc = list(science1)
        psycholog = list(psychology1)
        biolog = list(biology1)
        dhamma = list(dhammapada1)
        chemis = list(chemistry1)
        legal_t = list(legal_terms1)
        degre = list(degrees1)
        vers = list(verses1)
        dec = list(deck1)
        kora = list(koran1)

        def police2():
            time.sleep(0)   
            code = ["Code Red", "Code Blue", "Code Green", "Code Orange", "Code Yellow", "Code Black", "Code White", "Code Purple", "Code Pink"]
            cod = random.sample(code, 1)[0]
            urgency = ["Critical", "High", "Medium", "Low", "Lowest"]
            urge = random.sample(urgency, 1)[0]
            polis = ["3511 A vehicle that has been impounded for a mandatory 30 days", "A.P.S. Arizona Public Service", "A.S.A.P. As soon as possible", "A.T.F. Bureau of Alcohol, Tobacco, and Firearms", "BAILED OUT Subject jumped out of car and ran", "BYFRND Boyfriend", "BEER RUN Shoplifting beer", "BONDOUT Prisoner who is going to post bail and be released", "BEEN MADE/BURNED Undercover officer's ID is known", "BHND Behind", "BIKE Motorcycle", "BIKERS Motorcycle riders", "BOOKING Booking prisoner into jail", "BREAKING UP Radio transmissions are not being received clearly", "BUSTED Arrested", "C.C.W. Carrying concealed weapon", "C.O. Civilian observer", "COMP Complainant", "C.L.D. Citation in lieu of detention", "CRACK, ROCK Smokeable form of cocaine", "D.E.B. Drug Enforcement Bureau", "DIX Detectives", "D.O.A. Dead on arrival", "D.O.B. Date of birth", "D.O.C. Department of Corrections", "D.P.S. Department of Public Safety", "DRIVE BY Shots fired from a moving vehicle", "E.O.C. Emergency Operations Center", "EQUIPMENT Police vehicle", "E.R. Emergency Room", "E.T.A. Estimated time of arrival", "F.A.A. Federal Aviation Administration", "B.I. Federal Bureau of Investigation", "F.I. Field Interrogation (Form 36 card)", "FILE STOP Notation put in police record; File Stops are confirmed by R&I Bureau", "FLIR Device used by aircraft to check for heat sources", "F.O.J. From other jurisdiction", "FRONT DESK Information Desk at main station", "FUGITIVE A wanted person", "GAS WASH/WASHDOWN Fire Department needed to wash gas down", "G.C.I. /B.A. Test used to determine blood alcohol content", "G.I.B. General Investigations Bureau", "GOT THE EYE In view (on a code 5)", "GRN Green", "HOND Honda", "HIT Subject or item wanted", "H.G.N. Horizontal Gaze Nystagmus (a test for detecting drug / alcohol use)", "HOBBLES Nylon rope used for legs and hand restraint", "HOOK Wrecker", "HSE House", "ICE, CRYSTAL Smokeable methamphetamine", "J.C.C. Juvenile Corrections Center", "J.P. Justice of the Peace", "JUMPED ON Assaulted", "JUMPER Person attempting suicide by jumping", "LADDER Fire Department ladder truck", "MARQUIS Test for narcotics", "M.D.C. Mobile Digital Computer (Police car computer)", "MEDICS Paramedics", "MERZ Mercedes Benz", "MHP Mobile Home Park", "MOTOR Solo motor unit", "NUMBER 1 SITUATION Probable cause for arrest", "NUMBER 9's Citations", "OD Overdose", "ONE FROM LIST Contract wrecker (926)", "ONE ON ONE Suspect / witness I.D.", "ONE ROLL Fingerprints", "O.V. On view, officer just witnessed an incident", "PAGE 2 Additional charges filed on a subject already in custody", "P.C. Probable cause", "PLE Purple", "P.O. Probation officer", "RESTRAINTS Leather straps used to restrain prisoners", "RINGER Audible alarm", "ROLLOVER Accident involving overturned vehicle", "R.P. Responsible party", "S/E/C Southeast corner", "SEIZURE Impound a vehicle; subject having convulsions", "SGT Sergeant", "SILENT Silent alarm", "SLIM JIM Device used to open locked vehicle", "SMASH & GRAB Broke out window, grabbed items and ran", "S.O./M.C.S.O. Maricopa County Sheriff's Office", "S.R.P. Salt River Project", "STRIPPED Vehicle stripped", "TECH Radio or computer technician", "THIRTY-SIX Field interrogation (or form 36)", "THREE WHEELER Police 3-wheeled motorcycle", "TILL TAP Grab money from register", "DISPATCH AN ANIMAL To shoot an animal", "TRAFFIC BOX KEY Key used to open traffic signal control box", "XHUSB Ex-husband", "WAGON/WAGON Police paddy wagon"]
            pol_str = " , over, ".join(random.sample(polis, random.randint(1, 8)))
            locate = ["Local", "Local", "Foreign"]
            loc = random.sample(locate, 1)[0]
            direction = ["South", "North", "West", "East", "Southwest", "Southeast", "Northwest", "Northeast"]
            dire = random.sample(direction, 1)[0]  
            suspectcode = (round(random.random()*26))
            sus = "Suspect Code:"
            location = (round(random.random()*99999999,10))
            ct = datetime.datetime.now()
            po = "police:"
            final_result_string = f"{po} {cod}, Urgency: {urge}, {sus} {suspectcode}, Terms: ({pol_str}), Location Type: {loc}, Direction: {dire}, Coords: {location}, Timestamp: {ct}"
            return final_result_string 

        title = input("programs-monitor name: ")

        while True:
            try:
                buffer = float(input("time-buffer in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        buffer
        ct = datetime.datetime.now()
        monitor = "programs-monitor-start:"
        print(usr, monitor, title, ct)
        print()

        def generate_random_result():
            time.sleep(buffer)
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            random_result = (random.choice(nano), random.choice(nano), random.choice(nano), random.choice(acad), random.choice(medica), random.choice(scienc), random.choice(psycholog), random.choice(biolog), random.choice(dhamma), random.choice(dhamma), random.choice(chemis), random.choice(legal_t), random.choice(degre), random.choice(vers), random.choice(dec), police2(), police2(), police2(), police2(), police2(), random.choice(kora), random.choice(kora), random.choice(kora))
            result = random.sample(random_result, 1)
            result_text = ", ".join(result)
            print(maroon, random_letters, sitch, result, ctm)
            speak(result_text)
            print()

        def main_loop():
            while True:
                generate_random_result()
        
        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def msgs():
        while True:
            try:
                number = int(input("Indicate number of scans: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        numberstr = str(number)
        print()
        print("Scanning...")
        print()
        time.sleep(2)
        for _ in range(number):
            time.sleep(.1)
            integer = (round(random.random()*25))
            if integer > 15:
                if random.choice([True, False]):
                    ctm = datetime.datetime.now()
                    nano = (diction)
                    acad = (acadlist)
                    def generate_random_letters():
                        random1 = random.choice(string.ascii_letters)
                        random2 = random.choice(string.ascii_letters)
                        random3 = random.choice(string.ascii_letters)
                        letters = [random1, random2, random3]
                        random.shuffle(letters)
                        return letters
                    random_letters = generate_random_letters()
                    sitch  = (round(random.random()*9999,4))
                    kchat = random.sample(nano, random.randint(0,27))
                    kchat2 = random.sample(acad, random.randint(0,8))
                    msg = "msg:"
                    print(usr, msg, random_letters, sitch, kchat, kchat2, ctm)
                    print()                 
        print()
        ct = datetime.datetime.now()
        print("/scanning finished!", ct)
        print()

    def fuzz():
        ct = datetime.datetime.now()
        fuzz = "fuzzing..."
        print(fuzz, ct)
        time.sleep(3)
        print("#")
        time.sleep(.2)
        print("#")
        time.sleep(.2)
        print("#")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print("#")
        time.sleep(.2)
        print("#")
        time.sleep(.2)
        print("#")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print("%")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print(">")
        time.sleep(.2)
        print()
        print("You light an incense...")
        time.sleep(4)

    def tag():   
        rtag = input("tag: ")
        while True:
            try:
                number = int(input("Number of results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        for _ in range(number):
            time.sleep(.103)
            nano = (diction)
            ct = datetime.datetime.now()
            tag = "tag:"
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,7))
            print()
            print(tag, rtag, random_letters, sitch, kchat, ctm)

    def atag():   
        rtag = input("a-tag: ")
        while True:
            try:
                number = int(input("Number of results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        for _ in range(number):
            time.sleep(.103)
            nano = (diction)
            acad = (acadlist)
            ct = datetime.datetime.now()
            tag = "a-tag:"
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            kchat = random.sample(nano, random.randint(1,8))
            kchat2 = random.sample(acad, random.randint(1,7))
            print()
            print(tag, rtag, random_letters, sitch, kchat, kchat2, ctm)

    def ntag():  
        ctag = input("n-tag: ")
        while True:
            try:
                number = int(input("Number of results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        for _ in range(number):
            time.sleep(.103)
            an = (fcci) 
            acad = (acadlist)
            ct = datetime.datetime.now()
            tag = "n-tag:"
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            nn = random.sample(an, random.randint(1,10))
            wonyao_str = ''.join(nn)
            acadl = random.sample(acad, random.randint(1,7))
            print()
            print(tag, ctag, random_letters, sitch, wonyao_str, acadl, ctm)

    def MAI():
        import time
        while True:
            try:
                number = int(input("Indicate number of (MedProc AI) results: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        time.sleep(2)
        for _ in range(number):
            time.sleep(1.5)
            print()
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            asc = "ascii:"
            print(asc, usr, random_letters, sitch, ctm)
            pr1 = (round(random.random()*99999999999999999999999999999999999999999))
            pr2 = (round(random.random()*99999999999999999999999999999999999999999))
            pr3 = (round(random.random()*99999999999999999999999999999999999999999))
            pr4 = (round(random.random()*99999999999999999999999999999999999999999))
            pr5 = (round(random.random()*99999999999999999999999999999999999999999))
            pr6 = (round(random.random()*99999999999999999999999999999999999999999))
            pr7 = (round(random.random()*99999999999999999999999999999999999999999))
            pr8 = (round(random.random()*99999999999999999999999999999999999999999))
            pr9 = (round(random.random()*99999999999999999999999999999999999999999))
            pr10 = (round(random.random()*99999999999999999999999999999999999999999))
            pr11 = (round(random.random()*99999999999999999999999999999999999999999))
            pr12 = (round(random.random()*99999999999999999999999999999999999999999))
            print()
            print(pr1)
            print(pr2)
            print(pr3)
            print(pr4)
            print(pr5)
            print(pr6)
            print(pr7)
            print(pr8)
            print(pr9)
            print(pr10)
            print(pr11)
            print(pr12)
            print()
            time.sleep(2)
            if True:
                nano = (diction)
                acad = (acadlist)
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        ct = datetime.datetime.now()
                        tag = "a-tag:"
                        ctm = datetime.datetime.now()
                        def generate_random_letters():
                            random1 = random.choice(string.ascii_letters)
                            random2 = random.choice(string.ascii_letters)
                            random3 = random.choice(string.ascii_letters)
                            letters = [random1, random2, random3]
                            random.shuffle(letters)
                            return letters
                        random_letters = generate_random_letters()
                        sitch  = (round(random.random()*9999,4))
                        kchat = random.sample(nano, random.randint(1,8))
                        kchat2 = random.sample(acad, random.randint(1,7))
                        print()
                        print(usr, random_letters, sitch, kchat2, kchat, ctm)
                        print()
                        time.sleep(4.2)
            if True:
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("#", "#####", "##########", "##########################", "##########################", "##########################")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)
            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("V", "    V", "          V", "                    V", "                              V", "                                        V")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("v", "    v", "          v", "                    v", "                              v", "                                        v")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("O", "    O", "          O", "                    O", "                              O", "                                        O")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("o", "    o", "          o", "                    o", "                              o", "                                        o")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("0", "    0", "          0", "                    0", "                              0", "                                        0")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("H", "    H", "          H", "                    H", "                              H", "                                        H")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("h", "    h", "          h", "                    h", "                              h", "                                        h")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Q", "    Q", "          Q", "                    Q", "                              Q", "                                        Q")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("q", "    q", "          q", "                    q", "                              q", "                                        q")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Y", "    Y", "          Y", "                    Y", "                              Y", "                                        Y")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("y", "    y", "          y", "                    y", "                              y", "                                        y")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("I", "    I", "          I", "                    I", "                              I", "                                        I", "                              III", "                                        III")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("i", "    i", "          i", "                    i", "                              i", "                                        i", "                              iii", "                                        iii")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("L", "    L", "          L", "                    L", "                              L", "                                        L")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("l", "    l", "          l", "                    l", "                              l", "                                        l")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("X", "    X", "          X", "                    X", "                              X", "                                        X")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("x", "    x", "          x", "                    x", "                              x", "                                        x")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("U", "    U", "          U", "                    U", "                              U", "                                        U")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("u", "    u", "          u", "                    u", "                              u", "                                        u")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("G", "    G", "          G", "                    G", "                              G", "                                        G")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("g", "    g", "          g", "                    g", "                              g", "                                        g")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("B", "    B", "          B", "                    B", "                              B", "                                        B")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("b", "    b", "          b", "                    b", "                              b", "                                        b")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("P", "    P", "          P", "                    P", "                              P", "                                        P")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("p", "    p", "          p", "                    p", "                              p", "                                        p")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("T", "    T", "          T", "                    T", "                              T", "                                        T")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("t", "    t", "          t", "                    t", "                              t", "                                        t")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("C", "    C", "          C", "                    C", "                              C", "                                        C")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("c", "    c", "          c", "                    c", "                              c", "                                        c")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Z", "    Z", "          Z", "                    Z", "                              Z", "                                        Z")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("z", "    z", "          z", "                    z", "                              z", "                                        z")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 17:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("-======================", "-================", "-======================", "-================")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("#", "#####", "##########", "##########################", "##########################", "##########################")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

    def MAIc():
        import time
        print("Ctrl+C to stop")
        print()
        def generate_random_result():
            time.sleep(1.5)
            print()
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            asc = "ascii:"
            print(asc, usr, random_letters, sitch, ctm)
            pr1 = (round(random.random()*99999999999999999999999999999999999999999))
            pr2 = (round(random.random()*99999999999999999999999999999999999999999))
            pr3 = (round(random.random()*99999999999999999999999999999999999999999))
            pr4 = (round(random.random()*99999999999999999999999999999999999999999))
            pr5 = (round(random.random()*99999999999999999999999999999999999999999))
            pr6 = (round(random.random()*99999999999999999999999999999999999999999))
            pr7 = (round(random.random()*99999999999999999999999999999999999999999))
            pr8 = (round(random.random()*99999999999999999999999999999999999999999))
            pr9 = (round(random.random()*99999999999999999999999999999999999999999))
            pr10 = (round(random.random()*99999999999999999999999999999999999999999))
            pr11 = (round(random.random()*99999999999999999999999999999999999999999))
            pr12 = (round(random.random()*99999999999999999999999999999999999999999))
            print()
            print(pr1)
            print(pr2)
            print(pr3)
            print(pr4)
            print(pr5)
            print(pr6)
            print(pr7)
            print(pr8)
            print(pr9)
            print(pr10)
            print(pr11)
            print(pr12)
            print()
            time.sleep(2)
            if True:
                nano = (diction)
                acad = (acadlist)
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        ct = datetime.datetime.now()
                        tag = "a-tag:"
                        ctm = datetime.datetime.now()
                        def generate_random_letters():
                            random1 = random.choice(string.ascii_letters)
                            random2 = random.choice(string.ascii_letters)
                            random3 = random.choice(string.ascii_letters)
                            letters = [random1, random2, random3]
                            random.shuffle(letters)
                            return letters
                        random_letters = generate_random_letters()
                        sitch  = (round(random.random()*9999,4))
                        kchat = random.sample(nano, random.randint(1,8))
                        kchat2 = random.sample(acad, random.randint(1,7))
                        print()
                        print(usr, random_letters, sitch, kchat2, kchat, ctm)
                        print()
                        time.sleep(4.2)
            if True:
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("#", "#####", "##########", "##########################", "##########################", "##########################")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)
            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("V", "    V", "          V", "                    V", "                              V", "                                        V")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("v", "    v", "          v", "                    v", "                              v", "                                        v")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("O", "    O", "          O", "                    O", "                              O", "                                        O")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("o", "    o", "          o", "                    o", "                              o", "                                        o")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("0", "    0", "          0", "                    0", "                              0", "                                        0")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("H", "    H", "          H", "                    H", "                              H", "                                        H")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("h", "    h", "          h", "                    h", "                              h", "                                        h")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Q", "    Q", "          Q", "                    Q", "                              Q", "                                        Q")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("q", "    q", "          q", "                    q", "                              q", "                                        q")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Y", "    Y", "          Y", "                    Y", "                              Y", "                                        Y")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("y", "    y", "          y", "                    y", "                              y", "                                        y")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("I", "    I", "          I", "                    I", "                              I", "                                        I", "                              III", "                                        III")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("i", "    i", "          i", "                    i", "                              i", "                                        i", "                              iii", "                                        iii")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("L", "    L", "          L", "                    L", "                              L", "                                        L")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("l", "    l", "          l", "                    l", "                              l", "                                        l")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("X", "    X", "          X", "                    X", "                              X", "                                        X")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("x", "    x", "          x", "                    x", "                              x", "                                        x")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("U", "    U", "          U", "                    U", "                              U", "                                        U")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("u", "    u", "          u", "                    u", "                              u", "                                        u")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("G", "    G", "          G", "                    G", "                              G", "                                        G")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("g", "    g", "          g", "                    g", "                              g", "                                        g")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("B", "    B", "          B", "                    B", "                              B", "                                        B")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("b", "    b", "          b", "                    b", "                              b", "                                        b")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("P", "    P", "          P", "                    P", "                              P", "                                        P")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("p", "    p", "          p", "                    p", "                              p", "                                        p")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("T", "    T", "          T", "                    T", "                              T", "                                        T")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("t", "    t", "          t", "                    t", "                              t", "                                        t")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("C", "    C", "          C", "                    C", "                              C", "                                        C")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("c", "    c", "          c", "                    c", "                              c", "                                        c")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("Z", "    Z", "          Z", "                    Z", "                              Z", "                                        Z")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 20:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*8))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("z", "    z", "          z", "                    z", "                              z", "                                        z")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 17:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("-======================", "-================", "-======================", "-================")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

            if True:
                integer = (round(random.random()*25))
                if integer > 15:
                    if random.choice([True, False]):
                        time.sleep(1.5)
                        t  = (round(random.random()*10))
                        for _ in range(t):
                            ctm = datetime.datetime.now()
                            hashes = ("#", "#####", "##########", "##########################", "##########################", "##########################")
                            hashh = random.sample(hashes, random.randint(1,1))
                            print(usr, hashh)
                            print()
                            time.sleep(.5)

        def main_loop():
            while True:
                generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def guard():
        while True:
            try:
                fps = float(input("Indicate speed in (halfed) seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        name = input("guard_name: ")
        fps
        print()
        print("Ctrl+C to stop")
        time.sleep(3.5)
        def generate_random_result():
            time.sleep(fps)
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            asc = "guard:"
            print()
            print(asc, usr, name, random_letters, sitch, ctm)
            pr1 = (round(random.random()*99999999999999999999999999999999999999999))
            pr2 = (round(random.random()*99999999999999999999999999999999999999999))
            pr3 = (round(random.random()*99999999999999999999999999999999999999999))
            pr4 = (round(random.random()*99999999999999999999999999999999999999999))
            pr5 = (round(random.random()*99999999999999999999999999999999999999999))
            pr6 = (round(random.random()*99999999999999999999999999999999999999999))
            pr7 = (round(random.random()*99999999999999999999999999999999999999999))
            pr8 = (round(random.random()*99999999999999999999999999999999999999999))
            pr9 = (round(random.random()*99999999999999999999999999999999999999999))
            pr10 = (round(random.random()*99999999999999999999999999999999999999999))
            pr11 = (round(random.random()*99999999999999999999999999999999999999999))
            pr12 = (round(random.random()*99999999999999999999999999999999999999999))
            print()
            print(pr1)
            print(pr2)
            print(pr3)
            print(pr4)
            print(pr5)
            print(pr6)
            print(pr7)
            print(pr8)
            print(pr9)
            print(pr10)
            print(pr11)
            print(pr12)
            print()

        def main_loop():
            while True:
                generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def frames():
        while True:
            try:
                number = int(input("Indicate number of (frames) results: "))
                fps = float(input("Indicate speed in (halfed) seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        number
        fps
        name = input("frames name: ")
        for _ in range(number):
            time.sleep(fps)
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                random.shuffle(letters)
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*9999,4))
            asc = "frames:"
            print()
            print(asc, usr, name, random_letters, sitch, ctm)
            pr1 = (round(random.random()*99999999999999999999999999999999999999999))
            pr2 = (round(random.random()*99999999999999999999999999999999999999999))
            pr3 = (round(random.random()*99999999999999999999999999999999999999999))
            pr4 = (round(random.random()*99999999999999999999999999999999999999999))
            pr5 = (round(random.random()*99999999999999999999999999999999999999999))
            pr6 = (round(random.random()*99999999999999999999999999999999999999999))
            pr7 = (round(random.random()*99999999999999999999999999999999999999999))
            pr8 = (round(random.random()*99999999999999999999999999999999999999999))
            pr9 = (round(random.random()*99999999999999999999999999999999999999999))
            pr10 = (round(random.random()*99999999999999999999999999999999999999999))
            pr11 = (round(random.random()*99999999999999999999999999999999999999999))
            pr12 = (round(random.random()*99999999999999999999999999999999999999999))
            print()
            print(pr1)
            print(pr2)
            print(pr3)
            print(pr4)
            print(pr5)
            print(pr6)
            print(pr7)
            print(pr8)
            print(pr9)
            print(pr10)
            print(pr11)
            print(pr12)
            print()

    def oscillator():
        print("Ctrl+C to stop")
        print()
        def generate_random_result():
            meter = ["                              ", "*                             ", " *                            ", "  *                           ", "   *                          ", "    *                         ", "     *                        ", "      *                       ", "       *                      ", "        *                     ", "         *                    ", "          *                   ", "           *                  ", "            *                 ", "             *                ", "              *               ", "               *              ", "                *             ", "                 *            ", "                  *           ", "                   *          ", "                    *         ", "                     *        ", "                      *       ", "                       *      ", "                        *     ", "                         *    ", "                          *   ", "                           *  ", "                            * ", "                             *"]
            oscill = random.sample(meter, 1)
            print(oscill)

        def main_loop():
            while True:
                time.sleep(.1)
                integer = (round(random.random()*5))
                if integer > 2:
                    generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def toscillator():
        print("Ctrl+C to stop")
        print()

        while True:
            try:
                buffer = float(input("time-buffer in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break

        def generate_random_result():
            meter = ["                              ", "*                             ", " *                            ", "  *                           ", "   *                          ", "    *                         ", "     *                        ", "      *                       ", "       *                      ", "        *                     ", "         *                    ", "          *                   ", "           *                  ", "            *                 ", "             *                ", "              *               ", "               *              ", "                *             ", "                 *            ", "                  *           ", "                   *          ", "                    *         ", "                     *        ", "                      *       ", "                       *      ", "                        *     ", "                         *    ", "                          *   ", "                           *  ", "                            * ", "                             *"]
            oscill = random.sample(meter, 1)
            print(oscill)

        def main_loop():
            while True:
                time.sleep(buffer)
                generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def burner():
        nano = (diction)
        print("Not recording")
        print()
        time.sleep(.4)
        title = input("burn name: ")
        ct = datetime.datetime.now()
        monitor = "burner-start:"
        print(usr, monitor, title, ct)
        print()
        print()
        def generate_random_result():
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                random4 = random.choice(string.ascii_letters)
                random5 = random.choice(string.ascii_letters)
                random6 = random.choice(string.ascii_letters)
                random7 = random.choice(string.ascii_letters)
                random8 = random.choice(string.ascii_letters)
                random9 = random.choice(string.ascii_letters)
                random10 = random.choice(string.ascii_letters)
                random11 = random.choice(string.ascii_letters)
                random12 = random.choice(string.ascii_letters)
                random13 = random.choice(string.ascii_letters)
                random14 = random.choice(string.ascii_letters)
                random15 = random.choice(string.ascii_letters)
                random16 = random.choice(string.ascii_letters)
                random17 = random.choice(string.ascii_letters)
                random18 = random.choice(string.ascii_letters)
                random19 = random.choice(string.ascii_letters)
                random20 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3, random4, random5, random6, random7, random8, random9, random10, random11, random12, random13, random14, random15, random16, random17, random18, random19, random20]
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*999999999999999,5))
            kchat = random.sample(nano, random.randint(1,2))
            print(title, ctm, random_letters, sitch, kchat)
        
        def main_loop():
            while True:
                time.sleep(random.randint(0,1))
                integer = (round(random.random()*10))
                if integer > 5:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def tburner():
        nano = (diction)
        print("Not recording")
        print()
        time.sleep(.4)
        title = input("burn name: ")
        while True:
            try:
                buffer = float(input("time-buffer in seconds: "))
            except ValueError:
                print("Invalid value")
            else:
                break
        ct = datetime.datetime.now()
        monitor = "burner-start:"
        print(usr, monitor, title, ct)
        print()
        print()
        def generate_random_result():
            ctm = datetime.datetime.now()
            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                random4 = random.choice(string.ascii_letters)
                random5 = random.choice(string.ascii_letters)
                random6 = random.choice(string.ascii_letters)
                random7 = random.choice(string.ascii_letters)
                random8 = random.choice(string.ascii_letters)
                random9 = random.choice(string.ascii_letters)
                random10 = random.choice(string.ascii_letters)
                random11 = random.choice(string.ascii_letters)
                random12 = random.choice(string.ascii_letters)
                random13 = random.choice(string.ascii_letters)
                random14 = random.choice(string.ascii_letters)
                random15 = random.choice(string.ascii_letters)
                random16 = random.choice(string.ascii_letters)
                random17 = random.choice(string.ascii_letters)
                random18 = random.choice(string.ascii_letters)
                random19 = random.choice(string.ascii_letters)
                random20 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3, random4, random5, random6, random7, random8, random9, random10, random11, random12, random13, random14, random15, random16, random17, random18, random19, random20]
                return letters
            random_letters = generate_random_letters()
            sitch  = (round(random.random()*999999999999999,5))
            kchat = random.sample(nano, random.randint(1,2))
            print(title, ctm, random_letters, sitch, kchat)
        
        def main_loop():
            while True:
                time.sleep(buffer)
                generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def xcbmp():

        time.sleep(.3)

        print()
        print("DISCLAIMER: This works on Android and must have Termux and Termux-API installed from F-Droid and Google Text-to-Speech options set to 'Chinese'")
        print()
        print("Ctrl+C To Stop")
        print()
        print("'FNTCCI (C)'")
        print()

        time.sleep(.3)

        c_fcci2 = ['a', 'ai', 'an', 'ang', 'ao', 'ba', 'bai', 'ban', 'bang', 'bao', 'bei', 'ben', 'beng', 'bi', 'bian', 'biao', 'bie', 'bin', 'bing', 'bo', 'bu', 'ca', 'cai', 'can', 'cang', 'cao', 'ce', 'cei', 'cen', 'ceng', 'cha', 'chai', 'chan', 'chang', 'chao', 'che', 'chen', 'cheng', 'chi', 'chong', 'chou', 'chu', 'chua', 'chuai', 'chuan', 'chuang', 'chui', 'chun', 'chuo', 'ci', 'cong', 'cou', 'cu', 'cuan', 'cui', 'cun', 'cuo', 'da', 'dai', 'dan', 'dang', 'dao', 'de', 'dei', 'den', 'deng', 'di', 'dia', 'dian', 'diao', 'die', 'ding', 'diu', 'dong', 'dou', 'du', 'duan', 'dui', 'dun', 'duo', 'e', 'ei', 'en', 'eng', 'er', 'fa', 'fan', 'fang', 'fei', 'fen', 'feng', 'fo', 'fou', 'fu', 'ga', 'gai', 'gan', 'gang', 'gao', 'ge', 'gei', 'gen', 'geng', 'gong', 'gou', 'gu', 'gua', 'guai', 'guan', 'guang', 'gui', 'gun', 'guo', 'ha', 'hai', 'han', 'hang', 'hao', 'he', 'hei', 'hen', 'heng', 'hong', 'hou', 'hu', 'hua', 'huai', 'huan', 'huang', 'hui', 'hun', 'huo', 'ji', 'jia', 'jian', 'jiang', 'jiao', 'jie', 'jin', 'jing', 'jiong', 'jiu', 'ju', 'juan', 'jue', 'jun', 'ka', 'kai', 'kan', 'kang', 'kao', 'ke', 'kei', 'ken', 'keng', 'kong', 'kou', 'ku', 'kua', 'kuai', 'kuan', 'kuang', 'kui', 'kun', 'kuo', 'la', 'lai', 'lan', 'lang', 'lao', 'le', 'lei', 'leng', 'li', 'lia', 'lian', 'liang', 'liao', 'lie', 'lin', 'ling', 'liu', 'long', 'lou', 'lu', 'luan', 'lun', 'luo', 'lü', 'lüe', 'ma', 'mai', 'man', 'mang', 'mao', 'me', 'mei', 'men', 'meng', 'mi', 'mian', 'miao', 'mie', 'min', 'ming', 'miu', 'mo', 'mou', 'mu', 'na', 'nai', 'nan', 'nang', 'nao', 'ne', 'nei', 'nen', 'neng', 'ni', 'nian', 'niang', 'niao', 'nie', 'nin', 'ning', 'niu', 'nong', 'nou', 'nu', 'nuan', 'nuo', 'nü', 'nüe', 'o', 'ou', 'pa', 'pai', 'pan', 'pang', 'pao', 'pei', 'pen', 'peng', 'pi', 'pian', 'piao', 'pie', 'pin', 'ping', 'po', 'pou', 'pu', 'qi', 'qia', 'qian', 'qiang', 'qiao', 'qie', 'qin', 'qing', 'qiong', 'qiu', 'qu', 'quan', 'que', 'qun', 'ran', 'rang', 'rao', 're', 'ren', 'reng', 'ri', 'rong', 'rou', 'ru', 'ruan', 'rui', 'run', 'ruo', 'sa', 'sai', 'san', 'sang', 'sao', 'se', 'sen', 'seng', 'sha', 'shai', 'shan', 'shang', 'shao', 'she', 'shei', 'shen', 'sheng', 'shi', 'shou', 'shu', 'shua', 'shuai', 'shuan', 'shuang', 'shui', 'shun', 'shuo', 'si', 'song', 'sou', 'su', 'suan', 'sui', 'sun', 'suo', 'ta', 'tai', 'tan', 'tang', 'tao', 'te', 'tei', 'teng', 'ti', 'tian', 'tiao', 'tie', 'ting', 'tong', 'tou', 'tu', 'tuan', 'tui', 'tun', 'tuo', 'wa', 'wai', 'wan', 'wang', 'wei', 'wen', 'weng', 'wo', 'wu', 'xi', 'xia', 'xian', 'xiang', 'xiao', 'xie', 'xin', 'xing', 'xiong', 'xiu', 'xu', 'xuan', 'xue', 'xun', 'ya', 'yan', 'yang', 'yao', 'ye', 'yi', 'yin', 'ying', 'yo', 'yong', 'you', 'yu', 'yuan', 'yue', 'yun', 'za', 'zai', 'zan', 'zang', 'zao', 'ze', 'zei', 'zen', 'zeng', 'zha', 'zhai', 'zhan', 'zhang', 'zhao', 'zhe', 'zhei', 'zhen', 'zheng', 'zhi', 'zhong', 'zhou', 'zhu', 'zhua', 'zhuai', 'zhuan', 'zhuang', 'zhui', 'zhun', 'zhuo', 'zi', 'zong', 'zou', 'zu', 'zuan', 'zui', 'zun', 'zuo', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ']
        
        maroon = "^m^"

        cnano2 = (c_fcci2)

        ct = datetime.datetime.now()

        monitor = "xcbmp-start:"
        print(monitor, ct)
        print()

        def generate_random_result():

            ctm = datetime.datetime.now()

            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters

            random_letters = generate_random_letters()

            sitch  = (round(random.random()*9999,4))

            cci2 = random.sample(cnano2, random.randint(1,10))

            result_text = "".join(cci2)

            print(maroon, random_letters, sitch, result_text, ctm)

            speak(result_text)

            print()
            
        def main_loop():
            while True:
                time.sleep(random.randint(0,6))
                integer = (round(random.random()*18))
                if integer > 10:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def xhbmp():

        time.sleep(.3)

        print()
        print("DISCLAIMER: This works on Android and must have Termux and Termux-API installed from F-Droid and Google Text-to-Speech options set to 'Korean'")
        print()
        print("Ctrl+C To Stop")
        print()
        print("'FNTCCI (H)'")
        print()

        time.sleep(.3)

        h_fcci2 = ["ga", "gya", "geo", "gyeo", "go", "gyo", "gu", "gyu", "geu", "gi", "gae", "gyae", "ge", "gye", "gwa", "gwae", "goe", "gwo", "gwe", "gwi", "gui", "kka", "kkya", "kkeo", "kkyeo", "kko", "kkyo", "kku", "kkyu", "kkeu", "kki", "kkae", "kkyae", "kke", "kkye", "kkwa", "kkwae", "kkoe", "kkwo", "kkwe", "kkwi", "kkui", "na", "nya", "neo", "nyeo", "no", "nyo", "nu", "nyu", "neu", "ni", "nae", "nyae", "ne", "nye", "nwa", "nwae", "noe", "nwo", "nwe", "nwi", "nui", "da", "dya", "deo", "dyeo", "do", "dyo", "du", "dyu", "deu", "di", "dae", "dyae", "de", "dye", "dwa", "dwae", "doe", "dwo", "dwe", "dwi", "dui", "tta", "ttya", "tteo", "ttyeo", "tto", "ttyo", "ttu", "ttyu", "tteu", "tti", "ttae", "ttyae", "tte", "ttye", "ttwa", "ttwae", "ttoe", "ttwo", "ttwe", "ttwi", "ttui", "ra", "rya", "reo", "ryeo", "ro", "ryo", "ru", "ryu", "reu", "ri", "rae", "ryae", "re", "rye", "rwa", "rwae", "roe", "rwo", "rwe", "rwi", "rui", "ma", "mya", "meo", "myeo", "mo", "myo", "mu", "myu", "meu", "mi", "mae", "myae", "me", "mye", "mwa", "mwae", "moe", "mwo", "mwe", "mwi", "mui", "ba", "bya", "beo", "byeo", "bo", "byo", "bu", "byu", "beu", "bi", "bae", "byae", "be", "bye", "bwa", "bwae", "boe", "bwo", "bwe", "bwi", "bui", "ppa", "ppya", "ppeo", "ppyeo", "ppo", "ppyo", "ppu", "ppyu", "ppeu", "ppi", "ppae", "ppyae", "ppe", "ppye", "ppwa", "ppwae", "ppoe", "ppwo", "ppwe", "ppwi", "ppui", "sa", "sya", "seo", "syeo", "so", "syo", "su", "syu", "seu", "si", "sae", "syae", "se", "sye", "swa", "swae", "soe", "swo", "swe", "swi", "sui", "ssa", "ssya", "sseo", "ssyeo", "sso", "ssyo", "ssu", "ssyu", "sseu", "ssi", "ssae", "ssyae", "sse", "ssye", "sswa", "sswae", "ssoe", "sswo", "sswe", "sswi", "ssui", "a", "ya", "eo", "yeo", "o", "yo", "u", "yu", "eu", "i", "ae", "yae", "e", "ye", "wa", "wae", "oe", "wo", "we", "wi", "ui", "ja", "jya", "jeo", "jyeo", "jo", "jyo", "ju", "jyu", "jeu", "ji", "jae", "jyae", "je", "jye", "jwa", "jwae", "joe", "jwo", "jwe", "jwi", "jui", "jja", "jjya", "jjeo", "jjyeo", "jjo", "jjyo", "jju", "jjyu", "jjeu", "jji", "jjae", "jjyae", "jje", "jjye", "jjwa", "jjwae", "jjoe", "jjwo", "jjwe", "jjwi", "jjui", "cha", "chya", "cheo", "chyeo", "cho", "chyo", "chu", "chyu", "cheu", "chi", "chae", "chyae", "che", "chye", "chwa", "chwae", "choe", "chwo", "chwe", "chwi", "chui", "ka", "kya", "keo", "kyeo", "ko", "kyo", "ku", "kyu", "keu", "ki", "kae", "kyae", "ke", "kye", "kwa", "kwae", "koe", "kwo", "kwe", "kwi", "kui", "ta", "tya", "teo", "tyeo", "to", "tyo", "tu", "tyu", "teu", "ti", "tae", "tyae", "te", "tye", "twa", "twae", "toe", "two", "twe", "twi", "tui", "pa", "pya", "peo", "pyeo", "po", "pyo", "pu", "pyu", "peu", "pi", "pae", "pyae", "pe", "pye", "pwa", "pwae", "poe", "pwo", "pwe", "pwi", "pui", "ha", "hya", "heo", "hyeo", "ho", "hyo", "hu", "hyu", "heu", "hi", "hae", "hyae", "he", "hye", "hwa", "hwae", "hoe", "hwo", "hwe", "hwi", "hui", ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ']

        maroon = "^m^"

        hnano2 = (h_fcci2)

        ct = datetime.datetime.now()

        monitor = "xhbmp-start:"
        print(monitor, ct)
        print()

        def generate_random_result():

            ctm = datetime.datetime.now()

            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters

            random_letters = generate_random_letters()

            sitch  = (round(random.random()*9999,4))

            hcci2 = random.sample(hnano2, random.randint(1,10))

            result_text = "".join(hcci2)

            print(maroon, random_letters, sitch, result_text, ctm)

            speak(result_text)

            print()
            
        def main_loop():
            while True:
                time.sleep(random.randint(0,6))
                integer = (round(random.random()*18))
                if integer > 10:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def xjbmp():

        time.sleep(.3)

        print()
        print("DISCLAIMER: This works on Android and must have Termux and Termux-API installed from F-Droid and Google Text-to-Speech options set to 'Japanese'")
        print()
        print("Ctrl+C To Stop")
        print()
        print("'FNTCCI (J)'")
        print()

        time.sleep(.3)

        jfcci2 = ["a", "i", "u", "e", "o", "ka", "ki", "ku", "ke", "ko", "kya", "kyu", "kyo", "ga", "gi", "gu", "ge", "go", "gya", "gyu", "gyo", "sa", "shi", "su", "se", "so", "sha", "shu", "sho", "za", "ji", "zu", "ze", "zo", "ja", "ju", "jo", "ta", "chi", "tsu", "te", "to", "cha", "chu", "cho", "da", "de", "do", "na", "ni", "nu", "ne", "no", "nya", "nyu", "nyo", "ha", "hi", "fu", "he", "ho", "hya", "hyu", "hyo", "ba", "bi", "bu", "be", "bo", "bya", "byu", "byo", "pa", "pi", "pu", "pe", "po", "pya", "pyu", "pyo", "ma", "mi", "mu", "me", "mo", "mya", "myu", "myo", "ya", "yu", "yo", "ra", "ri", "ru", "re", "ro", "rya", "ryu", "ryo", "wa", "wo", "n", ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ']

        maroon = "^m^"

        jnano2 = (jfcci2)

        ct = datetime.datetime.now()

        monitor = "xjbmp-start:"
        print(monitor, ct)
        print()

        def generate_random_result():

            ctm = datetime.datetime.now()

            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters

            random_letters = generate_random_letters()

            sitch  = (round(random.random()*9999,4))

            jcci2 = random.sample(jnano2, random.randint(1,10))

            result_text = "".join(jcci2)

            print(maroon, random_letters, sitch, result_text, ctm)

            speak(result_text)

            print()
            
        def main_loop():
            while True:
                time.sleep(random.randint(0,6))
                integer = (round(random.random()*18))
                if integer > 10:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def xfbmp():

        time.sleep(.3)

        print()
        print("DISCLAIMER: This works on Android and must have Termux and Termux-API installed from F-Droid and Google Text-to-Speech options set to 'Filipino/Tagalog'")
        print()
        print("Ctrl+C To Stop")
        print()
        print("'FNTCCI (F/T)'")
        print()

        time.sleep(.3)

        t_fcci2 = ["a", "e", "i", "o", "u", "ba", "be", "bi", "bo", "bu", "ka", "ke", "ki", "ko", "ku", "da", "de", "di", "do", "du", "ga", "ge", "gi", "go", "gu", "ha", "he", "hi", "ho", "hu", "la", "le", "li", "lo", "lu", "ma", "me", "mi", "mo", "mu", "na", "ne", "ni", "no", "nu", "nga", "nge", "ngi", "ngo", "ngu", "pa", "pe", "pi", "po", "pu", "ra", "re", "ri", "ro", "ru", "sa", "se", "si", "so", "su", "ta", "te", "ti", "to", "tu", "wa", "we", "wi", "wo", "wu", "ya", "ye", "yi", "yo", "yu", ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ']

        maroon = "^m^"

        fnano2 = (t_fcci2)

        ct = datetime.datetime.now()

        monitor = "xfbmp-start:"
        print(monitor, ct)
        print()

        def generate_random_result():

            ctm = datetime.datetime.now()

            def generate_random_letters():
                random1 = random.choice(string.ascii_letters)
                random2 = random.choice(string.ascii_letters)
                random3 = random.choice(string.ascii_letters)
                letters = [random1, random2, random3]
                return letters

            random_letters = generate_random_letters()

            sitch  = (round(random.random()*9999,4))

            tcci2 = random.sample(fnano2, random.randint(1,10))

            result_text = "".join(tcci2)

            print(maroon, random_letters, sitch, result_text, ctm)

            speak(result_text)

            print()
            
        def main_loop():
            while True:
                time.sleep(random.randint(0,6))
                integer = (round(random.random()*18))
                if integer > 10:
                    if random.choice([True, False]):
                        generate_random_result()

        try:
            main_loop()
        except KeyboardInterrupt:
            print("\nStopped by user.")

    def choice():
        choice = ''
        while choice !='pray' and choice !='slot' and choice !='search for items' and choice !='surf' and choice !='sleep' and choice !='eat' and choice !='meditate' and choice !='find coins' and choice !='draw card' and choice !='fly' and choice !='drink coffee' and choice !='drink tea' and choice !='surf' and choice !='dhammapada' and choice !='skate' and choice !='art' and choice !='give alms' and choice !='radio' and choice !='hack' and choice !='message' and choice !='brawl' and choice !='souls'and choice !='hipster tarot' and choice !='mp3' and choice !='spar' and choice !='train' and choice !='rest' and choice !='psalms' and choice !='haiku' and choice !='muslim prayer' and choice !='karate' and choice !='koans' and choice !='equips' and choice !='rpg' and choice !='archery' and choice !='color key' and choice !='doodling' and choice !='BUMP' and choice !='MA' and choice !='Magic' and choice !='commands' and choice !='ascii' and choice !='zen melody' and choice !='monopoly' and choice !='light incense' and choice  !='stats' and choice !='prayer' and choice !='progress' and choice !='collections' and choice !='football' and choice !='c' and choice !='map' and choice !='search' and choice !='print time' and choice !='entry' and choice !='posting' and choice !='koran' and choice !='heBrews' and choice !='Medicals' and choice !='M' and choice !='Clearance' and choice !='MiCasa' and choice !='stuff' and choice !='worship' and choice !='Earth Science' and choice !='SCI' and choice !='value' and choice !='psychology' and choice !='psyc' and choice !='Patient Simu' and choice !='biology' and choice !='B' and choice !='legal terms' and choice !='Law' and choice !='the heart sutra' and choice !='License' and choice !='police' and choice !='prad' and choice !='climb' and choice !='chemistry' and choice !='ch' and choice !='weapon start' and choice !='wstart' and choice !='teletubby' and choice !='note' and choice !='save' and choice !='journal' and choice !='version' and choice !='ai' and choice !='auto-mat' and choice !='AAM' and choice !='ID' and choice !='IDC' and choice !='echo' and choice !='monitor-start' and choice !='mstart' and choice !='change username' and choice !='username' and choice !='user' and choice !='fuzz' and choice !='message-scan' and choice !='scan' and choice !='monitor-search' and choice !='msearch' and choice !='tag' and choice !='atag' and choice !='a-tag' and choice !='acad-monitor' and choice !='astart' and choice !='acad-search' and choice !='asearch' and choice !='oscillator' and choice !='oscillate' and choice !='oscill' and choice !='amror' and choice !='game' and choice !='amsearch' and choice !='amror-search' and choice !='amror search' and choice !='profile' and choice !='Profile' and choice !='herbs' and choice !='herbals' and choice !='degree' and choice !='degrees' and choice !='major' and choice !='majors' and choice !='MedProc AI' and choice !='MAI' and choice !='frames' and choice !='fsearch' and choice !='ascsearch' and choice !='alerts' and choice !='Alerts' and choice !='burner-start' and choice !='burner start' and choice !='burner' and choice !='burn' and choice !='kiomai' and choice !='KIOMAI' and choice !='GES' and choice !='call' and choice !='time-monitor':
            print()
            choice = input(usr)
            ct = datetime.datetime.now()

            if choice == "version":
                version()

            if choice == "commands":
                commands()

            if choice == "GES" or choice == "CAI" or choice == "CAI Environments" or choice == "CAI environments" or choice == "cai environments":
                GES()
                
            if choice == 'print time':
                print_time()

            if choice == 'profile' or choice == 'Profile':
                profile()

            if choice == 'change username' or choice == 'username' or choice == 'user':
                change_username()

            if choice == 'alerts' or choice == 'Alerts':
                alerts()

            if choice == 'echo':
                echo()

            if choice == "pray":
                pray()

            if choice == "climb":
                climb()
                
            if choice == "prayer":
                prayer()
                
            if choice == "stats":
                stats()

            if choice == "progress":
                progress()
                
            if choice == "light incense":
                light_incense()

            if choice == "the heart sutra":
                heart_sutra()

            if choice == "heBrews":
                hebrews()

            if choice == 'teletubby':
                teletubby()

            if choice == "herbs" or choice == "herbals":
                herbs()

            if choice == "legal terms" or choice == "Law":
                legal_terms()

            if choice == "degree" or choice == "degrees" or choice == "major" or choice == "majors":
                degree()

            if choice == "biology" or choice == "B":
                biology()

            if choice == "chemistry" or choice == "ch":
                chemistry()

            if choice == "Patient Simu":
                patient_simu()

            if choice == "Earth Science" or choice == "SCI":
                earth_science()

            if choice == "psychology" or choice == "psyc":
                psychology()

            if choice == "Medicals" or choice == "M":
                medicals()

            if choice == "License":
                license()

            if choice == "police" or choice == "prad":
                police()

            if choice == "Clearance":
                clearance()

            if choice == "":
                nano()

            if choice == "entry":
                entry()

            if choice == "MiCasa":
                micasa()

            if choice == "stuff":
                stuff()

            if choice == "worship":
                worship()

            if choice == "posting":
                posting()

            if choice == "muslim prayer" or choice == "fajr" or choice == "before dawn":
                muslim_prayer()

            if choice == choice == "dhuhr" or choice == "noon":
                muslim_prayer2()

            if choice == choice == "asr" or choice == "late afternoon":
                muslim_prayer2()

            if choice == choice == "maghrib" or choice == "at sunset":
                muslim_prayer3()

            if choice == choice == "isha" or choice == "nighttime":
                muslim_prayer2()

            if choice == "meditate":
                meditate()

            if choice == "sleep":
                sleep()

            if choice == "eat":
                eat()

            if choice == "find coins":
                find_coins()

            if choice == "slot":
                slot()

            if choice == "draw card":
                draw_card()

            if choice == "search for items":
                search_for_items()

            if choice == "fly":
                fly()

            if choice == "drink coffee":
                drink_coffee()

            if choice == "drink tea":
                drink_tea()

            if choice == "surf":
                surf()

            if choice == "collections":
                collections()

            if choice == "doodling":
                doodling()

            if choice == "zen melody":
                zen_melody()

            if choice == "value":
                value()

            if choice == "BUMP":
                bump()

            if choice == "MA":
                ma()

            if choice == "skate":
                skate()

            if choice == "ID":
                ID()

            if choice == "IDC":
                IDC()

            if choice == "art":
                art()

            if choice == "radio":
                radio()

            if choice == "give alms":
                give_alms()

            if choice == "brawl":
                brawl()

            if choice == "karate":
                karate()

            if choice == "koans":
                koans()

            if choice == "hipster tarot":
                hipster_tarot()

            if choice == "hack":
                hack()

            if choice == "spar":
                spar()

            if choice == "train":
                train()

            if choice == "rest":
                rest()

            if choice == "haiku":
                haiku()

            if choice == "psalms":
                psalms()

            if choice == "dhammapada":
                dhammapada()

            if choice == "koran":
                koran()

            if choice == "message" or choice == "lh":
                message()

            if choice == "souls":
                souls()

            if choice == "guard" or choice == "guards":
                guard()

            if choice == "c":
                c()

            if choice == "ascii" or choice == "  ":
                asciii()

            if choice == "mp3":
                mp3()

            if choice == "monopoly":
                monopoly()

            if choice == "equips":
                equips()

            if choice == "rpg":
                rpg()

            if choice == "archery":
                archery()

            if choice == "color key":
                color_key()

            if choice == "Magic":
                magic()
                
            if choice == "football":
                football()
           
            if choice == "map":
                mapp()

            if choice == "ai" or choice == "auto-mat" or choice == "AAM":
                auto_mat()

            if choice == "donate":
                print("Contact the developer at usvu.tech@gmail.com")
                time.sleep(5)

            if choice == "exit":
                exit()
            if choice == "close":
                exit()
            if choice == "quit":
                exit()

            if choice == "weapon start" or choice == "wstart":
                weapon_start()

            if choice == "call":
                call()

            if choice == "monitor-start" or choice == "mstart":
                monitor_start()

            if choice == "acad-monitor" or choice == "astart":
                acad_monitor()

            if choice == "time monitor" or choice == "time-monitor" or choice == "tmonitor" or choice == "t-monitor" or choice == "tm":
                time_monitor()

            if choice == "speech time monitor" or choice == "speech-time-monitor" or choice == "speech time-monitor" or choice == "speech tmonitor" or choice == "stmonitor":
                s_time_monitor()

            if choice == "message-scan" or choice == "scan":
                msgs()

            if choice == "fuzz":
                fuzz()

            if choice == "tag":
                tag()

            if choice == "atag" or choice == "a-tag":
                atag()

            if choice == "MedProc" or choice == "medproc" or choice == "MedProc AI" or choice == "medproc AI" or choice == "medproc ai" or choice == "MAI" or choice == "Mai":
                MAI()

            if choice == "MAIc" or choice == "MedProcCont" or choice == "medproccont" or choice == "MPC" or choice == "mpc":
                MAIc()

            if choice == "frames" or choice == "fps":
                frames()

            if choice == "oscillator" or choice == "oscillate" or choice == "oscill":
                oscillator()

            if choice == "toscillator" or choice == "toscillate" or choice == "toscill" or choice == "time-oscill" or choice == "time-oscillate" or choice == "time-oscillator":
                toscillator()

            if choice == "burner-start" or choice == "burner start" or choice == "burner" or choice == "burn" or choice == "Burn":
                burner()

            if choice == "time-burner-start" or choice == "time burner start" or choice == "time burner" or choice == "tburn" or choice == "time burn" or choice == "tburner" or choice == "tBurn" or choice == "time-burner":
                tburner()

            if choice == 'search' or choice == 'fsearch':
                search()

            if choice == "busearch" or choice == "burner search" or choice == "burner-search" or choice == "bsearch" or choice == "b-search":
                busearch()

            if choice == "zuz" or choice == "ZUZ" or choice == "pp" or choice == "PP" or choice == "Zuz":
                zuz()

            if choice == "programs" or choice == "Programs" or choice == "Prog" or choice == "PROGR" or choice == "program" or choice == "Program" or choice == "progr":
                programs()

            if choice == "ls":
                ls()

            if choice == "cd":
                cd()

            if choice == "mkdir":
                mkdir()

            if choice == "clear" or choice == "cl":
                clear()

            if choice == "rm":
                rm()

            if choice == "pwd":
                pwd()

            if choice == "Tinien" or choice == "tinien" or choice == " " or choice == "**":
                tinie_N()

            if choice == "ntag" or choice == "n-tag":
                ntag()

            if choice == "fstart" or choice == "f-start" or choice == "fmonitor" or choice == "fmonitor" or choice == "fcci" or choice == "fcci monitor" or choice == "fcci-monitor" or choice == "FCCI" or choice == "FCCI-monitor" or choice == "FCCI monitor":
                fntcci_monitor()

            if choice == "type-text" or choice == "type text" or choice == "typetext":
                text()

            if choice == "xcbmp":
                xcbmp()

            if choice == "xhbmp":
                xhbmp()

            if choice == "xjbmp":
                xjbmp()

            if choice == "xfbmp":
                xfbmp()

    chooseAgain = "yes"
    while chooseAgain:
        choice()

    chooseAgain = input()

if __name__ == "__main__":
    main()









